// Copyright 2010 The Emscripten Authors.  All rights reserved.
// Emscripten is available under two separate licenses, the MIT license and the
// University of Illinois/NCSA Open Source License.  Both these licenses can be
// found in the LICENSE file.

// The Module object: Our interface to the outside world. We import
// and export values on it. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to check if Module already exists (e.g. case 3 above).
// Substitution will be replaced with actual code on later stage of the build,
// this way Closure Compiler will not mangle it (e.g. case 4. above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module = typeof Module !== 'undefined' ? Module : {};

// --pre-jses are emitted after the Module integration code, so that they can
// refer to Module (if they choose; they can also define Module)
// {{PRE_JSES}}

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
var key;
for (key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

Module['arguments'] = [];
Module['thisProgram'] = './this.program';
Module['quit'] = function(status, toThrow) {
  throw toThrow;
};
Module['preRun'] = [];
Module['postRun'] = [];

// Determine the runtime environment we are in. You can customize this by
// setting the ENVIRONMENT setting at compile time (see settings.js).

var ENVIRONMENT_IS_WEB = false;
var ENVIRONMENT_IS_WORKER = false;
var ENVIRONMENT_IS_NODE = false;
var ENVIRONMENT_IS_SHELL = false;
ENVIRONMENT_IS_WEB = typeof window === 'object';
ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER;
ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (Module['ENVIRONMENT']) {
  throw new Error('Module.ENVIRONMENT has been deprecated. To force the environment, use the ENVIRONMENT compile-time option (for example, -s ENVIRONMENT=web or -s ENVIRONMENT=node)');
}

// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)

// `/` should be present at the end if `scriptDirectory` is not empty
var scriptDirectory = '';
function locateFile(path) {
  if (Module['locateFile']) {
    return Module['locateFile'](path, scriptDirectory);
  } else {
    return scriptDirectory + path;
  }
}

if (ENVIRONMENT_IS_NODE) {
  scriptDirectory = __dirname + '/';

  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  var nodeFS;
  var nodePath;

  Module['read'] = function shell_read(filename, binary) {
    var ret;
      if (!nodeFS) nodeFS = require('fs');
      if (!nodePath) nodePath = require('path');
      filename = nodePath['normalize'](filename);
      ret = nodeFS['readFileSync'](filename);
    return binary ? ret : ret.toString();
  };

  Module['readBinary'] = function readBinary(filename) {
    var ret = Module['read'](filename, true);
    if (!ret.buffer) {
      ret = new Uint8Array(ret);
    }
    assert(ret.buffer);
    return ret;
  };

  if (process['argv'].length > 1) {
    Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });
  // Currently node will swallow unhandled rejections, but this behavior is
  // deprecated, and in the future it will exit with error status.
  process['on']('unhandledRejection', abort);

  Module['quit'] = function(status) {
    process['exit'](status);
  };

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
} else
if (ENVIRONMENT_IS_SHELL) {


  if (typeof read != 'undefined') {
    Module['read'] = function shell_read(f) {
      return read(f);
    };
  }

  Module['readBinary'] = function readBinary(f) {
    var data;
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof quit === 'function') {
    Module['quit'] = function(status) {
      quit(status);
    }
  }
} else
if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  if (ENVIRONMENT_IS_WORKER) { // Check worker, not web, since window could be polyfilled
    scriptDirectory = self.location.href;
  } else if (document.currentScript) { // web
    scriptDirectory = document.currentScript.src;
  }
  // blob urls look like blob:http://site.com/etc/etc and we cannot infer anything from them.
  // otherwise, slice off the final part of the url to find the script directory.
  // if scriptDirectory does not contain a slash, lastIndexOf will return -1,
  // and scriptDirectory will correctly be replaced with an empty string.
  if (scriptDirectory.indexOf('blob:') !== 0) {
    scriptDirectory = scriptDirectory.substr(0, scriptDirectory.lastIndexOf('/')+1);
  } else {
    scriptDirectory = '';
  }


  Module['read'] = function shell_read(url) {
      var xhr = new XMLHttpRequest();
      xhr.open('GET', url, false);
      xhr.send(null);
      return xhr.responseText;
  };

  if (ENVIRONMENT_IS_WORKER) {
    Module['readBinary'] = function readBinary(url) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, false);
        xhr.responseType = 'arraybuffer';
        xhr.send(null);
        return new Uint8Array(xhr.response);
    };
  }

  Module['readAsync'] = function readAsync(url, onload, onerror) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'arraybuffer';
    xhr.onload = function xhr_onload() {
      if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
        onload(xhr.response);
        return;
      }
      onerror();
    };
    xhr.onerror = onerror;
    xhr.send(null);
  };

  Module['setWindowTitle'] = function(title) { document.title = title };
} else
{
  throw new Error('environment detection error');
}

// Set up the out() and err() hooks, which are how we can print to stdout or
// stderr, respectively.
// If the user provided Module.print or printErr, use that. Otherwise,
// console.log is checked first, as 'print' on the web will open a print dialogue
// printErr is preferable to console.warn (works better in shells)
// bind(console) is necessary to fix IE/Edge closed dev tools panel behavior.
var out = Module['print'] || (typeof console !== 'undefined' ? console.log.bind(console) : (typeof print !== 'undefined' ? print : null));
var err = Module['printErr'] || (typeof printErr !== 'undefined' ? printErr : ((typeof console !== 'undefined' && console.warn.bind(console)) || out));

// Merge back in the overrides
for (key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// Free the object hierarchy contained in the overrides, this lets the GC
// reclaim data used e.g. in memoryInitializerRequest, which is a large typed array.
moduleOverrides = undefined;

// perform assertions in shell.js after we set up out() and err(), as otherwise if an assertion fails it cannot print the message
assert(typeof Module['memoryInitializerPrefixURL'] === 'undefined', 'Module.memoryInitializerPrefixURL option was removed, use Module.locateFile instead');
assert(typeof Module['pthreadMainPrefixURL'] === 'undefined', 'Module.pthreadMainPrefixURL option was removed, use Module.locateFile instead');
assert(typeof Module['cdInitializerPrefixURL'] === 'undefined', 'Module.cdInitializerPrefixURL option was removed, use Module.locateFile instead');
assert(typeof Module['filePackagePrefixURL'] === 'undefined', 'Module.filePackagePrefixURL option was removed, use Module.locateFile instead');



// Copyright 2017 The Emscripten Authors.  All rights reserved.
// Emscripten is available under two separate licenses, the MIT license and the
// University of Illinois/NCSA Open Source License.  Both these licenses can be
// found in the LICENSE file.

// {{PREAMBLE_ADDITIONS}}

var STACK_ALIGN = 16;

// stack management, and other functionality that is provided by the compiled code,
// should not be used before it is ready
stackSave = stackRestore = stackAlloc = setTempRet0 = getTempRet0 = function() {
  abort('cannot use the stack before compiled code is ready to run, and has provided stack access');
};

function staticAlloc(size) {
  assert(!staticSealed);
  var ret = STATICTOP;
  STATICTOP = (STATICTOP + size + 15) & -16;
  assert(STATICTOP < TOTAL_MEMORY, 'not enough memory for static allocation - increase TOTAL_MEMORY');
  return ret;
}

function dynamicAlloc(size) {
  assert(DYNAMICTOP_PTR);
  var ret = HEAP32[DYNAMICTOP_PTR>>2];
  var end = (ret + size + 15) & -16;
  HEAP32[DYNAMICTOP_PTR>>2] = end;
  if (end >= TOTAL_MEMORY) {
    var success = enlargeMemory();
    if (!success) {
      HEAP32[DYNAMICTOP_PTR>>2] = ret;
      return 0;
    }
  }
  return ret;
}

function alignMemory(size, factor) {
  if (!factor) factor = STACK_ALIGN; // stack alignment (16-byte) by default
  var ret = size = Math.ceil(size / factor) * factor;
  return ret;
}

function getNativeTypeSize(type) {
  switch (type) {
    case 'i1': case 'i8': return 1;
    case 'i16': return 2;
    case 'i32': return 4;
    case 'i64': return 8;
    case 'float': return 4;
    case 'double': return 8;
    default: {
      if (type[type.length-1] === '*') {
        return 4; // A pointer
      } else if (type[0] === 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 === 0);
        return bits / 8;
      } else {
        return 0;
      }
    }
  }
}

function warnOnce(text) {
  if (!warnOnce.shown) warnOnce.shown = {};
  if (!warnOnce.shown[text]) {
    warnOnce.shown[text] = 1;
    err(text);
  }
}

var asm2wasmImports = { // special asm2wasm imports
    "f64-rem": function(x, y) {
        return x % y;
    },
    "debugger": function() {
        debugger;
    }
};

// dynamic linking
var $LDSO = {
  loadedLibs: {         // handle -> dso [refcount, name, module, global]
    // program itself
    // XXX uglifyjs fails on "[-1]: {"
    '-1': {
      refcount: Infinity,   // = nodelete
      name:     '__self__',
      module:   Module,
      global:   true
    }
  },

  loadedLibNames: {     // name   -> handle
    // program itself
    '__self__': -1
  },
}

// fetchBinary fetches binaray data @ url. (async)
function fetchBinary(url) {
  return fetch(url, { credentials: 'same-origin' }).then(function(response) {
    if (!response['ok']) {
      throw "failed to load binary file at '" + url + "'";
    }
    return response['arrayBuffer']();
  }).then(function(buffer) {
    return new Uint8Array(buffer);
  });
}

// loadDynamicLibrary loads dynamic library @ lib URL / path and returns handle for loaded DSO.
//
// Several flags affect the loading:
//
// - if flags.global=true, symbols from the loaded library are merged into global
//   process namespace. Flags.global is thus similar to RTLD_GLOBAL in ELF.
//
// - if flags.nodelete=true, the library will be never unloaded. Flags.nodelete
//   is thus similar to RTLD_NODELETE in ELF.
//
// - if flags.loadAsync=true, the loading is performed asynchronously and
//   loadDynamicLibrary returns corresponding promise.
//
// - if flags.fs is provided, it is used as FS-like interface to load library data.
//   By default, when flags.fs=undefined, native loading capabilities of the
//   environment are used.
//
// If a library was already loaded, it is not loaded a second time. However
// flags.global and flags.nodelete are handled every time a load request is made.
// Once a library becomes "global" or "nodelete", it cannot be removed or unloaded.
function loadDynamicLibrary(lib, flags) {
  // when loadDynamicLibrary did not have flags, libraries were loaded globally & permanently
  if (flags === undefined) {
    flags = {global: true, nodelete: true}
  }

  var handle = $LDSO.loadedLibNames[lib];
  var dso;
  if (handle) {
    // the library is being loaded or has been loaded already.
    //
    // however it could be previously loaded only locally and if we get
    // load request with global=true we have to make it globally visible now.
    dso = $LDSO.loadedLibs[handle];
    if (flags.global && !dso.global) {
      dso.global = true;
      if (dso.module !== 'loading') {
        // ^^^ if module is 'loading' - symbols merging will be eventually done by the loader.
        mergeLibSymbols(dso.module)
      }
    }
    // same for "nodelete"
    if (flags.nodelete && dso.refcount !== Infinity) {
      dso.refcount = Infinity;
    }
    dso.refcount++
    return flags.loadAsync ? Promise.resolve(handle) : handle;
  }

  // allocate new DSO & handle
  handle = 1
  for (var key in $LDSO.loadedLibs) { // not all browsers support Object.keys()
    if ($LDSO.loadedLibs.hasOwnProperty(key)) handle++;
  }
  dso = {
    refcount: flags.nodelete ? Infinity : 1,
    name:     lib,
    module:   'loading',
    global:   flags.global,
  };
  $LDSO.loadedLibNames[lib] = handle;
  $LDSO.loadedLibs[handle] = dso;

  // libData <- lib
  function loadLibData() {
    // for js we only imitate async for both native & fs modes.
    var libData;
    if (flags.fs) {
      libData = flags.fs.readFile(lib, {encoding: 'utf8'});
    } else {
      libData = Module['read'](lib);
    }
    return flags.loadAsync ? Promise.resolve(libData) : libData;
  }

  // libModule <- libData
  function createLibModule(libData) {
    var libModule = eval(libData)(
      alignFunctionTables(),
      Module
    );
    // load dynamic libraries that this js lib depends on
    // (wasm loads needed libraries _before_ lib in its own codepath)
    if (libModule.dynamicLibraries) {
      if (flags.loadAsync) {
        return Promise.all(libModule.dynamicLibraries.map(function(dynNeeded) {
          return loadDynamicLibrary(dynNeeed, flags);
        })).then(function() {
          return libModule;
        });
      }

      libModule.dynamicLibraries.forEach(function(dynNeeded) {
        loadDynamicLibrary(dynNeeded, flags);
      });
    }
    return libModule;
  }

  // libModule <- lib
  function getLibModule() {
    // lookup preloaded cache first
    if (Module['preloadedWasm'] !== undefined &&
        Module['preloadedWasm'][lib] !== undefined) {
      var libModule = Module['preloadedWasm'][lib];
      return flags.loadAsync ? Promise.resolve(libModule) : libModule;
    }

    // module not preloaded - load lib data and create new module from it
    if (flags.loadAsync) {
      return loadLibData(lib).then(function(libData) {
        return createLibModule(libData);
      });
    }

    return createLibModule(loadLibData(lib));
  }

  // Module.symbols <- libModule.symbols (flags.global handler)
  function mergeLibSymbols(libModule) {
    // add symbols into global namespace TODO: weak linking etc.
    for (var sym in libModule) {
      if (!libModule.hasOwnProperty(sym)) {
        continue;
      }

      // When RTLD_GLOBAL is enable, the symbols defined by this shared object will be made
      // available for symbol resolution of subsequently loaded shared objects.
      //
      // We should copy the symbols (which include methods and variables) from SIDE_MODULE to MAIN_MODULE.
      //
      // Module of SIDE_MODULE has not only the symbols (which should be copied)
      // but also others (print*, asmGlobal*, FUNCTION_TABLE_**, NAMED_GLOBALS, and so on).
      //
      // When the symbol (which should be copied) is method, Module._* 's type becomes function.
      // When the symbol (which should be copied) is variable, Module._* 's type becomes number.
      //
      // Except for the symbol prefix (_), there is no difference in the symbols (which should be copied) and others.
      // So this just copies over compiled symbols (which start with _).
      if (sym[0] !== '_') {
        continue;
      }

      if (!Module.hasOwnProperty(sym)) {
        Module[sym] = libModule[sym];
      }
    }
  }

  // module for lib is loaded - update the dso
  function moduleLoaded(libModule) {
    if (dso.global) {
      mergeLibSymbols(libModule);
    }
    dso.module = libModule;
  }

  if (flags.loadAsync) {
    return getLibModule().then(function(libModule) {
      moduleLoaded(libModule);
      return handle;
    })
  }

  moduleLoaded(getLibModule());
  return handle;
}


function getFunctionTables(module) {
  if (!module) module = Module;
  var tables = {};
  for (var t in module) {
    if (/^FUNCTION_TABLE_.*/.test(t)) {
      var table = module[t];
      if (typeof table === 'object') tables[t.substr('FUNCTION_TABLE_'.length)] = table;
    }
  }
  return tables;
}

function alignFunctionTables(module) {
  var tables = getFunctionTables(module);
  var maxx = 0;
  for (var sig in tables) {
    maxx = Math.max(maxx, tables[sig].length);
  }
  assert(maxx >= 0);
  for (var sig in tables) {
    var table = tables[sig];
    while (table.length < maxx) table.push(0);
  }
  return maxx;
}

// register functions from a new module being loaded
function registerFunctions(sigs, newModule) {
  sigs.forEach(function(sig) {
    if (!Module['FUNCTION_TABLE_' + sig]) {
      Module['FUNCTION_TABLE_' + sig] = [];
    }
  });
  var oldMaxx = alignFunctionTables(); // align the new tables we may have just added
  var newMaxx = alignFunctionTables(newModule);
  var maxx = oldMaxx + newMaxx;
  sigs.forEach(function(sig) {
    var newTable = newModule['FUNCTION_TABLE_' + sig];
    var oldTable = Module['FUNCTION_TABLE_' + sig];
    assert(newTable !== oldTable);
    assert(oldTable.length === oldMaxx);
    for (var i = 0; i < newTable.length; i++) {
      oldTable.push(newTable[i]);
    }
    assert(oldTable.length === maxx);
  });
  assert(maxx === alignFunctionTables()); // align the ones we didn't touch
}
// export this so side modules can use it
Module['registerFunctions'] = registerFunctions;

var jsCallStartIndex = 1;
var functionPointers = new Array(0);

// 'sig' parameter is only used on LLVM wasm backend
function addFunction(func, sig) {
  if (typeof sig === 'undefined') {
    err('warning: addFunction(): You should provide a wasm function signature string as a second argument. This is not necessary for asm.js and asm2wasm, but is required for the LLVM wasm backend, so it is recommended for full portability.');
  }
  alignFunctionTables(); // XXX we should rely on this being an invariant
  var tables = getFunctionTables();
  var ret = -1;
  for (var sig in tables) {
    var table = tables[sig];
    if (ret < 0) ret = table.length;
    else assert(ret === table.length);
    table.push(func);
  }
  return ret;
}

function removeFunction(index) {
  alignFunctionTables(); // XXX we should rely on this being an invariant
  var tables = getFunctionTables();
  for (var sig in tables) {
    tables[sig][index] = null;
  }
}

var funcWrappers = {};

function getFuncWrapper(func, sig) {
  if (!func) return; // on null pointer, return undefined
  assert(sig);
  if (!funcWrappers[sig]) {
    funcWrappers[sig] = {};
  }
  var sigCache = funcWrappers[sig];
  if (!sigCache[func]) {
    // optimize away arguments usage in common cases
    if (sig.length === 1) {
      sigCache[func] = function dynCall_wrapper() {
        return dynCall(sig, func);
      };
    } else if (sig.length === 2) {
      sigCache[func] = function dynCall_wrapper(arg) {
        return dynCall(sig, func, [arg]);
      };
    } else {
      // general case
      sigCache[func] = function dynCall_wrapper() {
        return dynCall(sig, func, Array.prototype.slice.call(arguments));
      };
    }
  }
  return sigCache[func];
}


function makeBigInt(low, high, unsigned) {
  return unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0));
}

function dynCall(sig, ptr, args) {
  if (args && args.length) {
    assert(args.length == sig.length-1);
    assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
    return Module['dynCall_' + sig].apply(null, [ptr].concat(args));
  } else {
    assert(sig.length == 1);
    assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
    return Module['dynCall_' + sig].call(null, ptr);
  }
}

// tempRet0 is normally handled in the module. but in relocatable code,
// we need to share a single one among all the modules, so they all call
// out.
var tempRet0 = 0;

var setTempRet0 = function(value) {
  tempRet0 = value;
}

var getTempRet0 = function() {
  return tempRet0;
}

function getCompilerSetting(name) {
  throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for getCompilerSetting or emscripten_get_compiler_setting to work';
}

var Runtime = {
  // FIXME backwards compatibility layer for ports. Support some Runtime.*
  //       for now, fix it there, then remove it from here. That way we
  //       can minimize any period of breakage.
  dynCall: dynCall, // for SDL2 port
  // helpful errors
  getTempRet0: function() { abort('getTempRet0() is now a top-level function, after removing the Runtime object. Remove "Runtime."') },
  staticAlloc: function() { abort('staticAlloc() is now a top-level function, after removing the Runtime object. Remove "Runtime."') },
  stackAlloc: function() { abort('stackAlloc() is now a top-level function, after removing the Runtime object. Remove "Runtime."') },
};

// The address globals begin at. Very low in memory, for code size and optimization opportunities.
// Above 0 is static memory, starting with globals.
// Then the stack.
// Then 'dynamic' memory for sbrk.
var GLOBAL_BASE = 8;

GLOBAL_BASE = alignMemory(GLOBAL_BASE, 16);

// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in:
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at:
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html



//========================================
// Runtime essentials
//========================================

// whether we are quitting the application. no code should run after this.
// set in exit() and abort()
var ABORT = false;

// set by exit() and abort().  Passed to 'onExit' handler.
// NOTE: This is also used as the process return code code in shell environments
// but only when noExitRuntime is false.
var EXITSTATUS = 0;

/** @type {function(*, string=)} */
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  assert(func, 'Cannot call unknown function ' + ident + ', make sure it is exported');
  return func;
}

var JSfuncs = {
  // Helpers for cwrap -- it can't refer to Runtime directly because it might
  // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
  // out what the minified function name is.
  'stackSave': function() {
    stackSave()
  },
  'stackRestore': function() {
    stackRestore()
  },
  // type conversion from js to c
  'arrayToC' : function(arr) {
    var ret = stackAlloc(arr.length);
    writeArrayToMemory(arr, ret);
    return ret;
  },
  'stringToC' : function(str) {
    var ret = 0;
    if (str !== null && str !== undefined && str !== 0) { // null string
      // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
      var len = (str.length << 2) + 1;
      ret = stackAlloc(len);
      stringToUTF8(str, ret, len);
    }
    return ret;
  }
};

// For fast lookup of conversion functions
var toC = {
  'string': JSfuncs['stringToC'], 'array': JSfuncs['arrayToC']
};


// C calling interface.
function ccall(ident, returnType, argTypes, args, opts) {
  function convertReturnValue(ret) {
    if (returnType === 'string') return Pointer_stringify(ret);
    if (returnType === 'boolean') return Boolean(ret);
    return ret;
  }

  var func = getCFunc(ident);
  var cArgs = [];
  var stack = 0;
  assert(returnType !== 'array', 'Return type should not be "array".');
  if (args) {
    for (var i = 0; i < args.length; i++) {
      var converter = toC[argTypes[i]];
      if (converter) {
        if (stack === 0) stack = stackSave();
        cArgs[i] = converter(args[i]);
      } else {
        cArgs[i] = args[i];
      }
    }
  }
  var ret = func.apply(null, cArgs);
  ret = convertReturnValue(ret);
  if (stack !== 0) stackRestore(stack);
  return ret;
}

function cwrap(ident, returnType, argTypes, opts) {
  return function() {
    return ccall(ident, returnType, argTypes, arguments, opts);
  }
}

/** @type {function(number, number, string, boolean=)} */
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}

/** @type {function(number, string, boolean=)} */
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for getValue: ' + type);
    }
  return null;
}

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
/** @type {function((TypedArray|Array<number>|number), string, number, number=)} */
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [typeof _malloc === 'function' ? _malloc : staticAlloc, stackAlloc, staticAlloc, dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var stop;
    ptr = ret;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(/** @type {!Uint8Array} */ (slab), ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return staticAlloc(size);
  if (!runtimeInitialized) return dynamicAlloc(size);
  return _malloc(size);
}

/** @type {function(number, number=)} */
function Pointer_stringify(ptr, length) {
  if (length === 0 || !ptr) return '';
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    assert(ptr + i < TOTAL_MEMORY);
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return UTF8ToString(ptr);
}

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

var UTF8Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf8') : undefined;
function UTF8ArrayToString(u8Array, idx) {
  var endPtr = idx;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  while (u8Array[endPtr]) ++endPtr;

  if (endPtr - idx > 16 && u8Array.subarray && UTF8Decoder) {
    return UTF8Decoder.decode(u8Array.subarray(idx, endPtr));
  } else {
    var u0, u1, u2, u3, u4, u5;

    var str = '';
    while (1) {
      // For UTF8 byte structure, see:
      // http://en.wikipedia.org/wiki/UTF-8#Description
      // https://www.ietf.org/rfc/rfc2279.txt
      // https://tools.ietf.org/html/rfc3629
      u0 = u8Array[idx++];
      if (!u0) return str;
      if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
      u1 = u8Array[idx++] & 63;
      if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
      u2 = u8Array[idx++] & 63;
      if ((u0 & 0xF0) == 0xE0) {
        u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
      } else {
        u3 = u8Array[idx++] & 63;
        if ((u0 & 0xF8) == 0xF0) {
          u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
        } else {
          u4 = u8Array[idx++] & 63;
          if ((u0 & 0xFC) == 0xF8) {
            u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
          } else {
            u5 = u8Array[idx++] & 63;
            u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
          }
        }
      }
      if (u0 < 0x10000) {
        str += String.fromCharCode(u0);
      } else {
        var ch = u0 - 0x10000;
        str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
      }
    }
  }
}

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8,ptr);
}

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array.
//                    This count should include the null terminator,
//                    i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) {
      var u1 = str.charCodeAt(++i);
      u = 0x10000 + ((u & 0x3FF) << 10) | (u1 & 0x3FF);
    }
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF8(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  return stringToUTF8Array(str, HEAPU8,outPtr, maxBytesToWrite);
}

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

var UTF16Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf-16le') : undefined;
function UTF16ToString(ptr) {
  assert(ptr % 2 == 0, 'Pointer passed to UTF16ToString must be aligned to two bytes!');
  var endPtr = ptr;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  var idx = endPtr >> 1;
  while (HEAP16[idx]) ++idx;
  endPtr = idx << 1;

  if (endPtr - ptr > 32 && UTF16Decoder) {
    return UTF16Decoder.decode(HEAPU8.subarray(ptr, endPtr));
  } else {
    var i = 0;

    var str = '';
    while (1) {
      var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
      if (codeUnit == 0) return str;
      ++i;
      // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
      str += String.fromCharCode(codeUnit);
    }
  }
}

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 2 == 0, 'Pointer passed to stringToUTF16 must be aligned to two bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF16(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}

function UTF32ToString(ptr) {
  assert(ptr % 4 == 0, 'Pointer passed to UTF32ToString must be aligned to four bytes!');
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 4 == 0, 'Pointer passed to stringToUTF32 must be aligned to four bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF32(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}

// Allocate heap space for a JS string, and write it there.
// It is the responsibility of the caller to free() that memory.
function allocateUTF8(str) {
  var size = lengthBytesUTF8(str) + 1;
  var ret = _malloc(size);
  if (ret) stringToUTF8Array(str, HEAP8, ret, size);
  return ret;
}

// Allocate stack space for a JS string, and write it there.
function allocateUTF8OnStack(str) {
  var size = lengthBytesUTF8(str) + 1;
  var ret = stackAlloc(size);
  stringToUTF8Array(str, HEAP8, ret, size);
  return ret;
}

function demangle(func) {
  warnOnce('warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  return func;
}

function demangleAll(text) {
  var regex =
    /__Z[\w\d_]+/g;
  return text.replace(regex,
    function(x) {
      var y = demangle(x);
      return x === y ? x : (y + ' [' + x + ']');
    });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  var js = jsStackTrace();
  if (Module['extraStackTrace']) js += '\n' + Module['extraStackTrace']();
  return demangleAll(js);
}

// Memory management

var PAGE_SIZE = 16384;
var WASM_PAGE_SIZE = 65536;
var ASMJS_PAGE_SIZE = 16777216;
var MIN_TOTAL_MEMORY = 16777216;

function alignUp(x, multiple) {
  if (x % multiple > 0) {
    x += multiple - (x % multiple);
  }
  return x;
}

var HEAP,
/** @type {ArrayBuffer} */
  buffer,
/** @type {Int8Array} */
  HEAP8,
/** @type {Uint8Array} */
  HEAPU8,
/** @type {Int16Array} */
  HEAP16,
/** @type {Uint16Array} */
  HEAPU16,
/** @type {Int32Array} */
  HEAP32,
/** @type {Uint32Array} */
  HEAPU32,
/** @type {Float32Array} */
  HEAPF32,
/** @type {Float64Array} */
  HEAPF64;

function updateGlobalBuffer(buf) {
  Module['buffer'] = buffer = buf;
}

function updateGlobalBufferViews() {
  Module['HEAP8'] = HEAP8 = new Int8Array(buffer);
  Module['HEAP16'] = HEAP16 = new Int16Array(buffer);
  Module['HEAP32'] = HEAP32 = new Int32Array(buffer);
  Module['HEAPU8'] = HEAPU8 = new Uint8Array(buffer);
  Module['HEAPU16'] = HEAPU16 = new Uint16Array(buffer);
  Module['HEAPU32'] = HEAPU32 = new Uint32Array(buffer);
  Module['HEAPF32'] = HEAPF32 = new Float32Array(buffer);
  Module['HEAPF64'] = HEAPF64 = new Float64Array(buffer);
}

var STATIC_BASE, STATICTOP, staticSealed; // static area
var STACK_BASE, STACKTOP, STACK_MAX; // stack area
var DYNAMIC_BASE, DYNAMICTOP_PTR; // dynamic area handled by sbrk

  STATIC_BASE = STATICTOP = STACK_BASE = STACKTOP = STACK_MAX = DYNAMIC_BASE = DYNAMICTOP_PTR = 0;
  staticSealed = false;


// Initializes the stack cookie. Called at the startup of main and at the startup of each thread in pthreads mode.
function writeStackCookie() {
  assert((STACK_MAX & 3) == 0);
  HEAPU32[(STACK_MAX >> 2)-1] = 0x02135467;
  HEAPU32[(STACK_MAX >> 2)-2] = 0x89BACDFE;
}

function checkStackCookie() {
  if (HEAPU32[(STACK_MAX >> 2)-1] != 0x02135467 || HEAPU32[(STACK_MAX >> 2)-2] != 0x89BACDFE) {
    abort('Stack overflow! Stack cookie has been overwritten, expected hex dwords 0x89BACDFE and 0x02135467, but received 0x' + HEAPU32[(STACK_MAX >> 2)-2].toString(16) + ' ' + HEAPU32[(STACK_MAX >> 2)-1].toString(16));
  }
  // Also test the global address 0 for integrity.
  if (HEAP32[0] !== 0x63736d65 /* 'emsc' */) throw 'Runtime error: The application has corrupted its heap memory area (address zero)!';
}

function abortStackOverflow(allocSize) {
  abort('Stack overflow! Attempted to allocate ' + allocSize + ' bytes on the stack, but stack has only ' + (STACK_MAX - stackSave() + allocSize) + ' bytes available!');
}


function abortOnCannotGrowMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which allows increasing the size at runtime but prevents some optimizations, (3) set Module.TOTAL_MEMORY to a higher value before the program runs, or (4) if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ');
}


function enlargeMemory() {
  abortOnCannotGrowMemory();
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;
if (TOTAL_MEMORY < TOTAL_STACK) err('TOTAL_MEMORY should be larger than TOTAL_STACK, was ' + TOTAL_MEMORY + '! (TOTAL_STACK=' + TOTAL_STACK + ')');

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && Int32Array.prototype.subarray !== undefined && Int32Array.prototype.set !== undefined,
       'JS engine does not provide full typed array support');



// Use a provided buffer, if there is one, or else allocate a new one
if (Module['buffer']) {
  buffer = Module['buffer'];
  assert(buffer.byteLength === TOTAL_MEMORY, 'provided buffer should be ' + TOTAL_MEMORY + ' bytes, but it is ' + buffer.byteLength);
} else {
  // Use a WebAssembly memory where available
  {
    buffer = new ArrayBuffer(TOTAL_MEMORY);
  }
  assert(buffer.byteLength === TOTAL_MEMORY);
  Module['buffer'] = buffer;
}
updateGlobalBufferViews();


function getTotalMemory() {
  return TOTAL_MEMORY;
}

// Endianness check (note: assumes compiler arch was little-endian)
  HEAP32[0] = 0x63736d65; /* 'emsc' */
HEAP16[1] = 0x6373;
if (HEAPU8[2] !== 0x73 || HEAPU8[3] !== 0x63) throw 'Runtime error: expected the system to be little-endian!';

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Module['dynCall_v'](func);
      } else {
        Module['dynCall_vi'](func, callback.arg);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the main() is called

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  checkStackCookie();
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  checkStackCookie();
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  checkStackCookie();
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  checkStackCookie();
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}

// Deprecated: This function should not be called because it is unsafe and does not provide
// a maximum length limit of how many bytes it is allowed to write. Prefer calling the
// function stringToUTF8Array() instead, which takes in a maximum length that can be used
// to be secure from out of bounds writes.
/** @deprecated */
function writeStringToMemory(string, buffer, dontAddNull) {
  warnOnce('writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!');

  var /** @type {number} */ lastChar, /** @type {number} */ end;
  if (dontAddNull) {
    // stringToUTF8Array always appends null. If we don't want to do that, remember the
    // character that existed at the location where the null will be placed, and restore
    // that after the write (below).
    end = buffer + lengthBytesUTF8(string);
    lastChar = HEAP8[end];
  }
  stringToUTF8(string, buffer, Infinity);
  if (dontAddNull) HEAP8[end] = lastChar; // Restore the value under the null character.
}

function writeArrayToMemory(array, buffer) {
  assert(array.length >= 0, 'writeArrayToMemory array must have a length (should be an array or typed array)')
  HEAP8.set(array, buffer);
}

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    assert(str.charCodeAt(i) === str.charCodeAt(i)&0xff);
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

assert(Math.imul, 'This browser does not support Math.imul(), build with LEGACY_VM_SUPPORT or POLYFILL_OLD_MATH_FUNCTIONS to add in a polyfill');
assert(Math.fround, 'This browser does not support Math.fround(), build with LEGACY_VM_SUPPORT or POLYFILL_OLD_MATH_FUNCTIONS to add in a polyfill');
assert(Math.clz32, 'This browser does not support Math.clz32(), build with LEGACY_VM_SUPPORT or POLYFILL_OLD_MATH_FUNCTIONS to add in a polyfill');
assert(Math.trunc, 'This browser does not support Math.trunc(), build with LEGACY_VM_SUPPORT or POLYFILL_OLD_MATH_FUNCTIONS to add in a polyfill');

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_round = Math.round;
var Math_min = Math.min;
var Math_max = Math.max;
var Math_clz32 = Math.clz32;
var Math_trunc = Math.trunc;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// Module.preRun (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
var runDependencyTracking = {};

function getUniqueRunDependency(id) {
  var orig = id;
  while (1) {
    if (!runDependencyTracking[id]) return id;
    id = orig + Math.random();
  }
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        if (ABORT) {
          clearInterval(runDependencyWatcher);
          runDependencyWatcher = null;
          return;
        }
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            err('still waiting on run dependencies:');
          }
          err('dependency: ' + dep);
        }
        if (shown) {
          err('(end of list)');
        }
      }, 10000);
    }
  } else {
    err('warning: run dependency added without ID');
  }
}

function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    err('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


if (!Module['dynamicLibraries']) Module['dynamicLibraries'] = [];
Module['dynamicLibraries'] = ["libk_so.js"].concat(Module['dynamicLibraries']);


addOnPreRun(function() {
  function runPostSets() {
    if (Module['asm']['runPostSets']) {
      Module['asm']['runPostSets']();
    }
  }
  function loadDynamicLibraries(libs) {
    if (libs) {
      libs.forEach(function(lib) {
        // libraries linked to main never go away
        loadDynamicLibrary(lib, {global: true, nodelete: true});
      });
    }
    runPostSets();
  }
  // if we can load dynamic libraries synchronously, do so, otherwise, preload
  loadDynamicLibraries(Module['dynamicLibraries']);
});

function lookupSymbol(ptr) { // for a pointer, print out all symbols that resolve to it
  var ret = [];
  for (var i in Module) {
    if (Module[i] === ptr) ret.push(i);
  }
  print(ptr + ' is ' + ret);
}

var memoryInitializer = null;






// Copyright 2017 The Emscripten Authors.  All rights reserved.
// Emscripten is available under two separate licenses, the MIT license and the
// University of Illinois/NCSA Open Source License.  Both these licenses can be
// found in the LICENSE file.

// Prefix of data URIs emitted by SINGLE_FILE and related options.
var dataURIPrefix = 'data:application/octet-stream;base64,';

// Indicates whether filename is a base64 data URI.
function isDataURI(filename) {
  return String.prototype.startsWith ?
      filename.startsWith(dataURIPrefix) :
      filename.indexOf(dataURIPrefix) === 0;
}





// === Body ===

var ASM_CONSTS = [];





STATIC_BASE = GLOBAL_BASE;

STATICTOP = STATIC_BASE + 172144;
/* global initializers */  __ATINIT__.push();


/* memory initializer */ allocate([222,18,4,149,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,0,0,0,0,120,0,0,11,0,0,0,0,4,0,0,10,0,0,0,0,2,0,0,9,0,0,0,0,1,0,0,8,0,0,0,128,0,0,0,7,0,0,0,64,0,0,0,6,0,0,0,32,0,0,0,5,0,0,0,16,0,0,0,4,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,84,33,34,25,13,1,2,3,17,75,28,12,16,4,11,29,18,30,39,104,110,111,112,113,98,32,5,6,15,19,20,21,26,8,22,7,40,36,23,24,9,10,14,27,31,37,35,131,130,125,38,42,43,60,61,62,63,67,71,74,77,88,89,90,91,92,93,94,95,96,97,99,100,101,102,103,105,106,107,108,114,115,116,121,122,123,124,0,0,0,0,0,0,0,0,0,73,108,108,101,103,97,108,32,98,121,116,101,32,115,101,113,117,101,110,99,101,0,68,111,109,97,105,110,32,101,114,114,111,114,0,82,101,115,117,108,116,32,110,111,116,32,114,101,112,114,101,115,101,110,116,97,98,108,101,0,78,111,116,32,97,32,116,116,121,0,80,101,114,109,105,115,115,105,111,110,32,100,101,110,105,101,100,0,79,112,101,114,97,116,105,111,110,32,110,111,116,32,112,101,114,109,105,116,116,101,100,0,78,111,32,115,117,99,104,32,102,105,108,101,32,111,114,32,100,105,114,101,99,116,111,114,121,0,78,111,32,115,117,99,104,32,112,114,111,99,101,115,115,0,70,105,108,101,32,101,120,105,115,116,115,0,86,97,108,117,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,100,97,116,97,32,116,121,112,101,0,78,111,32,115,112,97,99,101,32,108,101,102,116,32,111,110,32,100,101,118,105,99,101,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,82,101,115,111,117,114,99,101,32,98,117,115,121,0,73,110,116,101,114,114,117,112,116,101,100,32,115,121,115,116,101,109,32,99,97,108,108,0,82,101,115,111,117,114,99,101,32,116,101,109,112,111,114,97,114,105,108,121,32,117,110,97,118,97,105,108,97,98,108,101,0,73,110,118,97,108,105,100,32,115,101,101,107,0,67,114,111,115,115,45,100,101,118,105,99,101,32,108,105,110,107,0,82,101,97,100,45,111,110,108,121,32,102,105,108,101,32,115,121,115,116,101,109,0,68,105,114,101,99,116,111,114,121,32,110,111,116,32,101,109,112,116,121,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,112,101,101,114,0,79,112,101,114,97,116,105,111,110,32,116,105,109,101,100,32,111,117,116,0,67,111,110,110,101,99,116,105,111,110,32,114,101,102,117,115,101,100,0,72,111,115,116,32,105,115,32,100,111,119,110,0,72,111,115,116,32,105,115,32,117,110,114,101,97,99,104,97,98,108,101,0,65,100,100,114,101,115,115,32,105,110,32,117,115,101,0,66,114,111,107,101,110,32,112,105,112,101,0,73,47,79,32,101,114,114,111,114,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,32,111,114,32,97,100,100,114,101,115,115,0,66,108,111,99,107,32,100,101,118,105,99,101,32,114,101,113,117,105,114,101,100,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,0,78,111,116,32,97,32,100,105,114,101,99,116,111,114,121,0,73,115,32,97,32,100,105,114,101,99,116,111,114,121,0,84,101,120,116,32,102,105,108,101,32,98,117,115,121,0,69,120,101,99,32,102,111,114,109,97,116,32,101,114,114,111,114,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,65,114,103,117,109,101,110,116,32,108,105,115,116,32,116,111,111,32,108,111,110,103,0,83,121,109,98,111,108,105,99,32,108,105,110,107,32,108,111,111,112,0,70,105,108,101,110,97,109,101,32,116,111,111,32,108,111,110,103,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,32,105,110,32,115,121,115,116,101,109,0,78,111,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,115,32,97,118,97,105,108,97,98,108,101,0,66,97,100,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,0,78,111,32,99,104,105,108,100,32,112,114,111,99,101,115,115,0,66,97,100,32,97,100,100,114,101,115,115,0,70,105,108,101,32,116,111,111,32,108,97,114,103,101,0,84,111,111,32,109,97,110,121,32,108,105,110,107,115,0,78,111,32,108,111,99,107,115,32,97,118,97,105,108,97,98,108,101,0,82,101,115,111,117,114,99,101,32,100,101,97,100,108,111,99,107,32,119,111,117,108,100,32,111,99,99,117,114,0,83,116,97,116,101,32,110,111,116,32,114,101,99,111,118,101,114,97,98,108,101,0,80,114,101,118,105,111,117,115,32,111,119,110,101,114,32,100,105,101,100,0,79,112,101,114,97,116,105,111,110,32,99,97,110,99,101,108,101,100,0,70,117,110,99,116,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,78,111,32,109,101,115,115,97,103,101,32,111,102,32,100,101,115,105,114,101,100,32,116,121,112,101,0,73,100,101,110,116,105,102,105,101,114,32,114,101,109,111,118,101,100,0,68,101,118,105,99,101,32,110,111,116,32,97,32,115,116,114,101,97,109,0,78,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,0,68,101,118,105,99,101,32,116,105,109,101,111,117,116,0,79,117,116,32,111,102,32,115,116,114,101,97,109,115,32,114,101,115,111,117,114,99,101,115,0,76,105,110,107,32,104,97,115,32,98,101,101,110,32,115,101,118,101,114,101,100,0,80,114,111,116,111,99,111,108,32,101,114,114,111,114,0,66,97,100,32,109,101,115,115,97,103,101,0,70,105,108,101,32,100,101,115,99,114,105,112,116,111,114,32,105,110,32,98,97,100,32,115,116,97,116,101,0,78,111,116,32,97,32,115,111,99,107,101,116,0,68,101,115,116,105,110,97,116,105,111,110,32,97,100,100,114,101,115,115,32,114,101,113,117,105,114,101,100,0,77,101,115,115,97,103,101,32,116,111,111,32,108,97,114,103,101,0,80,114,111,116,111,99,111,108,32,119,114,111,110,103,32,116,121,112,101,32,102,111,114,32,115,111,99,107,101,116,0,80,114,111,116,111,99,111,108,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,80,114,111,116,111,99,111,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,111,99,107,101,116,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,78,111,116,32,115,117,112,112,111,114,116,101,100,0,80,114,111,116,111,99,111,108,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,65,100,100,114,101,115,115,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,112,114,111,116,111,99,111,108,0,65,100,100,114,101,115,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,101,116,119,111,114,107,32,105,115,32,100,111,119,110,0,78,101,116,119,111,114,107,32,117,110,114,101,97,99,104,97,98,108,101,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,110,101,116,119,111,114,107,0,67,111,110,110,101,99,116,105,111,110,32,97,98,111,114,116,101,100,0,78,111,32,98,117,102,102,101,114,32,115,112,97,99,101,32,97,118,97,105,108,97,98,108,101,0,83,111,99,107,101,116,32,105,115,32,99,111,110,110,101,99,116,101,100,0,83,111,99,107,101,116,32,110,111,116,32,99,111,110,110,101,99,116,101,100,0,67,97,110,110,111,116,32,115,101,110,100,32,97,102,116,101,114,32,115,111,99,107,101,116,32,115,104,117,116,100,111,119,110,0,79,112,101,114,97,116,105,111,110,32,97,108,114,101,97,100,121,32,105,110,32,112,114,111,103,114,101,115,115,0,79,112,101,114,97,116,105,111,110,32,105,110,32,112,114,111,103,114,101,115,115,0,83,116,97,108,101,32,102,105,108,101,32,104,97,110,100,108,101,0,82,101,109,111,116,101,32,73,47,79,32,101,114,114,111,114,0,81,117,111,116,97,32,101,120,99,101,101,100,101,100,0,78,111,32,109,101,100,105,117,109,32,102,111,117,110,100,0,87,114,111,110,103,32,109,101,100,105,117,109,32,116,121,112,101,0,78,111,32,101,114,114,111,114,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,130,203,222,106,3,205,50,62,66,8,141,14,238,191,178,63,245,156,20,97,252,192,10,64,221,174,45,150,152,79,69,64,31,253,94,226,219,89,101,64,224,33,250,129,124,215,100,64,219,107,247,84,59,49,132,62,52,62,136,62,197,190,178,63,156,119,39,231,151,248,255,63,229,111,249,170,191,253,44,64,74,220,251,41,142,170,63,64,180,75,129,113,177,64,48,64,166,67,227,191,34,97,72,64,179,78,84,134,131,45,134,64,99,252,77,228,75,240,172,64,40,106,199,215,108,60,185,64,192,177,79,217,170,168,163,64,15,244,28,32,235,167,98,192,237,122,192,247,150,93,62,64,64,75,209,228,145,213,112,64,34,191,179,34,69,102,138,64,20,194,92,156,124,151,139,64,101,19,0,14,83,149,106,64,49,41,179,248,106,62,21,192,188,57,91,54,213,120,100,64,99,5,107,78,88,162,191,64,63,140,211,84,82,102,1,65,67,43,165,131,218,131,40,65,61,11,222,40,107,166,41,65,197,48,149,44,109,253,20,193,67,21,94,251,179,177,84,64,206,192,33,218,160,59,160,64,109,30,89,123,210,103,210,64,114,35,224,151,227,181,235,64,160,84,122,31,24,145,225,64,9,198,219,190,87,234,180,192,0,0,0,0,0,0,0,0,44,254,255,255,255,191,178,63,214,52,179,91,82,137,39,64,37,24,48,21,99,109,129,64,109,244,24,62,153,77,193,64,102,21,144,14,212,18,226,64,217,140,204,41,143,61,180,61,76,176,114,209,255,191,178,63,211,61,149,185,176,87,23,64,233,136,135,10,146,227,96,64,129,196,200,157,249,12,144,64,166,227,198,83,233,23,159,64,134,170,225,111,3,225,37,190,75,226,192,247,246,255,177,191,116,128,164,174,178,69,3,192,20,78,185,76,74,247,53,192,69,26,10,66,34,10,77,192,15,216,146,168,172,114,63,192,109,2,39,233,22,211,119,190,66,30,94,73,98,255,177,191,67,168,36,138,57,54,247,191,243,167,175,237,243,138,30,192,3,99,36,197,230,98,38,192,15,231,143,175,129,222,9,192,211,125,7,132,146,237,65,64,14,124,74,70,57,152,118,64,214,97,16,109,110,166,146,64,126,155,195,184,252,159,145,64,129,144,55,252,150,178,101,64,0,0,0,0,0,0,0,0,89,89,139,144,101,56,54,64,143,135,232,14,158,6,97,64,155,7,234,66,134,231,112,64,255,250,182,58,3,60,99,64,9,24,57,68,179,80,45,64,0,0,0,0,0,0,0,0,81,103,169,7,51,34,93,64,56,105,89,80,125,243,173,64,95,176,182,110,187,210,227,64,189,169,159,143,15,129,252,64,220,73,44,79,119,65,231,64,0,0,0,0,0,0,0,0,222,197,152,12,129,96,78,64,100,40,126,92,2,109,144,64,96,29,190,143,248,90,183,64,56,250,118,250,184,204,194,64,100,232,11,199,29,204,162,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,253,255,255,255,255,177,191,121,167,79,180,208,41,32,192,99,232,25,123,2,17,112,192,252,202,77,205,110,106,163,192,61,100,204,54,11,133,180,192,204,149,228,71,177,24,169,189,198,251,154,230,255,255,177,191,191,107,12,249,112,163,16,192,131,23,125,90,47,235,80,192,99,204,66,103,179,179,116,192,215,139,163,40,239,166,117,192,93,61,127,102,158,160,230,63,0,0,0,0,0,136,57,61,68,23,117,250,82,176,230,63,0,0,0,0,0,0,216,60,254,217,11,117,18,192,230,63,0,0,0,0,0,120,40,189,191,118,212,221,220,207,230,63,0,0,0,0,0,192,30,61,41,26,101,60,178,223,230,63,0,0,0,0,0,0,216,188,227,58,89,152,146,239,230,63,0,0,0,0,0,0,188,188,134,147,81,249,125,255,230,63,0,0,0,0,0,216,47,189,163,45,244,102,116,15,231,63,0,0,0,0,0,136,44,189,195,95,236,232,117,31,231,63,0,0,0,0,0,192,19,61,5,207,234,134,130,47,231,63,0,0,0,0,0,48,56,189,82,129,165,72,154,63,231,63,0,0,0,0,0,192,0,189,252,204,215,53,189,79,231,63,0,0,0,0,0,136,47,61,241,103,66,86,235,95,231,63,0,0,0,0,0,224,3,61,72,109,171,177,36,112,231,63,0,0,0,0,0,208,39,189,56,93,222,79,105,128,231,63,0,0,0,0,0,0,221,188,0,29,172,56,185,144,231,63,0,0,0,0,0,0,227,60,120,1,235,115,20,161,231,63,0,0,0,0,0,0,237,188,96,208,118,9,123,177,231,63,0,0,0,0,0,64,32,61,51,193,48,1,237,193,231,63,0,0,0,0,0,0,160,60,54,134,255,98,106,210,231,63,0,0,0,0,0,144,38,189,59,78,207,54,243,226,231,63,0,0,0,0,0,224,2,189,232,195,145,132,135,243,231,63,0,0,0,0,0,88,36,189,78,27,62,84,39,4,232,63,0,0,0,0,0,0,51,61,26,7,209,173,210,20,232,63,0,0,0,0,0,0,15,61,126,205,76,153,137,37,232,63,0,0,0,0,0,192,33,189,208,66,185,30,76,54,232,63,0,0,0,0,0,208,41,61,181,202,35,70,26,71,232,63,0,0,0,0,0,16,71,61,188,91,159,23,244,87,232,63,0,0,0,0,0,96,34,61,175,145,68,155,217,104,232,63,0,0,0,0,0,196,50,189,149,163,49,217,202,121,232,63,0,0,0,0,0,0,35,189,184,101,138,217,199,138,232,63,0,0,0,0,0,128,42,189,0,88,120,164,208,155,232,63,0,0,0,0,0,0,237,188,35,162,42,66,229,172,232,63,0,0,0,0,0,40,51,61,250,25,214,186,5,190,232,63,0,0,0,0,0,180,66,61,131,67,181,22,50,207,232,63,0,0,0,0,0,208,46,189,76,102,8,94,106,224,232,63,0,0,0,0,0,80,32,189,7,120,21,153,174,241,232,63,0,0,0,0,0,40,40,61,14,44,40,208,254,2,233,63,0,0,0,0,0,176,28,189,150,255,145,11,91,20,233,63,0,0,0,0,0,224,5,189,249,47,170,83,195,37,233,63,0,0,0,0,0,64,245,60,74,198,205,176,55,55,233,63,0,0,0,0,0,32,23,61,174,152,95,43,184,72,233,63,0,0,0,0,0,0,9,189,203,82,200,203,68,90,233,63,0,0,0,0,0,104,37,61,33,111,118,154,221,107,233,63,0,0,0,0,0,208,54,189,42,78,222,159,130,125,233,63,0,0,0,0,0,0,1,189,163,35,122,228,51,143,233,63,0,0,0,0,0,0,45,61,4,6,202,112,241,160,233,63,0,0,0,0,0,164,56,189,137,255,83,77,187,178,233,63,0,0,0,0,0,92,53,61,91,241,163,130,145,196,233,63,0,0,0,0,0,184,38,61,197,184,75,25,116,214,233,63,0,0,0,0,0,0,236,188,142,35,227,25,99,232,233,63,0,0,0,0,0,208,23,61,2,243,7,141,94,250,233,63,0,0,0,0,0,64,22,61,77,229,93,123,102,12,234,63,0,0,0,0,0,0,245,188,246,184,142,237,122,30,234,63,0,0,0,0,0,224,9,61,39,46,74,236,155,48,234,63,0,0,0,0,0,216,42,61,93,10,70,128,201,66,234,63,0,0,0,0,0,240,26,189,155,37,62,178,3,85,234,63,0,0,0,0,0,96,11,61,19,98,244,138,74,103,234,63,0,0,0,0,0,136,56,61,167,179,48,19,158,121,234,63,0,0,0,0,0,32,17,61,141,46,193,83,254,139,234,63,0,0,0,0,0,192,6,61,210,252,121,85,107,158,234,63,0,0,0,0,0,184,41,189,184,111,53,33,229,176,234,63,0,0,0,0,0,112,43,61,129,243,211,191,107,195,234,63,0,0,0,0,0,0,217,60,128,39,60,58,255,213,234,63,0,0,0,0,0,0,228,60,163,210,90,153,159,232,234,63,0,0,0,0,0,144,44,189,103,243,34,230,76,251,234,63,0,0,0,0,0,80,22,61,144,183,141,41,7,14,235,63,0,0,0,0,0,212,47,61,169,137,154,108,206,32,235,63,0,0,0,0,0,112,18,61,75,26,79,184,162,51,235,63,0,0,0,0,0,71,77,61,231,71,183,21,132,70,235,63,0,0,0,0,0,56,56,189,58,89,229,141,114,89,235,63,0,0,0,0,0,0,152,60,106,197,241,41,110,108,235,63,0,0,0,0,0,208,10,61,80,94,251,242,118,127,235,63,0,0,0,0,0,128,222,60,178,73,39,242,140,146,235,63,0,0,0,0,0,192,4,189,3,6,161,48,176,165,235,63,0,0,0,0,0,112,13,189,102,111,154,183,224,184,235,63,0,0,0,0,0,144,13,61,255,193,75,144,30,204,235,63,0,0,0,0,0,160,2,61,111,161,243,195,105,223,235,63,0,0,0,0,0,120,31,189,184,29,215,91,194,242,235,63,0,0,0,0,0,160,16,189,233,178,65,97,40,6,236,63,0,0,0,0,0,64,17,189,224,82,133,221,155,25,236,63,0,0,0,0,0,224,11,61,238,100,250,217,28,45,236,63,0,0,0,0,0,64,9,189,47,208,255,95,171,64,236,63,0,0,0,0,0,208,14,189,21,253,250,120,71,84,236,63,0,0,0,0,0,102,57,61,203,208,87,46,241,103,236,63,0,0,0,0,0,16,26,189,182,193,136,137,168,123,236,63,0,0,0,0,128,69,88,189,51,231,6,148,109,143,236,63,0,0,0,0,0,72,26,189,223,196,81,87,64,163,236,63,0,0,0,0,0,0,203,60,148,144,239,220,32,183,236,63,0,0,0,0,0,64,1,61,137,22,109,46,15,203,236,63,0,0,0,0,0,32,240,60,18,196,93,85,11,223,236,63,0,0,0,0,0,96,243,60,59,171,91,91,21,243,236,63,0,0,0,0,0,144,6,189,188,137,7,74,45,7,237,63,0,0,0,0,0,160,9,61,250,200,8,43,83,27,237,63,0,0,0,0,0,224,21,189,133,138,13,8,135,47,237,63,0,0,0,0,0,40,29,61,3,162,202,234,200,67,237,63,0,0,0,0,0,160,1,61,145,164,251,220,24,88,237,63,0,0,0,0,0,0,223,60,161,230,98,232,118,108,237,63,0,0,0,0,0,160,3,189,78,131,201,22,227,128,237,63,0,0,0,0,0,216,12,189,144,96,255,113,93,149,237,63,0,0,0,0,0,192,244,60,174,50,219,3,230,169,237,63,0,0,0,0,0,144,255,60,37,131,58,214,124,190,237,63,0,0,0,0,0,128,233,60,69,180,1,243,33,211,237,63,0,0,0,0,0,32,245,188,191,5,28,100,213,231,237,63,0,0,0,0,0,112,29,189,236,154,123,51,151,252,237,63,0,0,0,0,0,20,22,189,94,125,25,107,103,17,238,63,0,0,0,0,0,72,11,61,231,163,245,20,70,38,238,63,0,0,0,0,0,206,64,61,92,238,22,59,51,59,238,63,0,0,0,0,0,104,12,61,180,63,139,231,46,80,238,63,0,0,0,0,0,48,9,189,104,109,103,36,57,101,238,63,0,0,0,0,0,0,229,188,68,76,199,251,81,122,238,63,0,0,0,0,0,248,7,189,38,183,205,119,121,143,238,63,0,0,0,0,0,112,243,188,232,144,164,162,175,164,238,63,0,0,0,0,0,208,229,60,228,202,124,134,244,185,238,63,0,0,0,0,0,26,22,61,13,104,142,45,72,207,238,63,0,0,0,0,0,80,245,60,20,133,24,162,170,228,238,63,0,0,0,0,0,64,198,60,19,90,97,238,27,250,238,63,0,0,0,0,0,128,238,188,6,65,182,28,156,15,239,63,0,0,0,0,0,136,250,188,99,185,107,55,43,37,239,63,0,0,0,0,0,144,44,189,117,114,221,72,201,58,239,63,0,0,0,0,0,0,170,60,36,69,110,91,118,80,239,63,0,0,0,0,0,240,244,188,253,68,136,121,50,102,239,63,0,0,0,0,0,128,202,60,56,190,156,173,253,123,239,63,0,0,0,0,0,188,250,60,130,60,36,2,216,145,239,63,0,0,0,0,0,96,212,188,142,144,158,129,193,167,239,63,0,0,0,0,0,12,11,189,17,213,146,54,186,189,239,63,0,0,0,0,0,224,192,188,148,113,143,43,194,211,239,63,0,0,0,0,128,222,16,189,238,35,42,107,217,233,239,63,0,0,0,0,0,67,238,60,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,190,188,90,250,26,11,240,63,0,0,0,0,0,64,179,188,3,51,251,169,61,22,240,63,0,0,0,0,0,23,18,189,130,2,59,20,104,33,240,63,0,0,0,0,0,64,186,60,108,128,119,62,154,44,240,63,0,0,0,0,0,152,239,60,202,187,17,46,212,55,240,63,0,0,0,0,0,64,199,188,137,127,110,232,21,67,240,63,0,0,0,0,0,48,216,60,103,84,246,114,95,78,240,63,0,0,0,0,0,63,26,189,90,133,21,211,176,89,240,63,0,0,0,0,0,132,2,189,149,31,60,14,10,101,240,63,0,0,0,0,0,96,241,60,26,247,221,41,107,112,240,63,0,0,0,0,0,36,21,61,45,168,114,43,212,123,240,63,0,0,0,0,0,160,233,188,208,155,117,24,69,135,240,63,0,0,0,0,0,64,230,60,200,7,102,246,189,146,240,63,0,0,0,0,0,120,0,189,131,243,198,202,62,158,240,63,0,0,0,0,0,0,152,188,48,57,31,155,199,169,240,63,0,0,0,0,0,160,255,60,252,136,249,108,88,181,240,63,0,0,0,0,0,200,250,188,138,108,228,69,241,192,240,63,0,0,0,0,0,192,217,60,22,72,114,43,146,204,240,63,0,0,0,0,0,32,5,61,216,93,57,35,59,216,240,63,0,0,0,0,0,208,250,188,243,209,211,50,236,227,240,63,0,0,0,0,0,172,27,61,166,169,223,95,165,239,240,63,0,0,0,0,0,232,4,189,240,210,254,175,102,251,240,63,0,0,0,0,0,48,13,189,75,35,215,40,48,7,241,63,0,0,0,0,0,80,241,60,91,91,18,208,1,19,241,63,0,0,0,0,0,0,236,60,249,42,94,171,219,30,241,63,0,0,0,0,0,188,22,61,213,49,108,192,189,42,241,63,0,0,0,0,0,64,232,60,125,4,242,20,168,54,241,63,0,0,0,0,0,208,14,189,233,45,169,174,154,66,241,63,0,0,0,0,0,224,232,60,56,49,79,147,149,78,241,63,0,0,0,0,0,64,235,60,113,142,165,200,152,90,241,63,0,0,0,0,0,48,5,61,223,195,113,84,164,102,241,63,0,0,0,0,0,56,3,61,17,82,125,60,184,114,241,63,0,0,0,0,0,212,40,61,159,187,149,134,212,126,241,63,0,0,0,0,0,208,5,189,147,141,140,56,249,138,241,63,0,0,0,0,0,136,28,189,102,93,55,88,38,151,241,63,0,0,0,0,0,240,17,61,167,203,111,235,91,163,241,63,0,0,0,0,0,72,16,61,227,135,19,248,153,175,241,63,0,0,0,0,0,57,71,189,84,93,4,132,224,187,241,63,0,0,0,0,0,228,36,61,67,28,40,149,47,200,241,63,0,0,0,0,0,32,10,189,178,185,104,49,135,212,241,63,0,0,0,0,0,128,227,60,49,64,180,94,231,224,241,63,0,0,0,0,0,192,234,60,56,217,252,34,80,237,241,63,0,0,0,0,0,144,1,61,247,205,56,132,193,249,241,63,0,0,0,0,0,120,27,189,143,141,98,136,59,6,242,63,0,0,0,0,0,148,45,61,30,168,120,53,190,18,242,63,0,0,0,0,0,0,216,60,65,221,125,145,73,31,242,63,0,0,0,0,0,52,43,61,35,19,121,162,221,43,242,63,0,0,0,0,0,248,25,61,231,97,117,110,122,56,242,63,0,0,0,0,0,200,25,189,39,20,130,251,31,69,242,63,0,0,0,0,0,48,2,61,2,166,178,79,206,81,242,63,0,0,0,0,0,72,19,189,176,206,30,113,133,94,242,63,0,0,0,0,0,112,18,61,22,125,226,101,69,107,242,63,0,0,0,0,0,208,17,61,15,224,29,52,14,120,242,63,0,0,0,0,0,238,49,61,62,99,245,225,223,132,242,63,0,0,0,0,0,192,20,189,48,187,145,117,186,145,242,63,0,0,0,0,0,216,19,189,9,223,31,245,157,158,242,63,0,0,0,0,0,176,8,61,155,14,209,102,138,171,242,63,0,0,0,0,0,124,34,189,58,218,218,208,127,184,242,63,0,0,0,0,0,52,42,61,249,26,119,57,126,197,242,63,0,0,0,0,0,128,16,189,217,2,228,166,133,210,242,63,0,0,0,0,0,208,14,189,121,21,100,31,150,223,242,63,0,0,0,0,0,32,244,188,207,46,62,169,175,236,242,63,0,0,0,0,0,152,36,189,34,136,189,74,210,249,242,63,0,0,0,0,0,48,22,189,37,182,49,10,254,6,243,63,0,0,0,0,0,54,50,189,11,165,238,237,50,20,243,63,0,0,0,0,128,223,112,189,184,215,76,252,112,33,243,63,0,0,0,0,0,72,34,189,162,233,168,59,184,46,243,63,0,0,0,0,0,152,37,189,102,23,100,178,8,60,243,63,0,0,0,0,0,208,30,61,39,250,227,102,98,73,243,63,0,0,0,0,0,0,220,188,15,159,146,95,197,86,243,63,0,0,0,0,0,216,48,189,185,136,222,162,49,100,243,63,0,0,0,0,0,200,34,61,57,170,58,55,167,113,243,63,0,0,0,0,0,96,32,61,254,116,30,35,38,127,243,63,0,0,0,0,0,96,22,189,56,216,5,109,174,140,243,63,0,0,0,0,0,224,10,189,195,62,113,27,64,154,243,63,0,0,0,0,0,114,68,189,32,160,229,52,219,167,243,63,0,0,0,0,0,32,8,61,149,110,236,191,127,181,243,63,0,0,0,0,0,128,62,61,242,168,19,195,45,195,243,63,0,0,0,0,0,128,239,60,34,225,237,68,229,208,243,63,0,0,0,0,0,160,23,189,187,52,18,76,166,222,243,63,0,0,0,0,0,48,38,61,204,78,28,223,112,236,243,63,0,0,0,0,0,166,72,189,140,126,172,4,69,250,243,63,0,0,0,0,0,220,60,189,187,160,103,195,34,8,244,63,0,0,0,0,0,184,37,61,149,46,247,33,10,22,244,63,0,0,0,0,0,192,30,61,70,70,9,39,251,35,244,63,0,0,0,0,0,96,19,189,32,169,80,217,245,49,244,63,0,0,0,0,0,152,35,61,235,185,132,63,250,63,244,63,0,0,0,0,0,0,250,60,25,137,97,96,8,78,244,63,0,0,0,0,0,192,246,188,1,210,167,66,32,92,244,63,0,0,0,0,0,192,11,189,22,0,29,237,65,106,244,63,0,0,0,0,0,128,18,189,38,51,139,102,109,120,244,63,0,0,0,0,0,224,48,61,0,60,193,181,162,134,244,63,0,0,0,0,0,64,45,189,4,175,146,225,225,148,244,63,0,0,0,0,0,32,12,61,114,211,215,240,42,163,244,63,0,0,0,0,0,80,30,189,1,184,109,234,125,177,244,63,0,0,0,0,0,128,7,61,225,41,54,213,218,191,244,63,0,0,0,0,0,128,19,189,50,193,23,184,65,206,244,63,0,0,0,0,0,128,0,61,219,221,253,153,178,220,244,63,0,0,0,0,0,112,44,61,150,171,216,129,45,235,244,63,0,0,0,0,0,224,28,189,2,45,157,118,178,249,244,63,0,0,0,0,0,32,25,61,193,49,69,127,65,8,245,63,0,0,0,0,0,192,8,189,42,102,207,162,218,22,245,63,0,0,0,0,0,0,250,188,234,81,63,232,125,37,245,63,0,0,0,0,0,8,74,61,218,78,157,86,43,52,245,63,0,0,0,0,0,216,38,189,26,172,246,244,226,66,245,63,0,0,0,0,0,68,50,189,219,148,93,202,164,81,245,63,0,0,0,0,0,60,72,61,107,17,233,221,112,96,245,63,0,0,0,0,0,176,36,61,222,41,181,54,71,111,245,63,0,0,0,0,0,90,65,61,14,196,226,219,39,126,245,63,0,0,0,0,0,224,41,189,111,199,151,212,18,141,245,63,0,0,0,0,0,8,35,189,76,11,255,39,8,156,245,63,0,0,0,0,0,236,77,61,39,84,72,221,7,171,245,63,0,0,0,0,0,0,196,188,244,122,168,251,17,186,245,63,0,0,0,0,0,8,48,61,11,70,89,138,38,201,245,63,0,0,0,0,0,200,38,189,63,142,153,144,69,216,245,63,0,0,0,0,0,154,70,61,225,32,173,21,111,231,245,63,0,0,0,0,0,64,27,189,202,235,220,32,163,246,245,63,0,0,0,0,0,112,23,61,184,220,118,185,225,5,246,63,0,0,0,0,0,248,38,61,21,247,205,230,42,21,246,63,0,0,0,0,0,0,1,61,49,85,58,176,126,36,246,63,0,0,0,0,0,208,21,189,181,41,25,29,221,51,246,63,0,0,0,0,0,208,18,189,19,195,204,52,70,67,246,63,0,0,0,0,0,128,234,188,250,142,188,254,185,82,246,63,0,0,0,0,0,96,40,189,151,51,85,130,56,98,246,63,0,0,0,0,0,254,113,61,142,50,8,199,193,113,246,63,0,0,0,0,0,32,55,189,126,169,76,212,85,129,246,63,0,0,0,0,0,128,230,60,113,148,158,177,244,144,246,63,0,0,0,0,0,120,41,189,3,0,0,0,4,0,0,0,4,0,0,0,6,0,0,0,131,249,162,0,68,78,110,0,252,41,21,0,209,87,39,0,221,52,245,0,98,219,192,0,60,153,149,0,65,144,67,0,99,81,254,0,187,222,171,0,183,97,197,0,58,110,36,0,210,77,66,0,73,6,224,0,9,234,46,0,28,146,209,0,235,29,254,0,41,177,28,0,232,62,167,0,245,53,130,0,68,187,46,0,156,233,132,0,180,38,112,0,65,126,95,0,214,145,57,0,83,131,57,0,156,244,57,0,139,95,132,0,40,249,189,0,248,31,59,0,222,255,151,0,15,152,5,0,17,47,239,0,10,90,139,0,109,31,109,0,207,126,54,0,9,203,39,0,70,79,183,0,158,102,63,0,45,234,95,0,186,39,117,0,229,235,199,0,61,123,241,0,247,57,7,0,146,82,138,0,251,107,234,0,31,177,95,0,8,93,141,0,48,3,86,0,123,252,70,0,240,171,107,0,32,188,207,0,54,244,154,0,227,169,29,0,94,97,145,0,8,27,230,0,133,153,101,0,160,20,95,0,141,64,104,0,128,216,255,0,39,115,77,0,6,6,49,0,202,86,21,0,201,168,115,0,123,226,96,0,107,140,192,0,0,0,0,0,0,0,0,0,0,0,0,64,251,33,249,63,0,0,0,0,45,68,116,62,0,0,0,128,152,70,248,60,0,0,0,96,81,204,120,59,0,0,0,128,131,27,240,57,0,0,0,64,32,37,122,56,0,0,0,128,34,130,227,54,0,0,0,0,29,243,105,53,79,200,143,211,169,207,53,190,84,237,174,81,235,63,186,191,255,217,2,51,194,112,18,192,218,22,93,194,113,236,76,192,95,213,24,71,211,135,108,192,246,27,92,95,185,102,107,192,210,38,198,68,38,241,135,190,16,176,72,145,142,62,186,191,218,78,187,105,132,4,6,192,127,144,104,193,226,169,51,192,170,74,16,222,163,41,69,192,82,110,207,57,54,95,53,192,228,103,211,204,35,213,71,64,62,238,49,192,235,14,133,64,154,124,142,68,78,104,170,64,166,84,29,166,186,171,181,64,75,223,212,13,122,188,157,64,31,49,10,41,112,230,96,192,255,100,174,120,138,136,61,64,186,28,130,219,104,159,111,64,247,160,73,206,5,172,135,64,41,192,212,72,37,27,135,64,212,216,62,60,94,126,99,64,107,232,27,231,134,214,19,192,229,205,91,222,166,44,100,64,25,132,216,208,98,145,190,64,152,94,183,176,154,87,0,65,25,156,134,114,83,246,37,65,92,173,25,119,210,87,36,65,24,170,165,14,105,249,17,193,178,17,90,255,178,81,84,64,57,248,123,231,49,31,159,64,41,206,100,13,31,15,209,64,151,209,186,170,109,87,232,64,75,54,124,207,4,75,219,64,4,160,255,252,46,111,178,192,0,0,0,0,0,0,0,0,243,253,255,255,255,63,186,191,247,121,103,162,145,69,48,192,118,181,228,83,208,188,135,192,21,116,248,64,231,36,199,192,106,156,208,101,208,166,231,192,152,160,161,26,67,250,182,189,239,127,89,203,255,63,186,191,75,173,3,202,230,28,32,192,176,185,167,108,109,245,102,192,79,115,49,105,198,116,149,192,157,167,253,136,227,104,164,192,221,158,173,167,33,252,41,62,123,209,33,91,245,255,189,63,138,173,94,232,188,118,15,64,41,209,166,157,72,143,65,64,55,24,44,77,133,195,86,64,229,62,168,142,143,71,72,64,244,68,85,246,212,233,124,62,131,13,118,190,66,255,189,63,192,174,143,249,183,242,2,64,100,169,113,127,55,124,40,64,226,142,127,23,168,177,49,64,254,193,116,165,73,75,20,64,156,6,52,161,73,101,65,64,95,167,241,7,51,12,117,64,35,213,55,80,124,91,144,64,233,49,46,163,125,214,139,64,83,237,46,124,109,242,89,64,0,0,0,0,0,0,0,0,220,236,213,138,189,111,53,64,213,44,249,20,147,82,95,64,217,219,162,213,216,8,109,64,169,132,24,218,122,107,93,64,146,81,78,244,177,186,32,64,0,0,0,0,0,0,0,0,172,108,101,142,69,141,92,64,79,39,77,150,220,133,172,64,127,187,197,151,134,11,226,64,187,23,143,178,44,212,247,64,45,11,122,105,17,21,222,64,0,0,0,0,0,0,0,0,61,99,175,168,234,163,77,64,1,103,6,27,54,251,142,64,251,182,6,87,68,233,180,64,21,187,165,184,176,164,190,64,81,94,111,3,48,128,151,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,252,255,255,255,255,189,63,206,127,127,53,157,122,42,64,144,165,46,101,212,192,121,64,204,50,165,163,125,69,174,64,221,130,39,195,122,234,190,64,125,202,225,218,103,6,173,61,67,0,193,226,255,255,189,63,227,21,99,110,4,54,27,64,237,2,38,69,185,19,91,64,73,214,82,208,22,45,128,64,183,12,126,187,184,133,128,64,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,0,0,0,0,0,0,24,64,0,0,0,0,0,0,56,64,0,0,0,0,0,0,94,64,0,0,0,0,0,128,134,64,0,0,0,0,0,176,179,64,0,0,0,0,0,176,227,64,0,0,0,0,0,38,22,65,0,0,0,0,128,175,75,65,0,0,0,0,168,8,131,65,0,0,0,0,252,140,188,65,0,0,0,192,140,50,247,65,0,0,0,40,59,76,52,66,0,0,128,117,119,7,115,66,0,0,128,117,119,7,179,66,0,0,216,236,238,55,244,66,0,0,115,202,236,190,54,67,0,144,104,48,185,2,123,67,0,90,65,190,179,225,192,67,32,198,181,233,59,40,6,68,108,240,89,97,82,119,78,68,0,0,0,0,0,0,0,0,158,164,193,67,81,234,21,66,87,76,245,117,112,252,35,66,26,182,138,129,50,161,32,66,26,38,232,34,181,176,16,66,232,161,165,179,193,127,246,65,63,243,211,245,24,116,213,65,42,95,185,123,12,171,173,65,152,204,93,249,118,248,125,65,76,244,128,80,233,241,69,65,235,135,135,31,66,182,6,65,4,216,88,8,172,135,191,64,82,59,188,123,96,90,106,64,5,39,246,31,147,13,4,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,8,131,65,0,0,0,128,105,189,156,65,0,0,0,176,166,253,161,65,0,0,0,112,113,24,153,65,0,0,0,144,182,238,133,65,0,0,0,224,113,113,105,65,0,0,0,0,123,31,68,65,0,0,0,0,188,208,21,65,0,0,0,0,128,231,223,64,0,0,0,0,0,20,158,64,0,0,0,0,0,128,80,64,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,55,101,33,67,23,139,244,69,214,188,2,72,156,178,47,73,148,190,34,73,72,203,143,200,0,0,0,0,0,0,0,0,84,68,236,65,71,251,124,67,46,96,61,68,42,217,56,68,242,242,27,67,55,180,158,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,189,141,44,130,193,131,230,61,196,58,39,57,198,131,54,61,199,0,0,0,0,0,0,0,0,50,137,63,180,117,244,209,189,35,36,48,192,22,79,157,193,31,77,41,194,178,249,170,193,0,0,0,0,0,0,0,0,13,225,79,49,171,255,239,61,231,181,123,64,69,122,12,66,42,28,182,66,124,60,66,66,0,0,0,0,0,0,0,0,168,78,231,51,22,250,239,61,192,149,23,64,188,225,67,65,65,141,141,65,77,90,162,64,0,0,0,0,0,0,0,0,77,42,11,66,152,97,168,67,227,219,130,68,237,179,94,68,108,147,207,66,0,0,0,0,0,0,0,0,0,0,0,0,236,125,171,65,153,148,250,66,199,70,104,67,215,91,235,66,144,213,5,65,0,0,0,0,0,0,0,0,0,0,0,0,44,106,228,66,229,46,100,69,53,92,16,71,102,161,190,71,139,168,240,70,0,0,0,0,0,0,0,0,0,0,0,0,85,31,109,66,177,217,119,68,35,74,167,69,134,37,245,69,128,1,188,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,61,234,212,83,65,163,6,206,67,237,43,114,69,214,83,247,69,0,0,0,0,0,0,0,0,63,51,104,45,255,255,239,61,35,176,217,64,202,157,216,66,183,104,1,68,198,45,4,68,0,0,0,0,0,0,0,0,27,104,150,49,112,255,149,61,227,7,86,64,197,124,42,66,223,206,42,67,228,187,38,67,0,0,0,0,0,0,0,0,219,137,33,52,42,246,149,61,191,196,255,63,253,237,103,65,113,84,253,65,140,5,130,65,0,0,0,0,0,0,0,0,22,9,67,66,28,108,49,68,95,130,103,69,103,227,201,69,87,69,29,69,89,63,21,195,0,0,0,0,0,0,0,0,184,236,242,65,143,172,134,67,41,50,83,68,229,187,92,68,152,170,84,67,88,243,169,192,0,0,0,0,0,0,0,0,170,198,35,67,194,18,253,69,147,50,11,72,212,30,68,73,89,51,77,73,105,235,167,200,0,0,0,0,0,0,0,0,160,141,165,66,7,221,1,69,148,62,147,70,29,175,93,71,193,136,12,71,190,82,167,197,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,61,147,74,60,65,25,107,11,68,202,108,10,70,160,150,16,71,0,0,0,0,0,0,0,0,121,236,161,45,255,255,149,61,134,189,186,64,144,28,7,67,205,103,128,68,75,191,248,68,0,0,0,0,0,0,0,0,27,8,47,177,184,255,143,189,149,45,26,192,82,186,175,193,18,81,104,194,101,149,251,193,0,0,0,0,0,0,0,0,183,152,190,179,18,251,143,189,204,177,185,191,159,87,244,192,54,23,51,193,13,244,78,192,0,0,0,0,0,0,0,0,148,108,15,66,202,193,180,67,115,51,149,68,230,255,140,68,184,148,45,67,0,0,0,0,0,0,0,0,0,0,0,0,45,195,177,65,240,52,8,67,50,60,135,67,26,224,25,67,154,133,106,65,0,0,0,0,0,0,0,0,0,0,0,0,152,17,233,66,235,155,111,69,219,149,30,71,124,8,228,71,186,11,58,71,0,0,0,0,0,0,0,0,0,0,0,0,8,4,115,66,19,104,131,68,196,215,186,69,200,101,22,70,238,96,22,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,189,134,78,1,193,20,136,128,195,118,83,27,197,90,40,164,197,0,0,0,0,0,0,0,0,138,197,72,173,255,255,143,189,136,27,133,192,123,89,135,194,155,157,165,195,121,55,173,195,0,0,0,0,0,0,0,0,22,86,231,158,175,3,210,60,155,43,161,134,155,132,6,61,130,118,73,104,194,37,60,61,17,234,45,129,153,151,113,61,149,100,121,225,127,253,165,61,187,189,215,217,223,124,219,61,149,214,38,232,11,46,17,62,58,140,48,226,142,121,69,62,72,175,188,154,242,215,122,62,141,237,181,160,247,198,176,62,241,104,227,136,181,248,228,62,45,67,28,235,226,54,26,63,252,169,241,210,77,98,80,63,123,20,174,71,225,122,132,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,64,143,64,0,0,0,0,0,136,195,64,0,0,0,0,0,106,248,64,0,0,0,0,128,132,46,65,0,0,0,0,208,18,99,65,0,0,0,0,132,215,151,65,0,0,0,0,101,205,205,65,0,0,0,32,95,160,2,66,0,0,0,232,118,72,55,66,0,0,0,162,148,26,109,66,0,0,64,229,156,48,162,66,0,0,144,30,196,188,214,66,0,0,52,38,245,107,12,67,0,0,0,0,0,0,0,0,205,59,127,102,158,160,230,63,135,1,235,115,20,161,231,63,219,160,42,66,229,172,232,63,144,240,163,130,145,196,233,63,173,211,90,153,159,232,234,63,156,82,133,221,155,25,236,63,135,164,251,220,24,88,237,63,218,144,164,162,175,164,238,63,0,0,0,0,0,0,240,63,15,137,249,108,88,181,240,63,123,81,125,60,184,114,241,63,56,98,117,110,122,56,242,63,21,183,49,10,254,6,243,63,34,52,18,76,166,222,243,63,39,42,54,213,218,191,244,63,41,84,72,221,7,171,245,63,149,191,214,51,189,55,134,53,172,197,39,55,23,183,209,56,111,18,131,58,10,215,35,60,205,204,204,61,0,0,128,63,0,0,32,65,0,0,200,66,0,0,122,68,0,64,28,70,0,80,195,71,0,36,116,73,128,150,24,75,0,0,0,0,0,0,0,0,45,244,81,88,207,140,177,192,70,246,181,203,41,49,3,199,4,91,112,48,180,93,253,32,120,127,139,154,216,89,41,80,104,72,137,171,167,86,3,108,255,183,205,136,63,212,119,180,43,165,163,112,241,186,228,168,252,65,131,253,217,111,225,138,122,47,45,116,150,7,31,13,9,94,3,118,44,112,247,64,165,44,167,111,87,65,168,170,116,223,160,88,100,3,74,199,196,60,83,174,175,95,24,4,21,177,227,109,40,134,171,12,164,191,67,240,233,80,129,57,87,22,82,55,65,0,32,26,192,0,32,31,0,1,1,47,50,1,1,5,57,1,1,15,74,1,1,45,121,1,1,5,112,3,1,3,145,3,32,17,163,3,32,9,0,4,80,16,16,4,32,32,96,4,1,33,138,4,1,53,193,4,1,13,208,4,1,63,20,5,1,19,49,5,48,38,160,1,1,5,179,1,1,3,205,1,1,15,222,1,1,17,248,1,1,39,34,2,1,17,216,3,1,23,0,30,1,149,160,30,1,95,8,31,248,8,24,31,248,6,40,31,248,8,56,31,248,8,72,31,248,6,104,31,248,8,136,31,248,8,152,31,248,8,168,31,248,8,184,31,248,2,186,31,182,2,200,31,170,4,216,31,248,2,218,31,156,2,232,31,248,2,234,31,144,2,248,31,128,2,250,31,130,2,70,2,1,9,16,5,1,3,96,33,16,16,0,44,48,47,103,44,1,5,128,44,1,99,235,44,1,3,64,166,1,45,128,166,1,23,34,167,1,13,50,167,1,61,121,167,1,3,126,167,1,9,144,167,1,3,160,167,1,9,33,255,32,26,0,0,0,0,0,0,0,0,0,0,0,0,73,0,49,1,83,0,127,1,48,1,105,0,120,1,255,0,129,1,83,2,130,1,131,1,132,1,133,1,134,1,84,2,135,1,136,1,137,1,86,2,138,1,87,2,139,1,140,1,142,1,221,1,143,1,89,2,144,1,91,2,145,1,146,1,147,1,96,2,148,1,99,2,150,1,105,2,151,1,104,2,152,1,153,1,156,1,111,2,157,1,114,2,159,1,117,2,166,1,128,2,167,1,168,1,169,1,131,2,172,1,173,1,174,1,136,2,175,1,176,1,177,1,138,2,178,1,139,2,183,1,146,2,184,1,185,1,188,1,189,1,196,1,198,1,196,1,197,1,197,1,198,1,199,1,201,1,199,1,200,1,200,1,201,1,202,1,204,1,202,1,203,1,203,1,204,1,241,1,243,1,241,1,242,1,242,1,243,1,244,1,245,1,246,1,149,1,247,1,191,1,32,2,158,1,134,3,172,3,136,3,173,3,137,3,174,3,138,3,175,3,140,3,204,3,142,3,205,3,143,3,206,3,153,3,69,3,153,3,190,31,163,3,194,3,247,3,248,3,250,3,251,3,96,30,155,30,158,30,223,0,89,31,81,31,91,31,83,31,93,31,85,31,95,31,87,31,188,31,179,31,204,31,195,31,236,31,229,31,252,31,243,31,58,2,101,44,59,2,60,2,61,2,154,1,62,2,102,44,65,2,66,2,67,2,128,1,68,2,137,2,69,2,140,2,244,3,184,3,249,3,242,3,253,3,123,3,254,3,124,3,255,3,125,3,192,4,207,4,38,33,201,3,42,33,107,0,43,33,229,0,50,33,78,33,131,33,132,33,96,44,97,44,98,44,107,2,99,44,125,29,100,44,125,2,109,44,81,2,110,44,113,2,111,44,80,2,112,44,82,2,114,44,115,44,117,44,118,44,126,44,63,2,127,44,64,2,242,44,243,44,125,167,121,29,139,167,140,167,141,167,101,2,170,167,102,2,199,16,39,45,205,16,45,45,118,3,119,3,156,3,181,0,146,3,208,3,152,3,209,3,166,3,213,3,160,3,214,3,154,3,240,3,161,3,241,3,149,3,245,3,207,3,215,3,0,0,0,0,0,0,0,0,0,0,0,0,18,17,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,17,34,35,36,17,37,38,39,40,41,42,43,44,17,45,46,47,16,16,48,16,16,16,16,16,16,16,49,50,51,16,52,53,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,54,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,55,17,17,17,17,56,17,57,58,59,60,61,62,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,63,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,64,65,17,66,67,68,69,70,71,72,73,16,16,16,74,75,76,77,78,16,16,16,79,80,16,16,16,16,81,16,16,16,16,16,16,16,16,16,17,17,17,82,83,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,84,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,85,16,16,16,16,86,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,87,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,88,89,90,91,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,92,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,254,255,255,7,254,255,255,7,0,0,0,0,0,4,32,4,255,255,127,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,195,255,3,0,31,80,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,223,60,64,215,255,255,251,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,3,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,254,255,255,255,127,2,254,255,255,255,255,0,0,0,0,0,255,191,182,0,255,255,255,7,7,0,0,0,255,7,255,255,255,255,255,255,255,254,255,195,255,255,255,255,255,255,255,255,255,255,255,255,239,31,254,225,255,159,0,0,255,255,255,255,255,255,0,224,255,255,255,255,255,255,255,255,255,255,255,255,3,0,255,255,255,255,255,7,48,4,255,255,255,252,255,31,0,0,255,255,255,1,0,0,0,0,0,0,0,0,253,31,0,0,0,0,0,0,240,3,255,127,255,255,255,255,255,255,255,239,255,223,225,255,207,255,254,254,238,159,249,255,255,253,197,227,159,89,128,176,207,255,3,0,238,135,249,255,255,253,109,195,135,25,2,94,192,255,63,0,238,191,251,255,255,253,237,227,191,27,1,0,207,255,0,0,238,159,249,255,255,253,237,227,159,25,192,176,207,255,2,0,236,199,61,214,24,199,255,195,199,29,129,0,192,255,0,0,238,223,253,255,255,253,239,227,223,29,96,3,207,255,0,0,236,223,253,255,255,253,239,227,223,29,96,64,207,255,6,0,236,223,253,255,255,255,255,231,223,93,128,0,207,255,0,252,236,255,127,252,255,255,251,47,127,128,95,255,0,0,12,0,254,255,255,255,255,127,255,7,63,32,255,3,0,0,0,0,150,37,240,254,174,236,255,59,95,32,255,243,0,0,0,0,1,0,0,0,255,3,0,0,255,254,255,255,255,31,254,255,3,255,255,254,255,255,255,31,0,0,0,0,0,0,0,0,255,255,255,255,255,255,127,249,255,3,255,255,231,193,255,255,127,64,255,51,255,255,255,255,191,32,255,255,255,255,255,247,255,255,255,255,255,255,255,255,255,61,127,61,255,255,255,255,255,61,255,255,255,255,61,127,61,255,127,255,255,255,255,255,255,255,61,255,255,255,255,255,255,255,255,135,0,0,0,0,255,255,0,0,255,255,255,255,255,255,255,255,255,255,31,0,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,254,255,255,7,255,255,255,255,255,255,255,255,255,199,1,0,255,223,15,0,255,255,15,0,255,255,15,0,255,223,13,0,255,255,255,255,255,255,207,255,255,1,128,16,255,3,0,0,0,0,255,3,255,255,255,255,255,255,255,255,255,255,255,0,255,255,255,255,255,7,255,255,255,255,255,255,255,255,63,0,255,255,255,31,255,15,255,1,192,255,255,255,255,63,31,0,255,255,255,255,255,15,255,255,255,3,255,3,0,0,0,0,255,255,255,15,255,255,255,255,255,255,255,127,254,255,31,0,255,3,255,3,128,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,255,239,15,255,3,0,0,0,0,255,255,255,255,255,243,255,255,255,255,255,255,191,255,3,0,255,255,255,255,255,255,63,0,255,227,255,255,255,255,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,222,111,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,63,63,255,255,255,255,63,63,255,170,255,255,255,63,255,255,255,255,255,255,223,95,220,31,207,15,255,31,220,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,128,0,0,255,31,0,0,0,0,0,0,0,0,0,0,0,0,132,252,47,62,80,189,255,243,224,67,0,0,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,255,255,255,3,0,0,255,255,255,255,255,127,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,120,12,0,255,255,255,255,191,32,255,255,255,255,255,255,255,128,0,0,255,255,127,0,127,127,127,127,127,127,127,127,255,255,255,255,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,254,3,62,31,254,255,255,255,255,255,255,255,255,255,127,224,254,255,255,255,255,255,255,255,255,255,255,247,224,255,255,255,255,63,254,255,255,255,255,255,255,255,255,255,255,127,0,0,255,255,255,7,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,0,0,0,0,0,0,255,255,255,255,255,63,255,31,255,255,255,15,0,0,255,255,255,255,255,127,240,143,255,255,255,128,255,255,255,255,255,255,255,255,255,255,0,0,0,0,128,255,252,255,255,255,255,255,255,255,255,255,255,255,255,121,15,0,255,7,0,0,0,0,0,0,0,0,0,255,187,247,255,255,255,0,0,0,255,255,255,255,255,255,15,0,255,255,255,255,255,255,255,255,15,0,255,3,0,0,252,8,255,255,255,255,255,7,255,255,255,255,7,0,255,255,255,31,255,255,255,255,255,255,247,255,0,128,255,3,0,0,0,0,255,255,255,255,255,255,127,0,255,63,255,3,255,255,127,4,255,255,255,255,255,255,255,127,5,0,0,56,255,255,60,0,126,126,126,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,7,255,3,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,255,127,248,255,255,255,255,255,15,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,3,0,0,0,0,127,0,248,224,255,253,127,95,219,255,255,255,255,255,255,255,255,255,255,255,255,255,3,0,0,0,248,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,0,0,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,255,3,254,255,255,7,254,255,255,7,192,255,255,255,255,255,255,255,255,255,255,127,252,252,252,28,0,0,0,0,255,239,255,255,127,255,255,183,255,63,255,63,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,7,0,0,0,0,0,0,0,0,255,255,255,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,31,255,255,255,255,255,255,1,0,0,0,0,0,255,255,255,127,0,0,255,255,255,7,0,0,0,0,0,0,255,255,255,63,255,255,255,255,15,255,62,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,3,0,0,0,0,0,0,0,0,0,0,63,253,255,255,255,255,191,145,255,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,63,0,255,255,255,3,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,192,0,0,0,0,0,0,0,0,111,240,239,254,255,255,15,0,0,0,0,0,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,63,0,255,255,63,0,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,63,0,0,0,192,255,0,0,252,255,255,255,255,255,255,1,0,0,255,255,255,1,255,3,255,255,255,255,255,255,199,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,30,0,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,63,0,255,3,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,31,0,255,255,255,255,255,127,0,0,248,255,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,223,100,222,255,235,239,255,255,255,255,255,255,255,191,231,223,223,255,255,255,123,95,252,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,253,255,255,247,255,255,255,247,255,255,223,255,255,255,223,255,255,127,255,255,255,127,255,255,255,253,255,255,255,253,255,255,247,207,255,255,255,255,255,255,239,255,255,255,150,254,247,10,132,234,150,170,150,247,247,94,255,251,255,15,238,251,255,15,0,0,0,0,0,0,0,0,32,0,0,0,9,0,0,0,10,0,0,0,13,0,0,0,11,0,0,0,12,0,0,0,133,0,0,0,0,32,0,0,1,32,0,0,2,32,0,0,3,32,0,0,4,32,0,0,5,32,0,0,6,32,0,0,8,32,0,0,9,32,0,0,10,32,0,0,40,32,0,0,41,32,0,0,95,32,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,46,85,84,70,45,56,0,0,0,0,0,0,0,0,0,76,67,95,67,84,89,80,69,0,0,0,0,76,67,95,78,85,77,69,82,73,67,0,0,76,67,95,84,73,77,69,0,0,0,0,0,76,67,95,67,79,76,76,65,84,69,0,0,76,67,95,77,79,78,69,84,65,82,89,0,76,67,95,77,69,83,83,65,71,69,83,0,0,0,0,0,0,0,0,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,18,16,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,16,16,34,35,16,36,37,38,39,40,41,42,43,16,44,45,46,17,47,48,17,17,49,17,17,17,50,51,52,53,54,55,56,57,17,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,58,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,59,16,60,61,62,63,64,65,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,66,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,67,16,16,68,16,69,70,71,16,72,16,73,16,16,16,16,74,75,76,77,16,16,78,16,79,80,16,16,16,16,81,16,16,16,16,16,16,16,16,16,16,16,16,16,82,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,83,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,84,85,86,87,16,16,88,89,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,90,16,91,92,93,94,95,96,97,98,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,0,252,1,0,0,248,1,0,0,120,0,0,0,0,255,251,223,251,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,0,252,255,224,175,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,32,64,176,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,134,254,255,255,255,0,64,73,0,0,0,0,0,24,0,223,255,0,200,0,0,0,0,0,0,0,1,0,60,0,0,0,0,0,0,0,0,0,0,0,0,16,224,1,30,0,96,255,191,0,0,0,0,0,0,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,207,3,0,0,0,3,0,32,255,127,0,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,16,0,32,30,0,48,0,1,0,0,0,0,0,0,0,0,16,0,32,0,0,0,0,252,15,0,0,0,0,0,0,0,16,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,0,0,0,0,3,0,0,0,0,0,0,0,0,16,0,32,0,0,0,0,253,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,255,7,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,255,0,0,0,0,0,0,0,16,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,63,2,0,0,0,0,0,0,0,0,0,4,0,0,0,0,16,0,0,0,0,0,0,128,0,128,192,223,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,254,255,255,255,0,252,255,255,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,192,255,223,255,7,0,0,0,0,0,0,0,0,0,0,128,6,0,252,0,0,24,62,0,0,128,191,0,204,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,96,255,255,255,31,0,0,255,3,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,1,0,0,24,0,0,0,0,0,0,0,0,0,56,0,0,0,0,16,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,254,127,47,0,0,255,3,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,255,255,255,255,0,0,0,192,0,0,0,0,0,0,0,0,1,0,224,159,0,0,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,0,0,252,255,255,255,31,0,0,0,0,0,12,0,0,0,0,0,0,64,0,12,240,0,0,0,0,0,0,192,248,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,255,0,255,255,255,33,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,127,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,224,0,224,0,224,0,96,128,248,255,255,255,252,255,255,255,255,255,127,31,252,241,127,255,127,0,0,255,255,255,3,0,0,255,255,255,255,1,0,123,3,208,193,175,66,0,12,31,188,255,255,0,0,0,0,0,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,255,255,255,127,0,0,0,255,7,0,0,255,255,255,255,255,255,255,255,255,255,63,0,0,0,0,0,0,252,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,135,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,127,255,15,0,0,0,0,0,0,0,0,255,255,255,251,255,255,255,255,255,255,255,255,255,255,15,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,255,15,30,255,255,255,1,252,193,224,0,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,255,255,255,255,15,0,0,0,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,127,0,0,0,0,0,0,192,0,224,0,0,0,0,0,0,0,0,0,0,0,128,15,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,255,255,127,0,3,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,8,0,0,0,15,255,3,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,16,192,0,0,255,255,3,7,0,0,0,0,0,248,0,0,0,0,8,128,0,0,0,0,0,0,0,0,0,0,8,0,255,63,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,128,11,0,0,0,0,0,0,0,128,2,0,0,192,0,0,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,255,255,255,3,127,0,255,255,255,255,247,255,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,254,255,0,252,1,0,0,248,1,0,0,248,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,48,135,255,255,255,255,255,143,255,0,0,0,0,0,0,224,255,255,7,255,15,0,0,0,0,0,0,255,255,255,255,255,63,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,143,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,255,0,255,1,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,63,252,255,63,0,0,0,3,0,0,0,0,0,0,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,255,255,255,255,127,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,0,255,255,255,255,255,255,255,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,127,0,255,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,8,0,0,0,8,0,0,32,0,0,0,32,0,0,128,0,0,0,128,0,0,0,2,0,0,0,2,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,255,255,255,255,255,15,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,127,254,127,254,255,254,255,0,0,0,0,255,7,255,255,255,127,255,255,255,255,255,255,255,15,255,255,255,255,255,7,0,0,0,0,0,0,0,0,192,255,255,255,7,0,255,255,255,255,255,7,255,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,0,191,255,255,255,255,255,255,255,255,31,255,255,15,0,255,255,255,255,223,7,0,0,255,255,1,0,255,255,255,255,255,255,255,127,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,30,255,255,255,255,255,255,255,63,15,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,255,255,255,255,255,225,255,0,0,0,0,0,0,255,255,255,255,255,255,255,255,63,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,67,95,67,84,89,80,69,0,0,0,0,76,67,95,78,85,77,69,82,73,67,0,0,76,67,95,84,73,77,69,0,0,0,0,0,76,67,95,67,79,76,76,65,84,69,0,0,76,67,95,77,79,78,69,84,65,82,89,0,76,67,95,77,69,83,83,65,71,69,83,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,108,110,117,109,0,97,108,112,104,97,0,98,108,97,110,107,0,99,110,116,114,108,0,100,105,103,105,116,0,103,114,97,112,104,0,108,111,119,101,114,0,112,114,105,110,116,0,112,117,110,99,116,0,115,112,97,99,101,0,117,112,112,101,114,0,120,100,105,103,105,116,0,0,0,0,0,0,0,0,117,116,102,56,0,99,104,97,114,0,0,200,119,99,104,97,114,116,0,0,198,117,99,115,50,0,117,99,115,50,98,101,0,0,196,117,99,115,50,108,101,0,0,197,117,116,102,49,54,0,117,116,102,49,54,98,101,0,0,194,117,116,102,49,54,108,101,0,0,193,117,99,115,52,0,117,99,115,52,98,101,0,117,116,102,51,50,0,117,116,102,51,50,98,101,0,0,192,117,99,115,52,108,101,0,117,116,102,51,50,108,101,0,0,195,97,115,99,105,105,0,117,115,97,115,99,105,105,0,105,115,111,54,52,54,0,105,115,111,54,52,54,117,115,0,0,199,101,117,99,106,112,0,0,208,115,104,105,102,116,106,105,115,0,115,106,105,115,0,0,209,103,98,49,56,48,51,48,0,0,216,103,98,107,0,0,217,103,98,50,51,49,50,0,0,218,98,105,103,53,0,98,105,103,102,105,118,101,0,99,112,57,53,48,0,98,105,103,53,104,107,115,99,115,0,0,224,101,117,99,107,114,0,107,115,99,53,54,48,49,0,107,115,120,49,48,48,49,0,99,112,57,52,57,0,0,232,105,115,111,56,56,53,57,49,0,108,97,116,105,110,49,0,0,128,105,115,111,56,56,53,57,50,0,0,32,0,216,16,203,26,0,164,17,8,0,0,28,82,200,34,160,0,64,138,40,0,220,48,11,27,0,168,33,8,44,0,32,98,8,35,161,212,82,202,40,123,0,0,0,13,0,148,129,3,0,62,0,128,4,0,74,0,0,0,16,66,180,17,7,0,0,220,1,0,0,127,84,2,192,37,0,0,144,8,0,124,0,0,64,13,0,152,145,3,0,63,0,144,4,0,75,0,0,64,16,67,184,33,7,0,0,224,1,0,0,128,88,2,0,38,0,0,160,136,44,105,115,111,56,56,53,57,51,0,0,32,0,88,17,11,0,0,4,64,5,0,0,120,81,136,19,96,0,16,128,40,0,92,1,0,0,0,0,80,5,0,0,124,97,200,19,97,0,16,192,40,0,0,0,64,0,0,240,160,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,64,1,0,0,76,0,0,0,0,0,76,50,8,0,0,0,0,64,0,0,244,176,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,68,1,0,0,77,0,0,0,0,0,80,66,136,44,105,115,111,56,56,53,57,52,0,0,32,0,216,64,70,31,0,96,113,6,0,0,28,66,132,20,141,0,64,10,0,0,220,48,139,31,0,100,129,6,44,0,32,82,196,20,142,204,81,10,29,50,0,0,0,0,0,0,0,0,23,62,0,128,4,0,70,0,0,128,22,66,188,81,135,24,0,0,0,0,0,0,100,2,0,0,0,60,18,9,0,51,0,0,0,0,0,0,0,64,23,63,0,144,4,0,71,0,0,192,22,67,192,97,199,24,0,0,0,0,0,0,104,2,0,0,0,64,34,137,44,105,115,111,56,56,53,57,53,0,0,32,0,12,68,80,65,6,29,132,80,66,10,45,196,80,67,14,1,240,16,68,17,73,52,17,69,21,89,116,17,70,25,105,180,17,71,29,121,244,17,72,33,137,52,18,73,37,153,116,18,74,41,169,180,18,75,45,185,244,18,76,49,201,52,19,77,53,217,116,19,78,57,233,180,19,79,61,249,244,19,80,65,9,53,20,81,69,25,117,20,82,73,41,181,20,83,77,57,245,20,84,87,70,37,213,84,84,85,101,213,85,88,101,165,213,86,92,13,208,149,87,105,115,111,56,56,53,57,54,0,0,32,0,4,16,64,0,0,4,16,64,0,1,4,16,64,0,148,1,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,101,1,4,16,128,101,1,92,134,89,102,154,109,198,89,103,158,125,6,90,104,162,141,70,90,105,166,157,134,90,106,170,173,198,90,107,174,189,6,91,0,1,4,16,64,0,177,201,54,27,109,181,217,118,27,110,185,233,182,27,111,189,249,246,27,112,193,9,55,92,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,105,115,111,56,56,53,57,55,0,0,32,0,20,105,36,0,84,86,9,0,0,0,0,176,11,0,0,0,16,192,144,0,0,0,0,0,188,244,226,11,0,191,0,19,12,0,194,0,48,12,49,197,24,115,12,50,201,40,179,12,51,205,56,243,12,52,209,72,51,13,53,213,88,19,192,53,216,100,163,205,54,220,116,227,205,55,224,132,35,206,56,228,148,99,206,57,232,164,163,206,58,236,180,227,206,59,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,80,0,105,115,111,56,56,53,57,56,0,0,32,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,0,145,116,213,101,215,93,120,229,165,215,94,124,245,229,215,95,128,5,38,216,96,132,21,102,216,97,136,37,166,216,98,140,53,230,88,0,1,252,8,100,0,105,115,111,56,56,53,57,57,0,0,80,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,81,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,97,8,0,105,115,111,56,56,53,57,49,48,0,0,32,0,216,64,132,20,90,96,33,6,0,103,8,113,72,35,164,0,16,201,28,0,220,80,196,20,91,100,49,6,0,104,12,129,136,35,165,12,41,9,29,50,0,0,0,0,0,0,0,0,23,62,0,128,4,0,70,0,0,0,0,0,188,81,7,0,0,0,0,192,35,0,100,2,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,64,23,63,0,144,4,0,71,0,0,0,0,0,192,97,7,0,0,0,0,0,36,0,104,2,0,0,0,0,0,0,25,105,115,111,56,56,53,57,49,49,0,116,105,115,54,50,48,0,0,32,0,64,23,157,116,211,81,87,157,117,215,97,151,157,118,219,113,215,157,119,223,129,23,158,120,227,145,87,158,121,231,161,151,158,122,235,177,215,158,123,239,193,23,159,124,243,209,87,159,125,247,225,151,159,126,251,241,215,159,127,255,1,24,160,128,3,18,88,160,129,7,34,152,96,0,1,4,16,128,130,11,50,216,160,131,15,66,24,161,132,19,82,88,161,133,23,98,152,161,134,27,114,216,161,135,31,130,24,162,136,35,146,88,162,137,1,4,16,64,0,105,115,111,56,56,53,57,49,51,0,0,32,0,36,9,0,0,0,40,9,0,0,13,0,208,7,0,0,0,0,192,2,0,0,0,0,0,72,2,0,0,0,16,0,224,7,0,0,0,0,128,3,54,112,33,3,14,0,0,128,4,17,62,0,0,138,17,82,136,161,197,25,135,180,241,6,0,117,0,0,0,0,153,172,17,72,36,0,136,66,10,0,55,116,49,67,14,0,0,144,68,17,63,0,16,202,17,83,140,177,5,26,136,184,1,7,0,118,0,0,0,0,154,176,33,136,36,0,140,82,138,145,105,115,111,56,56,53,57,49,52,0,0,32,0,156,136,34,0,60,244,144,34,0,53,2,112,163,138,59,2,0,192,39,43,178,8,69,20,45,186,8,192,139,54,194,136,99,140,60,230,168,163,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,155,0,0,0,0,0,0,0,192,140,0,0,0,0,0,0,0,208,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,141,0,0,0,0,0,0,0,224,9,0,105,115,111,56,56,53,57,49,53,0,108,97,116,105,110,57,0,0,36,84,2,112,8,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,0,165,0,0,0,0,121,232,241,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,115,111,56,56,53,57,49,54,0,0,32,0,216,112,195,26,84,42,121,8,0,136,0,176,10,0,160,0,16,138,40,0,0,224,3,27,164,36,9,0,0,165,252,192,10,0,121,232,241,201,40,0,0,0,0,13,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,66,180,1,0,0,0,220,1,64,32,151,0,0,0,0,0,32,209,10,0,0,0,0,64,13,0,228,0,0,0,0,0,0,0,0,0,0,0,0,0,67,184,1,0,0,0,224,1,128,32,152,0,0,0,0,0,36,225,10,0,99,112,49,50,53,48,0,119,105,110,100,111,119,115,49,50,53,48,0,0,0,84,6,112,100,0,74,58,185,36,147,1,60,121,8,148,129,44,66,10,40,1,20,105,36,146,73,54,25,164,144,1,96,137,72,148,130,48,82,74,40,0,192,18,203,26,0,216,0,0,0,0,0,80,8,0,0,0,0,128,40,0,0,48,11,27,0,0,0,0,0,0,220,96,8,0,105,212,162,198,40,123,0,0,0,13,0,148,129,3,0,62,0,128,4,0,74,0,0,0,16,66,180,17,7,0,0,220,1,0,0,127,84,2,192,37,0,0,144,8,0,124,0,0,64,13,0,152,145,3,0,63,0,144,4,0,75,0,0,64,16,67,184,33,7,0,0,224,1,0,0,128,88,2,0,38,0,0,160,136,44,99,112,49,50,53,49,0,119,105,110,100,111,119,115,49,50,53,49,0,0,0,4,21,116,228,84,74,58,185,36,147,84,62,185,16,148,12,57,212,16,68,82,21,105,36,146,73,54,25,164,144,1,96,153,85,148,90,113,181,149,87,0,60,212,149,66,0,124,5,0,0,3,1,96,16,0,0,0,0,64,66,0,0,128,144,85,96,1,0,0,0,81,93,73,21,0,88,29,84,213,85,17,73,52,17,69,21,89,116,17,70,25,105,180,17,71,29,121,244,17,72,33,137,52,18,73,37,153,116,18,74,41,169,180,18,75,45,185,244,18,76,49,201,52,19,77,53,217,116,19,78,57,233,180,19,79,61,249,244,19,80,65,9,53,20,81,69,25,117,20,82,73,41,181,20,83,77,57,245,20,84,99,112,49,50,53,50,0,119,105,110,100,111,119,115,49,50,53,50,0,0,0,84,6,112,164,41,74,58,185,36,147,175,60,121,8,148,121,4,64,74,0,1,20,105,36,146,73,54,25,164,144,180,96,137,72,148,122,4,80,202,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,112,49,50,53,51,0,119,105,110,100,111,119,115,49,50,53,51,0,0,0,84,6,112,164,41,74,58,185,36,147,1,60,25,0,148,1,4,16,64,0,1,20,105,36,146,73,54,25,164,144,1,96,25,64,148,1,4,16,64,0,0,244,226,11,0,0,0,0,0,0,0,0,16,0,0,0,0,0,192,144,0,0,0,0,0,188,0,0,0,0,191,0,19,12,0,194,0,48,12,49,197,24,115,12,50,201,40,179,12,51,205,56,243,12,52,209,72,51,13,53,213,88,19,192,53,216,100,163,205,54,220,116,227,205,55,224,132,35,206,56,228,148,99,206,57,232,164,163,206,58,236,180,227,206,59,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,80,0,99,112,49,50,53,52,0,119,105,110,100,111,119,115,49,50,53,52,0,0,0,84,6,112,164,41,74,58,185,36,147,175,60,121,8,148,121,4,16,64,0,1,20,105,36,146,73,54,25,164,144,180,96,137,72,148,122,4,16,192,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,81,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,97,8,0,99,112,49,50,53,53,0,119,105,110,100,111,119,115,49,50,53,53,0,0,0,84,6,112,164,41,74,58,185,36,147,175,60,25,0,148,1,4,16,64,0,1,20,105,36,146,73,54,25,164,144,180,96,25,64,148,1,4,16,64,0,0,0,0,0,0,82,2,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,97,137,53,22,89,101,153,117,22,90,105,169,21,192,90,108,181,229,214,91,112,197,37,215,92,143,65,22,153,100,147,5,16,64,0,1,4,16,64,0,116,213,101,215,93,120,229,165,215,94,124,245,229,215,95,128,5,38,216,96,132,21,102,216,97,136,37,166,216,98,140,53,230,88,0,1,252,8,100,0,99,112,49,50,53,54,0,119,105,110,100,111,119,115,49,50,53,54,0,0,0,84,22,119,164,41,74,58,185,36,147,175,60,73,28,148,121,24,151,220,113,203,21,105,36,146,73,54,25,164,144,202,97,137,92,148,122,244,232,35,115,0,80,6,0,0,0,0,0,0,0,0,0,208,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,25,0,0,0,0,128,101,206,93,134,89,102,154,109,198,89,103,158,125,6,90,104,162,141,70,90,105,166,157,134,90,106,170,173,198,26,0,173,185,246,26,108,177,201,54,27,109,0,212,6,128,109,183,225,150,27,0,0,0,0,0,0,186,237,6,0,0,188,245,230,219,111,0,0,23,28,0,194,1,48,28,0,0,252,8,228,115,99,112,49,50,53,55,0,119,105,110,100,111,119,115,49,50,53,55,0,0,0,84,6,112,100,0,74,58,185,36,147,1,60,25,0,148,1,16,0,139,2,1,20,105,36,146,73,54,25,164,144,1,96,25,64,148,1,24,48,75,0,0,4,0,0,0,0,4,0,0,0,13,0,208,7,0,0,0,0,192,2,0,0,0,0,0,0,0,0,0,0,16,0,224,7,0,0,0,0,128,3,54,112,33,3,14,0,0,128,4,17,62,0,0,138,17,82,136,161,197,25,135,180,241,6,0,117,0,0,0,0,153,172,17,72,36,0,136,66,10,0,55,116,49,67,14,0,0,144,68,17,63,0,16,202,17,83,140,177,5,26,136,184,1,7,0,118,0,0,0,0,154,176,33,136,36,0,140,82,138,44,99,112,49,50,53,56,0,119,105,110,100,111,119,115,49,50,53,56,0,0,0,84,6,112,164,41,74,58,185,36,147,175,60,25,0,148,121,4,16,64,0,1,20,105,36,146,73,54,25,164,144,180,96,25,64,148,122,4,16,192,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,66,0,144,11,0,0,156,2,0,0,0,0,0,0,0,0,164,130,11,0,0,0,0,64,13,0,0,0,0,0,0,0,0,0,0,183,0,0,0,0,67,0,160,11,0,0,160,2,0,0,0,0,0,0,0,0,168,50,37,0,107,111,105,56,114,0,0,0,96,134,41,230,152,100,150,105,230,153,104,166,169,38,162,137,42,186,40,163,141,58,250,168,151,144,102,169,229,150,92,118,41,192,151,7,32,144,192,3,107,178,217,102,84,110,190,9,103,156,114,206,73,103,157,118,222,137,103,158,122,238,201,231,64,125,250,249,39,160,129,10,58,40,161,133,26,122,104,1,79,197,36,211,81,53,217,84,20,77,70,229,164,211,78,60,245,228,211,79,64,65,21,148,80,67,17,117,211,76,77,49,133,83,82,78,41,133,212,82,47,69,36,209,73,21,89,84,18,69,38,101,164,209,70,28,117,228,209,71,32,193,20,146,72,35,145,116,209,68,45,177,132,81,74,46,169,132,210,74,107,111,105,56,117,0,0,0,96,134,41,230,152,100,150,105,230,153,104,166,169,38,162,137,42,186,40,163,141,58,250,168,151,144,102,169,229,150,92,118,41,192,151,7,32,144,192,3,107,178,217,102,84,84,189,105,213,85,114,206,73,103,157,118,130,133,103,158,122,238,201,231,64,6,249,137,80,66,129,10,58,40,161,133,126,117,104,1,79,197,36,211,81,53,217,84,20,77,70,229,164,211,78,60,245,228,211,79,64,65,21,148,80,67,17,117,211,76,77,49,133,83,82,78,41,133,212,82,47,69,36,209,73,21,89,84,18,69,38,101,164,209,70,28,117,228,209,71,32,193,20,146,72,35,145,116,209,68,45,177,132,81,74,46,169,132,210,74,99,112,52,51,55,0,0,0,23,192,64,130,7,31,116,0,130,8,37,152,48,66,10,40,156,64,65,5,24,56,176,192,10,44,168,240,130,11,49,100,192,65,4,18,76,96,165,41,145,70,26,105,164,145,70,26,105,164,145,70,26,105,164,145,70,26,105,164,141,58,250,104,152,103,242,217,103,156,112,250,201,166,156,120,222,105,231,152,100,166,137,166,153,96,170,153,167,158,117,190,73,104,160,123,174,121,168,160,131,254,9,40,157,115,182,233,166,161,133,150,41,166,162,137,46,202,40,162,229,68,138,12,61,215,220,19,41,62,218,52,211,13,58,145,234,147,78,164,145,70,218,37,151,94,126,249,192,150,7,100,153,128,150,145,34,0,169,0,99,112,56,53,48,0,0,0,23,192,64,130,7,31,116,0,130,8,37,152,48,66,10,40,156,64,65,5,24,56,176,192,10,44,168,240,130,11,49,100,192,1,4,18,52,192,128,41,145,70,26,105,164,145,70,26,105,164,145,70,26,105,164,145,70,26,105,164,141,58,250,104,152,103,70,26,105,164,5,248,201,166,156,120,70,48,193,152,100,166,137,166,153,96,170,25,105,164,117,190,73,104,160,123,174,121,104,164,145,70,26,105,164,145,126,17,105,164,145,150,41,166,162,137,70,26,41,162,145,70,26,105,164,145,70,26,105,164,145,70,26,105,164,145,70,106,64,164,145,70,74,100,164,145,14,240,128,2,7,16,144,64,164,145,34,0,169,0,0,0,0,0,48,1,48,2,48,12,255,14,255,251,48,26,255,27,255,31,255,1,255,155,48,156,48,180,0,64,255,168,0,62,255,227,255,63,255,253,48,254,48,157,48,158,48,3,48,221,78,5,48,6,48,7,48,252,48,21,32,16,32,15,255,92,0,28,48,22,32,92,255,38,32,37,32,24,32,25,32,28,32,29,32,8,255,9,255,20,48,21,48,59,255,61,255,91,255,93,255,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,11,255,18,34,177,0,215,0,247,0,29,255,96,34,28,255,30,255,102,34,103,34,30,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,229,255,4,255,162,0,163,0,5,255,3,255,6,255,10,255,32,255,167,0,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,59,32,18,48,146,33,144,33,145,33,147,33,19,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,34,40,34,172,0,210,33,212,33,0,34,3,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,165,34,18,35,2,34,7,34,97,34,82,34,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,33,48,32,111,38,109,38,106,38,32,32,33,32,182,0,0,0,0,0,0,0,0,0,239,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,0,0,0,0,0,0,0,0,0,0,0,0,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,0,0,0,0,0,0,0,0,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,78,22,85,3,90,63,150,192,84,27,97,40,99,246,89,34,144,117,132,28,131,80,122,170,96,225,99,37,110,237,101,102,132,166,130,245,155,147,104,39,87,161,101,113,98,155,91,208,89,123,134,244,152,98,125,190,125,142,155,22,98,159,124,183,136,137,91,181,94,9,99,151,102,72,104,199,149,141,151,79,103,229,78,10,79,77,79,157,79,73,80,242,86,55,89,212,89,1,90,9,92,223,96,15,97,112,97,19,102,5,105,186,112,79,117,112,117,251,121,173,125,239,125,195,128,14,132,99,136,2,139,85,144,122,144,59,83,149,78,165,78,223,87,178,128,193,144,239,120,0,78,241,88,162,110,56,144,50,122,40,131,139,130,47,156,65,81,112,83,189,84,225,84,224,86,251,89,21,95,242,152,235,109,228,128,45,133,98,150,112,150,160,150,251,151,11,84,243,83,135,91,207,112,189,127,194,143,232,150,111,83,92,157,186,122,17,78,147,120,252,129,38,110,24,86,4,85,29,107,26,133,59,156,229,89,169,83,102,109,220,116,143,149,66,86,145,78,75,144,242,150,79,131,12,153,225,83,182,85,48,91,113,95,32,102,243,102,4,104,56,108,243,108,41,109,91,116,200,118,78,122,52,152,241,130,91,136,96,138,237,146,178,109,171,117,202,118,197,153,166,96,1,139,138,141,178,149,142,105,173,83,134,81,18,87,48,88,68,89,180,91,246,94,40,96,169,99,244,99,191,108,20,111,142,112,20,113,89,113,213,113,63,115,1,126,118,130,209,130,151,133,96,144,91,146,27,157,105,88,188,101,90,108,37,117,249,81,46,89,101,89,128,95,220,95,188,98,250,101,42,106,39,107,180,107,139,115,193,127,86,137,44,157,14,157,196,158,161,92,150,108,123,131,4,81,75,92,182,97,198,129,118,104,97,114,89,78,250,79,120,83,105,96,41,110,79,122,243,151,11,78,22,83,238,78,85,79,61,79,161,79,115,79,160,82,239,83,9,86,15,89,193,90,182,91,225,91,209,121,135,102,156,103,182,103,76,107,179,108,107,112,194,115,141,121,190,121,60,122,135,123,177,130,219,130,4,131,119,131,239,131,211,131,102,135,178,138,41,86,168,140,230,143,78,144,30,151,138,134,196,79,232,92,17,98,89,114,59,117,229,129,189,130,254,134,192,140,197,150,19,153,213,153,203,78,26,79,227,137,222,86,74,88,202,88,251,94,235,95,42,96,148,96,98,96,208,97,18,98,208,98,57,101,65,155,102,102,176,104,119,109,112,112,76,117,134,118,117,125,165,130,249,135,139,149,142,150,157,140,241,81,190,82,22,89,179,84,179,91,22,93,104,97,130,105,175,109,141,120,203,132,87,136,114,138,167,147,184,154,108,109,168,153,217,134,163,87,255,103,206,134,14,146,131,82,135,86,4,84,211,94,225,98,185,100,60,104,56,104,187,107,114,115,186,120,107,122,154,137,210,137,107,141,3,143,237,144,163,149,148,150,105,151,102,91,179,92,125,105,77,152,78,152,155,99,32,123,43,106,127,106,182,104,13,156,95,111,114,82,157,85,112,96,236,98,59,109,7,110,209,110,91,132,16,137,68,143,20,78,57,156,246,83,27,105,58,106,132,151,42,104,92,81,195,122,178,132,220,145,140,147,91,86,40,157,34,104,5,131,49,132,165,124,8,82,197,130,230,116,126,78,131,79,160,81,210,91,10,82,216,82,231,82,251,93,154,85,42,88,230,89,140,91,152,91,219,91,114,94,121,94,163,96,31,97,99,97,190,97,219,99,98,101,209,103,83,104,250,104,62,107,83,107,87,108,34,111,151,111,69,111,176,116,24,117,227,118,11,119,255,122,161,123,33,124,233,125,54,127,240,127,157,128,102,130,158,131,179,137,204,138,171,140,132,144,81,148,147,149,145,149,162,149,101,150,211,151,40,153,24,130,56,78,43,84,184,92,204,93,169,115,76,118,60,119,169,92,235,127,11,141,193,150,17,152,84,152,88,152,1,79,14,79,113,83,156,85,104,86,250,87,71,89,9,91,196,91,144,92,12,94,126,94,204,95,238,99,58,103,215,101,226,101,31,103,203,104,196,104,95,106,48,94,197,107,23,108,125,108,127,117,72,121,99,91,0,122,0,125,189,95,143,137,24,138,180,140,119,141,204,142,29,143,226,152,14,154,60,155,128,78,125,80,0,81,147,89,156,91,47,98,128,98,236,100,58,107,160,114,145,117,71,121,169,127,251,135,188,138,112,139,172,99,202,131,160,151,9,84,3,84,171,85,84,104,88,106,112,138,39,120,117,103,205,158,116,83,162,91,26,129,80,134,6,144,24,78,69,78,199,78,17,79,202,83,56,84,174,91,19,95,37,96,81,101,61,103,66,108,114,108,227,108,120,112,3,116,118,122,174,122,8,123,26,125,254,124,102,125,231,101,91,114,187,83,69,92,232,93,210,98,224,98,25,99,32,110,90,134,49,138,221,141,248,146,1,111,166,121,90,155,168,78,171,78,172,78,155,79,160,79,209,80,71,81,246,122,113,81,246,81,84,83,33,83,127,83,235,83,172,85,131,88,225,92,55,95,74,95,47,96,80,96,109,96,31,99,89,101,75,106,193,108,194,114,237,114,239,119,248,128,5,129,8,130,78,133,247,144,225,147,255,151,87,153,90,154,240,78,221,81,45,92,129,102,109,105,64,92,242,102,117,105,137,115,80,104,129,124,197,80,228,82,71,87,254,93,38,147,164,101,35,107,61,107,52,116,129,121,189,121,75,123,202,125,185,130,204,131,127,136,95,137,57,139,209,143,209,145,31,84,128,146,93,78,54,80,229,83,58,83,215,114,150,115,233,119,230,130,175,142,198,153,200,153,210,153,119,81,26,97,94,134,176,85,122,122,118,80,211,91,71,144,133,150,50,78,219,106,231,145,81,92,72,92,152,99,159,122,147,108,116,151,97,143,170,122,138,113,136,150,130,124,23,104,112,126,81,104,108,147,242,82,27,84,171,133,19,138,164,127,205,142,225,144,102,83,136,136,65,121,194,79,190,80,17,82,68,81,83,85,45,87,234,115,139,87,81,89,98,95,132,95,117,96,118,97,103,97,169,97,178,99,58,100,108,101,111,102,66,104,19,110,102,117,61,122,251,124,76,125,153,125,75,126,107,127,14,131,74,131,205,134,8,138,99,138,102,139,253,142,26,152,143,157,184,130,206,143,232,155,135,82,31,98,131,100,192,111,153,150,65,104,145,80,32,107,122,108,84,111,116,122,80,125,64,136,35,138,8,103,246,78,57,80,38,80,101,80,124,81,56,82,99,82,167,85,15,87,5,88,204,90,250,94,178,97,248,97,243,98,114,99,28,105,41,106,125,114,172,114,46,115,20,120,111,120,121,125,12,119,169,128,139,137,25,139,226,140,210,142,99,144,117,147,122,150,85,152,19,154,120,158,67,81,159,83,179,83,123,94,38,95,27,110,144,110,132,115,254,115,67,125,55,130,0,138,250,138,80,150,78,78,11,80,228,83,124,84,250,86,209,89,100,91,241,93,171,94,39,95,56,98,69,101,175,103,86,110,208,114,202,124,180,136,161,128,225,128,240,131,78,134,135,138,232,141,55,146,199,150,103,152,19,159,148,78,146,78,13,79,72,83,73,84,62,84,47,90,140,95,161,95,159,96,167,104,142,106,90,116,129,120,158,138,164,138,119,139,144,145,94,78,201,155,164,78,124,79,175,79,25,80,22,80,73,81,108,81,159,82,185,82,254,82,154,83,227,83,17,84,14,84,137,85,81,87,162,87,125,89,84,91,93,91,143,91,229,93,231,93,247,93,120,94,131,94,154,94,183,94,24,95,82,96,76,97,151,98,216,98,167,99,59,101,2,102,67,102,244,102,109,103,33,104,151,104,203,105,95,108,42,109,105,109,47,110,157,110,50,117,135,118,108,120,63,122,224,124,5,125,24,125,94,125,177,125,21,128,3,128,175,128,177,128,84,129,143,129,42,130,82,131,76,136,97,136,27,139,162,140,252,140,202,144,117,145,113,146,63,120,252,146,164,149,77,150,5,152,153,153,216,154,59,157,91,82,171,82,247,83,8,84,213,88,247,98,224,111,106,140,95,143,185,158,75,81,59,82,74,84,253,86,64,122,119,145,96,157,210,158,68,115,9,111,112,129,17,117,253,95,218,96,168,154,219,114,188,143,100,107,3,152,202,78,240,86,100,87,190,88,90,90,104,96,199,97,15,102,6,102,57,104,177,104,247,109,213,117,58,125,110,130,66,155,155,78,80,79,201,83,6,85,111,93,230,93,238,93,251,103,153,108,115,116,2,120,80,138,150,147,223,136,80,87,167,94,43,99,181,80,172,80,141,81,0,103,201,84,94,88,187,89,176,91,105,95,77,98,161,99,61,104,115,107,8,110,125,112,199,145,128,114,21,120,38,120,109,121,142,101,48,125,220,131,193,136,9,143,155,150,100,82,40,87,80,103,106,127,161,140,180,81,66,87,42,150,58,88,138,105,180,128,178,84,14,93,252,87,149,120,250,157,92,79,74,82,139,84,62,100,40,102,20,103,245,103,132,122,86,123,34,125,47,147,92,104,173,155,57,123,25,83,138,81,55,82,223,91,246,98,174,100,230,100,45,103,186,107,169,133,209,150,144,118,214,155,76,99,6,147,171,155,191,118,82,102,9,78,152,80,194,83,113,92,232,96,146,100,99,101,95,104,230,113,202,115,35,117,151,123,130,126,149,134,131,139,219,140,120,145,16,153,172,101,171,102,139,107,213,78,212,78,58,79,127,79,58,82,248,83,242,83,227,85,219,86,235,88,203,89,201,89,255,89,80,91,77,92,2,94,43,94,215,95,29,96,7,99,47,101,92,91,175,101,189,101,232,101,157,103,98,107,123,107,15,108,69,115,73,121,193,121,248,124,25,125,43,125,162,128,2,129,243,129,150,137,94,138,105,138,102,138,140,138,238,138,199,140,220,140,204,150,252,152,111,107,139,78,60,79,141,79,80,81,87,91,250,91,72,97,1,99,66,102,33,107,203,110,187,108,62,114,189,116,212,117,193,120,58,121,12,128,51,128,234,129,148,132,158,143,80,108,127,158,15,95,88,139,43,157,250,122,248,142,141,91,235,150,3,78,241,83,247,87,49,89,201,90,164,91,137,96,127,110,6,111,190,117,234,140,159,91,0,133,224,123,114,80,244,103,157,130,97,92,74,133,30,126,14,130,153,81,4,92,104,99,102,141,156,101,110,113,62,121,23,125,5,128,29,139,202,142,110,144,199,134,170,144,31,80,250,82,58,92,83,103,124,112,53,114,76,145,200,145,43,147,229,130,194,91,49,95,249,96,59,78,214,83,136,91,75,98,49,103,138,107,233,114,224,115,46,122,107,129,163,141,82,145,150,153,18,81,215,83,106,84,255,91,136,99,57,106,172,125,0,151,218,86,206,83,104,84,151,91,49,92,222,93,238,79,1,97,254,98,50,109,192,121,203,121,66,125,77,126,210,127,237,129,31,130,144,132,70,136,114,137,144,139,116,142,47,143,49,144,75,145,108,145,198,150,156,145,192,78,79,79,69,81,65,83,147,95,14,98,212,103,65,108,11,110,99,115,38,126,205,145,131,146,212,83,25,89,191,91,209,109,93,121,46,126,155,124,126,88,159,113,250,81,83,136,240,143,202,79,251,92,37,102,172,119,227,122,28,130,255,153,198,81,170,95,236,101,111,105,137,107,243,109,150,110,100,111,254,118,20,125,225,93,117,144,135,145,6,152,230,81,29,82,64,98,145,102,217,102,26,110,182,94,210,125,114,127,248,102,175,133,247,133,248,138,169,82,217,83,115,89,143,94,144,95,85,96,228,146,100,150,183,80,31,81,221,82,32,83,71,83,236,83,232,84,70,85,49,85,23,86,104,89,190,89,60,90,181,91,6,92,15,92,17,92,26,92,132,94,138,94,224,94,112,95,127,98,132,98,219,98,140,99,119,99,7,102,12,102,45,102,118,102,126,103,162,104,31,106,53,106,188,108,136,109,9,110,88,110,60,113,38,113,103,113,199,117,1,119,93,120,1,121,101,121,240,121,224,122,17,123,167,124,57,125,150,128,214,131,139,132,73,133,93,136,243,136,31,138,60,138,84,138,115,138,97,140,222,140,164,145,102,146,126,147,24,148,156,150,152,151,10,78,8,78,30,78,87,78,151,81,112,82,206,87,52,88,204,88,34,91,56,94,197,96,254,100,97,103,86,103,68,109,182,114,115,117,99,122,184,132,114,139,184,145,32,147,49,86,244,87,254,152,237,98,13,105,150,107,237,113,84,126,119,128,114,130,230,137,223,152,85,135,177,143,59,92,56,79,225,79,181,79,7,85,32,90,221,91,233,91,195,95,78,97,47,99,176,101,75,102,238,104,155,105,120,109,241,109,51,117,185,117,31,119,94,121,230,121,51,125,227,129,175,130,170,133,170,137,58,138,171,142,155,143,50,144,221,145,7,151,186,78,193,78,3,82,117,88,236,88,11,92,26,117,61,92,78,129,10,138,197,143,99,150,109,151,37,123,207,138,8,152,98,145,243,86,168,83,23,144,57,84,130,87,37,94,168,99,52,108,138,112,97,119,139,124,224,127,112,136,66,144,84,145,16,147,24,147,143,150,94,116,196,154,7,93,105,93,112,101,162,103,168,141,219,150,110,99,73,103,25,105,197,131,23,152,192,150,254,136,132,111,122,100,248,91,22,78,44,112,93,117,47,102,196,81,54,82,226,82,211,89,129,95,39,96,16,98,63,101,116,101,31,102,116,102,242,104,22,104,99,107,5,110,114,114,31,117,219,118,190,124,86,128,240,88,253,136,127,137,160,138,147,138,203,138,29,144,146,145,82,151,89,151,137,101,14,122,6,129,187,150,45,94,220,96,26,98,165,101,20,102,144,103,243,119,77,122,77,124,62,126,10,129,172,140,100,141,225,141,95,142,169,120,7,82,217,98,165,99,66,100,152,98,45,138,131,122,192,123,172,138,234,150,118,125,12,130,73,135,217,78,72,81,67,83,96,83,163,91,2,92,22,92,221,93,38,98,71,98,176,100,19,104,52,104,201,108,69,109,23,109,211,103,92,111,78,113,125,113,203,101,127,122,173,123,218,125,74,126,168,127,122,129,27,130,57,130,166,133,110,138,206,140,245,141,120,144,119,144,173,146,145,146,131,149,174,155,77,82,132,85,56,111,54,113,104,81,133,121,85,126,179,129,206,124,76,86,81,88,168,92,170,99,254,102,253,102,90,105,217,114,143,117,142,117,14,121,86,121,223,121,151,124,32,125,68,125,7,134,52,138,59,150,97,144,32,159,231,80,117,82,204,83,226,83,9,80,170,85,238,88,79,89,61,114,139,91,100,92,29,83,227,96,243,96,92,99,131,99,63,99,187,99,205,100,233,101,249,102,227,93,205,105,253,105,21,111,229,113,137,78,233,117,248,118,147,122,223,124,207,125,156,125,97,128,73,131,88,131,108,132,188,132,251,133,197,136,112,141,1,144,109,144,151,147,28,151,18,154,207,80,151,88,142,97,211,129,53,133,8,141,32,144,195,79,116,80,71,82,115,83,111,96,73,99,95,103,44,110,179,141,31,144,215,79,94,92,202,140,207,101,154,125,82,83,150,136,118,81,195,99,88,91,107,91,10,92,13,100,81,103,92,144,214,78,26,89,42,89,112,108,81,138,62,85,21,88,165,89,240,96,83,98,193,103,53,130,85,105,64,150,196,153,40,154,83,79,6,88,254,91,16,128,177,92,47,94,133,95,32,96,75,97,52,98,255,102,240,108,222,110,206,128,127,129,212,130,139,136,184,140,0,144,46,144,138,150,219,158,219,155,227,78,240,83,39,89,44,123,141,145,76,152,249,157,221,110,39,112,83,83,68,85,133,91,88,98,158,98,211,98,162,108,239,111,34,116,23,138,56,148,193,111,254,138,56,131,231,81,248,134,234,83,233,83,70,79,84,144,176,143,106,89,49,129,253,93,234,122,191,143,218,104,55,140,248,114,72,156,61,106,176,138,57,78,88,83,6,86,102,87,197,98,162,99,230,101,78,107,225,109,91,110,173,112,237,119,239,122,170,123,187,125,61,128,198,128,203,134,149,138,91,147,227,86,199,88,62,95,173,101,150,102,128,106,181,107,55,117,199,138,36,80,229,119,48,87,27,95,101,96,122,102,96,108,244,117,26,122,110,127,244,129,24,135,69,144,179,153,201,123,92,117,249,122,81,123,196,132,16,144,233,121,146,122,54,131,225,90,64,119,45,78,242,78,153,91,224,95,189,98,60,102,241,103,232,108,107,134,119,136,59,138,78,145,243,146,208,153,23,106,38,112,42,115,231,130,87,132,175,140,1,78,70,81,203,81,139,85,245,91,22,94,51,94,129,94,20,95,53,95,107,95,180,95,242,97,17,99,162,102,29,103,110,111,82,114,58,117,58,119,116,128,57,129,120,129,118,135,191,138,220,138,133,141,243,141,154,146,119,149,2,152,229,156,197,82,87,99,244,118,21,103,136,108,205,115,195,140,174,147,115,150,37,109,156,88,14,105,204,105,253,143,154,147,219,117,26,144,90,88,2,104,180,99,251,105,67,79,44,111,216,103,187,143,38,133,180,125,84,147,63,105,112,111,106,87,247,88,44,91,44,125,42,114,10,84,227,145,180,157,173,78,78,79,92,80,117,80,67,82,158,140,72,84,36,88,154,91,29,94,149,94,173,94,247,94,31,95,140,96,181,98,58,99,208,99,175,104,64,108,135,120,142,121,11,122,224,125,71,130,2,138,230,138,68,142,19,144,184,144,45,145,216,145,14,159,229,108,88,100,226,100,117,101,244,110,132,118,27,123,105,144,209,147,186,110,242,84,185,95,164,100,77,143,237,143,68,146,120,81,107,88,41,89,85,92,151,94,251,109,143,126,28,117,188,140,226,142,91,152,185,112,29,79,191,107,177,111,48,117,251,150,78,81,16,84,53,88,87,88,172,89,96,92,146,95,151,101,92,103,33,110,123,118,223,131,237,140,20,144,253,144,77,147,37,120,58,120,170,82,166,94,31,87,116,89,18,96,18,80,90,81,172,81,205,81,0,82,16,85,84,88,88,88,87,89,149,91,246,92,139,93,188,96,149,98,45,100,113,103,67,104,188,104,223,104,215,118,216,109,111,110,155,109,111,112,200,113,83,95,216,117,119,121,73,123,84,123,82,123,214,124,113,125,48,82,99,132,105,133,228,133,14,138,4,139,70,140,15,142,3,144,15,144,25,148,118,150,45,152,48,154,216,149,205,80,213,82,12,84,2,88,14,92,167,97,158,100,30,109,179,119,229,122,244,128,4,132,83,144,133,146,224,92,7,157,63,83,151,95,179,95,156,109,121,114,99,119,191,121,228,123,210,107,236,114,173,138,3,104,97,106,248,81,129,122,52,105,74,92,246,156,235,130,197,91,73,145,30,112,120,86,111,92,199,96,102,101,140,108,90,140,65,144,19,152,81,84,199,102,13,146,72,89,163,144,133,81,77,78,234,81,153,133,14,139,88,112,122,99,75,147,98,105,180,153,4,126,119,117,87,83,96,105,223,142,227,150,93,108,140,78,60,92,16,95,233,143,2,83,209,140,137,128,121,134,255,94,229,101,115,78,101,81,130,89,63,92,238,151,251,78,138,89,205,95,141,138,225,111,176,121,98,121,231,91,113,132,43,115,177,113,116,94,245,95,123,99,154,100,195,113,152,124,67,78,252,94,75,78,220,87,162,86,169,96,195,111,13,125,253,128,51,129,191,129,178,143,151,137,164,134,244,93,138,98,173,100,135,137,119,103,226,108,62,109,54,116,52,120,70,90,117,127,173,130,172,153,243,79,195,94,221,98,146,99,87,101,111,103,195,118,76,114,204,128,186,128,41,143,77,145,13,80,249,87,146,90,133,104,115,105,100,113,253,114,183,140,242,88,224,140,106,150,25,144,127,135,228,121,231,119,41,132,47,79,101,82,90,83,205,98,207,103,202,108,125,118,148,123,149,124,54,130,132,133,235,143,221,102,32,111,6,114,27,126,171,131,193,153,166,158,253,81,177,123,114,120,184,123,135,128,72,123,232,106,97,94,140,128,81,117,96,117,107,81,98,146,140,110,122,118,151,145,234,154,16,79,112,127,156,98,79,123,165,149,233,156,122,86,89,88,228,134,188,150,52,79,36,82,74,83,205,83,219,83,6,94,44,100,145,101,127,103,62,108,78,108,72,114,175,114,237,115,84,117,65,126,44,130,233,133,169,140,196,123,198,145,105,113,18,152,239,152,61,99,105,102,106,117,228,118,208,120,67,133,238,134,42,83,81,83,38,84,131,89,135,94,124,95,178,96,73,98,121,98,171,98,144,101,212,107,204,108,178,117,174,118,145,120,216,121,203,125,119,127,165,128,171,136,185,138,187,140,127,144,94,151,219,152,11,106,56,124,153,80,62,92,174,95,135,103,216,107,53,116,9,119,142,127,59,159,202,103,23,122,57,83,139,117,237,154,102,95,157,129,241,131,152,128,60,95,197,95,98,117,70,123,60,144,103,104,235,89,155,90,16,125,126,118,44,139,245,79,106,95,25,106,55,108,2,111,226,116,104,121,104,136,85,138,121,140,223,94,207,99,197,117,210,121,215,130,40,147,242,146,156,132,237,134,45,156,193,84,108,95,140,101,92,109,21,112,167,140,211,140,59,152,79,101,246,116,13,78,216,78,224,87,43,89,102,90,204,91,168,81,3,94,156,94,22,96,118,98,119,101,167,101,110,102,110,109,54,114,38,123,80,129,154,129,153,130,92,139,160,140,230,140,116,141,28,150,68,150,174,79,171,100,102,107,30,130,97,132,106,133,232,144,1,92,83,105,168,152,122,132,87,133,15,79,111,82,169,95,69,94,13,103,143,121,121,129,7,137,134,137,245,109,23,95,85,98,184,108,207,78,105,114,146,155,6,82,59,84,116,86,179,88,164,97,110,98,26,113,110,89,137,124,222,124,27,125,240,150,135,101,94,128,25,78,117,79,117,81,64,88,99,94,115,94,10,95,196,103,38,78,61,133,137,149,91,150,115,124,1,152,251,80,193,88,86,118,167,120,37,82,165,119,17,133,134,123,79,80,9,89,71,114,199,123,232,125,186,143,212,143,77,144,191,79,201,82,41,90,1,95,173,151,221,79,23,130,234,146,3,87,85,99,105,107,43,117,220,136,20,143,66,122,223,82,147,88,85,97,10,98,174,102,205,107,63,124,233,131,35,80,248,79,5,83,70,84,49,88,73,89,157,91,240,92,239,92,41,93,150,94,177,98,103,99,62,101,185,101,11,103,213,108,225,108,249,112,50,120,43,126,222,128,179,130,12,132,236,132,2,135,18,137,42,138,74,140,166,144,210,146,253,152,243,156,108,157,79,78,161,78,141,80,86,82,74,87,168,89,61,94,216,95,217,95,63,98,180,102,27,103,208,103,210,104,146,81,33,125,170,128,168,129,0,139,140,140,191,140,126,146,50,150,32,84,44,152,23,83,213,80,92,83,168,88,178,100,52,103,103,114,102,119,70,122,230,145,195,82,161,108,134,107,0,88,76,94,84,89,44,103,251,127,225,81,198,118,105,100,232,120,84,155,187,158,203,87,185,89,39,102,154,103,206,107,233,84,217,105,85,94,156,129,149,103,170,155,254,103,82,156,93,104,166,78,227,79,200,83,185,98,43,103,171,108,196,143,173,79,109,126,191,158,7,78,98,97,128,110,43,111,19,133,115,84,42,103,69,155,243,93,149,123,172,92,198,91,28,135,74,110,209,132,20,122,8,129,153,89,141,124,17,108,32,119,217,82,34,89,33,113,95,114,219,119,39,151,97,157,11,105,127,90,24,90,165,81,13,84,125,84,14,102,223,118,247,143,152,146,244,156,234,89,93,114,197,110,77,81,201,104,191,125,236,125,98,151,186,158,120,100,33,106,2,131,132,89,95,91,219,107,27,115,242,118,178,125,23,128,153,132,50,81,40,103,217,158,238,118,98,103,255,82,5,153,36,92,59,98,126,124,176,140,79,85,182,96,11,125,128,149,1,83,95,78,182,81,28,89,58,114,54,128,206,145,37,95,226,119,132,83,121,95,4,125,172,133,51,138,141,142,86,151,243,103,174,133,83,148,9,97,8,97,185,108,82,118,237,138,56,143,47,85,81,79,42,81,199,82,203,83,165,91,125,94,160,96,130,97,214,99,9,103,218,103,103,110,140,109,54,115,55,115,49,117,80,121,213,136,152,138,74,144,145,144,245,144,196,150,141,135,21,89,136,78,89,79,14,78,137,138,63,143,16,152,173,80,124,94,150,89,185,91,184,94,218,99,250,99,193,100,220,102,74,105,216,105,11,109,182,110,148,113,40,117,175,122,138,127,0,128,73,132,201,132,129,137,33,139,10,142,101,144,125,150,10,153,126,97,145,98,50,107,131,108,116,109,204,127,252,127,192,109,133,127,186,135,248,136,101,103,177,131,60,152,247,150,27,109,97,125,61,132,106,145,113,78,117,83,80,93,4,107,235,111,205,133,45,134,167,137,41,82,15,84,101,92,78,103,168,104,6,116,131,116,226,117,207,136,225,136,204,145,226,150,120,150,139,95,135,115,203,122,78,132,160,99,101,117,137,82,65,109,156,110,9,116,89,117,107,120,146,124,134,150,220,122,141,159,182,79,110,97,197,101,92,134,134,78,174,78,218,80,33,78,204,81,238,91,153,101,129,104,188,109,31,115,66,118,173,119,28,122,231,124,111,130,210,138,124,144,207,145,117,150,24,152,155,82,209,125,43,80,152,83,151,103,203,109,208,113,51,116,232,129,42,143,163,150,87,156,159,158,96,116,65,88,153,109,47,125,94,152,228,78,54,79,139,79,183,81,177,82,186,93,28,96,178,115,60,121,211,130,52,146,183,150,246,150,10,151,151,158,98,159,166,102,116,107,23,82,163,82,200,112,194,136,201,94,75,96,144,97,35,111,73,113,62,124,244,125,111,128,238,132,35,144,44,147,66,84,111,155,211,106,137,112,194,140,239,141,50,151,180,82,65,90,202,94,4,95,23,103,124,105,148,105,106,109,15,111,98,114,252,114,237,123,1,128,126,128,75,135,206,144,109,81,147,158,132,121,139,128,50,147,214,138,45,80,140,84,113,138,106,107,196,140,7,129,209,96,160,103,242,157,153,78,152,78,16,156,107,138,193,133,104,133,0,105,126,110,151,120,85,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,95,16,78,21,78,42,78,49,78,54,78,60,78,63,78,66,78,86,78,88,78,130,78,133,78,107,140,138,78,18,130,13,95,142,78,158,78,159,78,160,78,162,78,176,78,179,78,182,78,206,78,205,78,196,78,198,78,194,78,215,78,222,78,237,78,223,78,247,78,9,79,90,79,48,79,91,79,93,79,87,79,71,79,118,79,136,79,143,79,152,79,123,79,105,79,112,79,145,79,111,79,134,79,150,79,24,81,212,79,223,79,206,79,216,79,219,79,209,79,218,79,208,79,228,79,229,79,26,80,40,80,20,80,42,80,37,80,5,80,28,79,246,79,33,80,41,80,44,80,254,79,239,79,17,80,6,80,67,80,71,80,3,103,85,80,80,80,72,80,90,80,86,80,108,80,120,80,128,80,154,80,133,80,180,80,178,80,201,80,202,80,179,80,194,80,214,80,222,80,229,80,237,80,227,80,238,80,249,80,245,80,9,81,1,81,2,81,22,81,21,81,20,81,26,81,33,81,58,81,55,81,60,81,59,81,63,81,64,81,82,81,76,81,84,81,98,81,248,122,105,81,106,81,110,81,128,81,130,81,216,86,140,81,137,81,143,81,145,81,147,81,149,81,150,81,164,81,166,81,162,81,169,81,170,81,171,81,179,81,177,81,178,81,176,81,181,81,189,81,197,81,201,81,219,81,224,81,85,134,233,81,237,81,240,81,245,81,254,81,4,82,11,82,20,82,14,82,39,82,42,82,46,82,51,82,57,82,79,82,68,82,75,82,76,82,94,82,84,82,106,82,116,82,105,82,115,82,127,82,125,82,141,82,148,82,146,82,113,82,136,82,145,82,168,143,167,143,172,82,173,82,188,82,181,82,193,82,205,82,215,82,222,82,227,82,230,82,237,152,224,82,243,82,245,82,248,82,249,82,6,83,8,83,56,117,13,83,16,83,15,83,21,83,26,83,35,83,47,83,49,83,51,83,56,83,64,83,70,83,69,83,23,78,73,83,77,83,214,81,94,83,105,83,110,83,24,89,123,83,119,83,130,83,150,83,160,83,166,83,165,83,174,83,176,83,182,83,195,83,18,124,217,150,223,83,252,102,238,113,238,83,232,83,237,83,250,83,1,84,61,84,64,84,44,84,45,84,60,84,46,84,54,84,41,84,29,84,78,84,143,84,117,84,142,84,95,84,113,84,119,84,112,84,146,84,123,84,128,84,118,84,132,84,144,84,134,84,199,84,162,84,184,84,165,84,172,84,196,84,200,84,168,84,171,84,194,84,164,84,190,84,188,84,216,84,229,84,230,84,15,85,20,85,253,84,238,84,237,84,250,84,226,84,57,85,64,85,99,85,76,85,46,85,92,85,69,85,86,85,87,85,56,85,51,85,93,85,153,85,128,85,175,84,138,85,159,85,123,85,126,85,152,85,158,85,174,85,124,85,131,85,169,85,135,85,168,85,218,85,197,85,223,85,196,85,220,85,228,85,212,85,20,86,247,85,22,86,254,85,253,85,27,86,249,85,78,86,80,86,223,113,52,86,54,86,50,86,56,86,107,86,100,86,47,86,108,86,106,86,134,86,128,86,138,86,160,86,148,86,143,86,165,86,174,86,182,86,180,86,194,86,188,86,193,86,195,86,192,86,200,86,206,86,209,86,211,86,215,86,238,86,249,86,0,87,255,86,4,87,9,87,8,87,11,87,13,87,19,87,24,87,22,87,199,85,28,87,38,87,55,87,56,87,78,87,59,87,64,87,79,87,105,87,192,87,136,87,97,87,127,87,137,87,147,87,160,87,179,87,164,87,170,87,176,87,195,87,198,87,212,87,210,87,211,87,10,88,214,87,227,87,11,88,25,88,29,88,114,88,33,88,98,88,75,88,112,88,192,107,82,88,61,88,121,88,133,88,185,88,159,88,171,88,186,88,222,88,187,88,184,88,174,88,197,88,211,88,209,88,215,88,217,88,216,88,229,88,220,88,228,88,223,88,239,88,250,88,249,88,251,88,252,88,253,88,2,89,10,89,16,89,27,89,166,104,37,89,44,89,45,89,50,89,56,89,62,89,210,122,85,89,80,89,78,89,90,89,88,89,98,89,96,89,103,89,108,89,105,89,120,89,129,89,157,89,94,79,171,79,163,89,178,89,198,89,232,89,220,89,141,89,217,89,218,89,37,90,31,90,17,90,28,90,9,90,26,90,64,90,108,90,73,90,53,90,54,90,98,90,106,90,154,90,188,90,190,90,203,90,194,90,189,90,227,90,215,90,230,90,233,90,214,90,250,90,251,90,12,91,11,91,22,91,50,91,208,90,42,91,54,91,62,91,67,91,69,91,64,91,81,91,85,91,90,91,91,91,101,91,105,91,112,91,115,91,117,91,120,91,136,101,122,91,128,91,131,91,166,91,184,91,195,91,199,91,201,91,212,91,208,91,228,91,230,91,226,91,222,91,229,91,235,91,240,91,246,91,243,91,5,92,7,92,8,92,13,92,19,92,32,92,34,92,40,92,56,92,57,92,65,92,70,92,78,92,83,92,80,92,79,92,113,91,108,92,110,92,98,78,118,92,121,92,140,92,145,92,148,92,155,89,171,92,187,92,182,92,188,92,183,92,197,92,190,92,199,92,217,92,233,92,253,92,250,92,237,92,140,93,234,92,11,93,21,93,23,93,92,93,31,93,27,93,17,93,20,93,34,93,26,93,25,93,24,93,76,93,82,93,78,93,75,93,108,93,115,93,118,93,135,93,132,93,130,93,162,93,157,93,172,93,174,93,189,93,144,93,183,93,188,93,201,93,205,93,211,93,210,93,214,93,219,93,235,93,242,93,245,93,11,94,26,94,25,94,17,94,27,94,54,94,55,94,68,94,67,94,64,94,78,94,87,94,84,94,95,94,98,94,100,94,71,94,117,94,118,94,122,94,188,158,127,94,160,94,193,94,194,94,200,94,208,94,207,94,214,94,227,94,221,94,218,94,219,94,226,94,225,94,232,94,233,94,236,94,241,94,243,94,240,94,244,94,248,94,254,94,3,95,9,95,93,95,92,95,11,95,17,95,22,95,41,95,45,95,56,95,65,95,72,95,76,95,78,95,47,95,81,95,86,95,87,95,89,95,97,95,109,95,115,95,119,95,131,95,130,95,127,95,138,95,136,95,145,95,135,95,158,95,153,95,152,95,160,95,168,95,173,95,188,95,214,95,251,95,228,95,248,95,241,95,221,95,179,96,255,95,33,96,96,96,25,96,16,96,41,96,14,96,49,96,27,96,21,96,43,96,38,96,15,96,58,96,90,96,65,96,106,96,119,96,95,96,74,96,70,96,77,96,99,96,67,96,100,96,66,96,108,96,107,96,89,96,129,96,141,96,231,96,131,96,154,96,132,96,155,96,150,96,151,96,146,96,167,96,139,96,225,96,184,96,224,96,211,96,180,96,240,95,189,96,198,96,181,96,216,96,77,97,21,97,6,97,246,96,247,96,0,97,244,96,250,96,3,97,33,97,251,96,241,96,13,97,14,97,71,97,62,97,40,97,39,97,74,97,63,97,60,97,44,97,52,97,61,97,66,97,68,97,115,97,119,97,88,97,89,97,90,97,107,97,116,97,111,97,101,97,113,97,95,97,93,97,83,97,117,97,153,97,150,97,135,97,172,97,148,97,154,97,138,97,145,97,171,97,174,97,204,97,202,97,201,97,247,97,200,97,195,97,198,97,186,97,203,97,121,127,205,97,230,97,227,97,246,97,250,97,244,97,255,97,253,97,252,97,254,97,0,98,8,98,9,98,13,98,12,98,20,98,27,98,30,98,33,98,42,98,46,98,48,98,50,98,51,98,65,98,78,98,94,98,99,98,91,98,96,98,104,98,124,98,130,98,137,98,126,98,146,98,147,98,150,98,212,98,131,98,148,98,215,98,209,98,187,98,207,98,255,98,198,98,212,100,200,98,220,98,204,98,202,98,194,98,199,98,155,98,201,98,12,99,238,98,241,98,39,99,2,99,8,99,239,98,245,98,80,99,62,99,77,99,28,100,79,99,150,99,142,99,128,99,171,99,118,99,163,99,143,99,137,99,159,99,181,99,107,99,105,99,190,99,233,99,192,99,198,99,227,99,201,99,210,99,246,99,196,99,22,100,52,100,6,100,19,100,38,100,54,100,29,101,23,100,40,100,15,100,103,100,111,100,118,100,78,100,42,101,149,100,147,100,165,100,169,100,136,100,188,100,218,100,210,100,197,100,199,100,187,100,216,100,194,100,241,100,231,100,9,130,224,100,225,100,172,98,227,100,239,100,44,101,246,100,244,100,242,100,250,100,0,101,253,100,24,101,28,101,5,101,36,101,35,101,43,101,52,101,53,101,55,101,54,101,56,101,75,117,72,101,86,101,85,101,77,101,88,101,94,101,93,101,114,101,120,101,130,101,131,101,138,139,155,101,159,101,171,101,183,101,195,101,198,101,193,101,196,101,204,101,210,101,219,101,217,101,224,101,225,101,241,101,114,103,10,102,3,102,251,101,115,103,53,102,54,102,52,102,28,102,79,102,68,102,73,102,65,102,94,102,93,102,100,102,103,102,104,102,95,102,98,102,112,102,131,102,136,102,142,102,137,102,132,102,152,102,157,102,193,102,185,102,201,102,190,102,188,102,196,102,184,102,214,102,218,102,224,102,63,102,230,102,233,102,240,102,245,102,247,102,15,103,22,103,30,103,38,103,39,103,56,151,46,103,63,103,54,103,65,103,56,103,55,103,70,103,94,103,96,103,89,103,99,103,100,103,137,103,112,103,169,103,124,103,106,103,140,103,139,103,166,103,161,103,133,103,183,103,239,103,180,103,236,103,179,103,233,103,184,103,228,103,222,103,221,103,226,103,238,103,185,103,206,103,198,103,231,103,156,106,30,104,70,104,41,104,64,104,77,104,50,104,78,104,179,104,43,104,89,104,99,104,119,104,127,104,159,104,143,104,173,104,148,104,157,104,155,104,131,104,174,106,185,104,116,104,181,104,160,104,186,104,15,105,141,104,126,104,1,105,202,104,8,105,216,104,34,105,38,105,225,104,12,105,205,104,212,104,231,104,213,104,54,105,18,105,4,105,215,104,227,104,37,105,249,104,224,104,239,104,40,105,42,105,26,105,35,105,33,105,198,104,121,105,119,105,92,105,120,105,107,105,84,105,126,105,110,105,57,105,116,105,61,105,89,105,48,105,97,105,94,105,93,105,129,105,106,105,178,105,174,105,208,105,191,105,193,105,211,105,190,105,206,105,232,91,202,105,221,105,187,105,195,105,167,105,46,106,145,105,160,105,156,105,149,105,180,105,222,105,232,105,2,106,27,106,255,105,10,107,249,105,242,105,231,105,5,106,177,105,30,106,237,105,20,106,235,105,10,106,18,106,193,106,35,106,19,106,68,106,12,106,114,106,54,106,120,106,71,106,98,106,89,106,102,106,72,106,56,106,34,106,144,106,141,106,160,106,132,106,162,106,163,106,151,106,23,134,187,106,195,106,194,106,184,106,179,106,172,106,222,106,209,106,223,106,170,106,218,106,234,106,251,106,5,107,22,134,250,106,18,107,22,107,49,155,31,107,56,107,55,107,220,118,57,107,238,152,71,107,67,107,73,107,80,107,89,107,84,107,91,107,95,107,97,107,120,107,121,107,127,107,128,107,132,107,131,107,141,107,152,107,149,107,158,107,164,107,170,107,171,107,175,107,178,107,177,107,179,107,183,107,188,107,198,107,203,107,211,107,223,107,236,107,235,107,243,107,239,107,190,158,8,108,19,108,20,108,27,108,36,108,35,108,94,108,85,108,98,108,106,108,130,108,141,108,154,108,129,108,155,108,126,108,104,108,115,108,146,108,144,108,196,108,241,108,211,108,189,108,215,108,197,108,221,108,174,108,177,108,190,108,186,108,219,108,239,108,217,108,234,108,31,109,77,136,54,109,43,109,61,109,56,109,25,109,53,109,51,109,18,109,12,109,99,109,147,109,100,109,90,109,121,109,89,109,142,109,149,109,228,111,133,109,249,109,21,110,10,110,181,109,199,109,230,109,184,109,198,109,236,109,222,109,204,109,232,109,210,109,197,109,250,109,217,109,228,109,213,109,234,109,238,109,45,110,110,110,46,110,25,110,114,110,95,110,62,110,35,110,107,110,43,110,118,110,77,110,31,110,67,110,58,110,78,110,36,110,255,110,29,110,56,110,130,110,170,110,152,110,201,110,183,110,211,110,189,110,175,110,196,110,178,110,212,110,213,110,143,110,165,110,194,110,159,110,65,111,17,111,76,112,236,110,248,110,254,110,63,111,242,110,49,111,239,110,50,111,204,110,62,111,19,111,247,110,134,111,122,111,120,111,129,111,128,111,111,111,91,111,243,111,109,111,130,111,124,111,88,111,142,111,145,111,194,111,102,111,179,111,163,111,161,111,164,111,185,111,198,111,170,111,223,111,213,111,236,111,212,111,216,111,241,111,238,111,219,111,9,112,11,112,250,111,17,112,1,112,15,112,254,111,27,112,26,112,116,111,29,112,24,112,31,112,48,112,62,112,50,112,81,112,99,112,153,112,146,112,175,112,241,112,172,112,184,112,179,112,174,112,223,112,203,112,221,112,217,112,9,113,253,112,28,113,25,113,101,113,85,113,136,113,102,113,98,113,76,113,86,113,108,113,143,113,251,113,132,113,149,113,168,113,172,113,215,113,185,113,190,113,210,113,201,113,212,113,206,113,224,113,236,113,231,113,245,113,252,113,249,113,255,113,13,114,16,114,27,114,40,114,45,114,44,114,48,114,50,114,59,114,60,114,63,114,64,114,70,114,75,114,88,114,116,114,126,114,130,114,129,114,135,114,146,114,150,114,162,114,167,114,185,114,178,114,195,114,198,114,196,114,206,114,210,114,226,114,224,114,225,114,249,114,247,114,15,80,23,115,10,115,28,115,22,115,29,115,52,115,47,115,41,115,37,115,62,115,78,115,79,115,216,158,87,115,106,115,104,115,112,115,120,115,117,115,123,115,122,115,200,115,179,115,206,115,187,115,192,115,229,115,238,115,222,115,162,116,5,116,111,116,37,116,248,115,50,116,58,116,85,116,63,116,95,116,89,116,65,116,92,116,105,116,112,116,99,116,106,116,118,116,126,116,139,116,158,116,167,116,202,116,207,116,212,116,241,115,224,116,227,116,231,116,233,116,238,116,242,116,240,116,241,116,248,116,247,116,4,117,3,117,5,117,12,117,14,117,13,117,21,117,19,117,30,117,38,117,44,117,60,117,68,117,77,117,74,117,73,117,91,117,70,117,90,117,105,117,100,117,103,117,107,117,109,117,120,117,118,117,134,117,135,117,116,117,138,117,137,117,130,117,148,117,154,117,157,117,165,117,163,117,194,117,179,117,195,117,181,117,189,117,184,117,188,117,177,117,205,117,202,117,210,117,217,117,227,117,222,117,254,117,255,117,252,117,1,118,240,117,250,117,242,117,243,117,11,118,13,118,9,118,31,118,39,118,32,118,33,118,34,118,36,118,52,118,48,118,59,118,71,118,72,118,70,118,92,118,88,118,97,118,98,118,104,118,105,118,106,118,103,118,108,118,112,118,114,118,118,118,120,118,124,118,128,118,131,118,136,118,139,118,142,118,150,118,147,118,153,118,154,118,176,118,180,118,184,118,185,118,186,118,194,118,205,118,214,118,210,118,222,118,225,118,229,118,231,118,234,118,47,134,251,118,8,119,7,119,4,119,41,119,36,119,30,119,37,119,38,119,27,119,55,119,56,119,71,119,90,119,104,119,107,119,91,119,101,119,127,119,126,119,121,119,142,119,139,119,145,119,160,119,158,119,176,119,182,119,185,119,191,119,188,119,189,119,187,119,199,119,205,119,215,119,218,119,220,119,227,119,238,119,252,119,12,120,18,120,38,121,32,120,42,121,69,120,142,120,116,120,134,120,124,120,154,120,140,120,163,120,181,120,170,120,175,120,209,120,198,120,203,120,212,120,190,120,188,120,197,120,202,120,236,120,231,120,218,120,253,120,244,120,7,121,18,121,17,121,25,121,44,121,43,121,64,121,96,121,87,121,95,121,90,121,85,121,83,121,122,121,127,121,138,121,157,121,167,121,75,159,170,121,174,121,179,121,185,121,186,121,201,121,213,121,231,121,236,121,225,121,227,121,8,122,13,122,24,122,25,122,32,122,31,122,128,121,49,122,59,122,62,122,55,122,67,122,87,122,73,122,97,122,98,122,105,122,157,159,112,122,121,122,125,122,136,122,151,122,149,122,152,122,150,122,169,122,200,122,176,122,182,122,197,122,196,122,191,122,131,144,199,122,202,122,205,122,207,122,213,122,211,122,217,122,218,122,221,122,225,122,226,122,230,122,237,122,240,122,2,123,15,123,10,123,6,123,51,123,24,123,25,123,30,123,53,123,40,123,54,123,80,123,122,123,4,123,77,123,11,123,76,123,69,123,117,123,101,123,116,123,103,123,112,123,113,123,108,123,110,123,157,123,152,123,159,123,141,123,156,123,154,123,139,123,146,123,143,123,93,123,153,123,203,123,193,123,204,123,207,123,180,123,198,123,221,123,233,123,17,124,20,124,230,123,229,123,96,124,0,124,7,124,19,124,243,123,247,123,23,124,13,124,246,123,35,124,39,124,42,124,31,124,55,124,43,124,61,124,76,124,67,124,84,124,79,124,64,124,80,124,88,124,95,124,100,124,86,124,101,124,108,124,117,124,131,124,144,124,164,124,173,124,162,124,171,124,161,124,168,124,179,124,178,124,177,124,174,124,185,124,189,124,192,124,197,124,194,124,216,124,210,124,220,124,226,124,59,155,239,124,242,124,244,124,246,124,250,124,6,125,2,125,28,125,21,125,10,125,69,125,75,125,46,125,50,125,63,125,53,125,70,125,115,125,86,125,78,125,114,125,104,125,110,125,79,125,99,125,147,125,137,125,91,125,143,125,125,125,155,125,186,125,174,125,163,125,181,125,199,125,189,125,171,125,61,126,162,125,175,125,220,125,184,125,159,125,176,125,216,125,221,125,228,125,222,125,251,125,242,125,225,125,5,126,10,126,35,126,33,126,18,126,49,126,31,126,9,126,11,126,34,126,70,126,102,126,59,126,53,126,57,126,67,126,55,126,50,126,58,126,103,126,93,126,86,126,94,126,89,126,90,126,121,126,106,126,105,126,124,126,123,126,131,126,213,125,125,126,174,143,127,126,136,126,137,126,140,126,146,126,144,126,147,126,148,126,150,126,142,126,155,126,156,126,56,127,58,127,69,127,76,127,77,127,78,127,80,127,81,127,85,127,84,127,88,127,95,127,96,127,104,127,105,127,103,127,120,127,130,127,134,127,131,127,136,127,135,127,140,127,148,127,158,127,157,127,154,127,163,127,175,127,178,127,185,127,174,127,182,127,184,127,113,139,197,127,198,127,202,127,213,127,212,127,225,127,230,127,233,127,243,127,249,127,220,152,6,128,4,128,11,128,18,128,24,128,25,128,28,128,33,128,40,128,63,128,59,128,74,128,70,128,82,128,88,128,90,128,95,128,98,128,104,128,115,128,114,128,112,128,118,128,121,128,125,128,127,128,132,128,134,128,133,128,155,128,147,128,154,128,173,128,144,81,172,128,219,128,229,128,217,128,221,128,196,128,218,128,214,128,9,129,239,128,241,128,27,129,41,129,35,129,47,129,75,129,139,150,70,129,62,129,83,129,81,129,252,128,113,129,110,129,101,129,102,129,116,129,131,129,136,129,138,129,128,129,130,129,160,129,149,129,164,129,163,129,95,129,147,129,169,129,176,129,181,129,190,129,184,129,189,129,192,129,194,129,186,129,201,129,205,129,209,129,217,129,216,129,200,129,218,129,223,129,224,129,231,129,250,129,251,129,254,129,1,130,2,130,5,130,7,130,10,130,13,130,16,130,22,130,41,130,43,130,56,130,51,130,64,130,89,130,88,130,93,130,90,130,95,130,100,130,98,130,104,130,106,130,107,130,46,130,113,130,119,130,120,130,126,130,141,130,146,130,171,130,159,130,187,130,172,130,225,130,227,130,223,130,210,130,244,130,243,130,250,130,147,131,3,131,251,130,249,130,222,130,6,131,220,130,9,131,217,130,53,131,52,131,22,131,50,131,49,131,64,131,57,131,80,131,69,131,47,131,43,131,23,131,24,131,133,131,154,131,170,131,159,131,162,131,150,131,35,131,142,131,135,131,138,131,124,131,181,131,115,131,117,131,160,131,137,131,168,131,244,131,19,132,235,131,206,131,253,131,3,132,216,131,11,132,193,131,247,131,7,132,224,131,242,131,13,132,34,132,32,132,189,131,56,132,6,133,251,131,109,132,42,132,60,132,90,133,132,132,119,132,107,132,173,132,110,132,130,132,105,132,70,132,44,132,111,132,121,132,53,132,202,132,98,132,185,132,191,132,159,132,217,132,205,132,187,132,218,132,208,132,193,132,198,132,214,132,161,132,33,133,255,132,244,132,23,133,24,133,44,133,31,133,21,133,20,133,252,132,64,133,99,133,88,133,72,133,65,133,2,134,75,133,85,133,128,133,164,133,136,133,145,133,138,133,168,133,109,133,148,133,155,133,234,133,135,133,156,133,119,133,126,133,144,133,201,133,186,133,207,133,185,133,208,133,213,133,221,133,229,133,220,133,249,133,10,134,19,134,11,134,254,133,250,133,6,134,34,134,26,134,48,134,63,134,77,134,85,78,84,134,95,134,103,134,113,134,147,134,163,134,169,134,170,134,139,134,140,134,182,134,175,134,196,134,198,134,176,134,201,134,35,136,171,134,212,134,222,134,233,134,236,134,223,134,219,134,239,134,18,135,6,135,8,135,0,135,3,135,251,134,17,135,9,135,13,135,249,134,10,135,52,135,63,135,55,135,59,135,37,135,41,135,26,135,96,135,95,135,120,135,76,135,78,135,116,135,87,135,104,135,110,135,89,135,83,135,99,135,106,135,5,136,162,135,159,135,130,135,175,135,203,135,189,135,192,135,208,135,214,150,171,135,196,135,179,135,199,135,198,135,187,135,239,135,242,135,224,135,15,136,13,136,254,135,246,135,247,135,14,136,210,135,17,136,22,136,21,136,34,136,33,136,49,136,54,136,57,136,39,136,59,136,68,136,66,136,82,136,89,136,94,136,98,136,107,136,129,136,126,136,158,136,117,136,125,136,181,136,114,136,130,136,151,136,146,136,174,136,153,136,162,136,141,136,164,136,176,136,191,136,177,136,195,136,196,136,212,136,216,136,217,136,221,136,249,136,2,137,252,136,244,136,232,136,242,136,4,137,12,137,10,137,19,137,67,137,30,137,37,137,42,137,43,137,65,137,68,137,59,137,54,137,56,137,76,137,29,137,96,137,94,137,102,137,100,137,109,137,106,137,111,137,116,137,119,137,126,137,131,137,136,137,138,137,147,137,152,137,161,137,169,137,166,137,172,137,175,137,178,137,186,137,189,137,191,137,192,137,218,137,220,137,221,137,231,137,244,137,248,137,3,138,22,138,16,138,12,138,27,138,29,138,37,138,54,138,65,138,91,138,82,138,70,138,72,138,124,138,109,138,108,138,98,138,133,138,130,138,132,138,168,138,161,138,145,138,165,138,166,138,154,138,163,138,196,138,205,138,194,138,218,138,235,138,243,138,231,138,228,138,241,138,20,139,224,138,226,138,247,138,222,138,219,138,12,139,7,139,26,139,225,138,22,139,16,139,23,139,32,139,51,139,171,151,38,139,43,139,62,139,40,139,65,139,76,139,79,139,78,139,73,139,86,139,91,139,90,139,107,139,95,139,108,139,111,139,116,139,125,139,128,139,140,139,142,139,146,139,147,139,150,139,153,139,154,139,58,140,65,140,63,140,72,140,76,140,78,140,80,140,85,140,98,140,108,140,120,140,122,140,130,140,137,140,133,140,138,140,141,140,142,140,148,140,124,140,152,140,29,98,173,140,170,140,189,140,178,140,179,140,174,140,182,140,200,140,193,140,228,140,227,140,218,140,253,140,250,140,251,140,4,141,5,141,10,141,7,141,15,141,13,141,16,141,78,159,19,141,205,140,20,141,22,141,103,141,109,141,113,141,115,141,129,141,153,141,194,141,190,141,186,141,207,141,218,141,214,141,204,141,219,141,203,141,234,141,235,141,223,141,227,141,252,141,8,142,9,142,255,141,29,142,30,142,16,142,31,142,66,142,53,142,48,142,52,142,74,142,71,142,73,142,76,142,80,142,72,142,89,142,100,142,96,142,42,142,99,142,85,142,118,142,114,142,124,142,129,142,135,142,133,142,132,142,139,142,138,142,147,142,145,142,148,142,153,142,170,142,161,142,172,142,176,142,198,142,177,142,190,142,197,142,200,142,203,142,219,142,227,142,252,142,251,142,235,142,254,142,10,143,5,143,21,143,18,143,25,143,19,143,28,143,31,143,27,143,12,143,38,143,51,143,59,143,57,143,69,143,66,143,62,143,76,143,73,143,70,143,78,143,87,143,92,143,98,143,99,143,100,143,156,143,159,143,163,143,173,143,175,143,183,143,218,143,229,143,226,143,234,143,239,143,135,144,244,143,5,144,249,143,250,143,17,144,21,144,33,144,13,144,30,144,22,144,11,144,39,144,54,144,53,144,57,144,248,143,79,144,80,144,81,144,82,144,14,144,73,144,62,144,86,144,88,144,94,144,104,144,111,144,118,144,168,150,114,144,130,144,125,144,129,144,128,144,138,144,137,144,143,144,168,144,175,144,177,144,181,144,226,144,228,144,72,98,219,144,2,145,18,145,25,145,50,145,48,145,74,145,86,145,88,145,99,145,101,145,105,145,115,145,114,145,139,145,137,145,130,145,162,145,171,145,175,145,170,145,181,145,180,145,186,145,192,145,193,145,201,145,203,145,208,145,214,145,223,145,225,145,219,145,252,145,245,145,246,145,30,146,255,145,20,146,44,146,21,146,17,146,94,146,87,146,69,146,73,146,100,146,72,146,149,146,63,146,75,146,80,146,156,146,150,146,147,146,155,146,90,146,207,146,185,146,183,146,233,146,15,147,250,146,68,147,46,147,25,147,34,147,26,147,35,147,58,147,53,147,59,147,92,147,96,147,124,147,110,147,86,147,176,147,172,147,173,147,148,147,185,147,214,147,215,147,232,147,229,147,216,147,195,147,221,147,208,147,200,147,228,147,26,148,20,148,19,148,3,148,7,148,16,148,54,148,43,148,53,148,33,148,58,148,65,148,82,148,68,148,91,148,96,148,98,148,94,148,106,148,41,146,112,148,117,148,119,148,125,148,90,148,124,148,126,148,129,148,127,148,130,149,135,149,138,149,148,149,150,149,152,149,153,149,160,149,168,149,167,149,173,149,188,149,187,149,185,149,190,149,202,149,246,111,195,149,205,149,204,149,213,149,212,149,214,149,220,149,225,149,229,149,226,149,33,150,40,150,46,150,47,150,66,150,76,150,79,150,75,150,119,150,92,150,94,150,93,150,95,150,102,150,114,150,108,150,141,150,152,150,149,150,151,150,170,150,167,150,177,150,178,150,176,150,180,150,182,150,184,150,185,150,206,150,203,150,201,150,205,150,77,137,220,150,13,151,213,150,249,150,4,151,6,151,8,151,19,151,14,151,17,151,15,151,22,151,25,151,36,151,42,151,48,151,57,151,61,151,62,151,68,151,70,151,72,151,66,151,73,151,92,151,96,151,100,151,102,151,104,151,210,82,107,151,113,151,121,151,133,151,124,151,129,151,122,151,134,151,139,151,143,151,144,151,156,151,168,151,166,151,163,151,179,151,180,151,195,151,198,151,200,151,203,151,220,151,237,151,79,159,242,151,223,122,246,151,245,151,15,152,12,152,56,152,36,152,33,152,55,152,61,152,70,152,79,152,75,152,107,152,111,152,112,152,113,152,116,152,115,152,170,152,175,152,177,152,182,152,196,152,195,152,198,152,233,152,235,152,3,153,9,153,18,153,20,153,24,153,33,153,29,153,30,153,36,153,32,153,44,153,46,153,61,153,62,153,66,153,73,153,69,153,80,153,75,153,81,153,82,153,76,153,85,153,151,153,152,153,165,153,173,153,174,153,188,153,223,153,219,153,221,153,216,153,209,153,237,153,238,153,241,153,242,153,251,153,248,153,1,154,15,154,5,154,226,153,25,154,43,154,55,154,69,154,66,154,64,154,67,154,62,154,85,154,77,154,91,154,87,154,95,154,98,154,101,154,100,154,105,154,107,154,106,154,173,154,176,154,188,154,192,154,207,154,209,154,211,154,212,154,222,154,223,154,226,154,227,154,230,154,239,154,235,154,238,154,244,154,241,154,247,154,251,154,6,155,24,155,26,155,31,155,34,155,35,155,37,155,39,155,40,155,41,155,42,155,46,155,47,155,50,155,68,155,67,155,79,155,77,155,78,155,81,155,88,155,116,155,147,155,131,155,145,155,150,155,151,155,159,155,160,155,168,155,180,155,192,155,202,155,185,155,198,155,207,155,209,155,210,155,227,155,226,155,228,155,212,155,225,155,58,156,242,155,241,155,240,155,21,156,20,156,9,156,19,156,12,156,6,156,8,156,18,156,10,156,4,156,46,156,27,156,37,156,36,156,33,156,48,156,71,156,50,156,70,156,62,156,90,156,96,156,103,156,118,156,120,156,231,156,236,156,240,156,9,157,8,157,235,156,3,157,6,157,42,157,38,157,175,157,35,157,31,157,68,157,21,157,18,157,65,157,63,157,62,157,70,157,72,157,93,157,94,157,100,157,81,157,80,157,89,157,114,157,137,157,135,157,171,157,111,157,122,157,154,157,164,157,169,157,178,157,196,157,193,157,187,157,184,157,186,157,198,157,207,157,194,157,217,157,211,157,248,157,230,157,237,157,239,157,253,157,26,158,27,158,30,158,117,158,121,158,125,158,129,158,136,158,139,158,140,158,146,158,149,158,145,158,157,158,165,158,169,158,184,158,170,158,173,158,97,151,204,158,206,158,207,158,208,158,212,158,220,158,222,158,221,158,224,158,229,158,232,158,239,158,244,158,246,158,247,158,249,158,251,158,252,158,253,158,7,159,8,159,183,118,21,159,33,159,44,159,62,159,74,159,82,159,84,159,99,159,95,159,96,159,97,159,102,159,103,159,108,159,106,159,119,159,114,159,118,159,149,159,156,159,160,159,47,88,199,105,89,144,100,116,220,81,153,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,78,4,78,5,78,6,78,15,78,18,78,23,78,31,78,32,78,33,78,35,78,38,78,41,78,46,78,47,78,49,78,51,78,53,78,55,78,60,78,64,78,65,78,66,78,68,78,70,78,74,78,81,78,85,78,87,78,90,78,91,78,98,78,99,78,100,78,101,78,103,78,104,78,106,78,107,78,108,78,109,78,110,78,111,78,114,78,116,78,117,78,118,78,119,78,120,78,121,78,122,78,123,78,124,78,125,78,127,78,128,78,129,78,130,78,131,78,132,78,133,78,135,78,138,78,144,78,150,78,151,78,153,78,156,78,157,78,158,78,163,78,170,78,175,78,176,78,177,78,180,78,182,78,183,78,184,78,185,78,188,78,189,78,190,78,200,78,204,78,207,78,208,78,210,78,218,78,219,78,220,78,224,78,226,78,230,78,231,78,233,78,237,78,238,78,239,78,241,78,244,78,248,78,249,78,250,78,252,78,254,78,0,79,2,79,3,79,4,79,5,79,6,79,7,79,8,79,11,79,12,79,18,79,19,79,20,79,21,79,22,79,28,79,29,79,33,79,35,79,40,79,41,79,44,79,45,79,46,79,49,79,51,79,53,79,55,79,57,79,59,79,62,79,63,79,64,79,65,79,66,79,68,79,69,79,71,79,72,79,73,79,74,79,75,79,76,79,82,79,84,79,86,79,97,79,98,79,102,79,104,79,106,79,107,79,109,79,110,79,113,79,114,79,117,79,119,79,120,79,121,79,122,79,125,79,128,79,129,79,130,79,133,79,134,79,135,79,138,79,140,79,142,79,144,79,146,79,147,79,149,79,150,79,152,79,153,79,154,79,156,79,158,79,159,79,161,79,162,79,164,79,171,79,173,79,176,79,177,79,178,79,179,79,180,79,182,79,183,79,184,79,185,79,186,79,187,79,188,79,189,79,190,79,192,79,193,79,194,79,198,79,199,79,200,79,201,79,203,79,204,79,205,79,210,79,211,79,212,79,213,79,214,79,217,79,219,79,224,79,226,79,228,79,229,79,231,79,235,79,236,79,240,79,242,79,244,79,245,79,246,79,247,79,249,79,251,79,252,79,253,79,255,79,0,80,1,80,2,80,3,80,4,80,5,80,6,80,7,80,8,80,9,80,10,80,11,80,14,80,16,80,17,80,19,80,21,80,22,80,23,80,27,80,29,80,30,80,32,80,34,80,35,80,36,80,39,80,43,80,47,80,48,80,49,80,50,80,51,80,52,80,53,80,54,80,55,80,56,80,57,80,59,80,61,80,63,80,64,80,65,80,66,80,68,80,69,80,70,80,73,80,74,80,75,80,77,80,80,80,81,80,82,80,83,80,84,80,86,80,87,80,88,80,89,80,91,80,93,80,94,80,95,80,96,80,97,80,98,80,99,80,100,80,102,80,103,80,104,80,105,80,106,80,107,80,109,80,110,80,111,80,112,80,113,80,114,80,115,80,116,80,117,80,120,80,121,80,122,80,124,80,125,80,129,80,130,80,131,80,132,80,134,80,135,80,137,80,138,80,139,80,140,80,142,80,143,80,144,80,145,80,146,80,147,80,148,80,149,80,150,80,151,80,152,80,153,80,154,80,155,80,156,80,157,80,158,80,159,80,160,80,161,80,162,80,164,80,166,80,170,80,171,80,173,80,174,80,175,80,176,80,177,80,179,80,180,80,181,80,182,80,183,80,184,80,185,80,188,80,189,80,190,80,191,80,192,80,193,80,194,80,195,80,196,80,197,80,198,80,199,80,200,80,201,80,202,80,203,80,204,80,205,80,206,80,208,80,209,80,210,80,211,80,212,80,213,80,215,80,216,80,217,80,219,80,220,80,221,80,222,80,223,80,224,80,225,80,226,80,227,80,228,80,229,80,232,80,233,80,234,80,235,80,239,80,240,80,241,80,242,80,244,80,246,80,247,80,248,80,249,80,250,80,252,80,253,80,254,80,255,80,0,81,1,81,2,81,3,81,4,81,5,81,8,81,9,81,10,81,12,81,13,81,14,81,15,81,16,81,17,81,19,81,20,81,21,81,22,81,23,81,24,81,25,81,26,81,27,81,28,81,29,81,30,81,31,81,32,81,34,81,35,81,36,81,37,81,38,81,39,81,40,81,41,81,42,81,43,81,44,81,45,81,46,81,47,81,48,81,49,81,50,81,51,81,52,81,53,81,54,81,55,81,56,81,57,81,58,81,59,81,60,81,61,81,62,81,66,81,71,81,74,81,76,81,78,81,79,81,80,81,82,81,83,81,87,81,88,81,89,81,91,81,93,81,94,81,95,81,96,81,97,81,99,81,100,81,102,81,103,81,105,81,106,81,111,81,114,81,122,81,126,81,127,81,131,81,132,81,134,81,135,81,138,81,139,81,142,81,143,81,144,81,145,81,147,81,148,81,152,81,154,81,157,81,158,81,159,81,161,81,163,81,166,81,167,81,168,81,169,81,170,81,173,81,174,81,180,81,184,81,185,81,186,81,190,81,191,81,193,81,194,81,195,81,197,81,200,81,202,81,205,81,206,81,208,81,210,81,211,81,212,81,213,81,214,81,215,81,216,81,217,81,218,81,220,81,222,81,223,81,226,81,227,81,229,81,230,81,231,81,232,81,233,81,234,81,236,81,238,81,241,81,242,81,244,81,247,81,254,81,4,82,5,82,9,82,11,82,12,82,15,82,16,82,19,82,20,82,21,82,28,82,30,82,31,82,33,82,34,82,35,82,37,82,38,82,39,82,42,82,44,82,47,82,49,82,50,82,52,82,53,82,60,82,62,82,68,82,69,82,70,82,71,82,72,82,73,82,75,82,78,82,79,82,82,82,83,82,85,82,87,82,88,82,89,82,90,82,91,82,93,82,95,82,96,82,98,82,99,82,100,82,102,82,104,82,107,82,108,82,109,82,110,82,112,82,113,82,115,82,116,82,117,82,118,82,119,82,120,82,121,82,122,82,123,82,124,82,126,82,128,82,131,82,132,82,133,82,134,82,135,82,137,82,138,82,139,82,140,82,141,82,142,82,143,82,145,82,146,82,148,82,149,82,150,82,151,82,152,82,153,82,154,82,156,82,164,82,165,82,166,82,167,82,174,82,175,82,176,82,180,82,181,82,182,82,183,82,184,82,185,82,186,82,187,82,188,82,189,82,192,82,193,82,194,82,196,82,197,82,198,82,200,82,202,82,204,82,205,82,206,82,207,82,209,82,211,82,212,82,213,82,215,82,217,82,218,82,219,82,220,82,221,82,222,82,224,82,225,82,226,82,227,82,229,82,230,82,231,82,232,82,233,82,234,82,235,82,236,82,237,82,238,82,239,82,241,82,242,82,243,82,244,82,245,82,246,82,247,82,248,82,251,82,252,82,253,82,1,83,2,83,3,83,4,83,7,83,9,83,10,83,11,83,12,83,14,83,17,83,18,83,19,83,20,83,24,83,27,83,28,83,30,83,31,83,34,83,36,83,37,83,39,83,40,83,41,83,43,83,44,83,45,83,47,83,48,83,49,83,50,83,51,83,52,83,53,83,54,83,55,83,56,83,60,83,61,83,64,83,66,83,68,83,70,83,75,83,76,83,77,83,80,83,84,83,88,83,89,83,91,83,93,83,101,83,104,83,106,83,108,83,109,83,114,83,118,83,121,83,123,83,124,83,125,83,126,83,128,83,129,83,131,83,135,83,136,83,138,83,142,83,143,83,144,83,145,83,146,83,147,83,148,83,150,83,151,83,153,83,155,83,156,83,158,83,160,83,161,83,164,83,167,83,170,83,171,83,172,83,173,83,175,83,176,83,177,83,178,83,179,83,180,83,181,83,183,83,184,83,185,83,186,83,188,83,189,83,190,83,192,83,195,83,196,83,197,83,198,83,199,83,206,83,207,83,208,83,210,83,211,83,213,83,218,83,220,83,221,83,222,83,225,83,226,83,231,83,244,83,250,83,254,83,255,83,0,84,2,84,5,84,7,84,11,84,20,84,24,84,25,84,26,84,28,84,34,84,36,84,37,84,42,84,48,84,51,84,54,84,55,84,58,84,61,84,63,84,65,84,66,84,68,84,69,84,71,84,73,84,76,84,77,84,78,84,79,84,81,84,90,84,93,84,94,84,95,84,96,84,97,84,99,84,101,84,103,84,105,84,106,84,107,84,108,84,109,84,110,84,111,84,112,84,116,84,121,84,122,84,126,84,127,84,129,84,131,84,133,84,135,84,136,84,137,84,138,84,141,84,145,84,147,84,151,84,152,84,156,84,158,84,159,84,160,84,161,84,162,84,165,84,174,84,176,84,178,84,181,84,182,84,183,84,185,84,186,84,188,84,190,84,195,84,197,84,202,84,203,84,214,84,216,84,219,84,224,84,225,84,226,84,227,84,228,84,235,84,236,84,239,84,240,84,241,84,244,84,245,84,246,84,247,84,248,84,249,84,251,84,254,84,0,85,2,85,3,85,4,85,5,85,8,85,10,85,11,85,12,85,13,85,14,85,18,85,19,85,21,85,22,85,23,85,24,85,25,85,26,85,28,85,29,85,30,85,31,85,33,85,37,85,38,85,40,85,41,85,43,85,45,85,50,85,52,85,53,85,54,85,56,85,57,85,58,85,59,85,61,85,64,85,66,85,69,85,71,85,72,85,75,85,76,85,77,85,78,85,79,85,81,85,82,85,83,85,84,85,87,85,88,85,89,85,90,85,91,85,93,85,94,85,95,85,96,85,98,85,99,85,104,85,105,85,107,85,111,85,112,85,113,85,114,85,115,85,116,85,121,85,122,85,125,85,127,85,133,85,134,85,140,85,141,85,142,85,144,85,146,85,147,85,149,85,150,85,151,85,154,85,155,85,158,85,160,85,161,85,162,85,163,85,164,85,165,85,166,85,168,85,169,85,170,85,171,85,172,85,173,85,174,85,175,85,176,85,178,85,180,85,182,85,184,85,186,85,188,85,191,85,192,85,193,85,194,85,195,85,198,85,199,85,200,85,202,85,203,85,206,85,207,85,208,85,213,85,215,85,216,85,217,85,218,85,219,85,222,85,224,85,226,85,231,85,233,85,237,85,238,85,240,85,241,85,244,85,246,85,248,85,249,85,250,85,251,85,252,85,255,85,2,86,3,86,4,86,5,86,6,86,7,86,10,86,11,86,13,86,16,86,17,86,18,86,19,86,20,86,21,86,22,86,23,86,25,86,26,86,28,86,29,86,32,86,33,86,34,86,37,86,38,86,40,86,41,86,42,86,43,86,46,86,47,86,48,86,51,86,53,86,55,86,56,86,58,86,60,86,61,86,62,86,64,86,65,86,66,86,67,86,68,86,69,86,70,86,71,86,72,86,73,86,74,86,75,86,79,86,80,86,81,86,82,86,83,86,85,86,86,86,90,86,91,86,93,86,94,86,95,86,96,86,97,86,99,86,101,86,102,86,103,86,109,86,110,86,111,86,112,86,114,86,115,86,116,86,117,86,119,86,120,86,121,86,122,86,125,86,126,86,127,86,128,86,129,86,130,86,131,86,132,86,135,86,136,86,137,86,138,86,139,86,140,86,141,86,144,86,145,86,146,86,148,86,149,86,150,86,151,86,152,86,153,86,154,86,155,86,156,86,157,86,158,86,159,86,160,86,161,86,162,86,164,86,165,86,166,86,167,86,168,86,169,86,170,86,171,86,172,86,173,86,174,86,176,86,177,86,178,86,179,86,180,86,181,86,182,86,184,86,185,86,186,86,187,86,189,86,190,86,191,86,192,86,193,86,194,86,195,86,196,86,197,86,198,86,199,86,200,86,201,86,203,86,204,86,205,86,206,86,207,86,208,86,209,86,210,86,211,86,213,86,214,86,216,86,217,86,220,86,227,86,229,86,230,86,231,86,232,86,233,86,234,86,236,86,238,86,239,86,242,86,243,86,246,86,247,86,248,86,251,86,252,86,0,87,1,87,2,87,5,87,7,87,11,87,12,87,13,87,14,87,15,87,16,87,17,87,18,87,19,87,20,87,21,87,22,87,23,87,24,87,25,87,26,87,27,87,29,87,30,87,32,87,33,87,34,87,36,87,37,87,38,87,39,87,43,87,49,87,50,87,52,87,53,87,54,87,55,87,56,87,60,87,61,87,63,87,65,87,67,87,68,87,69,87,70,87,72,87,73,87,75,87,82,87,83,87,84,87,85,87,86,87,88,87,89,87,98,87,99,87,101,87,103,87,108,87,110,87,112,87,113,87,114,87,116,87,117,87,120,87,121,87,122,87,125,87,126,87,127,87,128,87,129,87,135,87,136,87,137,87,138,87,141,87,142,87,143,87,144,87,145,87,148,87,149,87,150,87,151,87,152,87,153,87,154,87,156,87,157,87,158,87,159,87,165,87,168,87,170,87,172,87,175,87,176,87,177,87,179,87,181,87,182,87,183,87,185,87,186,87,187,87,188,87,189,87,190,87,191,87,192,87,193,87,196,87,197,87,198,87,199,87,200,87,201,87,202,87,204,87,205,87,208,87,209,87,211,87,214,87,215,87,219,87,220,87,222,87,225,87,226,87,227,87,229,87,230,87,231,87,232,87,233,87,234,87,235,87,236,87,238,87,240,87,241,87,242,87,243,87,245,87,246,87,247,87,251,87,252,87,254,87,255,87,1,88,3,88,4,88,5,88,8,88,9,88,10,88,12,88,14,88,15,88,16,88,18,88,19,88,20,88,22,88,23,88,24,88,26,88,27,88,28,88,29,88,31,88,34,88,35,88,37,88,38,88,39,88,40,88,41,88,43,88,44,88,45,88,46,88,47,88,49,88,50,88,51,88,52,88,54,88,55,88,56,88,57,88,58,88,59,88,60,88,61,88,62,88,63,88,64,88,65,88,66,88,67,88,69,88,70,88,71,88,72,88,73,88,74,88,75,88,78,88,79,88,80,88,82,88,83,88,85,88,86,88,87,88,89,88,90,88,91,88,92,88,93,88,95,88,96,88,97,88,98,88,99,88,100,88,102,88,103,88,104,88,105,88,106,88,109,88,110,88,111,88,112,88,113,88,114,88,115,88,116,88,117,88,118,88,119,88,120,88,121,88,122,88,123,88,124,88,125,88,127,88,130,88,132,88,134,88,135,88,136,88,138,88,139,88,140,88,141,88,142,88,143,88,144,88,145,88,148,88,149,88,150,88,151,88,152,88,155,88,156,88,157,88,160,88,161,88,162,88,163,88,164,88,165,88,166,88,167,88,170,88,171,88,172,88,173,88,174,88,175,88,176,88,177,88,178,88,179,88,180,88,181,88,182,88,183,88,184,88,185,88,186,88,187,88,189,88,190,88,191,88,192,88,194,88,195,88,196,88,198,88,199,88,200,88,201,88,202,88,203,88,204,88,205,88,206,88,207,88,208,88,210,88,211,88,212,88,214,88,215,88,216,88,217,88,218,88,219,88,220,88,221,88,222,88,223,88,224,88,225,88,226,88,227,88,229,88,230,88,231,88,232,88,233,88,234,88,237,88,239,88,241,88,242,88,244,88,245,88,247,88,248,88,250,88,251,88,252,88,253,88,254,88,255,88,0,89,1,89,3,89,5,89,6,89,8,89,9,89,10,89,11,89,12,89,14,89,16,89,17,89,18,89,19,89,23,89,24,89,27,89,29,89,30,89,32,89,33,89,34,89,35,89,38,89,40,89,44,89,48,89,50,89,51,89,53,89,54,89,59,89,61,89,62,89,63,89,64,89,67,89,69,89,70,89,74,89,76,89,77,89,80,89,82,89,83,89,89,89,91,89,92,89,93,89,94,89,95,89,97,89,99,89,100,89,102,89,103,89,104,89,105,89,106,89,107,89,108,89,109,89,110,89,111,89,112,89,113,89,114,89,117,89,119,89,122,89,123,89,124,89,126,89,127,89,128,89,133,89,137,89,139,89,140,89,142,89,143,89,144,89,145,89,148,89,149,89,152,89,154,89,155,89,156,89,157,89,159,89,160,89,161,89,162,89,166,89,167,89,172,89,173,89,176,89,177,89,179,89,180,89,181,89,182,89,183,89,184,89,186,89,188,89,189,89,191,89,192,89,193,89,194,89,195,89,196,89,197,89,199,89,200,89,201,89,204,89,205,89,206,89,207,89,213,89,214,89,217,89,219,89,222,89,223,89,224,89,225,89,226,89,228,89,230,89,231,89,233,89,234,89,235,89,237,89,238,89,239,89,240,89,241,89,242,89,243,89,244,89,245,89,246,89,247,89,248,89,250,89,252,89,253,89,254,89,0,90,2,90,10,90,11,90,13,90,14,90,15,90,16,90,18,90,20,90,21,90,22,90,23,90,25,90,26,90,27,90,29,90,30,90,33,90,34,90,36,90,38,90,39,90,40,90,42,90,43,90,44,90,45,90,46,90,47,90,48,90,51,90,53,90,55,90,56,90,57,90,58,90,59,90,61,90,62,90,63,90,65,90,66,90,67,90,68,90,69,90,71,90,72,90,75,90,76,90,77,90,78,90,79,90,80,90,81,90,82,90,83,90,84,90,86,90,87,90,88,90,89,90,91,90,92,90,93,90,94,90,95,90,96,90,97,90,99,90,100,90,101,90,102,90,104,90,105,90,107,90,108,90,109,90,110,90,111,90,112,90,113,90,114,90,115,90,120,90,121,90,123,90,124,90,125,90,126,90,128,90,129,90,130,90,131,90,132,90,133,90,134,90,135,90,136,90,137,90,138,90,139,90,140,90,141,90,142,90,143,90,144,90,145,90,147,90,148,90,149,90,150,90,151,90,152,90,153,90,156,90,157,90,158,90,159,90,160,90,161,90,162,90,163,90,164,90,165,90,166,90,167,90,168,90,169,90,171,90,172,90,173,90,174,90,175,90,176,90,177,90,180,90,182,90,183,90,185,90,186,90,187,90,188,90,189,90,191,90,192,90,195,90,196,90,197,90,198,90,199,90,200,90,202,90,203,90,205,90,206,90,207,90,208,90,209,90,211,90,213,90,215,90,217,90,218,90,219,90,221,90,222,90,223,90,226,90,228,90,229,90,231,90,232,90,234,90,236,90,237,90,238,90,239,90,240,90,242,90,243,90,244,90,245,90,246,90,247,90,248,90,249,90,250,90,251,90,252,90,253,90,254,90,255,90,0,91,1,91,2,91,3,91,4,91,5,91,6,91,7,91,8,91,10,91,11,91,12,91,13,91,14,91,15,91,16,91,17,91,18,91,19,91,20,91,21,91,24,91,25,91,26,91,27,91,28,91,29,91,30,91,31,91,32,91,33,91,34,91,35,91,36,91,37,91,38,91,39,91,40,91,41,91,42,91,43,91,44,91,45,91,46,91,47,91,48,91,49,91,51,91,53,91,54,91,56,91,57,91,58,91,59,91,60,91,61,91,62,91,63,91,65,91,66,91,67,91,68,91,69,91,70,91,71,91,72,91,73,91,74,91,75,91,76,91,77,91,78,91,79,91,82,91,86,91,94,91,96,91,97,91,103,91,104,91,107,91,109,91,110,91,111,91,114,91,116,91,118,91,119,91,120,91,121,91,123,91,124,91,126,91,127,91,130,91,134,91,138,91,141,91,142,91,144,91,145,91,146,91,148,91,150,91,159,91,167,91,168,91,169,91,172,91,173,91,174,91,175,91,177,91,178,91,183,91,186,91,187,91,188,91,192,91,193,91,195,91,200,91,201,91,202,91,203,91,205,91,206,91,207,91,209,91,212,91,213,91,214,91,215,91,216,91,217,91,218,91,219,91,220,91,224,91,226,91,227,91,230,91,231,91,233,91,234,91,235,91,236,91,237,91,239,91,241,91,242,91,243,91,244,91,245,91,246,91,247,91,253,91,254,91,0,92,2,92,3,92,5,92,7,92,8,92,11,92,12,92,13,92,14,92,16,92,18,92,19,92,23,92,25,92,27,92,30,92,31,92,32,92,33,92,35,92,38,92,40,92,41,92,42,92,43,92,45,92,46,92,47,92,48,92,50,92,51,92,53,92,54,92,55,92,67,92,68,92,70,92,71,92,76,92,77,92,82,92,83,92,84,92,86,92,87,92,88,92,90,92,91,92,92,92,93,92,95,92,98,92,100,92,103,92,104,92,105,92,106,92,107,92,108,92,109,92,112,92,114,92,115,92,116,92,117,92,118,92,119,92,120,92,123,92,124,92,125,92,126,92,128,92,131,92,132,92,133,92,134,92,135,92,137,92,138,92,139,92,142,92,143,92,146,92,147,92,149,92,157,92,158,92,159,92,160,92,161,92,164,92,165,92,166,92,167,92,168,92,170,92,174,92,175,92,176,92,178,92,180,92,182,92,185,92,186,92,187,92,188,92,190,92,192,92,194,92,195,92,197,92,198,92,199,92,200,92,201,92,202,92,204,92,205,92,206,92,207,92,208,92,209,92,211,92,212,92,213,92,214,92,215,92,216,92,218,92,219,92,220,92,221,92,222,92,223,92,224,92,226,92,227,92,231,92,233,92,235,92,236,92,238,92,239,92,241,92,242,92,243,92,244,92,245,92,246,92,247,92,248,92,249,92,250,92,252,92,253,92,254,92,255,92,0,93,1,93,4,93,5,93,8,93,9,93,10,93,11,93,12,93,13,93,15,93,16,93,17,93,18,93,19,93,21,93,23,93,24,93,25,93,26,93,28,93,29,93,31,93,32,93,33,93,34,93,35,93,37,93,40,93,42,93,43,93,44,93,47,93,48,93,49,93,50,93,51,93,53,93,54,93,55,93,56,93,57,93,58,93,59,93,60,93,63,93,64,93,65,93,66,93,67,93,68,93,69,93,70,93,72,93,73,93,77,93,78,93,79,93,80,93,81,93,82,93,83,93,84,93,85,93,86,93,87,93,89,93,90,93,92,93,94,93,95,93,96,93,97,93,98,93,99,93,100,93,101,93,102,93,103,93,104,93,106,93,109,93,110,93,112,93,113,93,114,93,115,93,117,93,118,93,119,93,120,93,121,93,122,93,123,93,124,93,125,93,126,93,127,93,128,93,129,93,131,93,132,93,133,93,134,93,135,93,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,144,93,145,93,146,93,147,93,148,93,149,93,150,93,151,93,152,93,154,93,155,93,156,93,158,93,159,93,160,93,161,93,162,93,163,93,164,93,165,93,166,93,167,93,168,93,169,93,170,93,171,93,172,93,173,93,174,93,175,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,192,93,193,93,194,93,195,93,196,93,198,93,199,93,200,93,201,93,202,93,203,93,204,93,206,93,207,93,208,93,209,93,210,93,211,93,212,93,213,93,214,93,215,93,216,93,217,93,218,93,220,93,223,93,224,93,227,93,228,93,234,93,236,93,237,93,240,93,245,93,246,93,248,93,249,93,250,93,251,93,252,93,255,93,0,94,4,94,7,94,9,94,10,94,11,94,13,94,14,94,18,94,19,94,23,94,30,94,31,94,32,94,33,94,34,94,35,94,36,94,37,94,40,94,41,94,42,94,43,94,44,94,47,94,48,94,50,94,51,94,52,94,53,94,54,94,57,94,58,94,62,94,63,94,64,94,65,94,67,94,70,94,71,94,72,94,73,94,74,94,75,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,86,94,87,94,88,94,89,94,90,94,92,94,93,94,95,94,96,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,117,94,119,94,121,94,126,94,129,94,130,94,131,94,133,94,136,94,137,94,140,94,141,94,142,94,146,94,152,94,155,94,157,94,161,94,162,94,163,94,164,94,168,94,169,94,170,94,171,94,172,94,174,94,175,94,176,94,177,94,178,94,180,94,186,94,187,94,188,94,189,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,203,94,204,94,205,94,206,94,207,94,208,94,212,94,213,94,215,94,216,94,217,94,218,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,233,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,245,94,248,94,249,94,251,94,252,94,253,94,5,95,6,95,7,95,9,95,12,95,13,95,14,95,16,95,18,95,20,95,22,95,25,95,26,95,28,95,29,95,30,95,33,95,34,95,35,95,36,95,40,95,43,95,44,95,46,95,48,95,50,95,51,95,52,95,53,95,54,95,55,95,56,95,59,95,61,95,62,95,63,95,65,95,66,95,67,95,68,95,69,95,70,95,71,95,72,95,73,95,74,95,75,95,76,95,77,95,78,95,79,95,81,95,84,95,89,95,90,95,91,95,92,95,94,95,95,95,96,95,99,95,101,95,103,95,104,95,107,95,110,95,111,95,114,95,116,95,117,95,118,95,120,95,122,95,125,95,126,95,127,95,131,95,134,95,141,95,142,95,143,95,145,95,147,95,148,95,150,95,154,95,155,95,157,95,158,95,159,95,160,95,162,95,163,95,164,95,165,95,166,95,167,95,169,95,171,95,172,95,175,95,176,95,177,95,178,95,179,95,180,95,182,95,184,95,185,95,186,95,187,95,190,95,191,95,192,95,193,95,194,95,199,95,200,95,202,95,203,95,206,95,211,95,212,95,213,95,218,95,219,95,220,95,222,95,223,95,226,95,227,95,229,95,230,95,232,95,233,95,236,95,239,95,240,95,242,95,243,95,244,95,246,95,247,95,249,95,250,95,252,95,7,96,8,96,9,96,11,96,12,96,16,96,17,96,19,96,23,96,24,96,26,96,30,96,31,96,34,96,35,96,36,96,44,96,45,96,46,96,48,96,49,96,50,96,51,96,52,96,54,96,55,96,56,96,57,96,58,96,61,96,62,96,64,96,68,96,69,96,70,96,71,96,72,96,73,96,74,96,76,96,78,96,79,96,81,96,83,96,84,96,86,96,87,96,88,96,91,96,92,96,94,96,95,96,96,96,97,96,101,96,102,96,110,96,113,96,114,96,116,96,117,96,119,96,126,96,128,96,129,96,130,96,133,96,134,96,135,96,136,96,138,96,139,96,142,96,143,96,144,96,145,96,147,96,149,96,151,96,152,96,153,96,156,96,158,96,161,96,162,96,164,96,165,96,167,96,169,96,170,96,174,96,176,96,179,96,181,96,182,96,183,96,185,96,186,96,189,96,190,96,191,96,192,96,193,96,194,96,195,96,196,96,199,96,200,96,201,96,204,96,205,96,206,96,207,96,208,96,210,96,211,96,212,96,214,96,215,96,217,96,219,96,222,96,225,96,226,96,227,96,228,96,229,96,234,96,241,96,242,96,245,96,247,96,248,96,251,96,252,96,253,96,254,96,255,96,2,97,3,97,4,97,5,97,7,97,10,97,11,97,12,97,16,97,17,97,18,97,19,97,20,97,22,97,23,97,24,97,25,97,27,97,28,97,29,97,30,97,33,97,34,97,37,97,40,97,41,97,42,97,44,97,45,97,46,97,47,97,48,97,49,97,50,97,51,97,52,97,53,97,54,97,55,97,56,97,57,97,58,97,59,97,60,97,61,97,62,97,64,97,65,97,66,97,67,97,68,97,69,97,70,97,71,97,73,97,75,97,77,97,79,97,80,97,82,97,83,97,84,97,86,97,87,97,88,97,89,97,90,97,91,97,92,97,94,97,95,97,96,97,97,97,99,97,100,97,101,97,102,97,105,97,106,97,107,97,108,97,109,97,110,97,111,97,113,97,114,97,115,97,116,97,118,97,120,97,121,97,122,97,123,97,124,97,125,97,126,97,127,97,128,97,129,97,130,97,131,97,132,97,133,97,134,97,135,97,136,97,137,97,138,97,140,97,141,97,143,97,144,97,145,97,146,97,147,97,149,97,150,97,151,97,152,97,153,97,154,97,155,97,156,97,158,97,159,97,160,97,161,97,162,97,163,97,164,97,165,97,166,97,170,97,171,97,173,97,174,97,175,97,176,97,177,97,178,97,179,97,180,97,181,97,182,97,184,97,185,97,186,97,187,97,188,97,189,97,191,97,192,97,193,97,195,97,196,97,197,97,198,97,199,97,201,97,204,97,205,97,206,97,207,97,208,97,211,97,213,97,214,97,215,97,216,97,217,97,218,97,219,97,220,97,221,97,222,97,223,97,224,97,225,97,226,97,227,97,228,97,229,97,231,97,232,97,233,97,234,97,235,97,236,97,237,97,238,97,239,97,240,97,241,97,242,97,243,97,244,97,246,97,247,97,248,97,249,97,250,97,251,97,252,97,253,97,254,97,0,98,1,98,2,98,3,98,4,98,5,98,7,98,9,98,19,98,20,98,25,98,28,98,29,98,30,98,32,98,35,98,38,98,39,98,40,98,41,98,43,98,45,98,47,98,48,98,49,98,50,98,53,98,54,98,56,98,57,98,58,98,59,98,60,98,66,98,68,98,69,98,70,98,74,98,79,98,80,98,85,98,86,98,87,98,89,98,90,98,92,98,93,98,94,98,95,98,96,98,97,98,98,98,100,98,101,98,104,98,113,98,114,98,116,98,117,98,119,98,120,98,122,98,123,98,125,98,129,98,130,98,131,98,133,98,134,98,135,98,136,98,139,98,140,98,141,98,142,98,143,98,144,98,148,98,153,98,156,98,157,98,158,98,163,98,166,98,167,98,169,98,170,98,173,98,174,98,175,98,176,98,178,98,179,98,180,98,182,98,183,98,184,98,186,98,190,98,192,98,193,98,195,98,203,98,207,98,209,98,213,98,221,98,222,98,224,98,225,98,228,98,234,98,235,98,240,98,242,98,245,98,248,98,249,98,250,98,251,98,0,99,3,99,4,99,5,99,6,99,10,99,11,99,12,99,13,99,15,99,16,99,18,99,19,99,20,99,21,99,23,99,24,99,25,99,28,99,38,99,39,99,41,99,44,99,45,99,46,99,48,99,49,99,51,99,52,99,53,99,54,99,55,99,56,99,59,99,60,99,62,99,63,99,64,99,65,99,68,99,71,99,72,99,74,99,81,99,82,99,83,99,84,99,86,99,87,99,88,99,89,99,90,99,91,99,92,99,93,99,96,99,100,99,101,99,102,99,104,99,106,99,107,99,108,99,111,99,112,99,114,99,115,99,116,99,117,99,120,99,121,99,124,99,125,99,126,99,127,99,129,99,131,99,132,99,133,99,134,99,139,99,141,99,145,99,147,99,148,99,149,99,151,99,153,99,154,99,155,99,156,99,157,99,158,99,159,99,161,99,164,99,166,99,171,99,175,99,177,99,178,99,181,99,182,99,185,99,187,99,189,99,191,99,192,99,193,99,194,99,195,99,197,99,199,99,200,99,202,99,203,99,204,99,209,99,211,99,212,99,213,99,215,99,216,99,217,99,218,99,219,99,220,99,221,99,223,99,226,99,228,99,229,99,230,99,231,99,232,99,235,99,236,99,238,99,239,99,240,99,241,99,243,99,245,99,247,99,249,99,250,99,251,99,252,99,254,99,3,100,4,100,6,100,7,100,8,100,9,100,10,100,13,100,14,100,17,100,18,100,21,100,22,100,23,100,24,100,25,100,26,100,29,100,31,100,34,100,35,100,36,100,37,100,39,100,40,100,41,100,43,100,46,100,47,100,48,100,49,100,50,100,51,100,53,100,54,100,55,100,56,100,57,100,59,100,60,100,62,100,64,100,66,100,67,100,73,100,75,100,76,100,77,100,78,100,79,100,80,100,81,100,83,100,85,100,86,100,87,100,89,100,90,100,91,100,92,100,93,100,95,100,96,100,97,100,98,100,99,100,100,100,101,100,102,100,104,100,106,100,107,100,108,100,110,100,111,100,112,100,113,100,114,100,115,100,116,100,117,100,118,100,119,100,123,100,124,100,125,100,126,100,127,100,128,100,129,100,131,100,134,100,136,100,137,100,138,100,139,100,140,100,141,100,142,100,143,100,144,100,147,100,148,100,151,100,152,100,154,100,155,100,156,100,157,100,159,100,160,100,161,100,162,100,163,100,165,100,166,100,167,100,168,100,170,100,171,100,175,100,177,100,178,100,179,100,180,100,182,100,185,100,187,100,189,100,190,100,191,100,193,100,195,100,196,100,198,100,199,100,200,100,201,100,202,100,203,100,204,100,207,100,209,100,211,100,212,100,213,100,214,100,217,100,218,100,219,100,220,100,221,100,223,100,224,100,225,100,227,100,229,100,231,100,232,100,233,100,234,100,235,100,236,100,237,100,238,100,239,100,240,100,241,100,242,100,243,100,244,100,245,100,246,100,247,100,248,100,249,100,250,100,251,100,252,100,253,100,254,100,255,100,1,101,2,101,3,101,4,101,5,101,6,101,7,101,8,101,10,101,11,101,12,101,13,101,14,101,15,101,16,101,17,101,19,101,20,101,21,101,22,101,23,101,25,101,26,101,27,101,28,101,29,101,30,101,31,101,32,101,33,101,34,101,35,101,36,101,38,101,39,101,40,101,41,101,42,101,44,101,45,101,48,101,49,101,50,101,51,101,55,101,58,101,60,101,61,101,64,101,65,101,66,101,67,101,68,101,70,101,71,101,74,101,75,101,77,101,78,101,80,101,82,101,83,101,84,101,87,101,88,101,90,101,92,101,95,101,96,101,97,101,100,101,101,101,103,101,104,101,105,101,106,101,109,101,110,101,111,101,113,101,115,101,117,101,118,101,120,101,121,101,122,101,123,101,124,101,125,101,126,101,127,101,128,101,129,101,130,101,131,101,132,101,133,101,134,101,136,101,137,101,138,101,141,101,142,101,143,101,146,101,148,101,149,101,150,101,152,101,154,101,157,101,158,101,160,101,162,101,163,101,166,101,168,101,170,101,172,101,174,101,177,101,178,101,179,101,180,101,181,101,182,101,183,101,184,101,186,101,187,101,190,101,191,101,192,101,194,101,199,101,200,101,201,101,202,101,205,101,208,101,209,101,211,101,212,101,213,101,216,101,217,101,218,101,219,101,220,101,221,101,222,101,223,101,225,101,227,101,228,101,234,101,235,101,242,101,243,101,244,101,245,101,248,101,249,101,251,101,252,101,253,101,254,101,255,101,1,102,4,102,5,102,7,102,8,102,9,102,11,102,13,102,16,102,17,102,18,102,22,102,23,102,24,102,26,102,27,102,28,102,30,102,33,102,34,102,35,102,36,102,38,102,41,102,42,102,43,102,44,102,46,102,48,102,50,102,51,102,55,102,56,102,57,102,58,102,59,102,61,102,63,102,64,102,66,102,68,102,69,102,70,102,71,102,72,102,73,102,74,102,77,102,78,102,80,102,81,102,88,102,89,102,91,102,92,102,93,102,94,102,96,102,98,102,99,102,101,102,103,102,105,102,106,102,107,102,108,102,109,102,113,102,114,102,115,102,117,102,120,102,121,102,123,102,124,102,125,102,127,102,128,102,129,102,131,102,133,102,134,102,136,102,137,102,138,102,139,102,141,102,142,102,143,102,144,102,146,102,147,102,148,102,149,102,152,102,153,102,154,102,155,102,156,102,158,102,159,102,160,102,161,102,162,102,163,102,164,102,165,102,166,102,169,102,170,102,171,102,172,102,173,102,175,102,176,102,177,102,178,102,179,102,181,102,182,102,183,102,184,102,186,102,187,102,188,102,189,102,191,102,192,102,193,102,194,102,195,102,196,102,197,102,198,102,199,102,200,102,201,102,202,102,203,102,204,102,205,102,206,102,207,102,208,102,209,102,210,102,211,102,212,102,213,102,214,102,215,102,216,102,218,102,222,102,223,102,224,102,225,102,226,102,227,102,228,102,229,102,231,102,232,102,234,102,235,102,236,102,237,102,238,102,239,102,241,102,245,102,246,102,248,102,250,102,251,102,253,102,1,103,2,103,3,103,4,103,5,103,6,103,7,103,12,103,14,103,15,103,17,103,18,103,19,103,22,103,24,103,25,103,26,103,28,103,30,103,32,103,33,103,34,103,35,103,36,103,37,103,39,103,41,103,46,103,48,103,50,103,51,103,54,103,55,103,56,103,57,103,59,103,60,103,62,103,63,103,65,103,68,103,69,103,71,103,74,103,75,103,77,103,82,103,84,103,85,103,87,103,88,103,89,103,90,103,91,103,93,103,98,103,99,103,100,103,102,103,103,103,107,103,108,103,110,103,113,103,116,103,118,103,120,103,121,103,122,103,123,103,125,103,128,103,130,103,131,103,133,103,134,103,136,103,138,103,140,103,141,103,142,103,143,103,145,103,146,103,147,103,148,103,150,103,153,103,155,103,159,103,160,103,161,103,164,103,166,103,169,103,172,103,174,103,177,103,178,103,180,103,185,103,186,103,187,103,188,103,189,103,190,103,191,103,192,103,194,103,197,103,198,103,199,103,200,103,201,103,202,103,203,103,204,103,205,103,206,103,213,103,214,103,215,103,219,103,223,103,225,103,227,103,228,103,230,103,231,103,232,103,234,103,235,103,237,103,238,103,242,103,245,103,246,103,247,103,248,103,249,103,250,103,251,103,252,103,254,103,1,104,2,104,3,104,4,104,6,104,13,104,16,104,18,104,20,104,21,104,24,104,25,104,26,104,27,104,28,104,30,104,31,104,32,104,34,104,35,104,36,104,37,104,38,104,39,104,40,104,43,104,44,104,45,104,46,104,47,104,48,104,49,104,52,104,53,104,54,104,58,104,59,104,63,104,71,104,75,104,77,104,79,104,82,104,86,104,87,104,88,104,89,104,90,104,91,104,92,104,93,104,94,104,95,104,106,104,108,104,109,104,110,104,111,104,112,104,113,104,114,104,115,104,117,104,120,104,121,104,122,104,123,104,124,104,125,104,126,104,127,104,128,104,130,104,132,104,135,104,136,104,137,104,138,104,139,104,140,104,141,104,142,104,144,104,145,104,146,104,148,104,149,104,150,104,152,104,153,104,154,104,155,104,156,104,157,104,158,104,159,104,160,104,161,104,163,104,164,104,165,104,169,104,170,104,171,104,172,104,174,104,177,104,178,104,180,104,182,104,183,104,184,104,185,104,186,104,187,104,188,104,189,104,190,104,191,104,193,104,195,104,196,104,197,104,198,104,199,104,200,104,202,104,204,104,206,104,207,104,208,104,209,104,211,104,212,104,214,104,215,104,217,104,219,104,220,104,221,104,222,104,223,104,225,104,226,104,228,104,229,104,230,104,231,104,232,104,233,104,234,104,235,104,236,104,237,104,239,104,242,104,243,104,244,104,246,104,247,104,248,104,251,104,253,104,254,104,255,104,0,105,2,105,3,105,4,105,6,105,7,105,8,105,9,105,10,105,12,105,15,105,17,105,19,105,20,105,21,105,22,105,23,105,24,105,25,105,26,105,27,105,28,105,29,105,30,105,33,105,34,105,35,105,37,105,38,105,39,105,40,105,41,105,42,105,43,105,44,105,46,105,47,105,49,105,50,105,51,105,53,105,54,105,55,105,56,105,58,105,59,105,60,105,62,105,64,105,65,105,67,105,68,105,69,105,70,105,71,105,72,105,73,105,74,105,75,105,76,105,77,105,78,105,79,105,80,105,81,105,82,105,83,105,85,105,86,105,88,105,89,105,91,105,92,105,95,105,97,105,98,105,100,105,101,105,103,105,104,105,105,105,106,105,108,105,109,105,111,105,112,105,114,105,115,105,116,105,117,105,118,105,122,105,123,105,125,105,126,105,127,105,129,105,131,105,133,105,138,105,139,105,140,105,142,105,143,105,144,105,145,105,146,105,147,105,150,105,151,105,153,105,154,105,157,105,158,105,159,105,160,105,161,105,162,105,163,105,164,105,165,105,166,105,169,105,170,105,172,105,174,105,175,105,176,105,178,105,179,105,181,105,182,105,184,105,185,105,186,105,188,105,189,105,190,105,191,105,192,105,194,105,195,105,196,105,197,105,198,105,199,105,200,105,201,105,203,105,205,105,207,105,209,105,210,105,211,105,213,105,214,105,215,105,216,105,217,105,218,105,220,105,221,105,222,105,225,105,226,105,227,105,228,105,229,105,230,105,231,105,232,105,233,105,234,105,235,105,236,105,238,105,239,105,240,105,241,105,243,105,244,105,245,105,246,105,247,105,248,105,249,105,250,105,251,105,252,105,254,105,0,106,1,106,2,106,3,106,4,106,5,106,6,106,7,106,8,106,9,106,11,106,12,106,13,106,14,106,15,106,16,106,17,106,18,106,19,106,20,106,21,106,22,106,25,106,26,106,27,106,28,106,29,106,30,106,32,106,34,106,35,106,36,106,37,106,38,106,39,106,41,106,43,106,44,106,45,106,46,106,48,106,50,106,51,106,52,106,54,106,55,106,56,106,57,106,58,106,59,106,60,106,63,106,64,106,65,106,66,106,67,106,69,106,70,106,72,106,73,106,74,106,75,106,76,106,77,106,78,106,79,106,81,106,82,106,83,106,84,106,85,106,86,106,87,106,90,106,92,106,93,106,94,106,95,106,96,106,98,106,99,106,100,106,102,106,103,106,104,106,105,106,106,106,107,106,108,106,109,106,110,106,111,106,112,106,114,106,115,106,116,106,117,106,118,106,119,106,120,106,122,106,123,106,125,106,126,106,127,106,129,106,130,106,131,106,133,106,134,106,135,106,136,106,137,106,138,106,139,106,140,106,141,106,143,106,146,106,147,106,148,106,149,106,150,106,152,106,153,106,154,106,155,106,156,106,157,106,158,106,159,106,161,106,162,106,163,106,164,106,165,106,166,106,167,106,168,106,170,106,173,106,174,106,175,106,176,106,177,106,178,106,179,106,180,106,181,106,182,106,183,106,184,106,185,106,186,106,187,106,188,106,189,106,190,106,191,106,192,106,193,106,194,106,195,106,196,106,197,106,198,106,199,106,200,106,201,106,202,106,203,106,204,106,205,106,206,106,207,106,208,106,209,106,210,106,211,106,212,106,213,106,214,106,215,106,216,106,217,106,218,106,219,106,220,106,221,106,222,106,223,106,224,106,225,106,226,106,227,106,228,106,229,106,230,106,231,106,232,106,233,106,234,106,235,106,236,106,237,106,238,106,239,106,240,106,241,106,242,106,243,106,244,106,245,106,246,106,247,106,248,106,249,106,250,106,251,106,252,106,253,106,254,106,255,106,0,107,1,107,2,107,3,107,4,107,5,107,6,107,7,107,8,107,9,107,10,107,11,107,12,107,13,107,14,107,15,107,16,107,17,107,18,107,19,107,20,107,21,107,22,107,23,107,24,107,25,107,26,107,27,107,28,107,29,107,30,107,31,107,37,107,38,107,40,107,41,107,42,107,43,107,44,107,45,107,46,107,47,107,48,107,49,107,51,107,52,107,53,107,54,107,56,107,59,107,60,107,61,107,63,107,64,107,65,107,66,107,68,107,69,107,72,107,74,107,75,107,77,107,78,107,79,107,80,107,81,107,82,107,83,107,84,107,85,107,86,107,87,107,88,107,90,107,91,107,92,107,93,107,94,107,95,107,96,107,97,107,104,107,105,107,107,107,108,107,109,107,110,107,111,107,112,107,113,107,114,107,115,107,116,107,117,107,118,107,119,107,120,107,122,107,125,107,126,107,127,107,128,107,133,107,136,107,140,107,142,107,143,107,144,107,145,107,148,107,149,107,151,107,152,107,153,107,156,107,157,107,158,107,159,107,160,107,162,107,163,107,164,107,165,107,166,107,167,107,168,107,169,107,171,107,172,107,173,107,174,107,175,107,176,107,177,107,178,107,182,107,184,107,185,107,186,107,187,107,188,107,189,107,190,107,192,107,195,107,196,107,198,107,199,107,200,107,201,107,202,107,204,107,206,107,208,107,209,107,216,107,218,107,220,107,221,107,222,107,223,107,224,107,226,107,227,107,228,107,229,107,230,107,231,107,232,107,233,107,236,107,237,107,238,107,240,107,241,107,242,107,244,107,246,107,247,107,248,107,250,107,251,107,252,107,254,107,255,107,0,108,1,108,2,108,3,108,4,108,8,108,9,108,10,108,11,108,12,108,14,108,18,108,23,108,28,108,29,108,30,108,32,108,35,108,37,108,43,108,44,108,45,108,49,108,51,108,54,108,55,108,57,108,58,108,59,108,60,108,62,108,63,108,67,108,68,108,69,108,72,108,75,108,76,108,77,108,78,108,79,108,81,108,82,108,83,108,86,108,88,108,89,108,90,108,98,108,99,108,101,108,102,108,103,108,107,108,108,108,109,108,110,108,111,108,113,108,115,108,117,108,119,108,120,108,122,108,123,108,124,108,127,108,128,108,132,108,135,108,138,108,139,108,141,108,142,108,145,108,146,108,149,108,150,108,151,108,152,108,154,108,156,108,157,108,158,108,160,108,162,108,168,108,172,108,175,108,176,108,180,108,181,108,182,108,183,108,186,108,192,108,193,108,194,108,195,108,198,108,199,108,200,108,203,108,205,108,206,108,207,108,209,108,210,108,216,108,217,108,218,108,220,108,221,108,223,108,228,108,230,108,231,108,233,108,236,108,237,108,242,108,244,108,249,108,255,108,0,109,2,109,3,109,5,109,6,109,8,109,9,109,10,109,13,109,15,109,16,109,17,109,19,109,20,109,21,109,22,109,24,109,28,109,29,109,31,109,32,109,33,109,34,109,35,109,36,109,38,109,40,109,41,109,44,109,45,109,47,109,48,109,52,109,54,109,55,109,56,109,58,109,63,109,64,109,66,109,68,109,73,109,76,109,80,109,85,109,86,109,87,109,88,109,91,109,93,109,95,109,97,109,98,109,100,109,101,109,103,109,104,109,107,109,108,109,109,109,112,109,113,109,114,109,115,109,117,109,118,109,121,109,122,109,123,109,125,109,126,109,127,109,128,109,129,109,131,109,132,109,134,109,135,109,138,109,139,109,141,109,143,109,144,109,146,109,150,109,151,109,152,109,153,109,154,109,156,109,162,109,165,109,172,109,173,109,176,109,177,109,179,109,180,109,182,109,183,109,185,109,186,109,187,109,188,109,189,109,190,109,193,109,194,109,195,109,200,109,201,109,202,109,205,109,206,109,207,109,208,109,210,109,211,109,212,109,213,109,215,109,218,109,219,109,220,109,223,109,226,109,227,109,229,109,231,109,232,109,233,109,234,109,237,109,239,109,240,109,242,109,244,109,245,109,246,109,248,109,250,109,253,109,254,109,255,109,0,110,1,110,2,110,3,110,4,110,6,110,7,110,8,110,9,110,11,110,15,110,18,110,19,110,21,110,24,110,25,110,27,110,28,110,30,110,31,110,34,110,38,110,39,110,40,110,42,110,44,110,46,110,48,110,49,110,51,110,53,110,54,110,55,110,57,110,59,110,60,110,61,110,62,110,63,110,64,110,65,110,66,110,69,110,70,110,71,110,72,110,73,110,74,110,75,110,76,110,79,110,80,110,81,110,82,110,85,110,87,110,89,110,90,110,92,110,93,110,94,110,96,110,97,110,98,110,99,110,100,110,101,110,102,110,103,110,104,110,105,110,106,110,108,110,109,110,111,110,112,110,113,110,114,110,115,110,116,110,117,110,118,110,119,110,120,110,121,110,122,110,123,110,124,110,125,110,128,110,129,110,130,110,132,110,135,110,136,110,138,110,139,110,140,110,141,110,142,110,145,110,146,110,147,110,148,110,149,110,150,110,151,110,153,110,154,110,155,110,157,110,158,110,160,110,161,110,163,110,164,110,166,110,168,110,169,110,171,110,172,110,173,110,174,110,176,110,179,110,181,110,184,110,185,110,188,110,190,110,191,110,192,110,195,110,196,110,197,110,198,110,200,110,201,110,202,110,204,110,205,110,206,110,208,110,210,110,214,110,216,110,217,110,219,110,220,110,221,110,227,110,231,110,234,110,235,110,236,110,237,110,238,110,239,110,240,110,241,110,242,110,243,110,245,110,246,110,247,110,248,110,250,110,251,110,252,110,253,110,254,110,255,110,0,111,1,111,3,111,4,111,5,111,7,111,8,111,10,111,11,111,12,111,13,111,14,111,16,111,17,111,18,111,22,111,23,111,24,111,25,111,26,111,27,111,28,111,29,111,30,111,31,111,33,111,34,111,35,111,37,111,38,111,39,111,40,111,44,111,46,111,48,111,50,111,52,111,53,111,55,111,56,111,57,111,58,111,59,111,60,111,61,111,63,111,64,111,65,111,66,111,67,111,68,111,69,111,72,111,73,111,74,111,76,111,78,111,79,111,80,111,81,111,82,111,83,111,84,111,85,111,86,111,87,111,89,111,90,111,91,111,93,111,95,111,96,111,97,111,99,111,100,111,101,111,103,111,104,111,105,111,106,111,107,111,108,111,111,111,112,111,113,111,115,111,117,111,118,111,119,111,121,111,123,111,125,111,126,111,127,111,128,111,129,111,130,111,131,111,133,111,134,111,135,111,138,111,139,111,143,111,144,111,145,111,146,111,147,111,148,111,149,111,150,111,151,111,152,111,153,111,154,111,155,111,157,111,158,111,159,111,160,111,162,111,163,111,164,111,165,111,166,111,168,111,169,111,170,111,171,111,172,111,173,111,174,111,175,111,176,111,177,111,178,111,180,111,181,111,183,111,184,111,186,111,187,111,188,111,189,111,190,111,191,111,193,111,195,111,196,111,197,111,198,111,199,111,200,111,202,111,203,111,204,111,205,111,206,111,207,111,208,111,211,111,212,111,213,111,214,111,215,111,216,111,217,111,218,111,219,111,220,111,221,111,223,111,226,111,227,111,228,111,229,111,230,111,231,111,232,111,233,111,234,111,235,111,236,111,237,111,240,111,241,111,242,111,243,111,244,111,245,111,246,111,247,111,248,111,249,111,250,111,251,111,252,111,253,111,254,111,255,111,0,112,1,112,2,112,3,112,4,112,5,112,6,112,7,112,8,112,9,112,10,112,11,112,12,112,13,112,14,112,15,112,16,112,18,112,19,112,20,112,21,112,22,112,23,112,24,112,25,112,28,112,29,112,30,112,31,112,32,112,33,112,34,112,36,112,37,112,38,112,39,112,40,112,41,112,42,112,43,112,44,112,45,112,46,112,47,112,48,112,49,112,50,112,51,112,52,112,54,112,55,112,56,112,58,112,59,112,60,112,61,112,62,112,63,112,64,112,65,112,66,112,67,112,68,112,69,112,70,112,71,112,72,112,73,112,74,112,75,112,77,112,78,112,80,112,81,112,82,112,83,112,84,112,85,112,86,112,87,112,88,112,89,112,90,112,91,112,92,112,93,112,95,112,96,112,97,112,98,112,99,112,100,112,101,112,102,112,103,112,104,112,105,112,106,112,110,112,113,112,114,112,115,112,116,112,119,112,121,112,122,112,123,112,125,112,129,112,130,112,131,112,132,112,134,112,135,112,136,112,139,112,140,112,141,112,143,112,144,112,145,112,147,112,151,112,152,112,154,112,155,112,158,112,159,112,160,112,161,112,162,112,163,112,164,112,165,112,166,112,167,112,168,112,169,112,170,112,176,112,178,112,180,112,181,112,182,112,186,112,190,112,191,112,196,112,197,112,198,112,199,112,201,112,203,112,204,112,205,112,206,112,207,112,208,112,209,112,210,112,211,112,212,112,213,112,214,112,215,112,218,112,220,112,221,112,222,112,224,112,225,112,226,112,227,112,229,112,234,112,238,112,240,112,241,112,242,112,243,112,244,112,245,112,246,112,248,112,250,112,251,112,252,112,254,112,255,112,0,113,1,113,2,113,3,113,4,113,5,113,6,113,7,113,8,113,11,113,12,113,13,113,14,113,15,113,17,113,18,113,20,113,23,113,27,113,28,113,29,113,30,113,31,113,32,113,33,113,34,113,35,113,36,113,37,113,39,113,40,113,41,113,42,113,43,113,44,113,45,113,46,113,50,113,51,113,52,113,53,113,55,113,56,113,57,113,58,113,59,113,60,113,61,113,62,113,63,113,64,113,65,113,66,113,67,113,68,113,70,113,71,113,72,113,73,113,75,113,77,113,79,113,80,113,81,113,82,113,83,113,84,113,85,113,86,113,87,113,88,113,89,113,90,113,91,113,93,113,95,113,96,113,97,113,98,113,99,113,101,113,105,113,106,113,107,113,108,113,109,113,111,113,112,113,113,113,116,113,117,113,118,113,119,113,121,113,123,113,124,113,126,113,127,113,128,113,129,113,130,113,131,113,133,113,134,113,135,113,136,113,137,113,139,113,140,113,141,113,142,113,144,113,145,113,146,113,147,113,149,113,150,113,151,113,154,113,155,113,156,113,157,113,158,113,161,113,162,113,163,113,164,113,165,113,166,113,167,113,169,113,170,113,171,113,173,113,174,113,175,113,176,113,177,113,178,113,180,113,182,113,183,113,184,113,186,113,187,113,188,113,189,113,190,113,191,113,192,113,193,113,194,113,196,113,197,113,198,113,199,113,200,113,201,113,202,113,203,113,204,113,205,113,207,113,208,113,209,113,210,113,211,113,214,113,215,113,216,113,217,113,218,113,219,113,220,113,221,113,222,113,223,113,225,113,226,113,227,113,228,113,230,113,232,113,233,113,234,113,235,113,236,113,237,113,239,113,240,113,241,113,242,113,243,113,244,113,245,113,246,113,247,113,248,113,250,113,251,113,252,113,253,113,254,113,255,113,0,114,1,114,2,114,3,114,4,114,5,114,7,114,8,114,9,114,10,114,11,114,12,114,13,114,14,114,15,114,16,114,17,114,18,114,19,114,20,114,21,114,22,114,23,114,24,114,25,114,26,114,27,114,28,114,30,114,31,114,32,114,33,114,34,114,35,114,36,114,37,114,38,114,39,114,41,114,43,114,45,114,46,114,47,114,50,114,51,114,52,114,58,114,60,114,62,114,64,114,65,114,66,114,67,114,68,114,69,114,70,114,73,114,74,114,75,114,78,114,79,114,80,114,81,114,83,114,84,114,85,114,87,114,88,114,90,114,92,114,94,114,96,114,99,114,100,114,101,114,104,114,106,114,107,114,108,114,109,114,112,114,113,114,115,114,116,114,118,114,119,114,120,114,123,114,124,114,125,114,130,114,131,114,133,114,134,114,135,114,136,114,137,114,140,114,142,114,144,114,145,114,147,114,148,114,149,114,150,114,151,114,152,114,153,114,154,114,155,114,156,114,157,114,158,114,160,114,161,114,162,114,163,114,164,114,165,114,166,114,167,114,168,114,169,114,170,114,171,114,174,114,177,114,178,114,179,114,181,114,186,114,187,114,188,114,189,114,190,114,191,114,192,114,197,114,198,114,199,114,201,114,202,114,203,114,204,114,207,114,209,114,211,114,212,114,213,114,214,114,216,114,218,114,219,114,198,228,199,228,200,228,201,228,202,228,203,228,204,228,205,228,206,228,207,228,208,228,209,228,210,228,211,228,212,228,213,228,214,228,215,228,216,228,217,228,218,228,219,228,220,228,221,228,222,228,223,228,224,228,225,228,226,228,227,228,228,228,229,228,230,228,231,228,232,228,233,228,234,228,235,228,236,228,237,228,238,228,239,228,240,228,241,228,242,228,243,228,244,228,245,228,246,228,247,228,248,228,249,228,250,228,251,228,252,228,253,228,254,228,255,228,0,229,1,229,2,229,3,229,4,229,5,229,6,229,7,229,8,229,9,229,10,229,11,229,12,229,13,229,14,229,15,229,16,229,17,229,18,229,19,229,20,229,21,229,22,229,23,229,24,229,25,229,26,229,27,229,28,229,29,229,30,229,31,229,32,229,33,229,34,229,35,229,36,229,37,229,0,48,1,48,2,48,183,0,201,2,199,2,168,0,3,48,5,48,20,32,94,255,22,32,38,32,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,22,48,23,48,16,48,17,48,177,0,215,0,247,0,54,34,39,34,40,34,17,34,15,34,42,34,41,34,8,34,55,34,26,34,165,34,37,34,32,34,18,35,153,34,43,34,46,34,97,34,76,34,72,34,61,34,29,34,96,34,110,34,111,34,100,34,101,34,30,34,53,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,4,255,164,0,224,255,225,255,48,32,167,0,22,33,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,59,32,146,33,144,33,145,33,147,33,19,48,38,229,39,229,40,229,41,229,42,229,43,229,44,229,45,229,46,229,47,229,48,229,49,229,50,229,51,229,52,229,53,229,54,229,55,229,56,229,57,229,58,229,59,229,60,229,61,229,62,229,63,229,64,229,65,229,66,229,67,229,68,229,69,229,70,229,71,229,72,229,73,229,74,229,75,229,76,229,77,229,78,229,79,229,80,229,81,229,82,229,83,229,84,229,85,229,86,229,87,229,88,229,89,229,90,229,91,229,92,229,93,229,94,229,95,229,96,229,97,229,98,229,99,229,100,229,101,229,102,229,103,229,104,229,105,229,106,229,107,229,108,229,109,229,110,229,111,229,112,229,113,229,114,229,115,229,116,229,117,229,118,229,119,229,120,229,121,229,122,229,123,229,124,229,125,229,126,229,127,229,128,229,129,229,130,229,131,229,132,229,133,229,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,102,231,103,231,104,231,105,231,106,231,107,231,136,36,137,36,138,36,139,36,140,36,141,36,142,36,143,36,144,36,145,36,146,36,147,36,148,36,149,36,150,36,151,36,152,36,153,36,154,36,155,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,131,36,132,36,133,36,134,36,135,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,172,32,109,231,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,110,231,111,231,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,106,33,107,33,112,231,113,231,134,229,135,229,136,229,137,229,138,229,139,229,140,229,141,229,142,229,143,229,144,229,145,229,146,229,147,229,148,229,149,229,150,229,151,229,152,229,153,229,154,229,155,229,156,229,157,229,158,229,159,229,160,229,161,229,162,229,163,229,164,229,165,229,166,229,167,229,168,229,169,229,170,229,171,229,172,229,173,229,174,229,175,229,176,229,177,229,178,229,179,229,180,229,181,229,182,229,183,229,184,229,185,229,186,229,187,229,188,229,189,229,190,229,191,229,192,229,193,229,194,229,195,229,196,229,197,229,198,229,199,229,200,229,201,229,202,229,203,229,204,229,205,229,206,229,207,229,208,229,209,229,210,229,211,229,212,229,213,229,214,229,215,229,216,229,217,229,218,229,219,229,220,229,221,229,222,229,223,229,224,229,225,229,226,229,227,229,228,229,229,229,1,255,2,255,3,255,229,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,60,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,230,229,231,229,232,229,233,229,234,229,235,229,236,229,237,229,238,229,239,229,240,229,241,229,242,229,243,229,244,229,245,229,246,229,247,229,248,229,249,229,250,229,251,229,252,229,253,229,254,229,255,229,0,230,1,230,2,230,3,230,4,230,5,230,6,230,7,230,8,230,9,230,10,230,11,230,12,230,13,230,14,230,15,230,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,32,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,50,230,51,230,52,230,53,230,54,230,55,230,56,230,57,230,58,230,59,230,60,230,61,230,62,230,63,230,64,230,65,230,66,230,67,230,68,230,69,230,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,114,231,115,231,116,231,117,231,118,231,119,231,120,231,121,231,122,231,123,231,124,231,70,230,71,230,72,230,73,230,74,230,75,230,76,230,77,230,78,230,79,230,80,230,81,230,82,230,83,230,84,230,85,230,86,230,87,230,88,230,89,230,90,230,91,230,92,230,93,230,94,230,95,230,96,230,97,230,98,230,99,230,100,230,101,230,102,230,103,230,104,230,105,230,106,230,107,230,108,230,109,230,110,230,111,230,112,230,113,230,114,230,115,230,116,230,117,230,118,230,119,230,120,230,121,230,122,230,123,230,124,230,125,230,126,230,127,230,128,230,129,230,130,230,131,230,132,230,133,230,134,230,135,230,136,230,137,230,138,230,139,230,140,230,141,230,142,230,143,230,144,230,145,230,146,230,147,230,148,230,149,230,150,230,151,230,152,230,153,230,154,230,155,230,156,230,157,230,158,230,159,230,160,230,161,230,162,230,163,230,164,230,165,230,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,125,231,126,231,127,231,128,231,129,231,130,231,131,231,132,231,166,230,167,230,168,230,169,230,170,230,171,230,172,230,173,230,174,230,175,230,176,230,177,230,178,230,179,230,180,230,181,230,182,230,183,230,184,230,185,230,186,230,187,230,188,230,189,230,190,230,191,230,192,230,193,230,194,230,195,230,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,246,230,247,230,248,230,249,230,250,230,251,230,252,230,253,230,254,230,255,230,0,231,1,231,2,231,3,231,4,231,5,231,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,133,231,134,231,135,231,136,231,137,231,138,231,139,231,140,231,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,141,231,142,231,143,231,144,231,145,231,146,231,147,231,53,254,54,254,57,254,58,254,63,254,64,254,61,254,62,254,65,254,66,254,67,254,68,254,148,231,149,231,59,254,60,254,55,254,56,254,49,254,150,231,51,254,52,254,151,231,152,231,153,231,154,231,155,231,156,231,157,231,158,231,159,231,6,231,7,231,8,231,9,231,10,231,11,231,12,231,13,231,14,231,15,231,16,231,17,231,18,231,19,231,20,231,21,231,22,231,23,231,24,231,25,231,26,231,27,231,28,231,29,231,30,231,31,231,32,231,33,231,34,231,35,231,36,231,37,231,38,231,39,231,40,231,41,231,42,231,43,231,44,231,45,231,46,231,47,231,48,231,49,231,50,231,51,231,52,231,53,231,54,231,55,231,56,231,57,231,58,231,59,231,60,231,61,231,62,231,63,231,64,231,65,231,66,231,67,231,68,231,69,231,70,231,71,231,72,231,73,231,74,231,75,231,76,231,77,231,78,231,79,231,80,231,81,231,82,231,83,231,84,231,85,231,86,231,87,231,88,231,89,231,90,231,91,231,92,231,93,231,94,231,95,231,96,231,97,231,98,231,99,231,100,231,101,231,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,160,231,161,231,162,231,163,231,164,231,165,231,166,231,167,231,168,231,169,231,170,231,171,231,172,231,173,231,174,231,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,175,231,176,231,177,231,178,231,179,231,180,231,181,231,182,231,183,231,184,231,185,231,186,231,187,231,202,2,203,2,217,2,19,32,21,32,37,32,53,32,5,33,9,33,150,33,151,33,152,33,153,33,21,34,31,34,35,34,82,34,102,34,103,34,191,34,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,109,37,110,37,111,37,112,37,113,37,114,37,115,37,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,137,37,138,37,139,37,140,37,141,37,142,37,143,37,147,37,148,37,149,37,188,37,189,37,226,37,227,37,228,37,229,37,9,38,149,34,18,48,29,48,30,48,188,231,189,231,190,231,191,231,192,231,193,231,194,231,195,231,196,231,197,231,198,231,1,1,225,0,206,1,224,0,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,234,0,81,2,199,231,68,1,72,1,249,1,97,2,201,231,202,231,203,231,204,231,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,205,231,206,231,207,231,208,231,209,231,210,231,211,231,212,231,213,231,214,231,215,231,216,231,217,231,218,231,219,231,220,231,221,231,222,231,223,231,224,231,225,231,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,163,50,142,51,143,51,156,51,157,51,158,51,161,51,196,51,206,51,209,51,210,51,213,51,48,254,226,255,228,255,226,231,33,33,49,50,227,231,16,32,228,231,229,231,230,231,252,48,155,48,156,48,253,48,254,48,6,48,157,48,158,48,73,254,74,254,75,254,76,254,77,254,78,254,79,254,80,254,81,254,82,254,84,254,85,254,86,254,87,254,89,254,90,254,91,254,92,254,93,254,94,254,95,254,96,254,97,254,98,254,99,254,100,254,101,254,102,254,104,254,105,254,106,254,107,254,62,48,240,47,241,47,242,47,243,47,244,47,245,47,246,47,247,47,248,47,249,47,250,47,251,47,7,48,244,231,245,231,246,231,247,231,248,231,249,231,250,231,251,231,252,231,253,231,254,231,255,231,0,232,0,37,1,37,2,37,3,37,4,37,5,37,6,37,7,37,8,37,9,37,10,37,11,37,12,37,13,37,14,37,15,37,16,37,17,37,18,37,19,37,20,37,21,37,22,37,23,37,24,37,25,37,26,37,27,37,28,37,29,37,30,37,31,37,32,37,33,37,34,37,35,37,36,37,37,37,38,37,39,37,40,37,41,37,42,37,43,37,44,37,45,37,46,37,47,37,48,37,49,37,50,37,51,37,52,37,53,37,54,37,55,37,56,37,57,37,58,37,59,37,60,37,61,37,62,37,63,37,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,1,232,2,232,3,232,4,232,5,232,6,232,7,232,8,232,9,232,10,232,11,232,12,232,13,232,14,232,15,232,220,114,221,114,223,114,226,114,227,114,228,114,229,114,230,114,231,114,234,114,235,114,245,114,246,114,249,114,253,114,254,114,255,114,0,115,2,115,4,115,5,115,6,115,7,115,8,115,9,115,11,115,12,115,13,115,15,115,16,115,17,115,18,115,20,115,24,115,25,115,26,115,31,115,32,115,35,115,36,115,38,115,39,115,40,115,45,115,47,115,48,115,50,115,51,115,53,115,54,115,58,115,59,115,60,115,61,115,64,115,65,115,66,115,67,115,68,115,69,115,70,115,71,115,72,115,73,115,74,115,75,115,76,115,78,115,79,115,81,115,83,115,84,115,85,115,86,115,88,115,89,115,90,115,91,115,92,115,93,115,94,115,95,115,97,115,98,115,99,115,100,115,101,115,102,115,103,115,104,115,105,115,106,115,107,115,110,115,112,115,113,115,0,224,1,224,2,224,3,224,4,224,5,224,6,224,7,224,8,224,9,224,10,224,11,224,12,224,13,224,14,224,15,224,16,224,17,224,18,224,19,224,20,224,21,224,22,224,23,224,24,224,25,224,26,224,27,224,28,224,29,224,30,224,31,224,32,224,33,224,34,224,35,224,36,224,37,224,38,224,39,224,40,224,41,224,42,224,43,224,44,224,45,224,46,224,47,224,48,224,49,224,50,224,51,224,52,224,53,224,54,224,55,224,56,224,57,224,58,224,59,224,60,224,61,224,62,224,63,224,64,224,65,224,66,224,67,224,68,224,69,224,70,224,71,224,72,224,73,224,74,224,75,224,76,224,77,224,78,224,79,224,80,224,81,224,82,224,83,224,84,224,85,224,86,224,87,224,88,224,89,224,90,224,91,224,92,224,93,224,114,115,115,115,116,115,117,115,118,115,119,115,120,115,121,115,122,115,123,115,124,115,125,115,127,115,128,115,129,115,130,115,131,115,133,115,134,115,136,115,138,115,140,115,141,115,143,115,144,115,146,115,147,115,148,115,149,115,151,115,152,115,153,115,154,115,156,115,157,115,158,115,160,115,161,115,163,115,164,115,165,115,166,115,167,115,168,115,170,115,172,115,173,115,177,115,180,115,181,115,182,115,184,115,185,115,188,115,189,115,190,115,191,115,193,115,195,115,196,115,197,115,198,115,199,115,203,115,204,115,206,115,210,115,211,115,212,115,213,115,214,115,215,115,216,115,218,115,219,115,220,115,221,115,223,115,225,115,226,115,227,115,228,115,230,115,232,115,234,115,235,115,236,115,238,115,239,115,240,115,241,115,243,115,244,115,245,115,246,115,247,115,94,224,95,224,96,224,97,224,98,224,99,224,100,224,101,224,102,224,103,224,104,224,105,224,106,224,107,224,108,224,109,224,110,224,111,224,112,224,113,224,114,224,115,224,116,224,117,224,118,224,119,224,120,224,121,224,122,224,123,224,124,224,125,224,126,224,127,224,128,224,129,224,130,224,131,224,132,224,133,224,134,224,135,224,136,224,137,224,138,224,139,224,140,224,141,224,142,224,143,224,144,224,145,224,146,224,147,224,148,224,149,224,150,224,151,224,152,224,153,224,154,224,155,224,156,224,157,224,158,224,159,224,160,224,161,224,162,224,163,224,164,224,165,224,166,224,167,224,168,224,169,224,170,224,171,224,172,224,173,224,174,224,175,224,176,224,177,224,178,224,179,224,180,224,181,224,182,224,183,224,184,224,185,224,186,224,187,224,248,115,249,115,250,115,251,115,252,115,253,115,254,115,255,115,0,116,1,116,2,116,4,116,7,116,8,116,11,116,12,116,13,116,14,116,17,116,18,116,19,116,20,116,21,116,22,116,23,116,24,116,25,116,28,116,29,116,30,116,31,116,32,116,33,116,35,116,36,116,39,116,41,116,43,116,45,116,47,116,49,116,50,116,55,116,56,116,57,116,58,116,59,116,61,116,62,116,63,116,64,116,66,116,67,116,68,116,69,116,70,116,71,116,72,116,73,116,74,116,75,116,76,116,77,116,78,116,79,116,80,116,81,116,82,116,83,116,84,116,86,116,88,116,93,116,96,116,97,116,98,116,99,116,100,116,101,116,102,116,103,116,104,116,105,116,106,116,107,116,108,116,110,116,111,116,113,116,114,116,115,116,116,116,117,116,120,116,121,116,122,116,188,224,189,224,190,224,191,224,192,224,193,224,194,224,195,224,196,224,197,224,198,224,199,224,200,224,201,224,202,224,203,224,204,224,205,224,206,224,207,224,208,224,209,224,210,224,211,224,212,224,213,224,214,224,215,224,216,224,217,224,218,224,219,224,220,224,221,224,222,224,223,224,224,224,225,224,226,224,227,224,228,224,229,224,230,224,231,224,232,224,233,224,234,224,235,224,236,224,237,224,238,224,239,224,240,224,241,224,242,224,243,224,244,224,245,224,246,224,247,224,248,224,249,224,250,224,251,224,252,224,253,224,254,224,255,224,0,225,1,225,2,225,3,225,4,225,5,225,6,225,7,225,8,225,9,225,10,225,11,225,12,225,13,225,14,225,15,225,16,225,17,225,18,225,19,225,20,225,21,225,22,225,23,225,24,225,25,225,123,116,124,116,125,116,127,116,130,116,132,116,133,116,134,116,136,116,137,116,138,116,140,116,141,116,143,116,145,116,146,116,147,116,148,116,149,116,150,116,151,116,152,116,153,116,154,116,155,116,157,116,159,116,160,116,161,116,162,116,163,116,164,116,165,116,166,116,170,116,171,116,172,116,173,116,174,116,175,116,176,116,177,116,178,116,179,116,180,116,181,116,182,116,183,116,184,116,185,116,187,116,188,116,189,116,190,116,191,116,192,116,193,116,194,116,195,116,196,116,197,116,198,116,199,116,200,116,201,116,202,116,203,116,204,116,205,116,206,116,207,116,208,116,209,116,211,116,212,116,213,116,214,116,215,116,216,116,217,116,218,116,219,116,221,116,223,116,225,116,229,116,231,116,232,116,233,116,234,116,235,116,236,116,237,116,240,116,241,116,242,116,26,225,27,225,28,225,29,225,30,225,31,225,32,225,33,225,34,225,35,225,36,225,37,225,38,225,39,225,40,225,41,225,42,225,43,225,44,225,45,225,46,225,47,225,48,225,49,225,50,225,51,225,52,225,53,225,54,225,55,225,56,225,57,225,58,225,59,225,60,225,61,225,62,225,63,225,64,225,65,225,66,225,67,225,68,225,69,225,70,225,71,225,72,225,73,225,74,225,75,225,76,225,77,225,78,225,79,225,80,225,81,225,82,225,83,225,84,225,85,225,86,225,87,225,88,225,89,225,90,225,91,225,92,225,93,225,94,225,95,225,96,225,97,225,98,225,99,225,100,225,101,225,102,225,103,225,104,225,105,225,106,225,107,225,108,225,109,225,110,225,111,225,112,225,113,225,114,225,115,225,116,225,117,225,118,225,119,225,243,116,245,116,248,116,249,116,250,116,251,116,252,116,253,116,254,116,0,117,1,117,2,117,3,117,5,117,6,117,7,117,8,117,9,117,10,117,11,117,12,117,14,117,16,117,18,117,20,117,21,117,22,117,23,117,27,117,29,117,30,117,32,117,33,117,34,117,35,117,36,117,38,117,39,117,42,117,46,117,52,117,54,117,57,117,60,117,61,117,63,117,65,117,66,117,67,117,68,117,70,117,71,117,73,117,74,117,77,117,80,117,81,117,82,117,83,117,85,117,86,117,87,117,88,117,93,117,94,117,95,117,96,117,97,117,98,117,99,117,100,117,103,117,104,117,105,117,107,117,108,117,109,117,110,117,111,117,112,117,113,117,115,117,117,117,118,117,119,117,122,117,123,117,124,117,125,117,126,117,128,117,129,117,130,117,132,117,133,117,135,117,120,225,121,225,122,225,123,225,124,225,125,225,126,225,127,225,128,225,129,225,130,225,131,225,132,225,133,225,134,225,135,225,136,225,137,225,138,225,139,225,140,225,141,225,142,225,143,225,144,225,145,225,146,225,147,225,148,225,149,225,150,225,151,225,152,225,153,225,154,225,155,225,156,225,157,225,158,225,159,225,160,225,161,225,162,225,163,225,164,225,165,225,166,225,167,225,168,225,169,225,170,225,171,225,172,225,173,225,174,225,175,225,176,225,177,225,178,225,179,225,180,225,181,225,182,225,183,225,184,225,185,225,186,225,187,225,188,225,189,225,190,225,191,225,192,225,193,225,194,225,195,225,196,225,197,225,198,225,199,225,200,225,201,225,202,225,203,225,204,225,205,225,206,225,207,225,208,225,209,225,210,225,211,225,212,225,213,225,136,117,137,117,138,117,140,117,141,117,142,117,144,117,147,117,149,117,152,117,155,117,156,117,158,117,162,117,166,117,167,117,168,117,169,117,170,117,173,117,182,117,183,117,186,117,187,117,191,117,192,117,193,117,198,117,203,117,204,117,206,117,207,117,208,117,209,117,211,117,215,117,217,117,218,117,220,117,221,117,223,117,224,117,225,117,229,117,233,117,236,117,237,117,238,117,239,117,242,117,243,117,245,117,246,117,247,117,248,117,250,117,251,117,253,117,254,117,2,118,4,118,6,118,7,118,8,118,9,118,11,118,13,118,14,118,15,118,17,118,18,118,19,118,20,118,22,118,26,118,28,118,29,118,30,118,33,118,35,118,39,118,40,118,44,118,46,118,47,118,49,118,50,118,54,118,55,118,57,118,58,118,59,118,61,118,65,118,66,118,68,118,214,225,215,225,216,225,217,225,218,225,219,225,220,225,221,225,222,225,223,225,224,225,225,225,226,225,227,225,228,225,229,225,230,225,231,225,232,225,233,225,234,225,235,225,236,225,237,225,238,225,239,225,240,225,241,225,242,225,243,225,244,225,245,225,246,225,247,225,248,225,249,225,250,225,251,225,252,225,253,225,254,225,255,225,0,226,1,226,2,226,3,226,4,226,5,226,6,226,7,226,8,226,9,226,10,226,11,226,12,226,13,226,14,226,15,226,16,226,17,226,18,226,19,226,20,226,21,226,22,226,23,226,24,226,25,226,26,226,27,226,28,226,29,226,30,226,31,226,32,226,33,226,34,226,35,226,36,226,37,226,38,226,39,226,40,226,41,226,42,226,43,226,44,226,45,226,46,226,47,226,48,226,49,226,50,226,51,226,69,118,70,118,71,118,72,118,73,118,74,118,75,118,78,118,79,118,80,118,81,118,82,118,83,118,85,118,87,118,88,118,89,118,90,118,91,118,93,118,95,118,96,118,97,118,98,118,100,118,101,118,102,118,103,118,104,118,105,118,106,118,108,118,109,118,110,118,112,118,113,118,114,118,115,118,116,118,117,118,118,118,119,118,121,118,122,118,124,118,127,118,128,118,129,118,131,118,133,118,137,118,138,118,140,118,141,118,143,118,144,118,146,118,148,118,149,118,151,118,152,118,154,118,155,118,156,118,157,118,158,118,159,118,160,118,161,118,162,118,163,118,165,118,166,118,167,118,168,118,169,118,170,118,171,118,172,118,173,118,175,118,176,118,179,118,181,118,182,118,183,118,184,118,185,118,186,118,187,118,188,118,189,118,190,118,192,118,193,118,195,118,74,85,63,150,195,87,40,99,206,84,9,85,192,84,145,118,76,118,60,133,238,119,126,130,141,120,49,114,152,150,141,151,40,108,137,91,250,79,9,99,151,102,184,92,250,128,72,104,174,128,2,102,206,118,249,81,86,101,172,113,241,127,132,136,178,80,101,89,202,97,179,111,173,130,76,99,82,98,237,83,39,84,6,123,107,81,164,117,244,93,212,98,203,141,118,151,138,98,25,128,93,87,56,151,98,127,56,114,125,118,207,103,126,118,70,100,112,79,37,141,220,98,23,122,145,101,237,115,44,100,115,98,44,130,129,152,127,103,72,114,110,98,204,98,52,79,227,116,74,83,158,82,202,126,166,144,46,94,134,104,156,105,128,129,209,126,210,104,197,120,140,134,81,149,141,80,36,140,222,130,222,128,5,83,18,137,101,82,196,118,199,118,201,118,203,118,204,118,211,118,213,118,217,118,218,118,220,118,221,118,222,118,224,118,225,118,226,118,227,118,228,118,230,118,231,118,232,118,233,118,234,118,235,118,236,118,237,118,240,118,243,118,245,118,246,118,247,118,250,118,251,118,253,118,255,118,0,119,2,119,3,119,5,119,6,119,10,119,12,119,14,119,15,119,16,119,17,119,18,119,19,119,20,119,21,119,22,119,23,119,24,119,27,119,28,119,29,119,30,119,33,119,35,119,36,119,37,119,39,119,42,119,43,119,44,119,46,119,48,119,49,119,50,119,51,119,52,119,57,119,59,119,61,119,62,119,63,119,66,119,68,119,69,119,70,119,72,119,73,119,74,119,75,119,76,119,77,119,78,119,79,119,82,119,83,119,84,119,85,119,86,119,87,119,88,119,89,119,92,119,132,133,249,150,221,79,33,88,113,153,157,91,177,98,165,98,180,102,121,140,141,156,6,114,111,103,145,120,178,96,81,83,23,83,136,143,204,128,29,141,161,148,13,80,200,114,7,89,235,96,25,113,171,136,84,89,239,130,44,103,40,123,41,93,247,126,45,117,245,108,102,142,248,143,60,144,59,159,212,107,25,145,20,123,124,95,167,120,214,132,61,133,213,107,217,107,214,107,1,94,135,94,249,117,237,149,93,101,10,95,197,95,159,143,193,88,194,129,127,144,91,150,173,151,185,143,22,127,44,141,65,98,191,79,216,83,94,83,168,143,169,143,171,143,77,144,7,104,106,95,152,129,104,136,214,156,139,97,43,82,42,118,108,95,140,101,210,111,232,110,190,91,72,100,117,81,176,81,196,103,25,78,201,121,124,153,179,112,93,119,94,119,95,119,96,119,100,119,103,119,105,119,106,119,109,119,110,119,111,119,112,119,113,119,114,119,115,119,116,119,117,119,118,119,119,119,120,119,122,119,123,119,124,119,129,119,130,119,131,119,134,119,135,119,136,119,137,119,138,119,139,119,143,119,144,119,147,119,148,119,149,119,150,119,151,119,152,119,153,119,154,119,155,119,156,119,157,119,158,119,161,119,163,119,164,119,166,119,168,119,171,119,173,119,174,119,175,119,177,119,178,119,180,119,182,119,183,119,184,119,185,119,186,119,188,119,190,119,192,119,193,119,194,119,195,119,196,119,197,119,198,119,199,119,200,119,201,119,202,119,203,119,204,119,206,119,207,119,208,119,209,119,210,119,211,119,212,119,213,119,214,119,216,119,217,119,218,119,221,119,222,119,223,119,224,119,225,119,228,119,197,117,118,94,187,115,224,131,173,100,232,98,181,148,226,108,90,83,195,82,15,100,194,148,148,123,47,79,27,94,54,130,22,129,138,129,36,110,202,108,115,154,85,99,92,83,250,84,101,136,224,87,13,78,3,94,101,107,63,124,232,144,22,96,230,100,28,115,193,136,80,103,77,98,34,141,108,119,41,142,199,145,105,95,220,131,33,133,16,153,194,83,149,134,139,107,237,96,232,96,127,112,205,130,49,130,211,78,167,108,207,133,205,100,217,124,253,105,249,102,73,131,149,83,86,123,167,79,140,81,75,109,66,92,109,142,210,99,201,83,44,131,54,131,229,103,180,120,61,100,223,91,148,92,238,93,231,139,198,98,244,103,122,140,0,100,186,99,73,135,139,153,23,140,32,127,242,148,167,78,16,150,164,152,12,102,22,115,230,119,232,119,234,119,239,119,240,119,241,119,242,119,244,119,245,119,247,119,249,119,250,119,251,119,252,119,3,120,4,120,5,120,6,120,7,120,8,120,10,120,11,120,14,120,15,120,16,120,19,120,21,120,25,120,27,120,30,120,32,120,33,120,34,120,36,120,40,120,42,120,43,120,46,120,47,120,49,120,50,120,51,120,53,120,54,120,61,120,63,120,65,120,66,120,67,120,68,120,70,120,72,120,73,120,74,120,75,120,77,120,79,120,81,120,83,120,84,120,88,120,89,120,90,120,91,120,92,120,94,120,95,120,96,120,97,120,98,120,99,120,100,120,101,120,102,120,103,120,104,120,105,120,111,120,112,120,113,120,114,120,115,120,116,120,117,120,118,120,120,120,121,120,122,120,123,120,125,120,126,120,127,120,128,120,129,120,130,120,131,120,58,87,29,92,56,94,127,149,127,80,160,128,130,83,94,101,69,117,49,85,33,80,133,141,132,98,158,148,29,103,50,86,110,111,226,93,53,84,146,112,102,143,111,98,164,100,163,99,123,95,136,111,244,144,227,129,176,143,24,92,104,102,241,95,137,108,72,150,129,141,108,136,145,100,240,121,206,87,89,106,16,98,72,84,88,78,11,122,233,96,132,111,218,139,127,98,30,144,139,154,228,121,3,84,244,117,1,99,25,83,96,108,223,143,27,95,112,154,59,128,127,159,136,79,58,92,100,141,197,127,165,101,189,112,69,81,178,81,107,134,7,93,160,91,189,98,108,145,116,117,12,142,32,122,1,97,121,123,199,78,248,126,133,119,17,78,237,129,29,82,250,81,113,106,168,83,135,142,4,149,207,150,193,110,100,150,90,105,132,120,133,120,134,120,136,120,138,120,139,120,143,120,144,120,146,120,148,120,149,120,150,120,153,120,157,120,158,120,160,120,162,120,164,120,166,120,168,120,169,120,170,120,171,120,172,120,173,120,174,120,175,120,181,120,182,120,183,120,184,120,186,120,187,120,188,120,189,120,191,120,192,120,194,120,195,120,196,120,198,120,199,120,200,120,204,120,205,120,206,120,207,120,209,120,210,120,211,120,214,120,215,120,216,120,218,120,219,120,220,120,221,120,222,120,223,120,224,120,225,120,226,120,227,120,228,120,229,120,230,120,231,120,233,120,234,120,235,120,237,120,238,120,239,120,240,120,241,120,243,120,245,120,246,120,248,120,249,120,251,120,252,120,253,120,254,120,255,120,0,121,2,121,3,121,4,121,6,121,7,121,8,121,9,121,10,121,11,121,12,121,64,120,168,80,215,119,16,100,230,137,4,89,227,99,221,93,127,122,61,105,32,79,57,130,152,85,50,78,174,117,151,122,98,94,138,94,239,149,27,82,57,84,138,112,118,99,36,149,130,87,37,102,63,105,135,145,7,85,243,109,175,126,34,136,51,98,240,126,181,117,40,131,193,120,204,150,158,143,72,97,247,116,205,139,100,107,58,82,80,141,33,107,106,128,113,132,241,86,6,83,206,78,27,78,209,81,151,124,139,145,7,124,195,79,127,142,225,123,156,122,103,100,20,93,172,80,6,129,1,118,185,124,236,109,224,127,81,103,88,91,248,91,203,120,174,100,19,100,170,99,43,99,25,149,45,100,190,143,84,123,41,118,83,98,39,89,70,84,121,107,163,80,52,98,38,94,134,107,227,78,55,141,139,136,133,95,46,144,13,121,14,121,15,121,16,121,17,121,18,121,20,121,21,121,22,121,23,121,24,121,25,121,26,121,27,121,28,121,29,121,31,121,32,121,33,121,34,121,35,121,37,121,38,121,39,121,40,121,41,121,42,121,43,121,44,121,45,121,46,121,47,121,48,121,49,121,50,121,51,121,53,121,54,121,55,121,56,121,57,121,61,121,63,121,66,121,67,121,68,121,69,121,71,121,74,121,75,121,76,121,77,121,78,121,79,121,80,121,81,121,82,121,84,121,85,121,88,121,89,121,97,121,99,121,100,121,102,121,105,121,106,121,107,121,108,121,110,121,112,121,113,121,114,121,115,121,116,121,117,121,118,121,121,121,123,121,124,121,125,121,126,121,127,121,130,121,131,121,134,121,135,121,136,121,137,121,139,121,140,121,141,121,142,121,144,121,145,121,146,121,32,96,61,128,197,98,57,78,85,83,248,144,184,99,198,128,230,101,46,108,70,79,238,96,225,109,222,139,57,95,203,134,83,95,33,99,90,81,97,131,99,104,0,82,99,99,72,142,18,80,155,92,119,121,252,91,48,82,59,122,188,96,83,144,215,118,183,95,151,95,132,118,108,142,111,112,123,118,73,123,170,119,243,81,147,144,36,88,78,79,244,110,234,143,76,101,27,123,196,114,164,109,223,127,225,90,181,98,149,94,48,87,130,132,44,123,29,94,31,95,18,144,20,127,160,152,130,99,199,110,152,120,185,112,120,81,91,151,171,87,53,117,67,79,56,117,151,94,230,96,96,89,192,109,191,107,137,120,252,83,213,150,203,81,1,82,137,99,10,84,147,148,3,140,204,141,57,114,159,120,118,135,237,143,13,140,224,83,147,121,148,121,149,121,150,121,151,121,152,121,153,121,155,121,156,121,157,121,158,121,159,121,160,121,161,121,162,121,163,121,164,121,165,121,166,121,168,121,169,121,170,121,171,121,172,121,173,121,174,121,175,121,176,121,177,121,178,121,180,121,181,121,182,121,183,121,184,121,188,121,191,121,194,121,196,121,197,121,199,121,200,121,202,121,204,121,206,121,207,121,208,121,211,121,212,121,214,121,215,121,217,121,218,121,219,121,220,121,221,121,222,121,224,121,225,121,226,121,229,121,232,121,234,121,236,121,238,121,241,121,242,121,243,121,244,121,245,121,246,121,247,121,249,121,250,121,252,121,254,121,255,121,1,122,4,122,5,122,7,122,8,122,9,122,10,122,12,122,15,122,16,122,17,122,18,122,19,122,21,122,22,122,24,122,25,122,27,122,28,122,1,78,239,118,238,83,137,148,118,152,14,159,45,149,154,91,162,139,34,78,28,78,172,81,99,132,194,97,168,82,11,104,151,79,107,96,187,81,30,109,92,81,150,98,151,101,97,150,70,140,23,144,216,117,253,144,99,119,210,107,138,114,236,114,251,139,53,88,121,119,76,141,92,103,64,149,154,128,166,94,33,110,146,89,239,122,237,119,59,149,181,107,173,101,14,127,6,88,81,81,31,150,249,91,169,88,40,84,114,142,102,101,127,152,228,86,157,148,254,118,65,144,135,99,198,84,26,89,58,89,155,87,178,142,53,103,250,141,53,130,65,82,240,96,21,88,254,134,232,92,69,158,196,79,157,152,185,139,37,90,118,96,132,83,124,98,79,144,2,145,127,153,105,96,12,128,63,81,51,128,20,92,117,153,49,109,140,78,29,122,31,122,33,122,34,122,36,122,37,122,38,122,39,122,40,122,41,122,42,122,43,122,44,122,45,122,46,122,47,122,48,122,49,122,50,122,52,122,53,122,54,122,56,122,58,122,62,122,64,122,65,122,66,122,67,122,68,122,69,122,71,122,72,122,73,122,74,122,75,122,76,122,77,122,78,122,79,122,80,122,82,122,83,122,84,122,85,122,86,122,88,122,89,122,90,122,91,122,92,122,93,122,94,122,95,122,96,122,97,122,98,122,99,122,100,122,101,122,102,122,103,122,104,122,105,122,106,122,107,122,108,122,109,122,110,122,111,122,113,122,114,122,115,122,117,122,123,122,124,122,125,122,126,122,130,122,133,122,135,122,137,122,138,122,139,122,140,122,142,122,143,122,144,122,147,122,148,122,153,122,154,122,155,122,158,122,161,122,162,122,48,141,209,83,90,127,79,123,16,79,79,78,0,150,213,108,208,115,233,133,6,94,106,117,251,127,10,106,254,119,146,148,65,126,225,81,230,112,205,83,212,143,3,131,41,141,175,114,109,153,219,108,74,87,179,130,185,101,170,128,63,98,50,150,168,89,255,78,191,139,186,126,62,101,242,131,94,151,97,85,222,152,165,128,42,83,253,139,32,84,186,128,159,94,184,108,57,141,172,130,90,145,41,84,27,108,6,82,183,126,95,87,26,113,126,108,137,124,75,89,253,78,255,95,36,97,170,124,48,78,1,92,171,103,2,135,240,92,11,149,206,152,175,117,253,112,34,144,175,81,29,127,189,139,73,89,228,81,91,79,38,84,43,89,119,101,164,128,117,91,118,98,194,98,144,143,69,94,31,108,38,123,15,79,216,79,13,103,163,122,164,122,167,122,169,122,170,122,171,122,174,122,175,122,176,122,177,122,178,122,180,122,181,122,182,122,183,122,184,122,185,122,186,122,187,122,188,122,189,122,190,122,192,122,193,122,194,122,195,122,196,122,197,122,198,122,199,122,200,122,201,122,202,122,204,122,205,122,206,122,207,122,208,122,209,122,210,122,211,122,212,122,213,122,215,122,216,122,218,122,219,122,220,122,221,122,225,122,226,122,228,122,231,122,232,122,233,122,234,122,235,122,236,122,238,122,240,122,241,122,242,122,243,122,244,122,245,122,246,122,247,122,248,122,251,122,252,122,254,122,0,123,1,123,2,123,5,123,7,123,9,123,12,123,13,123,14,123,16,123,18,123,19,123,22,123,23,123,24,123,26,123,28,123,29,123,31,123,33,123,34,123,35,123,39,123,41,123,45,123,110,109,170,109,143,121,177,136,23,95,43,117,154,98,133,143,239,79,220,145,167,101,47,129,81,129,156,94,80,129,116,141,111,82,134,137,75,141,13,89,133,80,216,78,28,150,54,114,121,129,31,141,204,91,163,139,68,150,135,89,26,127,144,84,118,86,14,86,229,139,57,101,130,105,153,148,214,118,137,110,114,94,24,117,70,103,209,103,255,122,157,128,118,141,31,97,198,121,98,101,99,141,136,81,26,82,162,148,56,127,155,128,178,126,151,92,47,110,96,103,217,123,139,118,216,154,143,129,148,127,213,124,30,100,80,149,63,122,74,84,229,84,76,107,1,100,8,98,61,158,243,128,153,117,114,82,105,151,91,132,60,104,228,134,1,150,148,150,236,148,42,78,4,84,217,126,57,104,223,141,21,128,244,102,154,94,185,127,47,123,48,123,50,123,52,123,53,123,54,123,55,123,57,123,59,123,61,123,63,123,64,123,65,123,66,123,67,123,68,123,70,123,72,123,74,123,77,123,78,123,83,123,85,123,87,123,89,123,92,123,94,123,95,123,97,123,99,123,100,123,101,123,102,123,103,123,104,123,105,123,106,123,107,123,108,123,109,123,111,123,112,123,115,123,116,123,118,123,120,123,122,123,124,123,125,123,127,123,129,123,130,123,131,123,132,123,134,123,135,123,136,123,137,123,138,123,139,123,140,123,142,123,143,123,145,123,146,123,147,123,150,123,152,123,153,123,154,123,155,123,158,123,159,123,160,123,163,123,164,123,165,123,174,123,175,123,176,123,178,123,179,123,181,123,182,123,183,123,185,123,186,123,187,123,188,123,189,123,190,123,191,123,192,123,194,123,195,123,196,123,194,87,63,128,151,104,229,93,59,101,159,82,109,96,154,159,155,79,172,142,108,81,171,91,19,95,233,93,94,108,241,98,33,141,113,81,169,148,254,82,159,108,223,130,215,114,162,87,132,103,45,141,31,89,156,143,199,131,149,84,141,123,48,79,189,108,100,91,209,89,19,159,228,83,202,134,168,154,55,140,161,128,69,101,126,152,250,86,199,150,46,82,220,116,80,82,225,91,2,99,2,137,86,78,208,98,42,96,250,104,115,81,152,91,160,81,194,137,161,123,134,153,80,127,239,96,76,112,47,141,73,81,127,94,27,144,112,116,196,137,45,87,69,120,82,95,159,159,250,149,104,143,60,155,225,139,120,118,66,104,220,103,234,141,53,141,61,82,138,143,218,110,205,104,5,149,237,144,253,86,156,103,249,136,199,143,200,84,197,123,200,123,201,123,202,123,203,123,205,123,206,123,207,123,208,123,210,123,212,123,213,123,214,123,215,123,216,123,219,123,220,123,222,123,223,123,224,123,226,123,227,123,228,123,231,123,232,123,233,123,235,123,236,123,237,123,239,123,240,123,242,123,243,123,244,123,245,123,246,123,248,123,249,123,250,123,251,123,253,123,255,123,0,124,1,124,2,124,3,124,4,124,5,124,6,124,8,124,9,124,10,124,13,124,14,124,16,124,17,124,18,124,19,124,20,124,21,124,23,124,24,124,25,124,26,124,27,124,28,124,29,124,30,124,32,124,33,124,34,124,35,124,36,124,37,124,40,124,41,124,43,124,44,124,45,124,46,124,47,124,48,124,49,124,50,124,51,124,52,124,53,124,54,124,55,124,57,124,58,124,59,124,60,124,61,124,62,124,66,124,184,154,105,91,119,109,38,108,165,78,179,91,135,154,99,145,168,97,175,144,233,151,43,84,181,109,210,91,253,81,138,85,85,127,240,127,188,100,77,99,241,101,190,97,141,96,10,113,87,108,73,108,47,89,109,103,42,130,213,88,142,86,106,140,235,107,221,144,125,89,23,128,247,83,105,109,117,84,157,85,119,131,207,131,56,104,190,121,140,84,85,79,8,84,210,118,137,140,2,150,179,108,184,109,107,141,16,137,100,158,58,141,63,86,209,158,213,117,136,95,224,114,104,96,252,84,168,78,42,106,97,136,82,96,112,143,196,84,216,112,121,134,63,158,42,109,143,91,24,95,162,126,137,85,175,79,52,115,60,84,154,83,25,80,14,84,124,84,78,78,253,95,90,116,246,88,107,132,225,128,116,135,208,114,202,124,86,110,67,124,68,124,69,124,70,124,71,124,72,124,73,124,74,124,75,124,76,124,78,124,79,124,80,124,81,124,82,124,83,124,84,124,85,124,86,124,87,124,88,124,89,124,90,124,91,124,92,124,93,124,94,124,95,124,96,124,97,124,98,124,99,124,100,124,101,124,102,124,103,124,104,124,105,124,106,124,107,124,108,124,109,124,110,124,111,124,112,124,113,124,114,124,117,124,118,124,119,124,120,124,121,124,122,124,126,124,127,124,128,124,129,124,130,124,131,124,132,124,133,124,134,124,135,124,136,124,138,124,139,124,140,124,141,124,142,124,143,124,144,124,147,124,148,124,150,124,153,124,154,124,155,124,160,124,161,124,163,124,166,124,167,124,168,124,169,124,171,124,172,124,173,124,175,124,176,124,180,124,181,124,182,124,183,124,184,124,186,124,187,124,39,95,78,134,44,85,164,98,146,78,170,108,55,98,177,130,215,84,78,83,62,115,209,110,59,117,18,82,22,83,221,139,208,105,138,95,0,96,238,109,79,87,34,107,175,115,83,104,216,143,19,127,98,99,163,96,36,85,234,117,98,140,21,113,163,109,166,91,123,94,82,131,76,97,196,158,250,120,87,135,39,124,135,118,240,81,246,96,76,113,67,102,76,94,77,96,14,140,112,112,37,99,137,143,189,95,98,96,212,134,222,86,193,107,148,96,103,97,73,83,224,96,102,102,63,141,253,121,26,79,233,112,71,108,179,139,242,139,216,126,100,131,15,102,90,90,66,155,81,109,247,109,65,140,59,109,25,79,107,112,183,131,22,98,209,96,13,151,39,141,120,121,251,81,62,87,250,87,58,103,120,117,61,122,239,121,149,123,191,124,192,124,194,124,195,124,196,124,198,124,201,124,203,124,206,124,207,124,208,124,209,124,210,124,211,124,212,124,216,124,218,124,219,124,221,124,222,124,225,124,226,124,227,124,228,124,229,124,230,124,231,124,233,124,234,124,235,124,236,124,237,124,238,124,240,124,241,124,242,124,243,124,244,124,245,124,246,124,247,124,249,124,250,124,252,124,253,124,254,124,255,124,0,125,1,125,2,125,3,125,4,125,5,125,6,125,7,125,8,125,9,125,11,125,12,125,13,125,14,125,15,125,16,125,17,125,18,125,19,125,20,125,21,125,22,125,23,125,24,125,25,125,26,125,27,125,28,125,29,125,30,125,31,125,33,125,35,125,36,125,37,125,38,125,40,125,41,125,42,125,44,125,45,125,46,125,48,125,49,125,50,125,51,125,52,125,53,125,54,125,140,128,101,153,249,143,192,111,165,139,33,158,236,89,233,126,9,127,9,84,129,103,216,104,145,143,77,124,198,150,202,83,37,96,190,117,114,108,115,83,201,90,167,126,36,99,224,81,10,129,241,93,223,132,128,98,128,81,99,91,14,79,109,121,66,82,184,96,78,109,196,91,194,91,161,139,176,139,226,101,204,95,69,150,147,89,231,126,170,126,9,86,183,103,57,89,115,79,182,91,160,82,90,131,138,152,62,141,50,117,190,148,71,80,60,122,247,78,182,103,126,154,193,90,124,107,209,118,90,87,22,92,58,123,244,149,78,113,124,81,169,128,112,130,120,89,4,127,39,131,192,104,236,103,177,120,119,120,227,98,97,99,128,123,237,79,106,82,207,81,80,131,219,105,116,146,245,141,49,141,193,137,46,149,173,123,246,78,55,125,56,125,57,125,58,125,59,125,60,125,61,125,62,125,63,125,64,125,65,125,66,125,67,125,68,125,69,125,70,125,71,125,72,125,73,125,74,125,75,125,76,125,77,125,78,125,79,125,80,125,81,125,82,125,83,125,84,125,85,125,86,125,87,125,88,125,89,125,90,125,91,125,92,125,93,125,94,125,95,125,96,125,97,125,98,125,99,125,100,125,101,125,102,125,103,125,104,125,105,125,106,125,107,125,108,125,109,125,111,125,112,125,113,125,114,125,115,125,116,125,117,125,118,125,120,125,121,125,122,125,123,125,124,125,125,125,126,125,127,125,128,125,129,125,130,125,131,125,132,125,133,125,134,125,135,125,136,125,137,125,138,125,139,125,140,125,141,125,142,125,143,125,144,125,145,125,146,125,147,125,148,125,149,125,150,125,151,125,152,125,101,80,48,130,81,82,111,153,16,110,133,110,167,109,250,94,245,80,220,89,6,92,70,109,95,108,134,117,139,132,104,104,86,89,178,139,32,83,113,145,77,150,73,133,18,105,1,121,38,113,246,128,164,78,202,144,71,109,132,154,7,90,188,86,5,100,240,148,235,119,165,79,26,129,225,114,210,137,122,153,52,127,222,126,127,82,89,101,117,145,127,143,131,143,235,83,150,122,237,99,165,99,134,118,248,121,87,136,54,150,42,98,171,82,130,130,84,104,112,103,119,99,107,119,237,122,1,109,211,126,227,137,208,89,18,98,201,133,165,130,76,117,31,80,203,78,165,117,235,139,74,92,254,93,75,123,164,101,209,145,202,78,37,109,95,137,39,125,38,149,197,78,40,140,219,143,115,151,75,102,129,121,209,143,236,112,120,109,153,125,154,125,155,125,156,125,157,125,158,125,159,125,160,125,161,125,162,125,163,125,164,125,165,125,167,125,168,125,169,125,170,125,171,125,172,125,173,125,175,125,176,125,177,125,178,125,179,125,180,125,181,125,182,125,183,125,184,125,185,125,186,125,187,125,188,125,189,125,190,125,191,125,192,125,193,125,194,125,195,125,196,125,197,125,198,125,199,125,200,125,201,125,202,125,203,125,204,125,205,125,206,125,207,125,208,125,209,125,210,125,211,125,212,125,213,125,214,125,215,125,216,125,217,125,218,125,219,125,220,125,221,125,222,125,223,125,224,125,225,125,226,125,227,125,228,125,229,125,230,125,231,125,232,125,233,125,234,125,235,125,236,125,237,125,238,125,239,125,240,125,241,125,242,125,243,125,244,125,245,125,246,125,247,125,248,125,249,125,250,125,61,92,178,82,70,131,98,81,14,131,91,119,118,102,184,156,172,78,202,96,190,124,179,124,207,126,149,78,102,139,111,102,136,152,89,151,131,88,108,101,92,149,132,95,201,117,86,151,223,122,222,122,192,81,175,112,152,122,234,99,118,122,160,126,150,115,237,151,69,78,120,112,93,78,82,145,169,83,81,101,231,101,252,129,5,130,142,84,49,92,154,117,160,151,216,98,217,114,189,117,69,92,121,154,202,131,64,92,128,84,233,119,62,78,174,108,90,128,210,98,110,99,232,93,119,81,221,141,30,142,47,149,241,79,229,83,231,96,172,112,103,82,80,99,67,158,31,90,38,80,55,119,119,83,226,126,133,100,43,101,137,98,152,99,20,80,53,114,201,137,179,81,192,139,221,126,71,87,204,131,167,148,155,81,27,84,251,92,251,125,252,125,253,125,254,125,255,125,0,126,1,126,2,126,3,126,4,126,5,126,6,126,7,126,8,126,9,126,10,126,11,126,12,126,13,126,14,126,15,126,16,126,17,126,18,126,19,126,20,126,21,126,22,126,23,126,24,126,25,126,26,126,27,126,28,126,29,126,30,126,31,126,32,126,33,126,34,126,35,126,36,126,37,126,38,126,39,126,40,126,41,126,42,126,43,126,44,126,45,126,46,126,47,126,48,126,49,126,50,126,51,126,52,126,53,126,54,126,55,126,56,126,57,126,58,126,60,126,61,126,62,126,63,126,64,126,66,126,67,126,68,126,69,126,70,126,72,126,73,126,74,126,75,126,76,126,77,126,78,126,79,126,80,126,81,126,82,126,83,126,84,126,85,126,86,126,87,126,88,126,89,126,90,126,91,126,92,126,93,126,202,79,227,122,90,109,225,144,143,154,128,85,150,84,97,83,175,84,0,95,233,99,119,105,239,81,104,97,10,82,42,88,216,82,78,87,13,120,11,119,183,94,119,97,224,124,91,98,151,98,162,78,149,112,3,128,247,98,228,112,96,151,119,87,219,130,239,103,245,104,213,120,151,152,209,121,243,88,179,84,239,83,52,110,75,81,59,82,162,91,254,139,175,128,67,85,166,87,115,96,81,87,45,84,122,122,80,96,84,91,167,99,160,98,227,83,99,98,199,91,175,103,237,84,159,122,230,130,119,145,147,94,228,136,56,89,174,87,14,99,232,141,239,128,87,87,119,123,169,79,235,95,189,91,62,107,33,83,80,123,194,114,70,104,255,119,54,119,247,101,181,81,143,78,212,118,191,92,165,122,117,132,78,89,65,155,128,80,94,126,95,126,96,126,97,126,98,126,99,126,100,126,101,126,102,126,103,126,104,126,105,126,106,126,107,126,108,126,109,126,110,126,111,126,112,126,113,126,114,126,115,126,116,126,117,126,118,126,119,126,120,126,121,126,122,126,123,126,124,126,125,126,126,126,127,126,128,126,129,126,131,126,132,126,133,126,134,126,135,126,136,126,137,126,138,126,139,126,140,126,141,126,142,126,143,126,144,126,145,126,146,126,147,126,148,126,149,126,150,126,151,126,152,126,153,126,154,126,156,126,157,126,158,126,174,126,180,126,187,126,188,126,214,126,228,126,236,126,249,126,10,127,16,127,30,127,55,127,57,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,67,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,82,127,83,127,136,153,39,97,131,110,100,87,6,102,70,99,240,86,236,98,105,98,211,94,20,150,131,87,201,98,135,85,33,135,74,129,163,143,102,85,177,131,101,103,86,141,221,132,106,90,15,104,230,98,238,123,17,150,112,81,156,111,48,140,253,99,200,137,210,97,6,127,194,112,229,110,5,116,148,105,252,114,202,94,206,144,23,103,106,109,94,99,179,82,98,114,1,128,108,79,229,89,106,145,217,112,157,109,210,82,80,78,247,150,109,149,126,133,202,120,47,125,33,81,146,87,194,100,139,128,123,124,234,108,241,104,94,105,183,81,152,83,168,104,129,114,206,158,241,123,248,114,187,121,19,111,6,116,78,103,204,145,164,156,60,121,137,131,84,131,15,84,23,104,61,78,137,83,177,82,62,120,134,83,41,82,136,80,139,79,208,79,86,127,89,127,91,127,92,127,93,127,94,127,96,127,99,127,100,127,101,127,102,127,103,127,107,127,108,127,109,127,111,127,112,127,115,127,117,127,118,127,119,127,120,127,122,127,123,127,124,127,125,127,127,127,128,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,139,127,141,127,143,127,144,127,145,127,146,127,147,127,149,127,150,127,151,127,152,127,153,127,155,127,156,127,160,127,162,127,163,127,165,127,166,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,177,127,179,127,180,127,181,127,182,127,183,127,186,127,187,127,190,127,192,127,194,127,195,127,196,127,198,127,199,127,200,127,201,127,203,127,205,127,207,127,208,127,209,127,210,127,211,127,214,127,215,127,217,127,218,127,219,127,220,127,221,127,222,127,226,127,227,127,226,117,203,122,146,124,165,108,182,150,155,82,131,116,233,84,233,79,84,128,178,131,222,143,112,149,201,94,28,96,159,109,24,94,91,101,56,129,254,148,75,96,188,112,195,126,174,124,201,81,129,104,177,124,111,130,36,78,134,143,207,145,126,102,174,78,5,140,169,100,74,128,218,80,151,117,206,113,229,91,189,143,102,111,134,78,130,100,99,149,214,94,153,101,23,82,194,136,200,112,163,82,14,115,51,116,151,103,247,120,22,151,52,78,187,144,222,156,203,109,219,81,65,141,29,84,206,98,178,115,241,131,246,150,132,159,195,148,54,79,154,127,204,81,117,112,117,150,173,92,134,152,230,83,228,78,156,110,9,116,180,105,107,120,143,153,89,117,24,82,36,118,65,109,243,103,109,81,153,159,75,128,153,84,60,123,191,122,228,127,231,127,232,127,234,127,235,127,236,127,237,127,239,127,242,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,253,127,254,127,255,127,2,128,7,128,8,128,9,128,10,128,14,128,15,128,17,128,19,128,26,128,27,128,29,128,30,128,31,128,33,128,35,128,36,128,43,128,44,128,45,128,46,128,47,128,48,128,50,128,52,128,57,128,58,128,60,128,62,128,64,128,65,128,68,128,69,128,71,128,72,128,73,128,78,128,79,128,80,128,81,128,83,128,85,128,86,128,87,128,89,128,91,128,92,128,93,128,94,128,95,128,96,128,97,128,98,128,99,128,100,128,101,128,102,128,103,128,104,128,107,128,108,128,109,128,110,128,111,128,112,128,114,128,115,128,116,128,117,128,118,128,119,128,120,128,121,128,122,128,123,128,124,128,125,128,134,150,132,87,226,98,71,150,124,105,4,90,2,100,211,123,15,111,75,150,166,130,98,83,133,152,144,94,137,112,179,99,100,83,79,134,129,156,147,158,140,120,50,151,239,141,66,141,127,158,94,111,132,121,85,95,70,150,46,98,116,154,21,84,221,148,163,79,197,101,101,92,97,92,21,127,81,134,47,108,139,95,135,115,228,110,255,126,230,92,27,99,106,91,230,110,117,83,113,78,160,99,101,117,161,98,110,143,38,79,209,78,166,108,182,126,186,139,29,132,186,135,87,127,59,144,35,149,169,123,161,154,248,136,61,132,27,109,134,154,220,126,136,89,187,158,155,115,1,120,130,134,108,154,130,154,27,86,23,84,203,87,112,78,166,158,86,83,200,143,9,129,146,119,146,153,238,134,225,110,19,133,252,102,98,97,43,111,126,128,129,128,130,128,133,128,136,128,138,128,141,128,142,128,143,128,144,128,145,128,146,128,148,128,149,128,151,128,153,128,158,128,163,128,166,128,167,128,168,128,172,128,176,128,179,128,181,128,182,128,184,128,185,128,187,128,197,128,199,128,200,128,201,128,202,128,203,128,207,128,208,128,209,128,210,128,211,128,212,128,213,128,216,128,223,128,224,128,226,128,227,128,230,128,238,128,245,128,247,128,249,128,251,128,254,128,255,128,0,129,1,129,3,129,4,129,5,129,7,129,8,129,11,129,12,129,21,129,23,129,25,129,27,129,28,129,29,129,31,129,32,129,33,129,34,129,35,129,36,129,37,129,38,129,39,129,40,129,41,129,42,129,43,129,45,129,46,129,48,129,51,129,52,129,53,129,55,129,57,129,58,129,59,129,60,129,61,129,63,129,41,140,146,130,43,131,242,118,19,108,217,95,189,131,43,115,5,131,26,149,219,107,219,119,198,148,111,83,2,131,146,81,61,94,140,140,56,141,72,78,171,115,154,103,133,104,118,145,9,151,100,113,161,108,9,119,146,90,65,149,207,107,142,127,39,102,208,91,185,89,154,90,232,149,247,149,236,78,12,132,153,132,172,106,223,118,48,149,27,115,166,104,95,91,47,119,154,145,97,151,220,124,247,143,28,140,37,95,115,124,216,121,197,137,204,108,28,135,198,91,66,94,201,104,32,119,245,126,149,81,77,81,201,82,41,90,5,127,98,151,215,130,207,99,132,119,208,133,210,121,58,110,153,94,153,89,17,133,109,112,17,108,191,98,191,118,79,101,175,96,253,149,14,102,159,135,35,158,237,148,13,84,125,84,44,140,120,100,64,129,65,129,66,129,67,129,68,129,69,129,71,129,73,129,77,129,78,129,79,129,82,129,86,129,87,129,88,129,91,129,92,129,93,129,94,129,95,129,97,129,98,129,99,129,100,129,102,129,104,129,106,129,107,129,108,129,111,129,114,129,115,129,117,129,118,129,119,129,120,129,129,129,131,129,132,129,133,129,134,129,135,129,137,129,139,129,140,129,141,129,142,129,144,129,146,129,147,129,148,129,149,129,150,129,151,129,153,129,154,129,158,129,159,129,160,129,161,129,162,129,164,129,165,129,167,129,169,129,171,129,172,129,173,129,174,129,175,129,176,129,177,129,178,129,180,129,181,129,182,129,183,129,184,129,185,129,188,129,189,129,190,129,191,129,196,129,197,129,199,129,200,129,201,129,203,129,205,129,206,129,207,129,208,129,209,129,210,129,211,129,121,100,17,134,33,106,156,129,232,120,105,100,84,155,185,98,43,103,171,131,168,88,216,158,171,108,32,111,222,91,76,150,11,140,95,114,208,103,199,98,97,114,169,78,198,89,205,107,147,88,174,102,85,94,223,82,85,97,40,103,238,118,102,119,103,114,70,122,255,98,234,84,80,84,160,148,163,144,28,90,179,126,22,108,67,78,118,89,16,128,72,89,87,83,55,117,190,150,202,86,32,99,17,129,124,96,249,149,214,109,98,84,129,153,133,81,233,90,253,128,174,89,19,151,42,80,229,108,60,92,223,98,96,79,63,83,123,129,6,144,186,110,43,133,200,98,116,94,190,120,181,100,123,99,245,95,24,90,127,145,31,158,63,92,79,99,66,128,125,91,110,85,74,149,77,149,133,109,168,96,224,103,222,114,221,81,129,91,212,129,213,129,214,129,215,129,216,129,217,129,218,129,219,129,220,129,221,129,222,129,223,129,224,129,225,129,226,129,228,129,229,129,230,129,232,129,233,129,235,129,238,129,239,129,240,129,241,129,242,129,245,129,246,129,247,129,248,129,249,129,250,129,253,129,255,129,3,130,7,130,8,130,9,130,10,130,11,130,14,130,15,130,17,130,19,130,21,130,22,130,23,130,24,130,25,130,26,130,29,130,32,130,36,130,37,130,38,130,39,130,41,130,46,130,50,130,58,130,60,130,61,130,63,130,64,130,65,130,66,130,67,130,69,130,70,130,72,130,74,130,76,130,77,130,78,130,80,130,81,130,82,130,83,130,84,130,85,130,86,130,87,130,89,130,91,130,92,130,93,130,94,130,96,130,97,130,98,130,99,130,100,130,101,130,102,130,103,130,105,130,231,98,222,108,91,114,109,98,174,148,189,126,19,129,83,109,156,81,4,95,116,89,170,82,18,96,115,89,150,102,80,134,159,117,42,99,230,97,239,124,250,139,230,84,39,107,37,158,180,107,213,133,85,84,118,80,164,108,106,85,180,141,44,114,21,94,21,96,54,116,205,98,146,99,76,114,152,95,67,110,62,109,0,101,88,111,216,118,208,120,252,118,84,117,36,82,219,83,83,78,158,94,193,101,42,128,214,128,155,98,134,84,40,82,174,112,141,136,209,141,225,108,120,84,218,128,249,87,244,136,84,141,106,150,77,145,105,79,155,108,183,85,198,118,48,120,168,98,249,112,142,111,109,95,236,132,218,104,124,120,247,123,168,129,11,103,79,158,103,99,176,120,111,87,18,120,57,151,121,98,171,98,136,82,53,116,215,107,106,130,107,130,108,130,109,130,113,130,117,130,118,130,119,130,120,130,123,130,124,130,128,130,129,130,131,130,133,130,134,130,135,130,137,130,140,130,144,130,147,130,148,130,149,130,150,130,154,130,155,130,158,130,160,130,162,130,163,130,167,130,178,130,181,130,182,130,186,130,187,130,188,130,191,130,192,130,194,130,195,130,197,130,198,130,201,130,208,130,214,130,217,130,218,130,221,130,226,130,231,130,232,130,233,130,234,130,236,130,237,130,238,130,240,130,242,130,243,130,245,130,246,130,248,130,250,130,252,130,253,130,254,130,255,130,0,131,10,131,11,131,13,131,16,131,18,131,19,131,22,131,24,131,25,131,29,131,30,131,31,131,32,131,33,131,34,131,35,131,36,131,37,131,38,131,41,131,42,131,46,131,48,131,50,131,55,131,59,131,61,131,100,85,62,129,178,117,174,118,57,83,222,117,251,80,65,92,108,139,199,123,79,80,71,114,151,154,216,152,2,111,226,116,104,121,135,100,165,119,252,98,145,152,43,141,193,84,88,128,82,78,106,87,249,130,13,132,115,94,237,81,246,116,196,139,79,92,97,87,252,108,135,152,70,90,52,120,68,155,235,143,149,124,86,82,81,98,250,148,198,78,134,131,97,132,233,131,178,132,212,87,52,103,3,87,110,102,102,109,49,140,221,102,17,112,31,103,58,107,22,104,26,98,187,89,3,78,196,81,6,111,210,103,143,108,118,81,203,104,71,89,103,107,102,117,14,93,16,129,80,159,215,101,72,121,65,121,145,154,119,141,130,92,94,78,1,79,47,84,81,89,12,120,104,86,20,108,196,143,3,95,125,108,227,108,171,139,144,99,62,131,63,131,65,131,66,131,68,131,69,131,72,131,74,131,75,131,76,131,77,131,78,131,83,131,85,131,86,131,87,131,88,131,89,131,93,131,98,131,112,131,113,131,114,131,115,131,116,131,117,131,118,131,121,131,122,131,126,131,127,131,128,131,129,131,130,131,131,131,132,131,135,131,136,131,138,131,139,131,140,131,141,131,143,131,144,131,145,131,148,131,149,131,150,131,151,131,153,131,154,131,157,131,159,131,161,131,162,131,163,131,164,131,165,131,166,131,167,131,172,131,173,131,174,131,175,131,181,131,187,131,190,131,191,131,194,131,195,131,196,131,198,131,200,131,201,131,203,131,205,131,206,131,208,131,209,131,210,131,211,131,213,131,215,131,217,131,218,131,219,131,222,131,226,131,227,131,228,131,230,131,231,131,232,131,235,131,236,131,237,131,112,96,61,109,117,114,102,98,142,148,197,148,67,83,193,143,126,123,223,78,38,140,126,78,212,158,177,148,179,148,77,82,92,111,99,144,69,109,52,140,17,88,76,93,32,107,73,107,170,103,91,84,84,129,140,127,153,88,55,133,58,95,162,98,71,106,57,149,114,101,132,96,101,104,167,119,84,78,168,79,231,93,152,151,172,100,216,127,237,92,207,79,141,122,7,82,4,131,20,78,47,96,131,122,166,148,181,79,178,78,230,121,52,116,228,82,185,130,210,100,189,121,221,91,129,108,82,151,123,143,34,108,62,80,127,83,5,110,206,100,116,102,48,108,197,96,119,152,247,139,134,94,60,116,119,122,203,121,24,78,177,144,3,116,66,108,218,86,75,145,197,108,139,141,58,83,198,134,242,102,175,142,72,92,113,154,32,110,238,131,239,131,243,131,244,131,245,131,246,131,247,131,250,131,251,131,252,131,254,131,255,131,0,132,2,132,5,132,7,132,8,132,9,132,10,132,16,132,18,132,19,132,20,132,21,132,22,132,23,132,25,132,26,132,27,132,30,132,31,132,32,132,33,132,34,132,35,132,41,132,42,132,43,132,44,132,45,132,46,132,47,132,48,132,50,132,51,132,52,132,53,132,54,132,55,132,57,132,58,132,59,132,62,132,63,132,64,132,65,132,66,132,67,132,68,132,69,132,71,132,72,132,73,132,74,132,75,132,76,132,77,132,78,132,79,132,80,132,82,132,83,132,84,132,85,132,86,132,88,132,93,132,94,132,95,132,96,132,98,132,100,132,101,132,102,132,103,132,104,132,106,132,110,132,111,132,112,132,114,132,116,132,119,132,121,132,123,132,124,132,214,83,54,90,139,159,163,141,187,83,8,87,167,152,67,103,155,145,201,108,104,81,202,117,243,98,172,114,56,82,157,82,58,127,148,112,56,118,116,83,74,158,183,105,110,120,192,150,217,136,164,127,54,113,195,113,137,81,211,103,228,116,228,88,24,101,183,86,169,139,118,153,112,98,213,126,249,96,237,112,236,88,193,78,186,78,205,95,231,151,251,78,164,139,3,82,138,89,171,126,84,98,205,78,229,101,14,98,56,131,201,132,99,131,141,135,148,113,182,110,185,91,210,126,151,81,201,99,212,103,137,128,57,131,21,136,18,81,122,91,130,89,177,143,115,78,93,108,101,81,37,137,111,143,46,150,74,133,94,116,16,149,240,149,166,109,229,130,49,95,146,100,18,109,40,132,110,129,195,156,94,88,91,141,9,78,193,83,125,132,126,132,127,132,128,132,129,132,131,132,132,132,133,132,134,132,138,132,141,132,143,132,144,132,145,132,146,132,147,132,148,132,149,132,150,132,152,132,154,132,155,132,157,132,158,132,159,132,160,132,162,132,163,132,164,132,165,132,166,132,167,132,168,132,169,132,170,132,171,132,172,132,173,132,174,132,176,132,177,132,179,132,181,132,182,132,183,132,187,132,188,132,190,132,192,132,194,132,195,132,197,132,198,132,199,132,200,132,203,132,204,132,206,132,207,132,210,132,212,132,213,132,215,132,216,132,217,132,218,132,219,132,220,132,222,132,225,132,226,132,228,132,231,132,232,132,233,132,234,132,235,132,237,132,238,132,239,132,241,132,242,132,243,132,244,132,245,132,246,132,247,132,248,132,249,132,250,132,251,132,253,132,254,132,0,133,1,133,2,133,30,79,99,101,81,104,211,85,39,78,20,100,154,154,107,98,194,90,95,116,114,130,169,109,238,104,231,80,142,131,2,120,64,103,57,82,153,108,177,126,187,80,101,85,94,113,91,123,82,102,202,115,235,130,73,103,113,92,32,82,125,113,107,136,234,149,85,150,197,100,97,141,179,129,132,85,85,108,71,98,46,127,146,88,36,79,70,85,79,141,76,102,10,78,26,92,243,136,162,104,78,99,13,122,231,112,141,130,250,82,246,151,17,92,232,84,181,144,205,126,98,89,74,141,199,134,12,130,13,130,102,141,68,100,4,92,81,97,137,109,62,121,190,139,55,120,51,117,123,84,56,79,171,142,241,109,32,90,197,126,94,121,136,108,161,91,118,90,26,117,190,128,78,97,23,110,240,88,31,117,37,117,114,114,71,83,243,126,3,133,4,133,5,133,6,133,7,133,8,133,9,133,10,133,11,133,13,133,14,133,15,133,16,133,18,133,20,133,21,133,22,133,24,133,25,133,27,133,28,133,29,133,30,133,32,133,34,133,35,133,36,133,37,133,38,133,39,133,40,133,41,133,42,133,45,133,46,133,47,133,48,133,49,133,50,133,51,133,52,133,53,133,54,133,62,133,63,133,64,133,65,133,66,133,68,133,69,133,70,133,71,133,75,133,76,133,77,133,78,133,79,133,80,133,81,133,82,133,83,133,84,133,85,133,87,133,88,133,90,133,91,133,92,133,93,133,95,133,96,133,97,133,98,133,99,133,101,133,102,133,103,133,105,133,106,133,107,133,108,133,109,133,110,133,111,133,112,133,113,133,115,133,117,133,118,133,119,133,120,133,124,133,125,133,127,133,128,133,129,133,1,119,219,118,105,82,220,128,35,87,8,94,49,89,238,114,189,101,127,110,215,139,56,92,113,134,65,83,243,119,254,98,246,101,192,78,223,152,128,134,158,91,198,139,242,83,226,119,127,79,78,92,118,154,203,89,15,95,58,121,235,88,22,78,255,103,139,78,237,98,147,138,29,144,191,82,47,102,220,85,108,86,2,144,213,78,141,79,202,145,112,153,15,108,2,94,67,96,164,91,198,137,213,139,54,101,75,98,150,153,136,91,255,91,136,99,46,85,215,83,38,118,125,81,44,133,162,103,179,104,138,107,146,98,147,143,212,83,18,130,209,109,143,117,102,78,78,141,112,91,159,113,175,133,145,102,217,102,114,127,0,135,205,158,32,159,94,92,47,103,240,143,17,104,95,103,13,98,214,122,133,88,182,94,112,101,49,111,130,133,131,133,134,133,136,133,137,133,138,133,139,133,140,133,141,133,142,133,144,133,145,133,146,133,147,133,148,133,149,133,150,133,151,133,152,133,153,133,154,133,157,133,158,133,159,133,160,133,161,133,162,133,163,133,165,133,166,133,167,133,169,133,171,133,172,133,173,133,177,133,178,133,179,133,180,133,181,133,182,133,184,133,186,133,187,133,188,133,189,133,190,133,191,133,192,133,194,133,195,133,196,133,197,133,198,133,199,133,200,133,202,133,203,133,204,133,205,133,206,133,209,133,210,133,212,133,214,133,215,133,216,133,217,133,218,133,219,133,221,133,222,133,223,133,224,133,225,133,226,133,227,133,229,133,230,133,231,133,232,133,234,133,235,133,236,133,237,133,238,133,239,133,240,133,241,133,242,133,243,133,244,133,245,133,246,133,247,133,248,133,85,96,55,82,13,128,84,100,112,136,41,117,5,94,19,104,244,98,28,151,204,83,61,114,1,140,52,108,97,119,14,122,46,84,172,119,122,152,28,130,244,139,85,120,20,103,193,112,175,101,149,100,54,86,29,96,193,121,248,83,29,78,123,107,134,128,250,91,227,85,219,86,58,79,60,79,114,153,243,93,126,103,56,128,2,96,130,152,1,144,139,91,188,139,245,139,28,100,88,130,222,100,253,85,207,130,101,145,215,79,32,125,31,144,159,124,243,80,81,88,175,110,191,91,201,139,131,128,120,145,156,132,151,123,125,134,139,150,143,150,229,126,211,154,142,120,129,92,87,122,66,144,167,150,95,121,89,91,95,99,11,123,209,132,173,104,6,85,41,127,16,116,34,125,1,149,64,98,76,88,214,78,131,91,121,89,84,88,249,133,250,133,252,133,253,133,254,133,0,134,1,134,2,134,3,134,4,134,6,134,7,134,8,134,9,134,10,134,11,134,12,134,13,134,14,134,15,134,16,134,18,134,19,134,20,134,21,134,23,134,24,134,25,134,26,134,27,134,28,134,29,134,30,134,31,134,32,134,33,134,34,134,35,134,36,134,37,134,38,134,40,134,42,134,43,134,44,134,45,134,46,134,47,134,48,134,49,134,50,134,51,134,52,134,53,134,54,134,55,134,57,134,58,134,59,134,61,134,62,134,63,134,64,134,65,134,66,134,67,134,68,134,69,134,70,134,71,134,72,134,73,134,74,134,75,134,76,134,82,134,83,134,85,134,86,134,87,134,88,134,89,134,91,134,92,134,93,134,95,134,96,134,97,134,99,134,100,134,101,134,102,134,103,134,104,134,105,134,106,134,109,115,30,99,75,142,15,142,206,128,212,130,172,98,240,83,240,108,94,145,42,89,1,96,112,108,77,87,74,100,42,141,43,118,233,110,91,87,128,106,240,117,109,111,45,140,8,140,102,87,239,107,146,136,179,120,162,99,249,83,173,112,100,108,88,88,42,100,2,88,224,104,155,129,16,85,214,124,24,80,186,142,204,109,159,141,235,112,143,99,155,109,212,110,230,126,4,132,67,104,3,144,216,109,118,150,168,139,87,89,121,114,228,133,126,129,188,117,138,138,175,104,84,82,34,142,17,149,208,99,152,152,68,142,124,85,83,79,255,102,143,86,213,96,149,109,67,82,73,92,41,89,251,109,107,88,48,117,28,117,108,96,20,130,70,129,17,99,97,103,226,143,58,119,243,141,52,141,193,148,22,94,133,83,44,84,195,112,109,134,111,134,112,134,114,134,115,134,116,134,117,134,118,134,119,134,120,134,131,134,132,134,133,134,134,134,135,134,136,134,137,134,142,134,143,134,144,134,145,134,146,134,148,134,150,134,151,134,152,134,153,134,154,134,155,134,158,134,159,134,160,134,161,134,162,134,165,134,166,134,171,134,173,134,174,134,178,134,179,134,183,134,184,134,185,134,187,134,188,134,189,134,190,134,191,134,193,134,194,134,195,134,197,134,200,134,204,134,205,134,210,134,211,134,213,134,214,134,215,134,218,134,220,134,221,134,224,134,225,134,226,134,227,134,229,134,230,134,231,134,232,134,234,134,235,134,236,134,239,134,245,134,246,134,247,134,250,134,251,134,252,134,253,134,255,134,1,135,4,135,5,135,6,135,11,135,12,135,14,135,15,135,16,135,17,135,20,135,22,135,64,108,247,94,92,80,173,78,173,94,58,99,71,130,26,144,80,104,110,145,179,119,12,84,220,148,100,95,229,122,118,104,69,99,82,123,223,126,219,117,119,80,149,98,52,89,15,144,248,81,195,121,129,122,254,86,146,95,20,144,130,109,96,92,31,87,16,84,84,81,77,110,226,86,168,99,147,152,127,129,21,135,42,137,0,144,30,84,111,92,192,129,214,98,88,98,49,129,53,158,64,150,110,154,124,154,45,105,165,89,211,98,62,85,22,99,199,84,217,134,60,109,3,90,230,116,156,136,106,107,22,89,76,140,47,95,126,110,169,115,125,152,56,78,247,112,140,91,151,120,61,99,90,102,150,118,203,96,155,91,73,90,7,78,85,129,106,108,139,115,161,78,137,103,81,127,128,95,250,101,27,103,216,95,132,89,1,90,25,135,27,135,29,135,31,135,32,135,36,135,38,135,39,135,40,135,42,135,43,135,44,135,45,135,47,135,48,135,50,135,51,135,53,135,54,135,56,135,57,135,58,135,60,135,61,135,64,135,65,135,66,135,67,135,68,135,69,135,70,135,74,135,75,135,77,135,79,135,80,135,81,135,82,135,84,135,85,135,86,135,88,135,90,135,91,135,92,135,93,135,94,135,95,135,97,135,98,135,102,135,103,135,104,135,105,135,106,135,107,135,108,135,109,135,111,135,113,135,114,135,115,135,117,135,119,135,120,135,121,135,122,135,127,135,128,135,129,135,132,135,134,135,135,135,137,135,138,135,140,135,142,135,143,135,144,135,145,135,146,135,148,135,149,135,150,135,152,135,153,135,154,135,155,135,156,135,157,135,158,135,160,135,161,135,162,135,163,135,164,135,205,93,174,95,113,83,230,151,221,143,69,104,244,86,47,85,223,96,58,78,77,111,244,126,199,130,14,132,212,89,31,79,42,79,62,92,172,126,42,103,26,133,115,84,79,117,195,128,130,85,79,155,77,79,45,110,19,140,9,92,112,97,107,83,31,118,41,110,138,134,135,101,251,149,185,126,59,84,51,122,10,125,238,149,225,85,193,127,238,116,29,99,23,135,161,109,157,122,17,98,161,101,103,83,225,99,131,108,235,93,92,84,168,148,76,78,97,108,236,139,75,92,224,101,156,130,167,104,62,84,52,84,203,107,102,107,148,78,66,99,72,83,30,130,13,79,174,79,94,87,10,98,254,150,100,102,105,114,255,82,161,82,159,96,239,139,20,102,153,113,144,103,127,137,82,120,253,119,112,102,59,86,56,84,33,149,122,114,165,135,166,135,167,135,169,135,170,135,174,135,176,135,177,135,178,135,180,135,182,135,183,135,184,135,185,135,187,135,188,135,190,135,191,135,193,135,194,135,195,135,196,135,197,135,199,135,200,135,201,135,204,135,205,135,206,135,207,135,208,135,212,135,213,135,214,135,215,135,216,135,217,135,218,135,220,135,221,135,222,135,223,135,225,135,226,135,227,135,228,135,230,135,231,135,232,135,233,135,235,135,236,135,237,135,239,135,240,135,241,135,242,135,243,135,244,135,245,135,246,135,247,135,248,135,250,135,251,135,252,135,253,135,255,135,0,136,1,136,2,136,4,136,5,136,6,136,7,136,8,136,9,136,11,136,12,136,13,136,14,136,15,136,16,136,17,136,18,136,20,136,23,136,24,136,25,136,26,136,28,136,29,136,30,136,31,136,32,136,35,136,0,122,111,96,12,94,137,96,157,129,21,89,220,96,132,113,239,112,170,110,80,108,128,114,132,106,173,136,45,94,96,78,179,90,156,85,227,148,23,109,251,124,153,150,15,98,198,126,142,119,126,134,35,83,30,151,150,143,135,102,225,92,160,79,237,114,11,78,166,83,15,89,19,84,128,99,40,149,72,81,217,78,156,156,164,126,184,84,36,141,84,136,55,130,242,149,142,109,38,95,204,90,62,102,105,150,176,115,46,115,191,83,122,129,133,153,161,127,170,91,119,150,80,150,191,126,248,118,162,83,118,149,153,153,177,123,68,137,88,110,97,78,212,127,101,121,230,139,243,96,205,84,171,78,121,152,247,93,97,106,207,80,17,84,97,140,39,132,93,120,4,151,74,82,238,84,163,86,0,149,136,109,181,91,198,109,83,102,36,136,37,136,38,136,39,136,40,136,41,136,42,136,43,136,44,136,45,136,46,136,47,136,48,136,49,136,51,136,52,136,53,136,54,136,55,136,56,136,58,136,59,136,61,136,62,136,63,136,65,136,66,136,67,136,70,136,71,136,72,136,73,136,74,136,75,136,78,136,79,136,80,136,81,136,82,136,83,136,85,136,86,136,88,136,90,136,91,136,92,136,93,136,94,136,95,136,96,136,102,136,103,136,106,136,109,136,111,136,113,136,115,136,116,136,117,136,118,136,120,136,121,136,122,136,123,136,124,136,128,136,131,136,134,136,135,136,137,136,138,136,140,136,142,136,143,136,144,136,145,136,147,136,148,136,149,136,151,136,152,136,153,136,154,136,155,136,157,136,158,136,159,136,160,136,161,136,163,136,165,136,166,136,167,136,168,136,169,136,170,136,15,92,93,91,33,104,150,128,120,85,17,123,72,101,84,105,155,78,71,107,78,135,139,151,79,83,31,99,58,100,170,144,156,101,193,128,16,140,153,81,176,104,120,83,249,135,200,97,196,108,251,108,34,140,81,92,170,133,175,130,12,149,35,107,155,143,176,101,251,95,195,95,225,79,69,136,31,102,101,129,41,115,250,96,116,81,17,82,139,87,98,95,162,144,76,136,146,145,120,94,79,103,39,96,211,89,68,81,246,81,248,128,8,83,121,108,196,150,138,113,17,79,238,79,158,127,61,103,197,85,8,149,192,121,150,136,227,126,159,88,12,98,0,151,90,134,24,86,123,152,144,95,184,139,196,132,87,145,217,83,237,101,143,94,92,117,100,96,110,125,127,90,234,126,237,126,105,143,167,85,163,91,172,96,203,101,132,115,172,136,174,136,175,136,176,136,178,136,179,136,180,136,181,136,182,136,184,136,185,136,186,136,187,136,189,136,190,136,191,136,192,136,195,136,196,136,199,136,200,136,202,136,203,136,204,136,205,136,207,136,208,136,209,136,211,136,214,136,215,136,218,136,219,136,220,136,221,136,222,136,224,136,225,136,230,136,231,136,233,136,234,136,235,136,236,136,237,136,238,136,239,136,242,136,245,136,246,136,247,136,250,136,251,136,253,136,255,136,0,137,1,137,3,137,4,137,5,137,6,137,7,137,8,137,9,137,11,137,12,137,13,137,14,137,15,137,17,137,20,137,21,137,22,137,23,137,24,137,28,137,29,137,30,137,31,137,32,137,34,137,35,137,36,137,38,137,39,137,40,137,41,137,44,137,45,137,46,137,47,137,49,137,50,137,51,137,53,137,55,137,9,144,99,118,41,119,218,126,116,151,155,133,102,91,116,122,234,150,64,136,203,82,143,113,170,95,236,101,226,139,251,91,111,154,225,93,137,107,91,108,173,139,175,139,10,144,197,143,139,83,188,98,38,158,45,158,64,84,43,78,189,130,89,114,156,134,22,93,89,136,175,109,197,150,209,84,154,78,182,139,9,113,189,84,9,150,223,112,249,109,208,118,37,78,20,120,18,135,169,92,246,94,0,138,156,152,14,150,142,112,191,108,68,89,169,99,60,119,77,136,20,111,115,130,48,88,213,113,140,83,26,120,193,150,1,85,102,95,48,113,180,91,26,140,140,154,131,107,46,89,47,158,231,121,104,103,108,98,111,79,161,117,138,127,11,109,51,150,39,108,240,78,210,117,123,81,55,104,62,111,128,144,112,129,150,89,118,116,56,137,57,137,58,137,59,137,60,137,61,137,62,137,63,137,64,137,66,137,67,137,69,137,70,137,71,137,72,137,73,137,74,137,75,137,76,137,77,137,78,137,79,137,80,137,81,137,82,137,83,137,84,137,85,137,86,137,87,137,88,137,89,137,90,137,91,137,92,137,93,137,96,137,97,137,98,137,99,137,100,137,101,137,103,137,104,137,105,137,106,137,107,137,108,137,109,137,110,137,111,137,112,137,113,137,114,137,115,137,116,137,117,137,118,137,119,137,120,137,121,137,122,137,124,137,125,137,126,137,128,137,130,137,132,137,133,137,135,137,136,137,137,137,138,137,139,137,140,137,141,137,142,137,143,137,144,137,145,137,146,137,147,137,148,137,149,137,150,137,151,137,152,137,153,137,154,137,155,137,156,137,157,137,158,137,159,137,160,137,161,137,71,100,39,92,101,144,145,122,35,140,218,89,172,84,0,130,111,131,129,137,0,128,48,105,78,86,54,128,55,114,206,145,182,81,95,78,117,152,150,99,26,78,246,83,243,102,75,129,28,89,178,109,0,78,249,88,59,83,214,99,241,148,157,79,10,79,99,136,144,152,55,89,87,144,251,121,234,78,240,128,145,117,130,108,156,91,232,89,93,95,5,105,129,134,26,80,242,93,89,78,227,119,229,78,122,130,145,98,19,102,145,144,121,92,191,78,121,95,198,129,56,144,132,128,171,117,166,78,212,136,15,97,197,107,198,95,73,78,202,118,162,110,227,139,174,139,10,140,209,139,2,95,252,127,204,127,206,126,53,131,107,131,224,86,183,107,243,151,52,150,251,89,31,84,246,148,235,109,197,91,110,153,57,92,21,95,144,150,162,137,163,137,164,137,165,137,166,137,167,137,168,137,169,137,170,137,171,137,172,137,173,137,174,137,175,137,176,137,177,137,178,137,179,137,180,137,181,137,182,137,183,137,184,137,185,137,186,137,187,137,188,137,189,137,190,137,191,137,192,137,195,137,205,137,211,137,212,137,213,137,215,137,216,137,217,137,219,137,221,137,223,137,224,137,225,137,226,137,228,137,231,137,232,137,233,137,234,137,236,137,237,137,238,137,240,137,241,137,242,137,244,137,245,137,246,137,247,137,248,137,249,137,250,137,251,137,252,137,253,137,254,137,255,137,1,138,2,138,3,138,4,138,5,138,6,138,8,138,9,138,10,138,11,138,12,138,13,138,14,138,15,138,16,138,17,138,18,138,19,138,20,138,21,138,22,138,23,138,24,138,25,138,26,138,27,138,28,138,29,138,112,83,241,130,49,106,116,90,112,158,148,94,40,127,185,131,36,132,37,132,103,131,71,135,206,143,98,141,200,118,113,95,150,152,108,120,32,102,223,84,229,98,99,79,195,129,200,117,184,94,205,150,10,142,249,134,143,84,243,108,140,109,56,108,127,96,199,82,40,117,125,94,24,79,160,96,231,95,36,92,49,117,174,144,192,148,185,114,185,108,56,110,73,145,9,103,203,83,243,83,81,79,201,145,241,139,200,83,124,94,194,143,228,109,142,78,194,118,134,105,94,134,26,97,6,130,89,79,222,79,62,144,124,156,9,97,29,110,20,110,133,150,136,78,49,90,232,150,14,78,127,92,185,121,135,91,237,139,189,127,137,115,223,87,139,130,193,144,1,84,71,144,187,85,234,92,161,95,8,97,50,107,241,114,178,128,137,138,30,138,31,138,32,138,33,138,34,138,35,138,36,138,37,138,38,138,39,138,40,138,41,138,42,138,43,138,44,138,45,138,46,138,47,138,48,138,49,138,50,138,51,138,52,138,53,138,54,138,55,138,56,138,57,138,58,138,59,138,60,138,61,138,63,138,64,138,65,138,66,138,67,138,68,138,69,138,70,138,71,138,73,138,74,138,75,138,76,138,77,138,78,138,79,138,80,138,81,138,82,138,83,138,84,138,85,138,86,138,87,138,88,138,89,138,90,138,91,138,92,138,93,138,94,138,95,138,96,138,97,138,98,138,99,138,100,138,101,138,102,138,103,138,104,138,105,138,106,138,107,138,108,138,109,138,110,138,111,138,112,138,113,138,114,138,115,138,116,138,117,138,118,138,119,138,120,138,122,138,123,138,124,138,125,138,126,138,127,138,128,138,116,109,211,91,213,136,132,152,107,140,109,154,51,158,10,110,164,81,67,81,163,87,129,136,159,83,244,99,149,143,237,86,88,84,6,87,63,115,144,110,24,127,220,143,209,130,63,97,40,96,98,150,240,102,166,126,138,141,195,141,165,148,179,92,164,124,8,103,166,96,5,150,24,128,145,78,231,144,0,83,104,150,65,81,208,143,116,133,93,145,85,102,245,151,85,91,29,83,56,120,66,103,61,104,201,84,126,112,176,91,125,143,141,81,40,87,177,84,18,101,130,102,94,141,67,141,15,129,108,132,109,144,223,124,255,81,251,133,163,103,233,101,161,111,164,134,129,142,106,86,32,144,130,118,118,112,229,113,35,141,233,98,25,82,253,108,60,141,14,96,158,88,142,97,254,102,96,141,78,98,179,85,35,110,45,103,103,143,129,138,130,138,131,138,132,138,133,138,134,138,135,138,136,138,139,138,140,138,141,138,142,138,143,138,144,138,145,138,146,138,148,138,149,138,150,138,151,138,152,138,153,138,154,138,155,138,156,138,157,138,158,138,159,138,160,138,161,138,162,138,163,138,164,138,165,138,166,138,167,138,168,138,169,138,170,138,171,138,172,138,173,138,174,138,175,138,176,138,177,138,178,138,179,138,180,138,181,138,182,138,183,138,184,138,185,138,186,138,187,138,188,138,189,138,190,138,191,138,192,138,193,138,194,138,195,138,196,138,197,138,198,138,199,138,200,138,201,138,202,138,203,138,204,138,205,138,206,138,207,138,208,138,209,138,210,138,211,138,212,138,213,138,214,138,215,138,216,138,217,138,218,138,219,138,220,138,221,138,222,138,223,138,224,138,225,138,226,138,227,138,225,148,248,149,40,119,5,104,168,105,139,84,77,78,184,112,200,139,88,100,139,101,133,91,132,122,58,80,232,91,187,119,225,107,121,138,152,124,190,108,207,118,169,101,151,143,45,93,85,92,56,134,8,104,96,83,24,98,217,122,91,110,253,126,31,106,224,122,112,95,51,111,32,95,140,99,168,109,86,103,8,78,16,94,38,141,215,78,192,128,52,118,156,150,219,98,45,102,126,98,188,108,117,141,103,113,105,127,70,81,135,128,236,83,110,144,152,98,242,84,240,134,153,143,5,128,23,149,23,133,217,143,89,109,205,115,159,101,31,119,4,117,39,120,251,129,30,141,136,148,166,79,149,103,185,117,202,139,7,151,47,99,71,149,53,150,184,132,35,99,65,119,129,95,240,114,137,78,20,96,116,101,239,98,99,107,63,101,228,138,229,138,230,138,231,138,232,138,233,138,234,138,235,138,236,138,237,138,238,138,239,138,240,138,241,138,242,138,243,138,244,138,245,138,246,138,247,138,248,138,249,138,250,138,251,138,252,138,253,138,254,138,255,138,0,139,1,139,2,139,3,139,4,139,5,139,6,139,8,139,9,139,10,139,11,139,12,139,13,139,14,139,15,139,16,139,17,139,18,139,19,139,20,139,21,139,22,139,23,139,24,139,25,139,26,139,27,139,28,139,29,139,30,139,31,139,32,139,33,139,34,139,35,139,36,139,37,139,39,139,40,139,41,139,42,139,43,139,44,139,45,139,46,139,47,139,48,139,49,139,50,139,51,139,52,139,53,139,54,139,55,139,56,139,57,139,58,139,59,139,60,139,61,139,62,139,63,139,64,139,65,139,66,139,67,139,68,139,69,139,39,94,199,117,209,144,193,139,157,130,157,103,47,101,49,84,24,135,229,119,162,128,2,129,65,108,75,78,199,126,76,128,244,118,13,105,150,107,103,98,60,80,132,79,64,87,7,99,98,107,190,141,234,83,232,101,184,126,215,95,26,99,183,99,243,129,244,129,110,127,28,94,217,92,54,82,122,102,233,121,26,122,40,141,153,112,212,117,222,110,187,108,146,122,45,78,197,118,224,95,159,148,119,136,200,126,205,121,191,128,205,145,242,78,23,79,31,130,104,84,222,93,50,109,204,139,165,124,116,143,152,128,26,94,146,84,177,118,153,91,60,102,164,154,224,115,42,104,219,134,49,103,42,115,248,139,219,139,16,144,249,122,219,112,110,113,196,98,169,119,49,86,59,78,87,132,241,103,169,82,192,134,46,141,248,148,81,123,70,139,71,139,72,139,73,139,74,139,75,139,76,139,77,139,78,139,79,139,80,139,81,139,82,139,83,139,84,139,85,139,86,139,87,139,88,139,89,139,90,139,91,139,92,139,93,139,94,139,95,139,96,139,97,139,98,139,99,139,100,139,101,139,103,139,104,139,105,139,106,139,107,139,109,139,110,139,111,139,112,139,113,139,114,139,115,139,116,139,117,139,118,139,119,139,120,139,121,139,122,139,123,139,124,139,125,139,126,139,127,139,128,139,129,139,130,139,131,139,132,139,133,139,134,139,135,139,136,139,137,139,138,139,139,139,140,139,141,139,142,139,143,139,144,139,145,139,146,139,147,139,148,139,149,139,150,139,151,139,152,139,153,139,154,139,155,139,156,139,157,139,158,139,159,139,172,139,177,139,187,139,199,139,208,139,234,139,9,140,30,140,79,79,232,108,93,121,123,154,147,98,42,114,253,98,19,78,22,120,108,143,176,100,90,141,198,123,105,104,132,94,197,136,134,89,158,100,238,88,182,114,14,105,37,149,253,143,88,141,96,87,0,127,6,140,198,81,73,99,217,98,83,83,76,104,34,116,1,131,76,145,68,85,64,119,124,112,74,109,121,81,168,84,68,141,255,89,203,110,196,109,92,91,43,125,212,78,125,124,211,110,80,91,234,129,13,110,87,91,3,155,213,104,42,142,151,91,252,126,59,96,181,126,185,144,112,141,79,89,205,99,223,121,179,141,82,83,207,101,86,121,197,139,59,150,196,126,187,148,130,126,52,86,137,145,0,103,106,127,10,92,117,144,40,102,230,93,80,79,222,103,90,80,92,79,80,87,167,94,16,232,17,232,18,232,19,232,20,232,56,140,57,140,58,140,59,140,60,140,61,140,62,140,63,140,64,140,66,140,67,140,68,140,69,140,72,140,74,140,75,140,77,140,78,140,79,140,80,140,81,140,82,140,83,140,84,140,86,140,87,140,88,140,89,140,91,140,92,140,93,140,94,140,95,140,96,140,99,140,100,140,101,140,102,140,103,140,104,140,105,140,108,140,109,140,110,140,111,140,112,140,113,140,114,140,116,140,117,140,118,140,119,140,123,140,124,140,125,140,126,140,127,140,128,140,129,140,131,140,132,140,134,140,135,140,136,140,139,140,141,140,142,140,143,140,144,140,145,140,146,140,147,140,149,140,150,140,151,140,153,140,154,140,155,140,156,140,157,140,158,140,159,140,160,140,161,140,162,140,163,140,164,140,165,140,166,140,167,140,168,140,169,140,170,140,171,140,172,140,173,140,141,78,12,78,64,81,16,78,255,94,69,83,21,78,152,78,30,78,50,155,108,91,105,86,40,78,186,121,63,78,21,83,71,78,45,89,59,114,110,83,16,108,223,86,228,128,151,153,211,107,126,119,23,159,54,78,159,78,16,159,92,78,105,78,147,78,136,130,91,91,108,85,15,86,196,78,141,83,157,83,163,83,165,83,174,83,101,151,93,141,26,83,245,83,38,83,46,83,62,83,92,141,102,83,99,83,2,82,8,82,14,82,45,82,51,82,63,82,64,82,76,82,94,82,97,82,92,82,175,132,125,82,130,82,129,82,144,82,147,82,130,81,84,127,187,78,195,78,201,78,194,78,232,78,225,78,235,78,222,78,27,79,243,78,34,79,100,79,245,78,37,79,39,79,9,79,43,79,94,79,103,79,56,101,90,79,93,79,174,140,175,140,176,140,177,140,178,140,179,140,180,140,181,140,182,140,183,140,184,140,185,140,186,140,187,140,188,140,189,140,190,140,191,140,192,140,193,140,194,140,195,140,196,140,197,140,198,140,199,140,200,140,201,140,202,140,203,140,204,140,205,140,206,140,207,140,208,140,209,140,210,140,211,140,212,140,213,140,214,140,215,140,216,140,217,140,218,140,219,140,220,140,221,140,222,140,223,140,224,140,225,140,226,140,227,140,228,140,229,140,230,140,231,140,232,140,233,140,234,140,235,140,236,140,237,140,238,140,239,140,240,140,241,140,242,140,243,140,244,140,245,140,246,140,247,140,248,140,249,140,250,140,251,140,252,140,253,140,254,140,255,140,0,141,1,141,2,141,3,141,4,141,5,141,6,141,7,141,8,141,9,141,10,141,11,141,12,141,13,141,95,79,87,79,50,79,61,79,118,79,116,79,145,79,137,79,131,79,143,79,126,79,123,79,170,79,124,79,172,79,148,79,230,79,232,79,234,79,197,79,218,79,227,79,220,79,209,79,223,79,248,79,41,80,76,80,243,79,44,80,15,80,46,80,45,80,254,79,28,80,12,80,37,80,40,80,126,80,67,80,85,80,72,80,78,80,108,80,123,80,165,80,167,80,169,80,186,80,214,80,6,81,237,80,236,80,230,80,238,80,7,81,11,81,221,78,61,108,88,79,101,79,206,79,160,159,70,108,116,124,110,81,253,93,201,158,152,153,129,81,20,89,249,82,13,83,7,138,16,83,235,81,25,89,85,81,160,78,86,81,179,78,110,136,164,136,181,78,20,129,210,136,128,121,52,91,3,136,184,127,171,81,177,81,189,81,188,81,14,141,15,141,16,141,17,141,18,141,19,141,20,141,21,141,22,141,23,141,24,141,25,141,26,141,27,141,28,141,32,141,81,141,82,141,87,141,95,141,101,141,104,141,105,141,106,141,108,141,110,141,111,141,113,141,114,141,120,141,121,141,122,141,123,141,124,141,125,141,126,141,127,141,128,141,130,141,131,141,134,141,135,141,136,141,137,141,140,141,141,141,142,141,143,141,144,141,146,141,147,141,149,141,150,141,151,141,152,141,153,141,154,141,155,141,156,141,157,141,158,141,160,141,161,141,162,141,164,141,165,141,166,141,167,141,168,141,169,141,170,141,171,141,172,141,173,141,174,141,175,141,176,141,178,141,182,141,183,141,185,141,187,141,189,141,192,141,193,141,194,141,197,141,199,141,200,141,201,141,202,141,205,141,208,141,210,141,211,141,212,141,199,81,150,81,162,81,165,81,160,139,166,139,167,139,170,139,180,139,181,139,183,139,194,139,195,139,203,139,207,139,206,139,210,139,211,139,212,139,214,139,216,139,217,139,220,139,223,139,224,139,228,139,232,139,233,139,238,139,240,139,243,139,246,139,249,139,252,139,255,139,0,140,2,140,4,140,7,140,12,140,15,140,17,140,18,140,20,140,21,140,22,140,25,140,27,140,24,140,29,140,31,140,32,140,33,140,37,140,39,140,42,140,43,140,46,140,47,140,50,140,51,140,53,140,54,140,105,83,122,83,29,150,34,150,33,150,49,150,42,150,61,150,60,150,66,150,73,150,84,150,95,150,103,150,108,150,114,150,116,150,136,150,141,150,151,150,176,150,151,144,155,144,157,144,153,144,172,144,161,144,180,144,179,144,182,144,186,144,213,141,216,141,217,141,220,141,224,141,225,141,226,141,229,141,230,141,231,141,233,141,237,141,238,141,240,141,241,141,242,141,244,141,246,141,252,141,254,141,255,141,0,142,1,142,2,142,3,142,4,142,6,142,7,142,8,142,11,142,13,142,14,142,16,142,17,142,18,142,19,142,21,142,22,142,23,142,24,142,25,142,26,142,27,142,28,142,32,142,33,142,36,142,37,142,38,142,39,142,40,142,43,142,45,142,48,142,50,142,51,142,52,142,54,142,55,142,56,142,59,142,60,142,62,142,63,142,67,142,69,142,70,142,76,142,77,142,78,142,79,142,80,142,83,142,84,142,85,142,86,142,87,142,88,142,90,142,91,142,92,142,93,142,94,142,95,142,96,142,97,142,98,142,99,142,100,142,101,142,103,142,104,142,106,142,107,142,110,142,113,142,184,144,176,144,207,144,197,144,190,144,208,144,196,144,199,144,211,144,230,144,226,144,220,144,215,144,219,144,235,144,239,144,254,144,4,145,34,145,30,145,35,145,49,145,47,145,57,145,67,145,70,145,13,82,66,89,162,82,172,82,173,82,190,82,255,84,208,82,214,82,240,82,223,83,238,113,205,119,244,94,245,81,252,81,47,155,182,83,1,95,90,117,239,93,76,87,169,87,161,87,126,88,188,88,197,88,209,88,41,87,44,87,42,87,51,87,57,87,46,87,47,87,92,87,59,87,66,87,105,87,133,87,107,87,134,87,124,87,123,87,104,87,109,87,118,87,115,87,173,87,164,87,140,87,178,87,207,87,167,87,180,87,147,87,160,87,213,87,216,87,218,87,217,87,210,87,184,87,244,87,239,87,248,87,228,87,221,87,115,142,117,142,119,142,120,142,121,142,122,142,123,142,125,142,126,142,128,142,130,142,131,142,132,142,134,142,136,142,137,142,138,142,139,142,140,142,141,142,142,142,145,142,146,142,147,142,149,142,150,142,151,142,152,142,153,142,154,142,155,142,157,142,159,142,160,142,161,142,162,142,163,142,164,142,165,142,166,142,167,142,168,142,169,142,170,142,173,142,174,142,176,142,177,142,179,142,180,142,181,142,182,142,183,142,184,142,185,142,187,142,188,142,189,142,190,142,191,142,192,142,193,142,194,142,195,142,196,142,197,142,198,142,199,142,200,142,201,142,202,142,203,142,204,142,205,142,207,142,208,142,209,142,210,142,211,142,212,142,213,142,214,142,215,142,216,142,217,142,218,142,219,142,220,142,221,142,222,142,223,142,224,142,225,142,226,142,227,142,228,142,11,88,13,88,253,87,237,87,0,88,30,88,25,88,68,88,32,88,101,88,108,88,129,88,137,88,154,88,128,88,168,153,25,159,255,97,121,130,125,130,127,130,143,130,138,130,168,130,132,130,142,130,145,130,151,130,153,130,171,130,184,130,190,130,176,130,200,130,202,130,227,130,152,130,183,130,174,130,203,130,204,130,193,130,169,130,180,130,161,130,170,130,159,130,196,130,206,130,164,130,225,130,9,131,247,130,228,130,15,131,7,131,220,130,244,130,210,130,216,130,12,131,251,130,211,130,17,131,26,131,6,131,20,131,21,131,224,130,213,130,28,131,81,131,91,131,92,131,8,131,146,131,60,131,52,131,49,131,155,131,94,131,47,131,79,131,71,131,67,131,95,131,64,131,23,131,96,131,45,131,58,131,51,131,102,131,101,131,229,142,230,142,231,142,232,142,233,142,234,142,235,142,236,142,237,142,238,142,239,142,240,142,241,142,242,142,243,142,244,142,245,142,246,142,247,142,248,142,249,142,250,142,251,142,252,142,253,142,254,142,255,142,0,143,1,143,2,143,3,143,4,143,5,143,6,143,7,143,8,143,9,143,10,143,11,143,12,143,13,143,14,143,15,143,16,143,17,143,18,143,19,143,20,143,21,143,22,143,23,143,24,143,25,143,26,143,27,143,28,143,29,143,30,143,31,143,32,143,33,143,34,143,35,143,36,143,37,143,38,143,39,143,40,143,41,143,42,143,43,143,44,143,45,143,46,143,47,143,48,143,49,143,50,143,51,143,52,143,53,143,54,143,55,143,56,143,57,143,58,143,59,143,60,143,61,143,62,143,63,143,64,143,65,143,66,143,67,143,68,143,104,131,27,131,105,131,108,131,106,131,109,131,110,131,176,131,120,131,179,131,180,131,160,131,170,131,147,131,156,131,133,131,124,131,182,131,169,131,125,131,184,131,123,131,152,131,158,131,168,131,186,131,188,131,193,131,1,132,229,131,216,131,7,88,24,132,11,132,221,131,253,131,214,131,28,132,56,132,17,132,6,132,212,131,223,131,15,132,3,132,248,131,249,131,234,131,197,131,192,131,38,132,240,131,225,131,92,132,81,132,90,132,89,132,115,132,135,132,136,132,122,132,137,132,120,132,60,132,70,132,105,132,118,132,140,132,142,132,49,132,109,132,193,132,205,132,208,132,230,132,189,132,211,132,202,132,191,132,186,132,224,132,161,132,185,132,180,132,151,132,229,132,227,132,12,133,13,117,56,133,240,132,57,133,31,133,58,133,69,143,70,143,71,143,72,143,73,143,74,143,75,143,76,143,77,143,78,143,79,143,80,143,81,143,82,143,83,143,84,143,85,143,86,143,87,143,88,143,89,143,90,143,91,143,92,143,93,143,94,143,95,143,96,143,97,143,98,143,99,143,100,143,101,143,106,143,128,143,140,143,146,143,157,143,160,143,161,143,162,143,164,143,165,143,166,143,167,143,170,143,172,143,173,143,174,143,175,143,178,143,179,143,180,143,181,143,183,143,184,143,186,143,187,143,188,143,191,143,192,143,195,143,198,143,201,143,202,143,203,143,204,143,205,143,207,143,210,143,214,143,215,143,218,143,224,143,225,143,227,143,231,143,236,143,239,143,241,143,242,143,244,143,245,143,246,143,250,143,251,143,252,143,254,143,255,143,7,144,8,144,12,144,14,144,19,144,21,144,24,144,86,133,59,133,255,132,252,132,89,133,72,133,104,133,100,133,94,133,122,133,162,119,67,133,114,133,123,133,164,133,168,133,135,133,143,133,121,133,174,133,156,133,133,133,185,133,183,133,176,133,211,133,193,133,220,133,255,133,39,134,5,134,41,134,22,134,60,134,254,94,8,95,60,89,65,89,55,128,85,89,90,89,88,89,15,83,34,92,37,92,44,92,52,92,76,98,106,98,159,98,187,98,202,98,218,98,215,98,238,98,34,99,246,98,57,99,75,99,67,99,173,99,246,99,113,99,122,99,142,99,180,99,109,99,172,99,138,99,105,99,174,99,188,99,242,99,248,99,224,99,255,99,196,99,222,99,206,99,82,100,198,99,190,99,69,100,65,100,11,100,27,100,32,100,12,100,38,100,33,100,94,100,132,100,109,100,150,100,25,144,28,144,35,144,36,144,37,144,39,144,40,144,41,144,42,144,43,144,44,144,48,144,49,144,50,144,51,144,52,144,55,144,57,144,58,144,61,144,63,144,64,144,67,144,69,144,70,144,72,144,73,144,74,144,75,144,76,144,78,144,84,144,85,144,86,144,89,144,90,144,92,144,93,144,94,144,95,144,96,144,97,144,100,144,102,144,103,144,105,144,106,144,107,144,108,144,111,144,112,144,113,144,114,144,115,144,118,144,119,144,120,144,121,144,122,144,123,144,124,144,126,144,129,144,132,144,133,144,134,144,135,144,137,144,138,144,140,144,141,144,142,144,143,144,144,144,146,144,148,144,150,144,152,144,154,144,156,144,158,144,159,144,160,144,164,144,165,144,167,144,168,144,169,144,171,144,173,144,178,144,183,144,188,144,189,144,191,144,192,144,122,100,183,100,184,100,153,100,186,100,192,100,208,100,215,100,228,100,226,100,9,101,37,101,46,101,11,95,210,95,25,117,17,95,95,83,241,83,253,83,233,83,232,83,251,83,18,84,22,84,6,84,75,84,82,84,83,84,84,84,86,84,67,84,33,84,87,84,89,84,35,84,50,84,130,84,148,84,119,84,113,84,100,84,154,84,155,84,132,84,118,84,102,84,157,84,208,84,173,84,194,84,180,84,210,84,167,84,166,84,211,84,212,84,114,84,163,84,213,84,187,84,191,84,204,84,217,84,218,84,220,84,169,84,170,84,164,84,221,84,207,84,222,84,27,85,231,84,32,85,253,84,20,85,243,84,34,85,35,85,15,85,17,85,39,85,42,85,103,85,143,85,181,85,73,85,109,85,65,85,85,85,63,85,80,85,60,85,194,144,195,144,198,144,200,144,201,144,203,144,204,144,205,144,210,144,212,144,213,144,214,144,216,144,217,144,218,144,222,144,223,144,224,144,227,144,228,144,229,144,233,144,234,144,236,144,238,144,240,144,241,144,242,144,243,144,245,144,246,144,247,144,249,144,250,144,251,144,252,144,255,144,0,145,1,145,3,145,5,145,6,145,7,145,8,145,9,145,10,145,11,145,12,145,13,145,14,145,15,145,16,145,17,145,18,145,19,145,20,145,21,145,22,145,23,145,24,145,26,145,27,145,28,145,29,145,31,145,32,145,33,145,36,145,37,145,38,145,39,145,40,145,41,145,42,145,43,145,44,145,45,145,46,145,48,145,50,145,51,145,52,145,53,145,54,145,55,145,56,145,58,145,59,145,60,145,61,145,62,145,63,145,64,145,65,145,66,145,68,145,55,85,86,85,117,85,118,85,119,85,51,85,48,85,92,85,139,85,210,85,131,85,177,85,185,85,136,85,129,85,159,85,126,85,214,85,145,85,123,85,223,85,189,85,190,85,148,85,153,85,234,85,247,85,201,85,31,86,209,85,235,85,236,85,212,85,230,85,221,85,196,85,239,85,229,85,242,85,243,85,204,85,205,85,232,85,245,85,228,85,148,143,30,86,8,86,12,86,1,86,36,86,35,86,254,85,0,86,39,86,45,86,88,86,57,86,87,86,44,86,77,86,98,86,89,86,92,86,76,86,84,86,134,86,100,86,113,86,107,86,123,86,124,86,133,86,147,86,175,86,212,86,215,86,221,86,225,86,245,86,235,86,249,86,255,86,4,87,10,87,9,87,28,87,15,94,25,94,20,94,17,94,49,94,59,94,60,94,69,145,71,145,72,145,81,145,83,145,84,145,85,145,86,145,88,145,89,145,91,145,92,145,95,145,96,145,102,145,103,145,104,145,107,145,109,145,115,145,122,145,123,145,124,145,128,145,129,145,130,145,131,145,132,145,134,145,136,145,138,145,142,145,143,145,147,145,148,145,149,145,150,145,151,145,152,145,153,145,156,145,157,145,158,145,159,145,160,145,161,145,164,145,165,145,166,145,167,145,168,145,169,145,171,145,172,145,176,145,177,145,178,145,179,145,182,145,183,145,184,145,185,145,187,145,188,145,189,145,190,145,191,145,192,145,193,145,194,145,195,145,196,145,197,145,198,145,200,145,203,145,208,145,210,145,211,145,212,145,213,145,214,145,215,145,216,145,217,145,218,145,219,145,221,145,222,145,223,145,224,145,225,145,226,145,227,145,228,145,229,145,55,94,68,94,84,94,91,94,94,94,97,94,140,92,122,92,141,92,144,92,150,92,136,92,152,92,153,92,145,92,154,92,156,92,181,92,162,92,189,92,172,92,171,92,177,92,163,92,193,92,183,92,196,92,210,92,228,92,203,92,229,92,2,93,3,93,39,93,38,93,46,93,36,93,30,93,6,93,27,93,88,93,62,93,52,93,61,93,108,93,91,93,111,93,93,93,107,93,75,93,74,93,105,93,116,93,130,93,153,93,157,93,115,140,183,93,197,93,115,95,119,95,130,95,135,95,137,95,140,95,149,95,153,95,156,95,168,95,173,95,181,95,188,95,98,136,97,95,173,114,176,114,180,114,183,114,184,114,195,114,193,114,206,114,205,114,210,114,232,114,239,114,233,114,242,114,244,114,247,114,1,115,243,114,3,115,250,114,230,145,231,145,232,145,233,145,234,145,235,145,236,145,237,145,238,145,239,145,240,145,241,145,242,145,243,145,244,145,245,145,246,145,247,145,248,145,249,145,250,145,251,145,252,145,253,145,254,145,255,145,0,146,1,146,2,146,3,146,4,146,5,146,6,146,7,146,8,146,9,146,10,146,11,146,12,146,13,146,14,146,15,146,16,146,17,146,18,146,19,146,20,146,21,146,22,146,23,146,24,146,25,146,26,146,27,146,28,146,29,146,30,146,31,146,32,146,33,146,34,146,35,146,36,146,37,146,38,146,39,146,40,146,41,146,42,146,43,146,44,146,45,146,46,146,47,146,48,146,49,146,50,146,51,146,52,146,53,146,54,146,55,146,56,146,57,146,58,146,59,146,60,146,61,146,62,146,63,146,64,146,65,146,66,146,67,146,68,146,69,146,251,114,23,115,19,115,33,115,10,115,30,115,29,115,21,115,34,115,57,115,37,115,44,115,56,115,49,115,80,115,77,115,87,115,96,115,108,115,111,115,126,115,27,130,37,89,231,152,36,89,2,89,99,153,103,153,104,153,105,153,106,153,107,153,108,153,116,153,119,153,125,153,128,153,132,153,135,153,138,153,141,153,144,153,145,153,147,153,148,153,149,153,128,94,145,94,139,94,150,94,165,94,160,94,185,94,181,94,190,94,179,94,83,141,210,94,209,94,219,94,232,94,234,94,186,129,196,95,201,95,214,95,207,95,3,96,238,95,4,96,225,95,228,95,254,95,5,96,6,96,234,95,237,95,248,95,25,96,53,96,38,96,27,96,15,96,13,96,41,96,43,96,10,96,63,96,33,96,120,96,121,96,123,96,122,96,66,96,70,146,71,146,72,146,73,146,74,146,75,146,76,146,77,146,78,146,79,146,80,146,81,146,82,146,83,146,84,146,85,146,86,146,87,146,88,146,89,146,90,146,91,146,92,146,93,146,94,146,95,146,96,146,97,146,98,146,99,146,100,146,101,146,102,146,103,146,104,146,105,146,106,146,107,146,108,146,109,146,110,146,111,146,112,146,113,146,114,146,115,146,117,146,118,146,119,146,120,146,121,146,122,146,123,146,124,146,125,146,126,146,127,146,128,146,129,146,130,146,131,146,132,146,133,146,134,146,135,146,136,146,137,146,138,146,139,146,140,146,141,146,143,146,144,146,145,146,146,146,147,146,148,146,149,146,150,146,151,146,152,146,153,146,154,146,155,146,156,146,157,146,158,146,159,146,160,146,161,146,162,146,163,146,164,146,165,146,166,146,167,146,106,96,125,96,150,96,154,96,173,96,157,96,131,96,146,96,140,96,155,96,236,96,187,96,177,96,221,96,216,96,198,96,218,96,180,96,32,97,38,97,21,97,35,97,244,96,0,97,14,97,43,97,74,97,117,97,172,97,148,97,167,97,183,97,212,97,245,97,221,95,179,150,233,149,235,149,241,149,243,149,245,149,246,149,252,149,254,149,3,150,4,150,6,150,8,150,10,150,11,150,12,150,13,150,15,150,18,150,21,150,22,150,23,150,25,150,26,150,44,78,63,114,21,98,53,108,84,108,92,108,74,108,163,108,133,108,144,108,148,108,140,108,104,108,105,108,116,108,118,108,134,108,169,108,208,108,212,108,173,108,247,108,248,108,241,108,215,108,178,108,224,108,214,108,250,108,235,108,238,108,177,108,211,108,239,108,254,108,168,146,169,146,170,146,171,146,172,146,173,146,175,146,176,146,177,146,178,146,179,146,180,146,181,146,182,146,183,146,184,146,185,146,186,146,187,146,188,146,189,146,190,146,191,146,192,146,193,146,194,146,195,146,196,146,197,146,198,146,199,146,201,146,202,146,203,146,204,146,205,146,206,146,207,146,208,146,209,146,210,146,211,146,212,146,213,146,214,146,215,146,216,146,217,146,218,146,219,146,220,146,221,146,222,146,223,146,224,146,225,146,226,146,227,146,228,146,229,146,230,146,231,146,232,146,233,146,234,146,235,146,236,146,237,146,238,146,239,146,240,146,241,146,242,146,243,146,244,146,245,146,246,146,247,146,248,146,249,146,250,146,251,146,252,146,253,146,254,146,255,146,0,147,1,147,2,147,3,147,4,147,5,147,6,147,7,147,8,147,9,147,57,109,39,109,12,109,67,109,72,109,7,109,4,109,25,109,14,109,43,109,77,109,46,109,53,109,26,109,79,109,82,109,84,109,51,109,145,109,111,109,158,109,160,109,94,109,147,109,148,109,92,109,96,109,124,109,99,109,26,110,199,109,197,109,222,109,14,110,191,109,224,109,17,110,230,109,221,109,217,109,22,110,171,109,12,110,174,109,43,110,110,110,78,110,107,110,178,110,95,110,134,110,83,110,84,110,50,110,37,110,68,110,223,110,177,110,152,110,224,110,45,111,226,110,165,110,167,110,189,110,187,110,183,110,215,110,180,110,207,110,143,110,194,110,159,110,98,111,70,111,71,111,36,111,21,111,249,110,47,111,54,111,75,111,116,111,42,111,9,111,41,111,137,111,141,111,140,111,120,111,114,111,124,111,122,111,209,111,10,147,11,147,12,147,13,147,14,147,15,147,16,147,17,147,18,147,19,147,20,147,21,147,22,147,23,147,24,147,25,147,26,147,27,147,28,147,29,147,30,147,31,147,32,147,33,147,34,147,35,147,36,147,37,147,38,147,39,147,40,147,41,147,42,147,43,147,44,147,45,147,46,147,47,147,48,147,49,147,50,147,51,147,52,147,53,147,54,147,55,147,56,147,57,147,58,147,59,147,60,147,61,147,63,147,64,147,65,147,66,147,67,147,68,147,69,147,70,147,71,147,72,147,73,147,74,147,75,147,76,147,77,147,78,147,79,147,80,147,81,147,82,147,83,147,84,147,85,147,86,147,87,147,88,147,89,147,90,147,91,147,92,147,93,147,94,147,95,147,96,147,97,147,98,147,99,147,100,147,101,147,102,147,103,147,104,147,105,147,107,147,201,111,167,111,185,111,182,111,194,111,225,111,238,111,222,111,224,111,239,111,26,112,35,112,27,112,57,112,53,112,79,112,94,112,128,91,132,91,149,91,147,91,165,91,184,91,47,117,158,154,52,100,228,91,238,91,48,137,240,91,71,142,7,139,182,143,211,143,213,143,229,143,238,143,228,143,233,143,230,143,243,143,232,143,5,144,4,144,11,144,38,144,17,144,13,144,22,144,33,144,53,144,54,144,45,144,47,144,68,144,81,144,82,144,80,144,104,144,88,144,98,144,91,144,185,102,116,144,125,144,130,144,136,144,131,144,139,144,80,95,87,95,86,95,88,95,59,92,171,84,80,92,89,92,113,91,99,92,102,92,188,127,42,95,41,95,45,95,116,130,60,95,59,155,110,92,129,89,131,89,141,89,169,89,170,89,163,89,108,147,109,147,110,147,111,147,112,147,113,147,114,147,115,147,116,147,117,147,118,147,119,147,120,147,121,147,122,147,123,147,124,147,125,147,126,147,127,147,128,147,129,147,130,147,131,147,132,147,133,147,134,147,135,147,136,147,137,147,138,147,139,147,140,147,141,147,142,147,144,147,145,147,146,147,147,147,148,147,149,147,150,147,151,147,152,147,153,147,154,147,155,147,156,147,157,147,158,147,159,147,160,147,161,147,162,147,163,147,164,147,165,147,166,147,167,147,168,147,169,147,170,147,171,147,172,147,173,147,174,147,175,147,176,147,177,147,178,147,179,147,180,147,181,147,182,147,183,147,184,147,185,147,186,147,187,147,188,147,189,147,190,147,191,147,192,147,193,147,194,147,195,147,196,147,197,147,198,147,199,147,200,147,201,147,203,147,204,147,205,147,151,89,202,89,171,89,158,89,164,89,210,89,178,89,175,89,215,89,190,89,5,90,6,90,221,89,8,90,227,89,216,89,249,89,12,90,9,90,50,90,52,90,17,90,35,90,19,90,64,90,103,90,74,90,85,90,60,90,98,90,117,90,236,128,170,90,155,90,119,90,122,90,190,90,235,90,178,90,210,90,212,90,184,90,224,90,227,90,241,90,214,90,230,90,216,90,220,90,9,91,23,91,22,91,50,91,55,91,64,91,21,92,28,92,90,91,101,91,115,91,81,91,83,91,98,91,117,154,119,154,120,154,122,154,127,154,125,154,128,154,129,154,133,154,136,154,138,154,144,154,146,154,147,154,150,154,152,154,155,154,156,154,157,154,159,154,160,154,162,154,163,154,165,154,167,154,159,126,161,126,163,126,165,126,168,126,169,126,206,147,207,147,208,147,209,147,210,147,211,147,212,147,213,147,215,147,216,147,217,147,218,147,219,147,220,147,221,147,222,147,223,147,224,147,225,147,226,147,227,147,228,147,229,147,230,147,231,147,232,147,233,147,234,147,235,147,236,147,237,147,238,147,239,147,240,147,241,147,242,147,243,147,244,147,245,147,246,147,247,147,248,147,249,147,250,147,251,147,252,147,253,147,254,147,255,147,0,148,1,148,2,148,3,148,4,148,5,148,6,148,7,148,8,148,9,148,10,148,11,148,12,148,13,148,14,148,15,148,16,148,17,148,18,148,19,148,20,148,21,148,22,148,23,148,24,148,25,148,26,148,27,148,28,148,29,148,30,148,31,148,32,148,33,148,34,148,35,148,36,148,37,148,38,148,39,148,40,148,41,148,42,148,43,148,44,148,45,148,46,148,173,126,176,126,190,126,192,126,193,126,194,126,201,126,203,126,204,126,208,126,212,126,215,126,219,126,224,126,225,126,232,126,235,126,238,126,239,126,241,126,242,126,13,127,246,126,250,126,251,126,254,126,1,127,2,127,3,127,7,127,8,127,11,127,12,127,15,127,17,127,18,127,23,127,25,127,28,127,27,127,31,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,42,127,43,127,44,127,45,127,47,127,48,127,49,127,50,127,51,127,53,127,122,94,127,117,219,93,62,117,149,144,142,115,145,115,174,115,162,115,159,115,207,115,194,115,209,115,183,115,179,115,192,115,201,115,200,115,229,115,217,115,124,152,10,116,233,115,231,115,222,115,186,115,242,115,15,116,42,116,91,116,38,116,37,116,40,116,48,116,46,116,44,116,47,148,48,148,49,148,50,148,51,148,52,148,53,148,54,148,55,148,56,148,57,148,58,148,59,148,60,148,61,148,63,148,64,148,65,148,66,148,67,148,68,148,69,148,70,148,71,148,72,148,73,148,74,148,75,148,76,148,77,148,78,148,79,148,80,148,81,148,82,148,83,148,84,148,85,148,86,148,87,148,88,148,89,148,90,148,91,148,92,148,93,148,94,148,95,148,96,148,97,148,98,148,99,148,100,148,101,148,102,148,103,148,104,148,105,148,106,148,108,148,109,148,110,148,111,148,112,148,113,148,114,148,115,148,116,148,117,148,118,148,119,148,120,148,121,148,122,148,123,148,124,148,125,148,126,148,127,148,128,148,129,148,130,148,131,148,132,148,145,148,150,148,152,148,199,148,207,148,211,148,212,148,218,148,230,148,251,148,28,149,32,149,27,116,26,116,65,116,92,116,87,116,85,116,89,116,119,116,109,116,126,116,156,116,142,116,128,116,129,116,135,116,139,116,158,116,168,116,169,116,144,116,167,116,210,116,186,116,234,151,235,151,236,151,76,103,83,103,94,103,72,103,105,103,165,103,135,103,106,103,115,103,152,103,167,103,117,103,168,103,158,103,173,103,139,103,119,103,124,103,240,103,9,104,216,103,10,104,233,103,176,103,12,104,217,103,181,103,218,103,179,103,221,103,0,104,195,103,184,103,226,103,14,104,193,103,253,103,50,104,51,104,96,104,97,104,78,104,98,104,68,104,100,104,131,104,29,104,85,104,102,104,65,104,103,104,64,104,62,104,74,104,73,104,41,104,181,104,143,104,116,104,119,104,147,104,107,104,194,104,110,105,252,104,31,105,32,105,249,104,39,149,51,149,61,149,67,149,72,149,75,149,85,149,90,149,96,149,110,149,116,149,117,149,119,149,120,149,121,149,122,149,123,149,124,149,125,149,126,149,128,149,129,149,130,149,131,149,132,149,133,149,134,149,135,149,136,149,137,149,138,149,139,149,140,149,141,149,142,149,143,149,144,149,145,149,146,149,147,149,148,149,149,149,150,149,151,149,152,149,153,149,154,149,155,149,156,149,157,149,158,149,159,149,160,149,161,149,162,149,163,149,164,149,165,149,166,149,167,149,168,149,169,149,170,149,171,149,172,149,173,149,174,149,175,149,176,149,177,149,178,149,179,149,180,149,181,149,182,149,183,149,184,149,185,149,186,149,187,149,188,149,189,149,190,149,191,149,192,149,193,149,194,149,195,149,196,149,197,149,198,149,199,149,200,149,201,149,202,149,203,149,36,105,240,104,11,105,1,105,87,105,227,104,16,105,113,105,57,105,96,105,66,105,93,105,132,105,107,105,128,105,152,105,120,105,52,105,204,105,135,105,136,105,206,105,137,105,102,105,99,105,121,105,155,105,167,105,187,105,171,105,173,105,212,105,177,105,193,105,202,105,223,105,149,105,224,105,141,105,255,105,47,106,237,105,23,106,24,106,101,106,242,105,68,106,62,106,160,106,80,106,91,106,53,106,142,106,121,106,61,106,40,106,88,106,124,106,145,106,144,106,169,106,151,106,171,106,55,115,82,115,129,107,130,107,135,107,132,107,146,107,147,107,141,107,154,107,155,107,161,107,170,107,107,143,109,143,113,143,114,143,115,143,117,143,118,143,120,143,119,143,121,143,122,143,124,143,126,143,129,143,130,143,132,143,135,143,139,143,204,149,205,149,206,149,207,149,208,149,209,149,210,149,211,149,212,149,213,149,214,149,215,149,216,149,217,149,218,149,219,149,220,149,221,149,222,149,223,149,224,149,225,149,226,149,227,149,228,149,229,149,230,149,231,149,236,149,255,149,7,150,19,150,24,150,27,150,30,150,32,150,35,150,36,150,37,150,38,150,39,150,40,150,41,150,43,150,44,150,45,150,47,150,48,150,55,150,56,150,57,150,58,150,62,150,65,150,67,150,74,150,78,150,79,150,81,150,82,150,83,150,86,150,87,150,88,150,89,150,90,150,92,150,93,150,94,150,96,150,99,150,101,150,102,150,107,150,109,150,110,150,111,150,112,150,113,150,115,150,120,150,121,150,122,150,123,150,124,150,125,150,126,150,127,150,128,150,129,150,130,150,131,150,132,150,135,150,137,150,138,150,141,143,142,143,143,143,152,143,154,143,206,142,11,98,23,98,27,98,31,98,34,98,33,98,37,98,36,98,44,98,231,129,239,116,244,116,255,116,15,117,17,117,19,117,52,101,238,101,239,101,240,101,10,102,25,102,114,103,3,102,21,102,0,102,133,112,247,102,29,102,52,102,49,102,54,102,53,102,6,128,95,102,84,102,65,102,79,102,86,102,97,102,87,102,119,102,132,102,140,102,167,102,157,102,190,102,219,102,220,102,230,102,233,102,50,141,51,141,54,141,59,141,61,141,64,141,69,141,70,141,72,141,73,141,71,141,77,141,85,141,89,141,199,137,202,137,203,137,204,137,206,137,207,137,208,137,209,137,110,114,159,114,93,114,102,114,111,114,126,114,127,114,132,114,139,114,141,114,143,114,146,114,8,99,50,99,176,99,140,150,142,150,145,150,146,150,147,150,149,150,150,150,154,150,155,150,157,150,158,150,159,150,160,150,161,150,162,150,163,150,164,150,165,150,166,150,168,150,169,150,170,150,171,150,172,150,173,150,174,150,175,150,177,150,178,150,180,150,181,150,183,150,184,150,186,150,187,150,191,150,194,150,195,150,200,150,202,150,203,150,208,150,209,150,211,150,212,150,214,150,215,150,216,150,217,150,218,150,219,150,220,150,221,150,222,150,223,150,225,150,226,150,227,150,228,150,229,150,230,150,231,150,235,150,236,150,237,150,238,150,240,150,241,150,242,150,244,150,245,150,248,150,250,150,251,150,252,150,253,150,255,150,2,151,3,151,5,151,10,151,11,151,12,151,16,151,17,151,18,151,20,151,21,151,23,151,24,151,25,151,26,151,27,151,29,151,31,151,32,151,63,100,216,100,4,128,234,107,243,107,253,107,245,107,249,107,5,108,7,108,6,108,13,108,21,108,24,108,25,108,26,108,33,108,41,108,36,108,42,108,50,108,53,101,85,101,107,101,77,114,82,114,86,114,48,114,98,134,22,82,159,128,156,128,147,128,188,128,10,103,189,128,177,128,171,128,173,128,180,128,183,128,231,128,232,128,233,128,234,128,219,128,194,128,196,128,217,128,205,128,215,128,16,103,221,128,235,128,241,128,244,128,237,128,13,129,14,129,242,128,252,128,21,103,18,129,90,140,54,129,30,129,44,129,24,129,50,129,72,129,76,129,83,129,116,129,89,129,90,129,113,129,96,129,105,129,124,129,125,129,109,129,103,129,77,88,181,90,136,129,130,129,145,129,213,110,163,129,170,129,204,129,38,103,202,129,187,129,33,151,34,151,35,151,36,151,37,151,38,151,39,151,40,151,41,151,43,151,44,151,46,151,47,151,49,151,51,151,52,151,53,151,54,151,55,151,58,151,59,151,60,151,61,151,63,151,64,151,65,151,66,151,67,151,68,151,69,151,70,151,71,151,72,151,73,151,74,151,75,151,76,151,77,151,78,151,79,151,80,151,81,151,84,151,85,151,87,151,88,151,90,151,92,151,93,151,95,151,99,151,100,151,102,151,103,151,104,151,106,151,107,151,108,151,109,151,110,151,111,151,112,151,113,151,114,151,117,151,119,151,120,151,121,151,122,151,123,151,125,151,126,151,127,151,128,151,129,151,130,151,131,151,132,151,134,151,135,151,136,151,137,151,138,151,140,151,142,151,143,151,144,151,147,151,149,151,150,151,151,151,153,151,154,151,155,151,156,151,157,151,193,129,166,129,36,107,55,107,57,107,67,107,70,107,89,107,209,152,210,152,211,152,213,152,217,152,218,152,179,107,64,95,194,107,243,137,144,101,81,159,147,101,188,101,198,101,196,101,195,101,204,101,206,101,210,101,214,101,128,112,156,112,150,112,157,112,187,112,192,112,183,112,171,112,177,112,232,112,202,112,16,113,19,113,22,113,47,113,49,113,115,113,92,113,104,113,69,113,114,113,74,113,120,113,122,113,152,113,179,113,181,113,168,113,160,113,224,113,212,113,231,113,249,113,29,114,40,114,108,112,24,113,102,113,185,113,62,98,61,98,67,98,72,98,73,98,59,121,64,121,70,121,73,121,91,121,92,121,83,121,90,121,98,121,87,121,96,121,111,121,103,121,122,121,133,121,138,121,154,121,167,121,179,121,209,95,208,95,158,151,159,151,161,151,162,151,164,151,165,151,166,151,167,151,168,151,169,151,170,151,172,151,174,151,176,151,177,151,179,151,181,151,182,151,183,151,184,151,185,151,186,151,187,151,188,151,189,151,190,151,191,151,192,151,193,151,194,151,195,151,196,151,197,151,198,151,199,151,200,151,201,151,202,151,203,151,204,151,205,151,206,151,207,151,208,151,209,151,210,151,211,151,212,151,213,151,214,151,215,151,216,151,217,151,218,151,219,151,220,151,221,151,222,151,223,151,224,151,225,151,226,151,227,151,228,151,229,151,232,151,238,151,239,151,240,151,241,151,242,151,244,151,247,151,248,151,249,151,250,151,251,151,252,151,253,151,254,151,255,151,0,152,1,152,2,152,3,152,4,152,5,152,6,152,7,152,8,152,9,152,10,152,11,152,12,152,13,152,14,152,60,96,93,96,90,96,103,96,65,96,89,96,99,96,171,96,6,97,13,97,93,97,169,97,157,97,203,97,209,97,6,98,128,128,127,128,147,108,246,108,252,109,246,119,248,119,0,120,9,120,23,120,24,120,17,120,171,101,45,120,28,120,29,120,57,120,58,120,59,120,31,120,60,120,37,120,44,120,35,120,41,120,78,120,109,120,86,120,87,120,38,120,80,120,71,120,76,120,106,120,155,120,147,120,154,120,135,120,156,120,161,120,163,120,178,120,185,120,165,120,212,120,217,120,201,120,236,120,242,120,5,121,244,120,19,121,36,121,30,121,52,121,155,159,249,158,251,158,252,158,241,118,4,119,13,119,249,118,7,119,8,119,26,119,34,119,25,119,45,119,38,119,53,119,56,119,80,119,81,119,71,119,67,119,90,119,104,119,15,152,16,152,17,152,18,152,19,152,20,152,21,152,22,152,23,152,24,152,25,152,26,152,27,152,28,152,29,152,30,152,31,152,32,152,33,152,34,152,35,152,36,152,37,152,38,152,39,152,40,152,41,152,42,152,43,152,44,152,45,152,46,152,47,152,48,152,49,152,50,152,51,152,52,152,53,152,54,152,55,152,56,152,57,152,58,152,59,152,60,152,61,152,62,152,63,152,64,152,65,152,66,152,67,152,68,152,69,152,70,152,71,152,72,152,73,152,74,152,75,152,76,152,77,152,78,152,79,152,80,152,81,152,82,152,83,152,84,152,85,152,86,152,87,152,88,152,89,152,90,152,91,152,92,152,93,152,94,152,95,152,96,152,97,152,98,152,99,152,100,152,101,152,102,152,103,152,104,152,105,152,106,152,107,152,108,152,109,152,110,152,98,119,101,119,127,119,141,119,125,119,128,119,140,119,145,119,159,119,160,119,176,119,181,119,189,119,58,117,64,117,78,117,75,117,72,117,91,117,114,117,121,117,131,117,88,127,97,127,95,127,72,138,104,127,116,127,113,127,121,127,129,127,126,127,205,118,229,118,50,136,133,148,134,148,135,148,139,148,138,148,140,148,141,148,143,148,144,148,148,148,151,148,149,148,154,148,155,148,156,148,163,148,164,148,171,148,170,148,173,148,172,148,175,148,176,148,178,148,180,148,182,148,183,148,184,148,185,148,186,148,188,148,189,148,191,148,196,148,200,148,201,148,202,148,203,148,204,148,205,148,206,148,208,148,209,148,210,148,213,148,214,148,215,148,217,148,216,148,219,148,222,148,223,148,224,148,226,148,228,148,229,148,231,148,232,148,234,148,111,152,112,152,113,152,114,152,115,152,116,152,139,152,142,152,146,152,149,152,153,152,163,152,168,152,169,152,170,152,171,152,172,152,173,152,174,152,175,152,176,152,177,152,178,152,179,152,180,152,181,152,182,152,183,152,184,152,185,152,186,152,187,152,188,152,189,152,190,152,191,152,192,152,193,152,194,152,195,152,196,152,197,152,198,152,199,152,200,152,201,152,202,152,203,152,204,152,205,152,207,152,208,152,212,152,214,152,215,152,219,152,220,152,221,152,224,152,225,152,226,152,227,152,228,152,229,152,230,152,233,152,234,152,235,152,236,152,237,152,238,152,239,152,240,152,241,152,242,152,243,152,244,152,245,152,246,152,247,152,248,152,249,152,250,152,251,152,252,152,253,152,254,152,255,152,0,153,1,153,2,153,3,153,4,153,5,153,6,153,7,153,233,148,235,148,238,148,239,148,243,148,244,148,245,148,247,148,249,148,252,148,253,148,255,148,3,149,2,149,6,149,7,149,9,149,10,149,13,149,14,149,15,149,18,149,19,149,20,149,21,149,22,149,24,149,27,149,29,149,30,149,31,149,34,149,42,149,43,149,41,149,44,149,49,149,50,149,52,149,54,149,55,149,56,149,60,149,62,149,63,149,66,149,53,149,68,149,69,149,70,149,73,149,76,149,78,149,79,149,82,149,83,149,84,149,86,149,87,149,88,149,89,149,91,149,94,149,95,149,93,149,97,149,98,149,100,149,101,149,102,149,103,149,104,149,105,149,106,149,107,149,108,149,111,149,113,149,114,149,115,149,58,149,231,119,236,119,201,150,213,121,237,121,227,121,235,121,6,122,71,93,3,122,2,122,30,122,20,122,8,153,9,153,10,153,11,153,12,153,14,153,15,153,17,153,18,153,19,153,20,153,21,153,22,153,23,153,24,153,25,153,26,153,27,153,28,153,29,153,30,153,31,153,32,153,33,153,34,153,35,153,36,153,37,153,38,153,39,153,40,153,41,153,42,153,43,153,44,153,45,153,47,153,48,153,49,153,50,153,51,153,52,153,53,153,54,153,55,153,56,153,57,153,58,153,59,153,60,153,61,153,62,153,63,153,64,153,65,153,66,153,67,153,68,153,69,153,70,153,71,153,72,153,73,153,74,153,75,153,76,153,77,153,78,153,79,153,80,153,81,153,82,153,83,153,86,153,87,153,88,153,89,153,90,153,91,153,92,153,93,153,94,153,95,153,96,153,97,153,98,153,100,153,102,153,115,153,120,153,121,153,123,153,126,153,130,153,131,153,137,153,57,122,55,122,81,122,207,158,165,153,112,122,136,118,142,118,147,118,153,118,164,118,222,116,224,116,44,117,32,158,34,158,40,158,41,158,42,158,43,158,44,158,50,158,49,158,54,158,56,158,55,158,57,158,58,158,62,158,65,158,66,158,68,158,70,158,71,158,72,158,73,158,75,158,76,158,78,158,81,158,85,158,87,158,90,158,91,158,92,158,94,158,99,158,102,158,103,158,104,158,105,158,106,158,107,158,108,158,113,158,109,158,115,158,146,117,148,117,150,117,160,117,157,117,172,117,163,117,179,117,180,117,184,117,196,117,177,117,176,117,195,117,194,117,214,117,205,117,227,117,232,117,230,117,228,117,235,117,231,117,3,118,241,117,252,117,255,117,16,118,0,118,5,118,12,118,23,118,10,118,37,118,24,118,21,118,25,118,140,153,142,153,154,153,155,153,156,153,157,153,158,153,159,153,160,153,161,153,162,153,163,153,164,153,166,153,167,153,169,153,170,153,171,153,172,153,173,153,174,153,175,153,176,153,177,153,178,153,179,153,180,153,181,153,182,153,183,153,184,153,185,153,186,153,187,153,188,153,189,153,190,153,191,153,192,153,193,153,194,153,195,153,196,153,197,153,198,153,199,153,200,153,201,153,202,153,203,153,204,153,205,153,206,153,207,153,208,153,209,153,210,153,211,153,212,153,213,153,214,153,215,153,216,153,217,153,218,153,219,153,220,153,221,153,222,153,223,153,224,153,225,153,226,153,227,153,228,153,229,153,230,153,231,153,232,153,233,153,234,153,235,153,236,153,237,153,238,153,239,153,240,153,241,153,242,153,243,153,244,153,245,153,246,153,247,153,248,153,249,153,27,118,60,118,34,118,32,118,64,118,45,118,48,118,63,118,53,118,67,118,62,118,51,118,77,118,94,118,84,118,92,118,86,118,107,118,111,118,202,127,230,122,120,122,121,122,128,122,134,122,136,122,149,122,166,122,160,122,172,122,168,122,173,122,179,122,100,136,105,136,114,136,125,136,127,136,130,136,162,136,198,136,183,136,188,136,201,136,226,136,206,136,227,136,229,136,241,136,26,137,252,136,232,136,254,136,240,136,33,137,25,137,19,137,27,137,10,137,52,137,43,137,54,137,65,137,102,137,123,137,139,117,229,128,178,118,180,118,220,119,18,128,20,128,22,128,28,128,32,128,34,128,37,128,38,128,39,128,41,128,40,128,49,128,11,128,53,128,67,128,70,128,77,128,82,128,105,128,113,128,131,137,120,152,128,152,131,152,250,153,251,153,252,153,253,153,254,153,255,153,0,154,1,154,2,154,3,154,4,154,5,154,6,154,7,154,8,154,9,154,10,154,11,154,12,154,13,154,14,154,15,154,16,154,17,154,18,154,19,154,20,154,21,154,22,154,23,154,24,154,25,154,26,154,27,154,28,154,29,154,30,154,31,154,32,154,33,154,34,154,35,154,36,154,37,154,38,154,39,154,40,154,41,154,42,154,43,154,44,154,45,154,46,154,47,154,48,154,49,154,50,154,51,154,52,154,53,154,54,154,55,154,56,154,57,154,58,154,59,154,60,154,61,154,62,154,63,154,64,154,65,154,66,154,67,154,68,154,69,154,70,154,71,154,72,154,73,154,74,154,75,154,76,154,77,154,78,154,79,154,80,154,81,154,82,154,83,154,84,154,85,154,86,154,87,154,88,154,89,154,137,152,140,152,141,152,143,152,148,152,154,152,155,152,158,152,159,152,161,152,162,152,165,152,166,152,77,134,84,134,108,134,110,134,127,134,122,134,124,134,123,134,168,134,141,134,139,134,172,134,157,134,167,134,163,134,170,134,147,134,169,134,182,134,196,134,181,134,206,134,176,134,186,134,177,134,175,134,201,134,207,134,180,134,233,134,241,134,242,134,237,134,243,134,208,134,19,135,222,134,244,134,223,134,216,134,209,134,3,135,7,135,248,134,8,135,10,135,13,135,9,135,35,135,59,135,30,135,37,135,46,135,26,135,62,135,72,135,52,135,49,135,41,135,55,135,63,135,130,135,34,135,125,135,126,135,123,135,96,135,112,135,76,135,110,135,139,135,83,135,99,135,124,135,100,135,89,135,101,135,147,135,175,135,168,135,210,135,90,154,91,154,92,154,93,154,94,154,95,154,96,154,97,154,98,154,99,154,100,154,101,154,102,154,103,154,104,154,105,154,106,154,107,154,114,154,131,154,137,154,141,154,142,154,148,154,149,154,153,154,166,154,169,154,170,154,171,154,172,154,173,154,174,154,175,154,178,154,179,154,180,154,181,154,185,154,187,154,189,154,190,154,191,154,195,154,196,154,198,154,199,154,200,154,201,154,202,154,205,154,206,154,207,154,208,154,210,154,212,154,213,154,214,154,215,154,217,154,218,154,219,154,220,154,221,154,222,154,224,154,226,154,227,154,228,154,229,154,231,154,232,154,233,154,234,154,236,154,238,154,240,154,241,154,242,154,243,154,244,154,245,154,246,154,247,154,248,154,250,154,252,154,253,154,254,154,255,154,0,155,1,155,2,155,4,155,5,155,6,155,198,135,136,135,133,135,173,135,151,135,131,135,171,135,229,135,172,135,181,135,179,135,203,135,211,135,189,135,209,135,192,135,202,135,219,135,234,135,224,135,238,135,22,136,19,136,254,135,10,136,27,136,33,136,57,136,60,136,54,127,66,127,68,127,69,127,16,130,250,122,253,122,8,123,3,123,4,123,21,123,10,123,43,123,15,123,71,123,56,123,42,123,25,123,46,123,49,123,32,123,37,123,36,123,51,123,62,123,30,123,88,123,90,123,69,123,117,123,76,123,93,123,96,123,110,123,123,123,98,123,114,123,113,123,144,123,166,123,167,123,184,123,172,123,157,123,168,123,133,123,170,123,156,123,162,123,171,123,180,123,209,123,193,123,204,123,221,123,218,123,229,123,230,123,234,123,12,124,254,123,252,123,15,124,22,124,11,124,7,155,9,155,10,155,11,155,12,155,13,155,14,155,16,155,17,155,18,155,20,155,21,155,22,155,23,155,24,155,25,155,26,155,27,155,28,155,29,155,30,155,32,155,33,155,34,155,36,155,37,155,38,155,39,155,40,155,41,155,42,155,43,155,44,155,45,155,46,155,48,155,49,155,51,155,52,155,53,155,54,155,55,155,56,155,57,155,58,155,61,155,62,155,63,155,64,155,70,155,74,155,75,155,76,155,78,155,80,155,82,155,83,155,85,155,86,155,87,155,88,155,89,155,90,155,91,155,92,155,93,155,94,155,95,155,96,155,97,155,98,155,99,155,100,155,101,155,102,155,103,155,104,155,105,155,106,155,107,155,108,155,109,155,110,155,111,155,112,155,113,155,114,155,115,155,116,155,117,155,118,155,119,155,120,155,121,155,122,155,123,155,31,124,42,124,38,124,56,124,65,124,64,124,254,129,1,130,2,130,4,130,236,129,68,136,33,130,34,130,35,130,45,130,47,130,40,130,43,130,56,130,59,130,51,130,52,130,62,130,68,130,73,130,75,130,79,130,90,130,95,130,104,130,126,136,133,136,136,136,216,136,223,136,94,137,157,127,159,127,167,127,175,127,176,127,178,127,124,124,73,101,145,124,157,124,156,124,158,124,162,124,178,124,188,124,189,124,193,124,199,124,204,124,205,124,200,124,197,124,215,124,232,124,110,130,168,102,191,127,206,127,213,127,229,127,225,127,230,127,233,127,238,127,243,127,248,124,119,125,166,125,174,125,71,126,155,126,184,158,180,158,115,141,132,141,148,141,145,141,177,141,103,141,109,141,71,140,73,140,74,145,80,145,78,145,79,145,100,145,124,155,125,155,126,155,127,155,128,155,129,155,130,155,131,155,132,155,133,155,134,155,135,155,136,155,137,155,138,155,139,155,140,155,141,155,142,155,143,155,144,155,145,155,146,155,147,155,148,155,149,155,150,155,151,155,152,155,153,155,154,155,155,155,156,155,157,155,158,155,159,155,160,155,161,155,162,155,163,155,164,155,165,155,166,155,167,155,168,155,169,155,170,155,171,155,172,155,173,155,174,155,175,155,176,155,177,155,178,155,179,155,180,155,181,155,182,155,183,155,184,155,185,155,186,155,187,155,188,155,189,155,190,155,191,155,192,155,193,155,194,155,195,155,196,155,197,155,198,155,199,155,200,155,201,155,202,155,203,155,204,155,205,155,206,155,207,155,208,155,209,155,210,155,211,155,212,155,213,155,214,155,215,155,216,155,217,155,218,155,219,155,98,145,97,145,112,145,105,145,111,145,125,145,126,145,114,145,116,145,121,145,140,145,133,145,144,145,141,145,145,145,162,145,163,145,170,145,173,145,174,145,175,145,181,145,180,145,186,145,85,140,126,158,184,141,235,141,5,142,89,142,105,142,181,141,191,141,188,141,186,141,196,141,214,141,215,141,218,141,222,141,206,141,207,141,219,141,198,141,236,141,247,141,248,141,227,141,249,141,251,141,228,141,9,142,253,141,20,142,29,142,31,142,44,142,46,142,35,142,47,142,58,142,64,142,57,142,53,142,61,142,49,142,73,142,65,142,66,142,81,142,82,142,74,142,112,142,118,142,124,142,111,142,116,142,133,142,143,142,148,142,144,142,156,142,158,142,120,140,130,140,138,140,133,140,152,140,148,140,155,101,214,137,222,137,218,137,220,137,220,155,221,155,222,155,223,155,224,155,225,155,226,155,227,155,228,155,229,155,230,155,231,155,232,155,233,155,234,155,235,155,236,155,237,155,238,155,239,155,240,155,241,155,242,155,243,155,244,155,245,155,246,155,247,155,248,155,249,155,250,155,251,155,252,155,253,155,254,155,255,155,0,156,1,156,2,156,3,156,4,156,5,156,6,156,7,156,8,156,9,156,10,156,11,156,12,156,13,156,14,156,15,156,16,156,17,156,18,156,19,156,20,156,21,156,22,156,23,156,24,156,25,156,26,156,27,156,28,156,29,156,30,156,31,156,32,156,33,156,34,156,35,156,36,156,37,156,38,156,39,156,40,156,41,156,42,156,43,156,44,156,45,156,46,156,47,156,48,156,49,156,50,156,51,156,52,156,53,156,54,156,55,156,56,156,57,156,58,156,59,156,229,137,235,137,239,137,62,138,38,139,83,151,233,150,243,150,239,150,6,151,1,151,8,151,15,151,14,151,42,151,45,151,48,151,62,151,128,159,131,159,133,159,134,159,135,159,136,159,137,159,138,159,140,159,254,158,11,159,13,159,185,150,188,150,189,150,206,150,210,150,191,119,224,150,142,146,174,146,200,146,62,147,106,147,202,147,143,147,62,148,107,148,127,156,130,156,133,156,134,156,135,156,136,156,35,122,139,156,142,156,144,156,145,156,146,156,148,156,149,156,154,156,155,156,158,156,159,156,160,156,161,156,162,156,163,156,165,156,166,156,167,156,168,156,169,156,171,156,173,156,174,156,176,156,177,156,178,156,179,156,180,156,181,156,182,156,183,156,186,156,187,156,188,156,189,156,196,156,197,156,198,156,199,156,202,156,203,156,60,156,61,156,62,156,63,156,64,156,65,156,66,156,67,156,68,156,69,156,70,156,71,156,72,156,73,156,74,156,75,156,76,156,77,156,78,156,79,156,80,156,81,156,82,156,83,156,84,156,85,156,86,156,87,156,88,156,89,156,90,156,91,156,92,156,93,156,94,156,95,156,96,156,97,156,98,156,99,156,100,156,101,156,102,156,103,156,104,156,105,156,106,156,107,156,108,156,109,156,110,156,111,156,112,156,113,156,114,156,115,156,116,156,117,156,118,156,119,156,120,156,121,156,122,156,123,156,125,156,126,156,128,156,131,156,132,156,137,156,138,156,140,156,143,156,147,156,150,156,151,156,152,156,153,156,157,156,170,156,172,156,175,156,185,156,190,156,191,156,192,156,193,156,194,156,200,156,201,156,209,156,210,156,218,156,219,156,224,156,225,156,204,156,205,156,206,156,207,156,208,156,211,156,212,156,213,156,215,156,216,156,217,156,220,156,221,156,223,156,226,156,124,151,133,151,145,151,146,151,148,151,175,151,171,151,163,151,178,151,180,151,177,154,176,154,183,154,88,158,182,154,186,154,188,154,193,154,192,154,197,154,194,154,203,154,204,154,209,154,69,155,67,155,71,155,73,155,72,155,77,155,81,155,232,152,13,153,46,153,85,153,84,153,223,154,225,154,230,154,239,154,235,154,251,154,237,154,249,154,8,155,15,155,19,155,31,155,35,155,189,158,190,158,59,126,130,158,135,158,136,158,139,158,146,158,214,147,157,158,159,158,219,158,220,158,221,158,224,158,223,158,226,158,233,158,231,158,229,158,234,158,239,158,34,159,44,159,47,159,57,159,55,159,61,159,62,159,68,159,227,156,228,156,229,156,230,156,231,156,232,156,233,156,234,156,235,156,236,156,237,156,238,156,239,156,240,156,241,156,242,156,243,156,244,156,245,156,246,156,247,156,248,156,249,156,250,156,251,156,252,156,253,156,254,156,255,156,0,157,1,157,2,157,3,157,4,157,5,157,6,157,7,157,8,157,9,157,10,157,11,157,12,157,13,157,14,157,15,157,16,157,17,157,18,157,19,157,20,157,21,157,22,157,23,157,24,157,25,157,26,157,27,157,28,157,29,157,30,157,31,157,32,157,33,157,34,157,35,157,36,157,37,157,38,157,39,157,40,157,41,157,42,157,43,157,44,157,45,157,46,157,47,157,48,157,49,157,50,157,51,157,52,157,53,157,54,157,55,157,56,157,57,157,58,157,59,157,60,157,61,157,62,157,63,157,64,157,65,157,66,157,52,226,53,226,54,226,55,226,56,226,57,226,58,226,59,226,60,226,61,226,62,226,63,226,64,226,65,226,66,226,67,226,68,226,69,226,70,226,71,226,72,226,73,226,74,226,75,226,76,226,77,226,78,226,79,226,80,226,81,226,82,226,83,226,84,226,85,226,86,226,87,226,88,226,89,226,90,226,91,226,92,226,93,226,94,226,95,226,96,226,97,226,98,226,99,226,100,226,101,226,102,226,103,226,104,226,105,226,106,226,107,226,108,226,109,226,110,226,111,226,112,226,113,226,114,226,115,226,116,226,117,226,118,226,119,226,120,226,121,226,122,226,123,226,124,226,125,226,126,226,127,226,128,226,129,226,130,226,131,226,132,226,133,226,134,226,135,226,136,226,137,226,138,226,139,226,140,226,141,226,142,226,143,226,144,226,145,226,67,157,68,157,69,157,70,157,71,157,72,157,73,157,74,157,75,157,76,157,77,157,78,157,79,157,80,157,81,157,82,157,83,157,84,157,85,157,86,157,87,157,88,157,89,157,90,157,91,157,92,157,93,157,94,157,95,157,96,157,97,157,98,157,99,157,100,157,101,157,102,157,103,157,104,157,105,157,106,157,107,157,108,157,109,157,110,157,111,157,112,157,113,157,114,157,115,157,116,157,117,157,118,157,119,157,120,157,121,157,122,157,123,157,124,157,125,157,126,157,127,157,128,157,129,157,130,157,131,157,132,157,133,157,134,157,135,157,136,157,137,157,138,157,139,157,140,157,141,157,142,157,143,157,144,157,145,157,146,157,147,157,148,157,149,157,150,157,151,157,152,157,153,157,154,157,155,157,156,157,157,157,158,157,159,157,160,157,161,157,162,157,146,226,147,226,148,226,149,226,150,226,151,226,152,226,153,226,154,226,155,226,156,226,157,226,158,226,159,226,160,226,161,226,162,226,163,226,164,226,165,226,166,226,167,226,168,226,169,226,170,226,171,226,172,226,173,226,174,226,175,226,176,226,177,226,178,226,179,226,180,226,181,226,182,226,183,226,184,226,185,226,186,226,187,226,188,226,189,226,190,226,191,226,192,226,193,226,194,226,195,226,196,226,197,226,198,226,199,226,200,226,201,226,202,226,203,226,204,226,205,226,206,226,207,226,208,226,209,226,210,226,211,226,212,226,213,226,214,226,215,226,216,226,217,226,218,226,219,226,220,226,221,226,222,226,223,226,224,226,225,226,226,226,227,226,228,226,229,226,230,226,231,226,232,226,233,226,234,226,235,226,236,226,237,226,238,226,239,226,163,157,164,157,165,157,166,157,167,157,168,157,169,157,170,157,171,157,172,157,173,157,174,157,175,157,176,157,177,157,178,157,179,157,180,157,181,157,182,157,183,157,184,157,185,157,186,157,187,157,188,157,189,157,190,157,191,157,192,157,193,157,194,157,195,157,196,157,197,157,198,157,199,157,200,157,201,157,202,157,203,157,204,157,205,157,206,157,207,157,208,157,209,157,210,157,211,157,212,157,213,157,214,157,215,157,216,157,217,157,218,157,219,157,220,157,221,157,222,157,223,157,224,157,225,157,226,157,227,157,228,157,229,157,230,157,231,157,232,157,233,157,234,157,235,157,236,157,237,157,238,157,239,157,240,157,241,157,242,157,243,157,244,157,245,157,246,157,247,157,248,157,249,157,250,157,251,157,252,157,253,157,254,157,255,157,0,158,1,158,2,158,240,226,241,226,242,226,243,226,244,226,245,226,246,226,247,226,248,226,249,226,250,226,251,226,252,226,253,226,254,226,255,226,0,227,1,227,2,227,3,227,4,227,5,227,6,227,7,227,8,227,9,227,10,227,11,227,12,227,13,227,14,227,15,227,16,227,17,227,18,227,19,227,20,227,21,227,22,227,23,227,24,227,25,227,26,227,27,227,28,227,29,227,30,227,31,227,32,227,33,227,34,227,35,227,36,227,37,227,38,227,39,227,40,227,41,227,42,227,43,227,44,227,45,227,46,227,47,227,48,227,49,227,50,227,51,227,52,227,53,227,54,227,55,227,56,227,57,227,58,227,59,227,60,227,61,227,62,227,63,227,64,227,65,227,66,227,67,227,68,227,69,227,70,227,71,227,72,227,73,227,74,227,75,227,76,227,77,227,3,158,4,158,5,158,6,158,7,158,8,158,9,158,10,158,11,158,12,158,13,158,14,158,15,158,16,158,17,158,18,158,19,158,20,158,21,158,22,158,23,158,24,158,25,158,26,158,27,158,28,158,29,158,30,158,36,158,39,158,46,158,48,158,52,158,59,158,60,158,64,158,77,158,80,158,82,158,83,158,84,158,86,158,89,158,93,158,95,158,96,158,97,158,98,158,101,158,110,158,111,158,114,158,116,158,117,158,118,158,119,158,120,158,121,158,122,158,123,158,124,158,125,158,128,158,129,158,131,158,132,158,133,158,134,158,137,158,138,158,140,158,141,158,142,158,143,158,144,158,145,158,148,158,149,158,150,158,151,158,152,158,153,158,154,158,155,158,156,158,158,158,160,158,161,158,162,158,163,158,164,158,165,158,167,158,168,158,169,158,170,158,78,227,79,227,80,227,81,227,82,227,83,227,84,227,85,227,86,227,87,227,88,227,89,227,90,227,91,227,92,227,93,227,94,227,95,227,96,227,97,227,98,227,99,227,100,227,101,227,102,227,103,227,104,227,105,227,106,227,107,227,108,227,109,227,110,227,111,227,112,227,113,227,114,227,115,227,116,227,117,227,118,227,119,227,120,227,121,227,122,227,123,227,124,227,125,227,126,227,127,227,128,227,129,227,130,227,131,227,132,227,133,227,134,227,135,227,136,227,137,227,138,227,139,227,140,227,141,227,142,227,143,227,144,227,145,227,146,227,147,227,148,227,149,227,150,227,151,227,152,227,153,227,154,227,155,227,156,227,157,227,158,227,159,227,160,227,161,227,162,227,163,227,164,227,165,227,166,227,167,227,168,227,169,227,170,227,171,227,171,158,172,158,173,158,174,158,175,158,176,158,177,158,178,158,179,158,181,158,182,158,183,158,185,158,186,158,188,158,191,158,192,158,193,158,194,158,195,158,197,158,198,158,199,158,200,158,202,158,203,158,204,158,208,158,210,158,211,158,213,158,214,158,215,158,217,158,218,158,222,158,225,158,227,158,228,158,230,158,232,158,235,158,236,158,237,158,238,158,240,158,241,158,242,158,243,158,244,158,245,158,246,158,247,158,248,158,250,158,253,158,255,158,0,159,1,159,2,159,3,159,4,159,5,159,6,159,7,159,8,159,9,159,10,159,12,159,15,159,17,159,18,159,20,159,21,159,22,159,24,159,26,159,27,159,28,159,29,159,30,159,31,159,33,159,35,159,36,159,37,159,38,159,39,159,40,159,41,159,42,159,43,159,45,159,46,159,48,159,49,159,172,227,173,227,174,227,175,227,176,227,177,227,178,227,179,227,180,227,181,227,182,227,183,227,184,227,185,227,186,227,187,227,188,227,189,227,190,227,191,227,192,227,193,227,194,227,195,227,196,227,197,227,198,227,199,227,200,227,201,227,202,227,203,227,204,227,205,227,206,227,207,227,208,227,209,227,210,227,211,227,212,227,213,227,214,227,215,227,216,227,217,227,218,227,219,227,220,227,221,227,222,227,223,227,224,227,225,227,226,227,227,227,228,227,229,227,230,227,231,227,232,227,233,227,234,227,235,227,236,227,237,227,238,227,239,227,240,227,241,227,242,227,243,227,244,227,245,227,246,227,247,227,248,227,249,227,250,227,251,227,252,227,253,227,254,227,255,227,0,228,1,228,2,228,3,228,4,228,5,228,6,228,7,228,8,228,9,228,50,159,51,159,52,159,53,159,54,159,56,159,58,159,60,159,63,159,64,159,65,159,66,159,67,159,69,159,70,159,71,159,72,159,73,159,74,159,75,159,76,159,77,159,78,159,79,159,82,159,83,159,84,159,85,159,86,159,87,159,88,159,89,159,90,159,91,159,92,159,93,159,94,159,95,159,96,159,97,159,98,159,99,159,100,159,101,159,102,159,103,159,104,159,105,159,106,159,107,159,108,159,109,159,110,159,111,159,112,159,113,159,114,159,115,159,116,159,117,159,118,159,119,159,120,159,121,159,122,159,123,159,124,159,125,159,126,159,129,159,130,159,141,159,142,159,143,159,144,159,145,159,146,159,147,159,148,159,149,159,150,159,151,159,152,159,156,159,157,159,158,159,161,159,162,159,163,159,164,159,165,159,44,249,121,249,149,249,231,249,241,249,10,228,11,228,12,228,13,228,14,228,15,228,16,228,17,228,18,228,19,228,20,228,21,228,22,228,23,228,24,228,25,228,26,228,27,228,28,228,29,228,30,228,31,228,32,228,33,228,34,228,35,228,36,228,37,228,38,228,39,228,40,228,41,228,42,228,43,228,44,228,45,228,46,228,47,228,48,228,49,228,50,228,51,228,52,228,53,228,54,228,55,228,56,228,57,228,58,228,59,228,60,228,61,228,62,228,63,228,64,228,65,228,66,228,67,228,68,228,69,228,70,228,71,228,72,228,73,228,74,228,75,228,76,228,77,228,78,228,79,228,80,228,81,228,82,228,83,228,84,228,85,228,86,228,87,228,88,228,89,228,90,228,91,228,92,228,93,228,94,228,95,228,96,228,97,228,98,228,99,228,100,228,101,228,102,228,103,228,12,250,13,250,14,250,15,250,17,250,19,250,20,250,24,250,31,250,32,250,33,250,35,250,36,250,39,250,40,250,41,250,129,46,22,232,23,232,24,232,132,46,115,52,71,52,136,46,139,46,30,232,158,53,26,54,14,54,140,46,151,46,110,57,24,57,38,232,207,57,223,57,115,58,208,57,43,232,44,232,78,59,110,60,224,60,167,46,49,232,50,232,170,46,86,64,95,65,174,46,55,67,179,46,182,46,183,46,59,232,177,67,172,67,187,46,221,67,214,68,97,70,76,70,67,232,35,71,41,71,124,71,141,71,202,46,71,73,122,73,125,73,130,73,131,73,133,73,134,73,159,73,155,73,183,73,182,73,84,232,85,232,163,76,159,76,160,76,161,76,119,76,162,76,19,77,20,77,21,77,22,77,23,77,24,77,25,77,174,77,100,232,104,228,105,228,106,228,107,228,108,228,109,228,110,228,111,228,112,228,113,228,114,228,115,228,116,228,117,228,118,228,119,228,120,228,121,228,122,228,123,228,124,228,125,228,126,228,127,228,128,228,129,228,130,228,131,228,132,228,133,228,134,228,135,228,136,228,137,228,138,228,139,228,140,228,141,228,142,228,143,228,144,228,145,228,146,228,147,228,148,228,149,228,150,228,151,228,152,228,153,228,154,228,155,228,156,228,157,228,158,228,159,228,160,228,161,228,162,228,163,228,164,228,165,228,166,228,167,228,168,228,169,228,170,228,171,228,172,228,173,228,174,228,175,228,176,228,177,228,178,228,179,228,180,228,181,228,182,228,183,228,184,228,185,228,186,228,187,228,188,228,189,228,190,228,191,228,192,228,193,228,194,228,195,228,196,228,197,228,0,0,0,0,0,0,0,0,240,67,50,76,3,70,166,69,120,69,103,114,119,77,179,69,177,124,226,76,197,124,149,59,54,71,68,71,71,76,64,76,191,66,23,54,82,115,139,110,210,112,87,76,81,163,79,71,218,69,133,76,108,124,7,77,164,74,161,70,35,107,37,114,84,90,99,26,6,62,97,63,77,102,251,86,0,0,149,125,29,89,185,139,244,61,52,151,239,123,219,91,94,29,164,90,37,54,176,158,209,90,183,91,252,92,110,103,147,133,69,153,97,116,157,116,117,56,83,29,158,54,33,96,236,62,222,88,245,58,252,122,151,159,97,65,13,137,234,49,138,10,94,50,10,67,132,132,150,159,47,148,48,73,19,134,150,88,74,151,24,146,208,121,50,122,96,102,41,106,157,136,76,116,197,123,130,103,44,122,79,82,70,144,230,52,196,115,185,93,198,116,199,159,179,87,47,73,76,84,49,65,142,54,24,88,114,122,101,123,143,139,174,70,136,110,129,65,153,93,174,123,188,36,200,159,193,36,201,36,204,36,201,159,4,133,187,53,180,64,202,159,225,68,255,173,193,98,110,112,203,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,49,193,49,194,49,195,49,196,49,12,1,197,49,209,0,205,0,198,49,199,49,203,0,232,31,200,49,202,0,201,49,202,49,203,49,204,49,14,1,205,49,206,49,0,1,193,0,205,1,192,0,18,1,201,0,26,1,200,0,76,1,211,0,209,1,210,0,0,220,190,30,4,220,192,30,202,0,1,1,225,0,206,1,224,0,81,2,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,8,220,191,30,12,220,193,30,234,0,97,2,218,35,219,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,163,69,17,0,0,10,101,0,0,0,0,61,78,221,110,78,157,223,145,0,0,0,0,53,119,145,100,26,79,40,79,168,79,86,81,116,81,156,81,228,81,161,82,168,82,59,83,78,83,209,83,216,83,226,86,240,88,4,89,7,89,50,89,52,89,102,91,158,91,159,91,154,92,134,94,59,96,137,101,254,103,4,104,101,104,78,109,188,112,53,117,164,126,172,126,186,126,199,126,207,126,223,126,6,127,55,127,122,130,207,130,111,131,198,137,190,139,226,139,102,143,103,143,110,143,17,116,252,124,205,125,70,105,201,122,39,82,0,0,0,0,0,0,0,0,140,145,184,120,94,145,188,128,0,0,11,141,246,128,231,9,0,0,0,0,159,128,199,158,205,76,201,157,12,158,62,76,246,157,14,112,10,158,51,161,193,53,0,0,154,110,62,130,25,117,0,0,17,73,108,154,143,154,153,159,135,121,108,132,202,29,208,5,230,42,36,78,129,78,128,78,135,78,191,78,235,78,55,79,76,52,189,79,72,62,3,80,136,80,125,52,147,52,165,52,134,81,5,89,219,81,252,81,5,82,137,78,121,82,144,82,39,83,199,53,169,83,81,53,176,83,83,53,194,83,35,84,109,53,114,53,129,54,147,84,163,84,180,84,185,84,208,84,239,84,24,85,35,85,40,85,152,53,63,85,165,53,191,53,215,85,197,53,132,125,37,85,0,0,66,12,21,13,43,81,144,85,198,44,236,57,65,3,70,142,184,77,229,148,83,64,190,128,122,119,56,44,52,58,213,71,93,129,242,105,234,77,221,100,124,13,180,15,213,12,244,16,141,100,126,142,150,14,11,12,100,15,169,44,86,130,211,68,0,0,70,13,77,154,233,128,244,71,167,78,194,44,178,154,103,58,244,149,237,63,6,53,199,82,212,151,200,120,68,45,110,157,21,152,0,0,217,67,165,96,180,100,227,84,76,45,202,43,119,16,251,57,111,16,218,102,22,103,160,121,234,100,82,80,67,12,104,142,161,33,76,139,49,7,0,0,11,72,169,1,250,63,115,88,141,45,0,0,200,69,252,4,151,96,76,15,150,13,121,85,187,64,186,67,0,0,180,74,102,42,157,16,170,129,245,152,156,13,121,99,254,57,117,39,192,141,161,86,124,100,67,62,0,0,1,166,9,14,207,42,201,44,0,0,200,16,194,57,146,57,6,58,155,130,120,53,73,94,199,32,82,86,49,15,178,44,32,151,188,52,61,108,59,78,0,0,0,0,116,117,139,46,8,34,91,166,205,140,122,14,52,12,28,104,147,127,207,16,3,40,57,41,251,53,227,81,140,14,141,15,170,14,147,63,48,15,71,13,79,17,76,14,0,0,171,14,169,11,72,13,192,16,61,17,249,63,150,38,50,100,173,15,244,51,57,118,206,43,126,13,127,13,81,44,85,44,24,58,152,14,199,16,46,15,50,166,80,107,210,140,153,141,202,140,170,149,204,84,196,130,185,85,0,0,195,158,38,156,182,154,94,119,238,45,64,113,109,129,236,128,28,92,114,101,52,129,151,55,95,83,189,128,182,145,250,14,15,14,119,14,251,14,221,53,235,77,9,54,214,12,175,86,181,39,201,16,16,14,120,14,120,16,72,17,7,130,85,20,121,14,80,78,164,45,84,90,29,16,30,16,245,16,246,16,156,87,17,14,148,118,205,130,181,15,123,14,126,81,3,55,182,15,128,17,216,82,189,162,218,73,58,24,119,65,124,130,153,88,104,82,26,54,61,87,178,123,104,91,0,72,44,75,39,159,231,73,31,156,141,155,116,91,61,49,251,85,242,53,137,86,40,78,2,89,193,27,120,248,81,151,134,0,91,78,187,78,62,53,35,92,81,95,196,95,250,56,76,98,53,101,122,107,53,108,58,108,108,112,43,114,44,78,173,114,233,72,82,127,59,121,249,124,83,127,106,98,193,52,0,0,75,99,2,128,128,128,18,102,81,105,93,83,100,136,193,137,178,120,160,139,29,141,133,148,120,149,127,149,232,149,15,142,230,151,117,152,206,152,222,152,99,153,16,152,124,156,31,158,196,158,111,107,7,249,55,78,135,0,29,150,55,98,162,148,0,0,59,80,254,109,115,156,166,159,201,61,143,136,78,65,119,112,245,92,32,75,205,81,89,53,48,93,34,97,50,138,167,143,246,145,145,113,25,103,186,115,129,50,7,161,139,60,128,25,16,75,228,120,2,116,174,81,15,135,9,64,99,106,186,162,35,66,15,134,111,10,42,122,71,153,234,138,85,151,77,112,36,83,126,32,244,147,217,118,227,137,167,159,221,119,163,78,240,79,188,80,47,78,23,79,168,159,52,84,139,125,146,88,208,88,182,29,146,94,153,94,194,95,18,39,139,101,249,51,25,105,67,106,99,60,255,108,0,0,0,114,5,69,140,115,219,62,19,74,21,91,185,116,131,139,164,92,149,86,147,122,236,123,195,124,108,126,248,130,151,133,169,159,144,136,170,159,185,142,171,159,207,143,95,133,224,153,33,146,172,159,185,141,63,20,113,64,162,66,26,90,0,0,0,0,0,0,104,152,107,103,118,66,61,87,0,0,214,133,123,73,191,130,13,113,129,76,116,109,123,93,21,107,190,111,173,159,174,159,150,91,175,159,231,102,91,126,87,110,202,121,136,61,195,68,86,50,150,39,154,67,54,69,0,0,213,92,26,59,249,138,120,92,18,61,81,53,120,93,178,159,87,113,88,69,236,64,35,30,119,76,120,57,74,52,164,1,65,108,204,138,180,79,57,2,191,89,108,129,86,152,250,152,59,95,159,11,0,0,193,33,109,137,2,65,187,70,121,144,7,63,179,159,181,161,248,64,214,55,247,70,70,108,124,65,178,134,255,115,109,69,212,56,154,84,97,69,27,69,137,77,123,76,118,77,234,69,200,63,15,75,97,54,222,68,189,68,237,65,62,93,72,93,86,93,252,61,15,56,164,93,185,93,32,56,56,56,66,94,189,94,37,95,131,95,8,57,20,57,63,57,77,57,215,96,61,97,229,92,137,57,183,97,185,97,207,97,184,57,44,98,144,98,229,98,24,99,248,57,177,86,3,58,226,99,251,99,7,100,90,100,75,58,192,100,21,93,33,86,159,159,151,58,134,101,189,58,255,101,83,102,242,58,146,102,34,59,22,103,66,59,164,103,0,104,88,59,74,104,132,104,114,59,113,59,123,59,9,105,67,105,92,114,100,105,159,105,133,105,188,59,214,105,221,59,101,106,116,106,113,106,130,106,236,59,153,106,242,59,171,106,181,106,212,106,246,106,129,107,193,107,234,107,117,108,170,108,203,60,2,109,6,109,38,109,129,109,239,60,164,109,177,109,21,110,24,110,41,110,134,110,192,137,187,110,226,110,218,110,127,159,232,110,233,110,36,111,52,111,70,61,65,63,129,111,190,111,106,61,117,61,183,113,153,92,138,61,44,112,145,61,80,112,84,112,111,112,127,112,137,112,37,3,193,67,241,53,216,14,215,62,190,87,211,110,62,113,224,87,78,54,162,105,233,139,116,91,73,122,225,88,217,148,101,122,125,122,172,89,187,122,176,122,194,122,195,122,209,113,141,100,202,65,218,122,221,122,234,122,239,65,178,84,1,92,11,123,85,123,41,123,14,83,254,92,162,123,111,123,156,131,180,91,127,108,208,123,33,132,146,123,0,0,32,93,173,61,101,92,146,132,250,123,0,0,53,124,193,92,68,124,131,124,130,72,166,124,125,102,120,69,201,124,199,124,230,124,116,124,243,124,245,124,0,0,103,126,29,69,68,110,93,125,214,110,141,116,137,125,171,125,53,113,179,125,0,0,87,64,41,96,228,125,19,61,245,125,249,23,229,125,109,131,0,0,33,97,90,97,110,126,146,126,43,67,108,148,39,126,64,127,65,127,71,127,54,121,208,98,225,153,151,127,81,99,163,127,97,22,104,0,92,69,102,55,3,69,58,131,250,127,137,100,0,0,8,128,29,128,0,0,47,128,135,160,195,108,59,128,60,128,97,128,20,39,137,73,38,102,227,61,232,102,37,103,167,128,72,138,7,129,26,129,176,88,246,38,127,108,152,100,184,79,231,100,138,20,24,130,94,24,83,106,101,74,149,74,122,68,41,130,13,11,82,106,126,61,249,79,253,20,226,132,98,131,10,107,167,73,48,53,115,23,248,61,170,130,27,105,148,249,219,65,75,133,208,130,26,131,22,14,180,23,193,54,125,49,90,53,123,130,226,130,24,131,139,62,163,109,5,107,151,107,206,53,191,61,29,131,236,85,133,131,11,69,165,109,172,131,0,0,211,131,126,52,212,110,87,106,90,133,150,52,66,110,239,46,88,132,228,91,113,132,211,61,228,68,167,106,74,132,181,60,88,121,0,0,150,107,119,110,67,110,222,132,0,0,145,131,160,68,147,132,228,132,145,92,64,66,192,92,67,69,52,133,242,90,153,110,39,69,115,133,22,69,191,103,22,134,37,134,59,134,193,133,136,112,2,134,130,21,205,112,178,249,106,69,40,134,72,54,162,24,247,83,154,115,126,134,113,135,248,160,238,135,39,44,177,135,218,135,15,136,97,86,108,134,86,104,15,70,69,136,70,136,224,117,185,61,228,117,94,136,156,136,91,70,180,136,181,136,193,99,197,136,119,119,15,119,135,137,138,137,0,0,0,0,167,137,188,137,37,138,231,137,36,121,189,122,156,138,147,119,254,145,144,138,89,122,233,122,58,123,143,63,19,71,56,123,124,113,12,139,31,139,48,84,101,85,63,139,76,139,77,139,169,138,122,74,144,139,155,139,175,138,223,22,21,70,79,136,155,140,84,125,143,125,212,249,37,55,83,125,214,140,152,125,189,125,18,141,3,141,16,25,219,140,92,112,17,141,201,76,208,62,0,0,169,141,2,128,20,16,138,73,124,59,188,129,12,113,231,122,173,142,182,142,195,142,212,146,25,143,45,143,101,131,18,132,165,143,3,147,159,162,80,10,179,143,42,73,222,137,61,133,187,61,248,94,98,50,249,143,20,160,188,134,1,133,37,35,128,57,215,110,55,144,60,133,190,122,97,144,108,133,11,134,168,144,19,135,196,144,230,134,174,144,0,0,103,145,240,58,169,145,196,145,172,124,51,137,137,30,14,146,159,108,65,146,98,146,185,85,0,0,198,138,155,60,12,139,219,85,49,13,44,147,107,147,225,138,235,139,143,112,195,90,226,138,229,138,101,73,68,146,236,139,57,140,255,139,115,147,91,148,188,142,133,149,166,149,38,148,160,149,246,111,185,66,122,38,216,134,124,18,46,62,223,73,28,108,123,150,150,150,108,65,163,150,213,110,218,97,182,150,245,120,224,138,189,150,204,83,161,73,184,108,116,2,16,100,175,144,229,144,209,74,21,25,10,51,49,151,66,134,54,151,15,74,61,69,133,69,233,74,117,112,65,91,27,151,0,0,213,145,87,151,74,91,235,145,95,151,37,148,208,80,183,48,188,48,137,151,159,151,177,151,190,151,192,151,210,151,224,151,108,84,238,151,28,116,51,148,0,0,245,151,29,148,122,121,209,74,52,152,51,152,75,152,102,152,14,59,117,113,81,61,48,6,92,65,6,87,202,152,183,152,200,152,199,152,255,74,39,109,211,22,176,85,225,152,230,152,236,152,120,147,57,153,41,74,114,75,87,152,5,153,245,153,12,154,59,154,16,154,88,154,37,87,196,54,177,144,213,155,224,154,226,154,5,155,244,154,14,76,20,155,45,155,0,134,52,80,52,155,168,105,195,56,125,48,80,155,64,155,62,157,69,90,99,24,142,155,75,66,2,156,255,155,12,156,104,158,212,157,183,159,146,161,171,161,225,160,35,161,223,161,126,157,131,157,52,161,14,158,136,104,196,157,91,33,147,161,32,162,59,25,51,162,57,157,185,160,180,162,144,158,149,158,158,158,162,158,52,77,170,158,175,158,100,67,193,158,96,59,229,57,29,61,50,79,190,55,43,140,2,159,8,159,150,75,36,148,162,109,23,159,0,0,57,159,159,86,138,86,69,159,184,153,139,144,242,151,127,132,98,159,105,159,220,122,142,159,22,114,190,75,117,73,187,73,119,113,248,73,72,67,81,74,158,115,218,139,250,24,159,121,126,137,54,142,105,147,243,147,68,138,236,146,129,147,203,147,108,137,185,68,23,114,235,62,114,119,67,122,208,112,115,68,248,67,126,113,239,23,163,112,190,24,153,53,199,62,133,24,47,84,248,23,34,55,251,22,57,24,225,54,116,23,209,24,75,95,35,55,192,22,91,87,37,74,254,19,168,18,198,19,182,20,3,133,166,54,0,0,85,132,148,73,101,113,49,62,92,85,251,62,82,112,244,68,238,54,157,153,38,111,249,103,51,55,21,60,231,61,108,88,34,25,16,104,87,64,63,55,225,64,139,64,15,65,33,108,203,84,158,86,177,102,146,86,223,15,168,11,13,14,198,147,19,139,156,147,248,78,43,81,25,56,54,68,188,78,101,4,127,3,75,79,138,79,81,86,104,90,171,1,203,3,153,57,10,3,20,4,53,52,41,79,192,2,179,142,117,2,218,138,12,2,152,78,205,80,13,81,162,79,3,79,14,74,138,62,66,79,46,80,108,80,129,80,204,79,229,79,88,80,252,80,0,0,0,0,0,0,0,0,118,110,149,53,57,62,191,62,114,109,132,24,137,62,168,81,195,81,224,5,221,68,163,4,146,4,145,4,122,141,156,138,14,7,89,82,164,82,115,8,225,82,0,0,122,70,140,113,140,67,32,12,172,73,228,16,209,105,29,14,0,0,222,62,153,116,20,116,86,116,152,115,142,75,188,74,141,64,208,83,132,53,15,114,201,64,180,85,69,3,205,84,198,11,29,87,93,146,244,150,102,147,221,87,141,87,127,87,62,54,203,88,153,90,70,138,250,22,111,23,16,23,44,90,184,89,143,146,126,90,207,90,18,90,70,89,243,25,97,24,149,66,245,54,5,109,67,116,33,90,131,94,129,90,215,139,19,4,224,147,140,116,3,19,5,113,114,73,8,148,251,137,189,147,160,55,30,92,158,92,94,94,72,94,150,25,124,25,238,58,205,94,79,91,3,25,4,25,1,55,160,24,221,54,254,22,211,54,42,129,71,138,186,29,114,52,168,137,12,95,14,95,39,25,171,23,107,90,59,23,68,91,20,134,253,117,96,136,126,96,96,40,43,38,219,95,184,62,175,37,190,37,136,144,115,111,192,97,62,0,70,0,27,38,153,97,152,97,117,96,155,44,7,45,212,70,77,145,113,100,101,70,106,43,41,58,34,43,80,52,234,152,120,46,55,99,91,164,182,100,49,99,209,99,227,73,103,45,164,98,161,44,59,100,107,101,114,105,244,59,142,48,173,50,137,73,171,50,13,85,224,50,217,24,63,148,206,102,137,50,179,49,224,58,144,65,132,85,34,139,143,85,252,22,91,85,37,84,238,120,3,49,42,24,52,50,100,52,15,50,130,49,201,66,142,102,36,109,107,102,147,75,48,102,112,120,235,29,99,102,210,50,225,50,30,102,114,88,209,56,58,56,188,55,153,59,162,55,254,51,208,116,150,59,143,103,42,70,182,104,30,104,196,59,190,106,99,56,213,55,135,68,51,106,82,106,201,106,5,107,18,25,17,101,152,104,76,106,215,59,122,106,87,107,192,63,154,60,160,147,242,146,234,139,203,138,137,146,30,128,220,137,103,148,165,109,11,111,236,73,0,0,127,63,143,61,4,110,60,64,61,90,10,110,71,88,36,109,66,120,59,113,26,67,118,66,241,112,80,114,135,114,148,114,143,71,37,71,121,81,164,74,235,5,122,116,248,62,95,54,74,74,23,73,225,95,6,63,177,62,223,74,35,140,53,63,167,96,243,62,204,116,60,116,135,147,55,116,159,68,234,109,81,69,131,117,99,63,217,76,6,77,88,63,85,117,115,118,198,165,25,59,104,116,204,138,171,73,142,73,251,58,205,61,78,74,255,62,197,73,243,72,250,145,50,87,66,147,227,138,100,24,223,80,33,82,231,81,120,119,50,50,14,119,15,119,123,119,151,70,129,55,94,58,240,72,56,116,155,116,191,62,186,74,199,74,200,64,150,74,174,97,7,147,129,85,30,120,141,120,136,120,210,120,208,115,89,121,65,119,227,86,14,65,0,0,150,132,165,121,45,106,250,62,58,122,244,121,110,65,230,22,50,65,53,146,241,121,76,13,140,73,153,2,186,61,110,23,151,53,107,85,112,53,170,54,212,1,13,12,226,122,89,90,245,38,175,90,156,90,13,90,91,2,240,120,42,90,198,91,254,122,249,65,93,124,109,124,17,66,179,91,188,94,166,94,205,124,249,73,176,23,142,124,124,124,174,124,178,106,220,125,7,126,211,125,78,127,97,98,92,97,72,123,151,125,130,94,106,66,117,107,22,9,214,103,78,0,207,53,196,87,18,100,248,99,98,73,221,127,39,123,44,8,233,90,67,93,12,123,14,94,230,153,69,134,99,154,28,106,63,52,226,57,247,73,173,101,31,154,160,101,128,132,39,113,209,108,234,68,55,129,2,68,198,128,9,129,66,129,180,103,195,152,66,106,98,130,101,130,81,106,83,132,167,109,16,134,27,114,134,90,127,65,64,24,43,91,161,24,228,90,216,24,160,134,188,249,143,61,45,136,34,116,2,90,110,136,69,79,135,136,191,136,230,136,101,137,77,137,131,86,84,137,133,119,132,119,245,139,217,139,156,139,249,137,173,62,163,132,245,70,207,70,242,55,61,138,28,138,72,148,77,95,43,146,132,66,212,101,41,113,196,112,69,24,109,157,159,140,233,140,220,125,154,89,195,119,240,89,110,67,212,54,42,142,167,142,9,76,48,143,74,143,244,66,88,108,187,111,33,35,155,72,121,111,139,110,218,23,233,155,181,54,47,73,187,144,0,0,113,85,6,73,187,145,4,148,75,138,98,64,252,138,39,148,29,140,59,140,229,132,43,138,153,149,167,149,151,149,150,149,52,141,69,116,194,62,255,72,66,74,234,67,231,62,37,50,143,150,231,142,102,142,101,142,204,62,237,73,120,74,238,63,18,116,107,116,252,62,65,151,176,144,71,104,29,74,147,144,223,87,0,0,104,147,137,137,38,140,47,139,190,99,186,146,17,91,105,139,60,73,249,115,27,66,155,151,113,151,56,153,38,15,193,93,197,139,178,74,31,152,218,148,246,146,215,149,229,145,192,68,80,139,103,74,100,139,220,152,69,138,0,63,42,146,37,73,20,132,59,153,77,153,6,123,253,61,155,153,111,75,170,153,92,154,101,139,200,88,143,106,33,154,254,90,47,154,241,152,144,75,72,153,188,153,189,75,151,75,125,147,114,88,2,19,34,88,184,73,232,20,68,120,31,39,184,61,197,104,125,61,88,148,39,57,80,97,129,39,107,41,7,97,79,156,83,156,123,156,53,156,16,156,127,155,207,155,45,158,159,155,245,161,254,160,33,157,174,76,4,65,24,158,176,76,12,157,180,161,237,160,243,160,47,153,165,157,189,132,18,110,223,111,130,107,252,133,51,69,164,109,132,110,240,109,32,132,238,133,0,110,215,55,100,96,226,121,156,53,64,54,45,73,222,73,98,61,219,147,190,146,72,147,191,2,185,120,119,146,77,148,228,79,64,52,100,144,93,85,61,120,84,120,182,120,75,120,87,23,201,49,65,73,154,54,114,79,218,111,217,111,0,0,30,112,20,84,181,65,187,87,243,88,138,87,22,157,215,87,52,113,175,52,172,65,235,113,64,108,151,79,0,0,181,23,73,138,12,97,206,90,11,90,188,66,136,68,44,55,123,75,252,137,187,147,184,147,214,24,29,15,114,132,192,108,19,20,250,66,38,44,193,67,148,89,183,61,65,103,168,125,91,97,164,96,185,73,139,73,250,137,229,146,226,115,233,62,180,116,99,139,159,24,225,62,179,74,216,106,243,115,251,115,214,62,62,74,148,74,217,23,102,74,167,3,36,20,229,73,72,116,22,73,165,112,118,73,132,146,230,115,95,147,254,4,49,147,206,138,22,138,134,147,231,139,213,85,53,73,130,138,107,113,67,73,255,12,164,86,26,6,235,11,184,12,2,85,196,121,250,23,254,125,194,22,80,74,82,24,46,69,1,148,10,55,192,138,173,73,176,89,191,24,131,24,132,116,161,90,226,54,91,61,176,54,95,146,121,90,129,138,98,24,116,147,205,60,180,10,150,74,138,57,244,80,105,61,76,61,156,19,117,113,251,66,24,130,15,110,228,144,235,68,87,109,79,126,103,112,175,108,214,60,237,63,45,62,2,110,12,111,111,61,245,3,81,117,188,54,200,52,128,70,218,62,113,72,196,89,110,146,62,73,65,143,28,140,192,107,18,88,200,87,214,54,82,20,254,112,98,67,113,74,227,47,176,18,189,35,185,104,103,105,152,19,229,52,244,123,223,54,131,138,214,55,250,51,159,76,26,106,173,54,183,108,62,132,223,68,206,68,38,109,81,109,130,108,222,111,23,111,9,113,61,131,58,23,237,131,128,108,83,112,219,23,137,89,130,90,179,23,97,90,113,90,5,25,252,65,45,55,239,89,60,23,199,54,142,113,144,147,154,102,165,66,110,90,43,90,147,66,43,106,249,62,54,119,91,68,202,66,29,113,89,66,225,137,176,79,40,109,194,92,206,68,77,126,189,67,12,106,86,66,4,19,166,112,51,113,233,67,165,61,223,108,37,248,79,74,101,126,235,89,47,93,243,61,92,95,93,74,223,23,164,125,38,132,133,84,250,58,0,51,20,2,126,87,213,8,25,6,229,63,158,31,182,162,3,112,91,145,112,93,143,115,211,124,89,138,32,148,200,79,231,127,205,114,16,115,244,122,56,115,57,115,246,86,65,115,72,115,169,62,24,123,108,144,245,113,242,72,225,115,246,129,202,62,12,119,209,62,162,108,253,86,25,116,30,116,31,116,226,62,240,62,244,62,250,62,211,116,14,63,83,63,66,117,109,117,114,117,141,117,124,63,200,117,220,117,192,63,77,118,215,63,116,118,220,63,122,118,92,79,136,113,35,86,128,137,105,88,29,64,67,119,57,64,97,103,69,64,219,53,152,119,106,64,111,64,94,92,190,119,203,119,242,88,24,120,185,112,28,120,168,64,57,120,71,120,81,120,102,120,72,132,53,85,51,121,3,104,50,121,3,65,9,65,145,121,153,121,187,143,6,122,188,143,103,65,145,122,178,65,188,122,121,130,196,65,207,122,219,122,207,65,33,78,98,123,108,123,123,123,18,124,27,124,96,66,122,66,123,124,156,124,140,66,184,124,148,66,237,124,147,143,192,112,207,12,207,125,212,125,208,125,253,125,174,127,180,127,159,114,151,67,32,128,37,128,57,123,46,128,49,128,84,128,204,61,180,87,160,112,183,128,233,128,237,67,12,129,42,115,14,129,18,129,96,117,20,129,1,68,57,59,86,129,89,129,90,129,19,68,58,88,124,129,132,129,37,68,147,129,45,68,165,129,239,87,193,129,228,129,84,130,143,68,166,130,118,130,202,130,216,130,255,130,176,68,87,131,105,150,138,105,5,132,245,112,100,132,227,96,136,132,4,69,190,132,225,132,248,132,16,133,56,133,82,133,59,69,111,133,112,133,224,133,119,69,114,134,146,134,178,134,239,134,69,150,139,135,6,70,23,70,174,136,255,136,36,137,71,137,145,137,103,121,41,138,56,138,148,138,180,138,81,140,212,140,242,140,28,141,152,71,95,88,195,141,237,71,238,78,58,142,216,85,84,87,113,142,245,85,176,142,55,72,206,142,226,142,228,142,237,142,242,142,183,143,193,143,202,143,204,143,51,144,196,153,173,72,224,152,19,146,30,73,40,146,88,146,107,146,177,146,174,146,191,146,227,146,235,146,243,146,244,146,253,146,67,147,132,147,173,147,69,73,81,73,191,158,23,148,1,83,29,148,45,148,62,148,106,73,84,148,121,148,45,149,162,149,167,73,244,149,51,150,229,73,160,103,36,74,64,151,53,74,178,151,194,151,84,86,228,74,232,96,185,152,25,75,241,152,68,88,14,153,25,153,180,81,28,153,55,153,66,153,93,153,98,153,112,75,197,153,157,75,60,154,15,155,131,122,105,155,129,155,221,155,241,155,244,155,109,76,32,156,111,55,194,27,73,157,58,156,254,158,80,86,147,157,189,157,192,157,252,157,246,148,182,143,123,158,172,158,177,158,189,158,198,158,220,148,226,158,241,158,248,158,200,122,68,159,148,0,183,2,160,3,26,105,195,148,172,89,215,4,64,88,193,148,185,55,213,5,21,6,118,6,186,22,87,87,115,113,194,10,205,10,191,11,106,84,59,248,203,11,158,84,251,11,59,12,83,12,101,12,124,12,231,96,141,12,122,86,181,12,221,12,237,12,111,13,178,13,200,13,85,105,47,156,165,135,4,14,14,14,215,14,144,15,45,15,115,14,32,92,188,15,11,94,92,16,79,16,118,16,30,103,123,16,136,16,150,16,71,54,191,16,211,16,47,17,59,17,100,83,173,132,227,18,117,19,54,19,129,139,119,21,25,22,195,23,199,23,120,78,187,112,45,24,106,25,45,26,69,26,42,28,112,28,172,28,200,30,195,98,213,30,21,31,152,113,85,104,69,32,233,105,200,54,124,34,215,35,250,35,42,39,113,40,79,41,253,130,103,41,147,41,213,42,165,137,232,42,160,143,14,43,184,151,63,43,71,152,189,154,76,44,0,0,136,44,183,44,232,91,8,45,18,45,183,45,149,45,66,46,116,47,204,47,51,48,102,48,31,51,222,51,177,95,72,102,191,102,121,122,103,53,243,53,0,0,186,73,0,0,26,54,22,55,0,0,70,3,181,88,14,103,24,105,167,58,87,118,226,95,17,62,185,62,254,117,154,32,208,72,184,74,25,65,154,138,238,66,13,67,59,64,52,67,150,67,69,74,202,5,210,81,17,6,159,89,168,30,190,59,255,60,4,68,214,68,136,87,116,70,155,57,47,71,232,133,201,153,98,55,195,33,94,139,78,139,0,0,18,72,251,72,21,74,9,114,192,74,120,12,101,89,165,78,134,79,121,7,218,142,44,80,143,82,63,87,113,113,153,82,25,84,74,63,167,74,188,85,70,84,110,84,82,107,0,0,115,52,63,85,50,118,94,85,24,71,98,85,102,85,199,87,63,73,93,88,102,80,251,52,204,51,0,0,3,89,124,71,72,137,174,90,137,91,6,92,144,29,161,87,81,113,0,0,2,97,18,124,86,144,178,97,154,79,98,139,2,100,74,100,91,93,247,107,0,0,132,100,28,25,234,138,246,73,136,100,239,63,18,101,192,75,191,101,181,102,27,39,101,148,225,87,149,97,39,90,205,248,0,0,185,86,33,69,252,102,106,78,52,73,86,150,143,109,189,108,24,54,119,137,153,103,110,104,17,100,94,104,0,0,199,104,66,123,192,144,17,10,38,105,0,0,57,105,69,122,0,0,250,105,38,154,45,106,95,54,105,100,33,0,131,121,52,106,91,107,44,93,25,53,0,0,157,107,208,70,164,108,59,117,101,136,174,109,182,88,28,55,141,37,75,112,205,113,84,60,128,114,133,114,129,146,122,33,139,114,48,147,230,114,208,73,57,108,159,148,80,116,248,14,39,136,245,136,38,41,115,132,177,23,184,110,42,74,32,24,164,57,185,54,0,0,0,0,63,69,182,102,173,156,164,152,67,137,204,119,88,120,214,86,223,64,10,22,161,57,47,55,232,128,197,19,173,113,102,131,221,121,168,145,0,0,183,76,175,112,171,137,253,121,10,122,11,123,102,125,122,65,67,123,126,121,9,128,181,111,223,162,3,106,24,131,162,83,7,110,191,147,54,104,93,151,111,129,35,128,181,105,237,19,47,50,72,128,133,93,48,140,131,128,21,87,35,152,73,137,171,93,136,73,190,101,213,105,210,83,165,74,129,63,17,60,54,103,144,128,244,128,46,129,161,31,79,129,137,129,175,129,26,130,6,131,47,131,138,131,202,53,104,132,170,134,250,72,230,99,86,137,8,120,85,146,184,137,242,67,231,137,223,67,232,137,70,139,212,139,248,89,9,140,0,0,197,143,236,144,0,0,16,145,60,145,247,61,94,145,202,74,208,143,143,114,139,86,231,148,233,149,176,149,184,149,50,151,209,152,73,153,106,153,195,153,40,154,14,155,90,157,155,157,159,126,248,158,35,159,164,76,71,149,147,162,162,113,255,162,145,77,18,144,203,165,156,77,156,12,190,143,193,85,186,143,176,36,185,143,147,74,9,69,127,126,86,111,177,106,234,78,228,52,44,139,157,120,58,55,128,142,245,23,36,128,108,139,153,139,62,122,175,102,235,61,85,118,183,60,53,86,86,89,154,78,129,94,88,98,191,86,109,14,14,142,109,91,136,62,158,76,222,99,0,0,246,23,123,24,48,101,45,86,74,92,26,84,17,83,198,61,152,157,125,76,34,86,30,86,73,127,216,94,117,89,64,61,112,135,28,78,234,15,73,13,186,54,23,129,94,157,24,141,59,118,69,156,78,118,185,119,69,147,50,84,72,129,247,130,37,86,50,129,24,132,189,128,234,85,98,121,67,86,22,84,157,14,206,53,5,86,241,85,241,102,226,130,45,54,52,117,240,85,186,85,151,84,114,85,65,12,150,12,208,94,72,81,118,14,98,44,162,14,171,158,90,125,222,85,117,16,157,98,109,151,148,84,205,140,246,113,118,145,252,99,185,99,254,99,105,85,67,43,114,156,179,46,154,81,223,52,167,13,167,81,77,84,30,85,19,85,102,118,45,142,138,104,177,117,182,128,4,136,134,135,199,136,182,129,28,132,193,16,236,68,4,115,6,71,144,91,11,131,147,104,123,86,244,38,47,125,163,65,115,125,208,110,182,114,112,145,217,17,8,146,252,60,169,166,172,14,249,14,102,114,162,28,78,71,194,79,249,127,235,15,250,64,93,156,31,101,160,45,243,72,224,71,124,157,236,15,10,14,0,0,163,117,237,15,0,0,72,96,135,17,163,113,142,126,80,157,26,78,4,78,119,53,13,91,178,108,103,83,172,54,220,57,125,83,165,54,24,70,154,88,110,75,45,130,75,84,170,87,149,90,121,9,0,0,82,58,101,36,116,115,172,158,9,77,237,155,254,60,48,159,91,76,169,79,158,149,222,159,92,132,182,61,178,114,179,103,32,55,46,99,37,125,247,62,44,62,42,58,8,144,204,82,116,62,122,54,233,69,142,4,64,118,240,90,182,14,122,120,46,127,167,88,191,64,124,86,139,155,116,93,84,118,52,164,133,158,225,76,0,0,251,55,25,97,218,48,242,67,0,0,93,86,169,18,167,87,99,73,6,158,52,82,174,112,173,53,0,0,124,157,86,124,57,155,222,87,108,23,83,92,211,100,208,148,53,99,100,113,173,134,40,13,34,109,226,74,113,13,0,0,254,81,15,31,142,93,3,151,209,29,129,158,76,144,31,123,2,155,209,92,163,123,104,98,53,99,255,154,207,123,42,155,126,124,0,0,66,124,134,124,21,156,252,123,9,155,0,0,27,156,62,73,90,159,115,85,195,91,253,79,152,158,242,79,96,82,6,62,209,82,103,87,86,80,183,89,18,94,200,151,171,157,92,143,105,84,180,151,64,153,186,151,44,83,48,97,44,105,218,83,10,156,2,157,59,76,65,150,128,105,166,80,70,117,109,23,218,153,115,82,0,0,89,145,129,150,92,145,0,0,81,145,151,142,127,99,35,109,202,106,17,86,142,145,122,117,133,98,252,3,79,115,112,124,33,92,253,60,0,0,25,73,214,118,157,155,42,78,212,12,190,131,66,136,0,0,74,92,192,105,0,0,122,87,31,82,245,93,206,78,49,108,242,1,57,79,156,84,218,84,154,82,130,141,254,53,0,0,243,53,0,0,82,107,124,145,165,159,151,155,46,152,180,152,186,154,168,158,132,158,122,113,20,123,0,0,250,107,24,136,120,127,0,0,32,86,74,166,119,142,83,159,0,0,212,141,79,142,28,158,1,142,130,98,125,131,40,142,117,142,211,122,119,74,62,122,216,120,234,108,103,138,7,118,90,138,38,159,206,108,214,135,195,117,178,162,83,120,64,248,12,141,226,114,113,115,45,139,2,115,241,116,235,140,187,74,47,134,186,95,160,136,183,68,0,0,59,24,5,110,0,0,126,138,27,37,0,0,253,96,103,118,215,154,68,157,110,147,143,155,245,135,0,0,0,0,247,140,44,115,33,151,176,155,214,53,178,114,7,76,81,124,74,153,89,97,89,97,4,76,150,158,125,97,0,0,95,87,111,97,166,98,57,98,0,0,92,58,226,97,170,83,245,51,100,99,2,104,210,53,87,93,194,139,218,143,57,142,0,0,217,80,70,29,6,121,50,83,56,150,59,15,101,64,0,0,254,119,0,0,194,124,26,95,218,124,45,122,102,128,99,128,77,125,5,117,242,116,148,137,26,130,12,103,98,128,134,116,91,128,240,116,3,129,36,119,137,137,204,103,83,117,209,110,169,135,206,135,200,129,140,135,73,138,173,140,67,139,43,119,248,116,218,132,53,54,178,105,166,141,0,0,169,137,0,0,185,109,193,135,17,64,231,116,219,61,118,113,164,96,156,97,209,60,0,0,119,96,0,0,113,127,45,139,0,0,233,96,126,75,32,82,24,60,199,60,215,94,86,118,49,85,68,25,254,18,3,153,220,109,173,112,193,92,173,97,15,138,119,54,238,0,70,104,14,79,98,69,31,91,76,99,80,159,166,158,107,98,71,5,219,146,223,5,197,63,76,133,181,66,239,115,181,81,73,54,66,73,228,137,68,147,219,25,238,130,200,60,60,120,68,103,223,98,51,73,170,137,160,2,179,107,5,19,171,79,237,36,8,80,41,109,132,122,0,54,177,74,19,37,0,0,126,3,164,95,128,3,71,3,219,110,31,4,0,0,1,81,122,52,14,81,108,152,67,55,22,132,164,73,135,4,96,81,180,51,106,81,255,11,252,32,229,2,48,37,142,5,51,50,131,25,130,91,125,135,179,5,153,60,178,81,184,81,52,157,201,81,207,81,209,81,220,60,211,81,166,74,179,81,226,81,66,83,237,81,205,131,62,105,45,55,123,95,11,82,38,82,60,82,181,82,87,82,148,82,185,82,197,82,21,124,66,133,224,82,13,134,19,107,0,0,222,138,73,85,217,110,128,63,84,9,236,63,51,83,0,0,226,11,203,108,38,23,27,104,213,115,74,96,170,62,204,56,232,22,221,113,162,68,109,83,116,83,171,134,126,83,0,0,150,21,19,22,230,119,147,83,155,138,160,83,171,83,174,83,167,115,114,87,89,63,156,115,193,83,197,83,73,108,73,78,254,87,217,83,171,58,143,11,224,83,235,63,163,45,246,83,119,12,19,84,121,112,43,85,87,102,91,109,109,84,83,107,116,13,93,85,143,84,164,84,166,71,13,23,221,14,180,61,77,13,188,137,152,38,71,85,237,76,47,84,23,116,134,85,169,85,0,0,215,24,58,64,82,69,53,68,179,102,180,16,55,86,205,102,138,50,164,102,173,102,77,86,79,86,241,120,241,86,135,151,254,83,0,87,239,86,237,86,102,139,35,54,79,18,70,87,165,65,110,108,139,112,66,87,177,54,126,108,230,87,22,20,3,88,84,20,99,67,38,88,245,75,92,88,170,88,97,53,224,88,220,88,60,18,251,88,255,91,67,87,80,161,120,66,211,147,161,53,31,89,166,104,195,54,89,110,62,22,36,90,83,85,146,22,5,133,201,89,78,13,129,108,42,109,220,23,217,89,251,23,178,23,166,109,113,109,40,24,213,22,249,89,69,110,171,90,99,90,230,54,169,73,0,0,8,55,150,90,101,116,211,90,161,111,84,37,133,61,17,25,50,55,184,22,131,94,208,82,118,91,136,101,124,91,14,122,4,64,93,72,4,2,213,91,96,97,52,26,204,89,165,5,243,91,157,91,16,77,5,92,68,27,19,92,206,115,20,92,165,28,40,107,73,92,221,72,133,92,233,92,239,92,139,93,249,29,55,30,16,93,24,93,70,93,164,30,186,92,215,93,252,130,45,56,1,73,73,32,115,33,135,130,54,56,194,59,46,94,138,106,0,0,122,94,188,68,211,12,166,83,183,78,0,0,168,83,113,23,9,94,244,94,130,132,249,94,251,94,160,56,252,94,62,104,27,148,13,95,193,1,148,248,222,58,174,72,58,19,58,95,136,104,208,35,0,0,113,36,99,95,189,151,110,110,114,95,64,147,54,138,167,95,182,93,95,61,80,82,106,31,248,112,104,38,214,145,158,2,41,138,49,96,133,102,119,24,99,57,199,61,57,54,144,87,180,39,113,121,64,62,158,96,0,0,179,96,130,73,143,73,83,122,164,116,225,80,160,90,100,97,36,132,66,97,166,248,210,110,129,97,244,81,86,6,135,97,170,91,183,63,95,40,211,97,157,139,93,153,208,97,50,57,128,41,193,40,35,96,92,97,30,101,139,99,24,1,197,98,112,23,213,98,13,46,108,99,223,73,23,58,56,100,248,99,142,19,252,23,0,0,138,111,54,46,20,152,140,64,29,87,225,100,229,100,123,148,102,58,58,100,87,58,77,101,22,111,40,74,35,74,133,101,109,101,95,101,126,48,181,101,64,73,55,75,209,101,216,64,41,24,224,101,227,101,223,95,0,52,24,102,247,49,248,49,68,102,164,49,165,49,75,102,117,14,103,102,230,81,115,102,0,0,61,30,49,50,244,133,200,49,19,83,197,119,247,40,164,153,2,103,156,67,33,74,43,59,250,105,194,55,0,0,103,103,98,103,205,65,237,144,215,103,233,68,34,104,80,110,60,146,1,104,230,51,160,109,93,104,111,52,225,105,11,106,223,138,115,105,195,104,205,53,1,105,0,105,50,61,1,58,60,54,128,59,172,103,97,105,74,138,252,66,54,105,152,105,161,59,201,3,99,131,144,80,249,105,89,54,42,33,69,106,3,55,157,106,243,59,177,103,200,106,156,145,13,60,29,107,35,9,222,96,53,107,116,107,205,39,181,110,219,58,181,3,88,25,64,55,33,84,90,59,225,107,252,62,220,107,55,108,139,36,241,72,81,107,90,108,38,130,121,108,188,61,197,68,189,61,164,65,12,73,0,73,201,60,229,54,235,60,50,13,131,155,249,49,145,36,143,127,55,104,37,109,161,109,235,109,150,109,92,109,124,110,4,111,127,73,133,64,114,110,51,133,116,111,199,81,0,0,0,0,46,132,33,139,0,0,47,62,83,116,130,63,204,121,79,110,145,90,75,48,248,111,13,55,157,111,48,62,250,110,151,20,61,64,85,69,240,147,68,111,92,111,78,61,116,111,112,145,59,61,159,111,68,65,211,111,145,64,85,65,57,64,240,63,180,63,63,65,223,81,86,65,87,65,64,65,221,97,75,112,126,112,167,112,129,112,204,112,213,112,214,112,223,112,4,65,232,61,180,113,150,113,119,66,43,113,69,113,136,90,74,113,0,0,156,92,101,67,79,113,98,147,193,66,44,113,90,68,39,74,34,74,186,113,232,139,189,112,14,114,66,148,21,114,17,89,67,148,36,114,65,147,5,86,46,114,64,114,116,73,189,104,85,114,87,114,85,62,68,48,13,104,61,111,130,114,0,0,43,115,35,72,43,136,237,72,4,136,40,115,46,115,207,115,170,115,58,12,46,106,201,115,73,116,226,65,231,22,36,74,35,102,197,54,183,73,141,73,251,73,247,115,21,116,3,105,38,74,57,116,195,5,215,62,0,0,173,40,96,116,178,142,71,116,228,115,118,116,185,131,108,116,48,55,116,116,241,147,44,106,130,116,83,73,140,74,95,65,121,74,143,139,70,91,3,140,158,24,200,116,136,25,14,117,0,0,30,117,217,142,75,26,215,91,172,142,133,147,77,117,74,117,103,117,110,117,130,79,4,63,19,77,142,117,93,116,158,117,180,117,2,118,44,118,81,118,79,118,111,118,118,118,245,99,144,118,239,129,248,55,17,105,14,105,161,118,165,118,183,118,204,118,159,111,98,132,157,80,125,81,28,30,30,119,38,119,64,119,175,100,32,82,88,119,172,50,175,119,100,137,104,137,193,22,244,119,0,0,118,19,18,74,202,104,175,120,199,120,211,120,165,150,46,121,224,85,215,120,52,121,177,120,12,118,184,143,132,136,43,139,131,96,28,38,134,121,0,137,2,105,128,121,87,88,157,121,57,123,60,121,169,121,42,110,38,113,168,62,198,121,13,145,212,121,32,5,95,68,15,82,130,184,248,0,0,64,32,169,78,4,0,0,0,0,52,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,64,0,0,0,0,0,0,0,0,4,88,0,60,0,0,0,0,0,128,92,173,220,243,187,201,67,238,237,164,15,38,193,155,118,242,239,222,251,250,247,15,50,68,175,254,239,253,254,17,96,176,0,0,33,25,129,32,16,136,168,96,33,105,36,0,68,137,196,0,0,3,64,53,0,67,132,49,81,147,104,2,2,0,0,0,0,0,0,0,0,0,0,0,64,0,1,128,172,100,130,64,140,161,144,4,80,96,212,0,210,42,24,157,104,53,151,79,216,248,32,196,130,28,40,130,117,148,2,56,64,160,161,197,16,113,77,196,13,152,185,94,91,1,67,159,153,3,120,32,226,31,8,137,1,201,64,7,3,13,154,144,82,209,79,124,3,2,33,32,192,110,19,131,181,219,245,229,119,144,79,23,154,54,23,12,0,110,186,9,47,96,84,0,30,120,104,34,112,86,158,37,243,142,183,23,11,239,230,119,23,91,27,193,16,152,141,18,24,182,207,1,49,114,26,91,44,182,192,32,226,195,92,130,27,224,218,206,133,214,64,169,84,11,208,15,72,68,64,16,9,212,64,174,59,100,30,68,43,23,8,134,130,54,24,160,137,231,156,91,8,132,3,2,218,144,236,219,135,133,191,162,173,157,142,157,152,32,37,70,0,70,159,127,227,213,201,132,244,214,77,6,227,182,24,18,9,0,0,0,4,0,0,32,0,0,0,0,2,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,120,110,95,63,126,221,61,247,252,155,252,174,210,255,143,107,241,231,191,186,174,110,23,239,220,167,62,182,181,119,201,146,215,165,182,74,110,155,185,129,77,103,254,84,241,155,98,254,111,82,215,54,254,191,41,69,129,249,189,101,166,66,57,0,0,66,96,143,0,148,64,64,210,175,215,209,219,0,160,152,178,123,6,82,32,152,22,200,61,9,0,0,1,0,0,0,1,10,178,8,128,0,0,0,4,136,32,20,16,76,0,0,4,0,161,68,16,0,65,1,0,8,64,240,223,79,54,88,241,245,181,128,245,103,128,64,0,80,78,65,200,132,0,90,96,216,1,43,1,80,161,22,196,64,242,110,17,172,32,57,196,192,8,7,12,9,152,150,196,155,16,28,152,108,134,42,166,1,70,17,109,229,203,196,192,146,16,33,22,18,157,114,244,105,14,23,42,162,129,244,123,0,8,164,11,144,16,44,204,57,74,1,240,22,11,10,64,12,29,234,12,68,14,69,2,0,0,0,0,0,0,0,0,0,0,48,12,255,1,48,2,48,14,255,39,32,27,255,26,255,31,255,1,255,48,254,38,32,37,32,80,254,81,254,82,254,183,0,84,254,85,254,86,254,87,254,92,255,19,32,49,254,20,32,51,254,116,37,52,254,79,254,8,255,9,255,53,254,54,254,91,255,93,255,55,254,56,254,20,48,21,48,57,254,58,254,16,48,17,48,59,254,60,254,10,48,11,48,61,254,62,254,8,48,9,48,63,254,64,254,12,48,13,48,65,254,66,254,14,48,15,48,67,254,68,254,89,254,90,254,91,254,92,254,93,254,94,254,24,32,25,32,28,32,29,32,29,48,30,48,53,32,50,32,3,255,6,255,10,255,59,32,167,0,3,48,203,37,207,37,179,37,178,37,206,37,6,38,5,38,199,37,198,37,161,37,160,37,189,37,188,37,163,50,5,33,175,0,227,255,63,255,205,2,73,254,74,254,77,254,78,254,75,254,76,254,95,254,96,254,97,254,11,255,13,255,215,0,247,0,177,0,26,34,28,255,30,255,29,255,102,34,103,34,96,34,30,34,82,34,97,34,98,254,99,254,100,254,101,254,102,254,94,255,41,34,42,34,165,34,32,34,31,34,191,34,210,51,209,51,43,34,46,34,53,34,52,34,64,38,66,38,149,34,153,34,145,33,147,33,144,33,146,33,150,33,151,33,153,33,152,33,37,34,35,34,15,255,60,255,21,34,104,254,4,255,229,255,18,48,224,255,225,255,5,255,32,255,3,33,9,33,105,254,106,254,107,254,213,51,156,51,157,51,158,51,206,51,161,51,142,51,143,51,196,51,176,0,89,81,91,81,94,81,93,81,97,81,99,81,231,85,233,116,206,124,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,143,37,142,37,141,37,140,37,139,37,138,37,137,37,60,37,52,37,44,37,36,37,28,37,148,37,0,37,2,37,149,37,12,37,16,37,20,37,24,37,109,37,110,37,112,37,111,37,80,37,94,37,106,37,97,37,226,37,227,37,229,37,228,37,113,37,114,37,115,37,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,65,83,68,83,69,83,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,217,2,201,2,202,2,199,2,203,2,0,36,1,36,2,36,3,36,4,36,5,36,6,36,7,36,8,36,9,36,10,36,11,36,12,36,13,36,14,36,15,36,16,36,17,36,18,36,19,36,20,36,21,36,22,36,23,36,24,36,25,36,26,36,27,36,28,36,29,36,30,36,31,36,33,36,172,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,89,78,1,78,3,78,67,78,93,78,134,78,140,78,186,78,63,81,101,81,107,81,224,81,0,82,1,82,155,82,21,83,65,83,92,83,200,83,9,78,11,78,8,78,10,78,43,78,56,78,225,81,69,78,72,78,95,78,94,78,142,78,161,78,64,81,3,82,250,82,67,83,201,83,227,83,31,87,235,88,21,89,39,89,115,89,80,91,81,91,83,91,248,91,15,92,34,92,56,92,113,92,221,93,229,93,241,93,242,93,243,93,254,93,114,94,254,94,11,95,19,95,77,98,17,78,16,78,13,78,45,78,48,78,57,78,75,78,57,92,136,78,145,78,149,78,146,78,148,78,162,78,193,78,192,78,195,78,198,78,199,78,205,78,202,78,203,78,196,78,67,81,65,81,103,81,109,81,110,81,108,81,151,81,246,81,6,82,7,82,8,82,251,82,254,82,255,82,22,83,57,83,72,83,71,83,69,83,94,83,132,83,203,83,202,83,205,83,236,88,41,89,43,89,42,89,45,89,84,91,17,92,36,92,58,92,111,92,244,93,123,94,255,94,20,95,21,95,195,95,8,98,54,98,75,98,78,98,47,101,135,101,151,101,164,101,185,101,229,101,240,102,8,103,40,103,32,107,98,107,121,107,203,107,212,107,219,107,15,108,52,108,107,112,42,114,54,114,59,114,71,114,89,114,91,114,172,114,139,115,25,78,22,78,21,78,20,78,24,78,59,78,77,78,79,78,78,78,229,78,216,78,212,78,213,78,214,78,215,78,227,78,228,78,217,78,222,78,69,81,68,81,137,81,138,81,172,81,249,81,250,81,248,81,10,82,160,82,159,82,5,83,6,83,23,83,29,83,223,78,74,83,73,83,97,83,96,83,111,83,110,83,187,83,239,83,228,83,243,83,236,83,238,83,233,83,232,83,252,83,248,83,245,83,235,83,230,83,234,83,242,83,241,83,240,83,229,83,237,83,251,83,219,86,218,86,22,89,46,89,49,89,116,89,118,89,85,91,131,91,60,92,232,93,231,93,230,93,2,94,3,94,115,94,124,94,1,95,24,95,23,95,197,95,10,98,83,98,84,98,82,98,81,98,165,101,230,101,46,103,44,103,42,103,43,103,45,103,99,107,205,107,17,108,16,108,56,108,65,108,64,108,62,108,175,114,132,115,137,115,220,116,230,116,24,117,31,117,40,117,41,117,48,117,49,117,50,117,51,117,139,117,125,118,174,118,191,118,238,118,219,119,226,119,243,119,58,121,190,121,116,122,203,122,30,78,31,78,82,78,83,78,105,78,153,78,164,78,166,78,165,78,255,78,9,79,25,79,10,79,21,79,13,79,16,79,17,79,15,79,242,78,246,78,251,78,240,78,243,78,253,78,1,79,11,79,73,81,71,81,70,81,72,81,104,81,113,81,141,81,176,81,23,82,17,82,18,82,14,82,22,82,163,82,8,83,33,83,32,83,112,83,113,83,9,84,15,84,12,84,10,84,16,84,1,84,11,84,4,84,17,84,13,84,8,84,3,84,14,84,6,84,18,84,224,86,222,86,221,86,51,87,48,87,40,87,45,87,44,87,47,87,41,87,25,89,26,89,55,89,56,89,132,89,120,89,131,89,125,89,121,89,130,89,129,89,87,91,88,91,135,91,136,91,133,91,137,91,250,91,22,92,121,92,222,93,6,94,118,94,116,94,15,95,27,95,217,95,214,95,14,98,12,98,13,98,16,98,99,98,91,98,88,98,54,101,233,101,232,101,236,101,237,101,242,102,243,102,9,103,61,103,52,103,49,103,53,103,33,107,100,107,123,107,22,108,93,108,87,108,89,108,95,108,96,108,80,108,85,108,97,108,91,108,77,108,78,108,112,112,95,114,93,114,126,118,249,122,115,124,248,124,54,127,138,127,189,127,1,128,3,128,12,128,18,128,51,128,127,128,137,128,139,128,140,128,227,129,234,129,243,129,252,129,12,130,27,130,31,130,110,130,114,130,126,130,107,134,64,136,76,136,99,136,127,137,33,150,50,78,168,78,77,79,79,79,71,79,87,79,94,79,52,79,91,79,85,79,48,79,80,79,81,79,61,79,58,79,56,79,67,79,84,79,60,79,70,79,99,79,92,79,96,79,47,79,78,79,54,79,89,79,93,79,72,79,90,79,76,81,75,81,77,81,117,81,182,81,183,81,37,82,36,82,41,82,42,82,40,82,171,82,169,82,170,82,172,82,35,83,115,83,117,83,29,84,45,84,30,84,62,84,38,84,78,84,39,84,70,84,67,84,51,84,72,84,66,84,27,84,41,84,74,84,57,84,59,84,56,84,46,84,53,84,54,84,32,84,60,84,64,84,49,84,43,84,31,84,44,84,234,86,240,86,228,86,235,86,74,87,81,87,64,87,77,87,71,87,78,87,62,87,80,87,79,87,59,87,239,88,62,89,157,89,146,89,168,89,158,89,163,89,153,89,150,89,141,89,164,89,147,89,138,89,165,89,93,91,92,91,90,91,91,91,140,91,139,91,143,91,44,92,64,92,65,92,63,92,62,92,144,92,145,92,148,92,140,92,235,93,12,94,143,94,135,94,138,94,247,94,4,95,31,95,100,95,98,95,119,95,121,95,216,95,204,95,215,95,205,95,241,95,235,95,248,95,234,95,18,98,17,98,132,98,151,98,150,98,128,98,118,98,137,98,109,98,138,98,124,98,126,98,121,98,115,98,146,98,111,98,152,98,110,98,149,98,147,98,145,98,134,98,57,101,59,101,56,101,241,101,244,102,95,103,78,103,79,103,80,103,81,103,92,103,86,103,94,103,73,103,70,103,96,103,83,103,87,103,101,107,207,107,66,108,94,108,153,108,129,108,136,108,137,108,133,108,155,108,106,108,122,108,144,108,112,108,140,108,104,108,150,108,146,108,125,108,131,108,114,108,126,108,116,108,134,108,118,108,141,108,148,108,152,108,130,108,118,112,124,112,125,112,120,112,98,114,97,114,96,114,196,114,194,114,150,115,44,117,43,117,55,117,56,117,130,118,239,118,227,119,193,121,192,121,191,121,118,122,251,124,85,127,150,128,147,128,157,128,152,128,155,128,154,128,178,128,111,130,146,130,139,130,141,130,139,137,210,137,0,138,55,140,70,140,85,140,157,140,100,141,112,141,179,141,171,142,202,142,155,143,176,143,194,143,198,143,197,143,196,143,225,93,145,144,162,144,170,144,166,144,163,144,73,145,198,145,204,145,50,150,46,150,49,150,42,150,44,150,38,78,86,78,115,78,139,78,155,78,158,78,171,78,172,78,111,79,157,79,141,79,115,79,127,79,108,79,155,79,139,79,134,79,131,79,112,79,117,79,136,79,105,79,123,79,150,79,126,79,143,79,145,79,122,79,84,81,82,81,85,81,105,81,119,81,118,81,120,81,189,81,253,81,59,82,56,82,55,82,58,82,48,82,46,82,54,82,65,82,190,82,187,82,82,83,84,83,83,83,81,83,102,83,119,83,120,83,121,83,214,83,212,83,215,83,115,84,117,84,150,84,120,84,149,84,128,84,123,84,119,84,132,84,146,84,134,84,124,84,144,84,113,84,118,84,140,84,154,84,98,84,104,84,139,84,125,84,142,84,250,86,131,87,119,87,106,87,105,87,97,87,102,87,100,87,124,87,28,89,73,89,71,89,72,89,68,89,84,89,190,89,187,89,212,89,185,89,174,89,209,89,198,89,208,89,205,89,203,89,211,89,202,89,175,89,179,89,210,89,197,89,95,91,100,91,99,91,151,91,154,91,152,91,156,91,153,91,155,91,26,92,72,92,69,92,70,92,183,92,161,92,184,92,169,92,171,92,177,92,179,92,24,94,26,94,22,94,21,94,27,94,17,94,120,94,154,94,151,94,156,94,149,94,150,94,246,94,38,95,39,95,41,95,128,95,129,95,127,95,124,95,221,95,224,95,253,95,245,95,255,95,15,96,20,96,47,96,53,96,22,96,42,96,21,96,33,96,39,96,41,96,43,96,27,96,22,98,21,98,63,98,62,98,64,98,127,98,201,98,204,98,196,98,191,98,194,98,185,98,210,98,219,98,171,98,211,98,212,98,203,98,200,98,168,98,189,98,188,98,208,98,217,98,199,98,205,98,181,98,218,98,177,98,216,98,214,98,215,98,198,98,172,98,206,98,62,101,167,101,188,101,250,101,20,102,19,102,12,102,6,102,2,102,14,102,0,102,15,102,21,102,10,102,7,102,13,103,11,103,109,103,139,103,149,103,113,103,156,103,115,103,119,103,135,103,157,103,151,103,111,103,112,103,127,103,137,103,126,103,144,103,117,103,154,103,147,103,124,103,106,103,114,103,35,107,102,107,103,107,127,107,19,108,27,108,227,108,232,108,243,108,177,108,204,108,229,108,179,108,189,108,190,108,188,108,226,108,171,108,213,108,211,108,184,108,196,108,185,108,193,108,174,108,215,108,197,108,241,108,191,108,187,108,225,108,219,108,202,108,172,108,239,108,220,108,214,108,224,108,149,112,142,112,146,112,138,112,153,112,44,114,45,114,56,114,72,114,103,114,105,114,192,114,206,114,217,114,215,114,208,114,169,115,168,115,159,115,171,115,165,115,61,117,157,117,153,117,154,117,132,118,194,118,242,118,244,118,229,119,253,119,62,121,64,121,65,121,201,121,200,121,122,122,121,122,250,122,254,124,84,127,140,127,139,127,5,128,186,128,165,128,162,128,177,128,161,128,171,128,169,128,180,128,170,128,175,128,229,129,254,129,13,130,179,130,157,130,153,130,173,130,189,130,159,130,185,130,177,130,172,130,165,130,175,130,184,130,163,130,176,130,190,130,183,130,78,134,113,134,29,82,104,136,203,142,206,143,212,143,209,143,181,144,184,144,177,144,182,144,199,145,209,145,119,149,128,149,28,150,64,150,63,150,59,150,68,150,66,150,185,150,232,150,82,151,94,151,159,78,173,78,174,78,225,79,181,79,175,79,191,79,224,79,209,79,207,79,221,79,195,79,182,79,216,79,223,79,202,79,215,79,174,79,208,79,196,79,194,79,218,79,206,79,222,79,183,79,87,81,146,81,145,81,160,81,78,82,67,82,74,82,77,82,76,82,75,82,71,82,199,82,201,82,195,82,193,82,13,83,87,83,123,83,154,83,219,83,172,84,192,84,168,84,206,84,201,84,184,84,166,84,179,84,199,84,194,84,189,84,170,84,193,84,196,84,200,84,175,84,171,84,177,84,187,84,169,84,167,84,191,84,255,86,130,87,139,87,160,87,163,87,162,87,206,87,174,87,147,87,85,89,81,89,79,89,78,89,80,89,220,89,216,89,255,89,227,89,232,89,3,90,229,89,234,89,218,89,230,89,1,90,251,89,105,91,163,91,166,91,164,91,162,91,165,91,1,92,78,92,79,92,77,92,75,92,217,92,210,92,247,93,29,94,37,94,31,94,125,94,160,94,166,94,250,94,8,95,45,95,101,95,136,95,133,95,138,95,139,95,135,95,140,95,137,95,18,96,29,96,32,96,37,96,14,96,40,96,77,96,112,96,104,96,98,96,70,96,67,96,108,96,107,96,106,96,100,96,65,98,220,98,22,99,9,99,252,98,237,98,1,99,238,98,253,98,7,99,241,98,247,98,239,98,236,98,254,98,244,98,17,99,2,99,63,101,69,101,171,101,189,101,226,101,37,102,45,102,32,102,39,102,47,102,31,102,40,102,49,102,36,102,247,102,255,103,211,103,241,103,212,103,208,103,236,103,182,103,175,103,245,103,233,103,239,103,196,103,209,103,180,103,218,103,229,103,184,103,207,103,222,103,243,103,176,103,217,103,226,103,221,103,210,103,106,107,131,107,134,107,181,107,210,107,215,107,31,108,201,108,11,109,50,109,42,109,65,109,37,109,12,109,49,109,30,109,23,109,59,109,61,109,62,109,54,109,27,109,245,108,57,109,39,109,56,109,41,109,46,109,53,109,14,109,43,109,171,112,186,112,179,112,172,112,175,112,173,112,184,112,174,112,164,112,48,114,114,114,111,114,116,114,233,114,224,114,225,114,183,115,202,115,187,115,178,115,205,115,192,115,179,115,26,117,45,117,79,117,76,117,78,117,75,117,171,117,164,117,165,117,162,117,163,117,120,118,134,118,135,118,136,118,200,118,198,118,195,118,197,118,1,119,249,118,248,118,9,119,11,119,254,118,252,118,7,119,220,119,2,120,20,120,12,120,13,120,70,121,73,121,72,121,71,121,185,121,186,121,209,121,210,121,203,121,127,122,129,122,255,122,253,122,125,124,2,125,5,125,0,125,9,125,7,125,4,125,6,125,56,127,142,127,191,127,4,128,16,128,13,128,17,128,54,128,214,128,229,128,218,128,195,128,196,128,204,128,225,128,219,128,206,128,222,128,228,128,221,128,244,129,34,130,231,130,3,131,5,131,227,130,219,130,230,130,4,131,229,130,2,131,9,131,210,130,215,130,241,130,1,131,220,130,212,130,209,130,222,130,211,130,223,130,239,130,6,131,80,134,121,134,123,134,122,134,77,136,107,136,129,137,212,137,8,138,2,138,3,138,158,140,160,140,116,141,115,141,180,141,205,142,204,142,240,143,230,143,226,143,234,143,229,143,237,143,235,143,228,143,232,143,202,144,206,144,193,144,195,144,75,145,74,145,205,145,130,149,80,150,75,150,76,150,77,150,98,151,105,151,203,151,237,151,243,151,1,152,168,152,219,152,223,152,150,153,153,153,88,78,179,78,12,80,13,80,35,80,239,79,38,80,37,80,248,79,41,80,22,80,6,80,60,80,31,80,26,80,18,80,17,80,250,79,0,80,20,80,40,80,241,79,33,80,11,80,25,80,24,80,243,79,238,79,45,80,42,80,254,79,43,80,9,80,124,81,164,81,165,81,162,81,205,81,204,81,198,81,203,81,86,82,92,82,84,82,91,82,93,82,42,83,127,83,159,83,157,83,223,83,232,84,16,85,1,85,55,85,252,84,229,84,242,84,6,85,250,84,20,85,233,84,237,84,225,84,9,85,238,84,234,84,230,84,39,85,7,85,253,84,15,85,3,87,4,87,194,87,212,87,203,87,195,87,9,88,15,89,87,89,88,89,90,89,17,90,24,90,28,90,31,90,27,90,19,90,236,89,32,90,35,90,41,90,37,90,12,90,9,90,107,91,88,92,176,91,179,91,182,91,180,91,174,91,181,91,185,91,184,91,4,92,81,92,85,92,80,92,237,92,253,92,251,92,234,92,232,92,240,92,246,92,1,93,244,92,238,93,45,94,43,94,171,94,173,94,167,94,49,95,146,95,145,95,144,95,89,96,99,96,101,96,80,96,85,96,109,96,105,96,111,96,132,96,159,96,154,96,141,96,148,96,140,96,133,96,150,96,71,98,243,98,8,99,255,98,78,99,62,99,47,99,85,99,66,99,70,99,79,99,73,99,58,99,80,99,61,99,42,99,43,99,40,99,77,99,76,99,72,101,73,101,153,101,193,101,197,101,66,102,73,102,79,102,67,102,82,102,76,102,69,102,65,102,248,102,20,103,21,103,23,103,33,104,56,104,72,104,70,104,83,104,57,104,66,104,84,104,41,104,179,104,23,104,76,104,81,104,61,104,244,103,80,104,64,104,60,104,67,104,42,104,69,104,19,104,24,104,65,104,138,107,137,107,183,107,35,108,39,108,40,108,38,108,36,108,240,108,106,109,149,109,136,109,135,109,102,109,120,109,119,109,89,109,147,109,108,109,137,109,110,109,90,109,116,109,105,109,140,109,138,109,121,109,133,109,101,109,148,109,202,112,216,112,228,112,217,112,200,112,207,112,57,114,121,114,252,114,249,114,253,114,248,114,247,114,134,115,237,115,9,116,238,115,224,115,234,115,222,115,84,117,93,117,92,117,90,117,89,117,190,117,197,117,199,117,178,117,179,117,189,117,188,117,185,117,194,117,184,117,139,118,176,118,202,118,205,118,206,118,41,119,31,119,32,119,40,119,233,119,48,120,39,120,56,120,29,120,52,120,55,120,37,120,45,120,32,120,31,120,50,120,85,121,80,121,96,121,95,121,86,121,94,121,93,121,87,121,90,121,228,121,227,121,231,121,223,121,230,121,233,121,216,121,132,122,136,122,217,122,6,123,17,123,137,124,33,125,23,125,11,125,10,125,32,125,34,125,20,125,16,125,21,125,26,125,28,125,13,125,25,125,27,125,58,127,95,127,148,127,197,127,193,127,6,128,24,128,21,128,25,128,23,128,61,128,63,128,241,128,2,129,240,128,5,129,237,128,244,128,6,129,248,128,243,128,8,129,253,128,10,129,252,128,239,128,237,129,236,129,0,130,16,130,42,130,43,130,40,130,44,130,187,130,43,131,82,131,84,131,74,131,56,131,80,131,73,131,53,131,52,131,79,131,50,131,57,131,54,131,23,131,64,131,49,131,40,131,67,131,84,134,138,134,170,134,147,134,164,134,169,134,140,134,163,134,156,134,112,136,119,136,129,136,130,136,125,136,121,136,24,138,16,138,14,138,12,138,21,138,10,138,23,138,19,138,22,138,15,138,17,138,72,140,122,140,121,140,161,140,162,140,119,141,172,142,210,142,212,142,207,142,177,143,1,144,6,144,247,143,0,144,250,143,244,143,3,144,253,143,5,144,248,143,149,144,225,144,221,144,226,144,82,145,77,145,76,145,216,145,221,145,215,145,220,145,217,145,131,149,98,150,99,150,97,150,91,150,93,150,100,150,88,150,94,150,187,150,226,152,172,153,168,154,216,154,37,155,50,155,60,155,126,78,122,80,125,80,92,80,71,80,67,80,76,80,90,80,73,80,101,80,118,80,78,80,85,80,117,80,116,80,119,80,79,80,15,80,111,80,109,80,92,81,149,81,240,81,106,82,111,82,210,82,217,82,216,82,213,82,16,83,15,83,25,83,63,83,64,83,62,83,195,83,252,102,70,85,106,85,102,85,68,85,94,85,97,85,67,85,74,85,49,85,86,85,79,85,85,85,47,85,100,85,56,85,46,85,92,85,44,85,99,85,51,85,65,85,87,85,8,87,11,87,9,87,223,87,5,88,10,88,6,88,224,87,228,87,250,87,2,88,53,88,247,87,249,87,32,89,98,89,54,90,65,90,73,90,102,90,106,90,64,90,60,90,98,90,90,90,70,90,74,90,112,91,199,91,197,91,196,91,194,91,191,91,198,91,9,92,8,92,7,92,96,92,92,92,93,92,7,93,6,93,14,93,27,93,22,93,34,93,17,93,41,93,20,93,25,93,36,93,39,93,23,93,226,93,56,94,54,94,51,94,55,94,183,94,184,94,182,94,181,94,190,94,53,95,55,95,87,95,108,95,105,95,107,95,151,95,153,95,158,95,152,95,161,95,160,95,156,95,127,96,163,96,137,96,160,96,168,96,203,96,180,96,230,96,189,96,197,96,187,96,181,96,220,96,188,96,216,96,213,96,198,96,223,96,184,96,218,96,199,96,26,98,27,98,72,98,160,99,167,99,114,99,150,99,162,99,165,99,119,99,103,99,152,99,170,99,113,99,169,99,137,99,131,99,155,99,107,99,168,99,132,99,136,99,153,99,161,99,172,99,146,99,143,99,128,99,123,99,105,99,104,99,122,99,93,101,86,101,81,101,89,101,87,101,95,85,79,101,88,101,85,101,84,101,156,101,155,101,172,101,207,101,203,101,204,101,206,101,93,102,90,102,100,102,104,102,102,102,94,102,249,102,215,82,27,103,129,104,175,104,162,104,147,104,181,104,127,104,118,104,177,104,167,104,151,104,176,104,131,104,196,104,173,104,134,104,133,104,148,104,157,104,168,104,159,104,161,104,130,104,50,107,186,107,235,107,236,107,43,108,142,109,188,109,243,109,217,109,178,109,225,109,204,109,228,109,251,109,250,109,5,110,199,109,203,109,175,109,209,109,174,109,222,109,249,109,184,109,247,109,245,109,197,109,210,109,26,110,181,109,218,109,235,109,216,109,234,109,241,109,238,109,232,109,198,109,196,109,170,109,236,109,191,109,230,109,249,112,9,113,10,113,253,112,239,112,61,114,125,114,129,114,28,115,27,115,22,115,19,115,25,115,135,115,5,116,10,116,3,116,6,116,254,115,13,116,224,116,246,116,247,116,28,117,34,117,101,117,102,117,98,117,112,117,143,117,212,117,213,117,181,117,202,117,205,117,142,118,212,118,210,118,219,118,55,119,62,119,60,119,54,119,56,119,58,119,107,120,67,120,78,120,101,121,104,121,109,121,251,121,146,122,149,122,32,123,40,123,27,123,44,123,38,123,25,123,30,123,46,123,146,124,151,124,149,124,70,125,67,125,113,125,46,125,57,125,60,125,64,125,48,125,51,125,68,125,47,125,66,125,50,125,49,125,61,127,158,127,154,127,204,127,206,127,210,127,28,128,74,128,70,128,47,129,22,129,35,129,43,129,41,129,48,129,36,129,2,130,53,130,55,130,54,130,57,130,142,131,158,131,152,131,120,131,162,131,150,131,189,131,171,131,146,131,138,131,147,131,137,131,160,131,119,131,123,131,124,131,134,131,167,131,85,134,106,95,199,134,192,134,182,134,196,134,181,134,198,134,203,134,177,134,175,134,201,134,83,136,158,136,136,136,171,136,146,136,150,136,141,136,139,136,147,137,143,137,42,138,29,138,35,138,37,138,49,138,45,138,31,138,27,138,34,138,73,140,90,140,169,140,172,140,171,140,168,140,170,140,167,140,103,141,102,141,190,141,186,141,219,142,223,142,25,144,13,144,26,144,23,144,35,144,31,144,29,144,16,144,21,144,30,144,32,144,15,144,34,144,22,144,27,144,20,144,232,144,237,144,253,144,87,145,206,145,245,145,230,145,227,145,231,145,237,145,233,145,137,149,106,150,117,150,115,150,120,150,112,150,116,150,118,150,119,150,108,150,192,150,234,150,233,150,224,122,223,122,2,152,3,152,90,155,229,156,117,158,127,158,165,158,187,158,162,80,141,80,133,80,153,80,145,80,128,80,150,80,152,80,154,80,0,103,241,81,114,82,116,82,117,82,105,82,222,82,221,82,219,82,90,83,165,83,123,85,128,85,167,85,124,85,138,85,157,85,152,85,130,85,156,85,170,85,148,85,135,85,139,85,131,85,179,85,174,85,159,85,62,85,178,85,154,85,187,85,172,85,177,85,126,85,137,85,171,85,153,85,13,87,47,88,42,88,52,88,36,88,48,88,49,88,33,88,29,88,32,88,249,88,250,88,96,89,119,90,154,90,127,90,146,90,155,90,167,90,115,91,113,91,210,91,204,91,211,91,208,91,10,92,11,92,49,92,76,93,80,93,52,93,71,93,253,93,69,94,61,94,64,94,67,94,126,94,202,94,193,94,194,94,196,94,60,95,109,95,169,95,170,95,168,95,209,96,225,96,178,96,182,96,224,96,28,97,35,97,250,96,21,97,240,96,251,96,244,96,104,97,241,96,14,97,246,96,9,97,0,97,18,97,31,98,73,98,163,99,140,99,207,99,192,99,233,99,201,99,198,99,205,99,210,99,227,99,208,99,225,99,214,99,237,99,238,99,118,99,244,99,234,99,219,99,82,100,218,99,249,99,94,101,102,101,98,101,99,101,145,101,144,101,175,101,110,102,112,102,116,102,118,102,111,102,145,102,122,102,126,102,119,102,254,102,255,102,31,103,29,103,250,104,213,104,224,104,216,104,215,104,5,105,223,104,245,104,238,104,231,104,249,104,210,104,242,104,227,104,203,104,205,104,13,105,18,105,14,105,201,104,218,104,110,105,251,104,62,107,58,107,61,107,152,107,150,107,188,107,239,107,46,108,47,108,44,108,47,110,56,110,84,110,33,110,50,110,103,110,74,110,32,110,37,110,35,110,27,110,91,110,88,110,36,110,86,110,110,110,45,110,38,110,111,110,52,110,77,110,58,110,44,110,67,110,29,110,62,110,203,110,137,110,25,110,78,110,99,110,68,110,114,110,105,110,95,110,25,113,26,113,38,113,48,113,33,113,54,113,110,113,28,113,76,114,132,114,128,114,54,115,37,115,52,115,41,115,58,116,42,116,51,116,34,116,37,116,53,116,54,116,52,116,47,116,27,116,38,116,40,116,37,117,38,117,107,117,106,117,226,117,219,117,227,117,217,117,216,117,222,117,224,117,123,118,124,118,150,118,147,118,180,118,220,118,79,119,237,119,93,120,108,120,111,120,13,122,8,122,11,122,5,122,0,122,152,122,151,122,150,122,229,122,227,122,73,123,86,123,70,123,80,123,82,123,84,123,77,123,75,123,79,123,81,123,159,124,165,124,94,125,80,125,104,125,85,125,43,125,110,125,114,125,97,125,102,125,98,125,112,125,115,125,132,85,212,127,213,127,11,128,82,128,133,128,85,129,84,129,75,129,81,129,78,129,57,129,70,129,62,129,76,129,83,129,116,129,18,130,28,130,233,131,3,132,248,131,13,132,224,131,197,131,11,132,193,131,239,131,241,131,244,131,87,132,10,132,240,131,12,132,204,131,253,131,242,131,202,131,56,132,14,132,4,132,220,131,7,132,212,131,223,131,91,134,223,134,217,134,237,134,212,134,219,134,228,134,208,134,222,134,87,136,193,136,194,136,177,136,131,137,150,137,59,138,96,138,85,138,94,138,60,138,65,138,84,138,91,138,80,138,70,138,52,138,58,138,54,138,86,138,97,140,130,140,175,140,188,140,179,140,189,140,193,140,187,140,192,140,180,140,183,140,182,140,191,140,184,140,138,141,133,141,129,141,206,141,221,141,203,141,218,141,209,141,204,141,219,141,198,141,251,142,248,142,252,142,156,143,46,144,53,144,49,144,56,144,50,144,54,144,2,145,245,144,9,145,254,144,99,145,101,145,207,145,20,146,21,146,35,146,9,146,30,146,13,146,16,146,7,146,17,146,148,149,143,149,139,149,145,149,147,149,146,149,142,149,138,150,142,150,139,150,125,150,133,150,134,150,141,150,114,150,132,150,193,150,197,150,196,150,198,150,199,150,239,150,242,150,204,151,5,152,6,152,8,152,231,152,234,152,239,152,233,152,242,152,237,152,174,153,173,153,195,158,205,158,209,158,130,78,173,80,181,80,178,80,179,80,197,80,190,80,172,80,183,80,187,80,175,80,199,80,127,82,119,82,125,82,223,82,230,82,228,82,226,82,227,82,47,83,223,85,232,85,211,85,230,85,206,85,220,85,199,85,209,85,227,85,228,85,239,85,218,85,225,85,197,85,198,85,229,85,201,85,18,87,19,87,94,88,81,88,88,88,87,88,90,88,84,88,107,88,76,88,109,88,74,88,98,88,82,88,75,88,103,89,193,90,201,90,204,90,190,90,189,90,188,90,179,90,194,90,178,90,105,93,111,93,76,94,121,94,201,94,200,94,18,95,89,95,172,95,174,95,26,97,15,97,72,97,31,97,243,96,27,97,249,96,1,97,8,97,78,97,76,97,68,97,77,97,62,97,52,97,39,97,13,97,6,97,55,97,33,98,34,98,19,100,62,100,30,100,42,100,45,100,61,100,44,100,15,100,28,100,20,100,13,100,54,100,22,100,23,100,6,100,108,101,159,101,176,101,151,102,137,102,135,102,136,102,150,102,132,102,152,102,141,102,3,103,148,105,109,105,90,105,119,105,96,105,84,105,117,105,48,105,130,105,74,105,104,105,107,105,94,105,83,105,121,105,134,105,93,105,99,105,91,105,71,107,114,107,192,107,191,107,211,107,253,107,162,110,175,110,211,110,182,110,194,110,144,110,157,110,199,110,197,110,165,110,152,110,188,110,186,110,171,110,209,110,150,110,156,110,196,110,212,110,170,110,167,110,180,110,78,113,89,113,105,113,100,113,73,113,103,113,92,113,108,113,102,113,76,113,101,113,94,113,70,113,104,113,86,113,58,114,82,114,55,115,69,115,63,115,62,115,111,116,90,116,85,116,95,116,94,116,65,116,63,116,89,116,91,116,92,116,118,117,120,117,0,118,240,117,1,118,242,117,241,117,250,117,255,117,244,117,243,117,222,118,223,118,91,119,107,119,102,119,94,119,99,119,121,119,106,119,108,119,92,119,101,119,104,119,98,119,238,119,142,120,176,120,151,120,152,120,140,120,137,120,124,120,145,120,147,120,127,120,122,121,127,121,129,121,44,132,189,121,28,122,26,122,32,122,20,122,31,122,30,122,159,122,160,122,119,123,192,123,96,123,110,123,103,123,177,124,179,124,181,124,147,125,121,125,145,125,129,125,143,125,91,125,110,127,105,127,106,127,114,127,169,127,168,127,164,127,86,128,88,128,134,128,132,128,113,129,112,129,120,129,101,129,110,129,115,129,107,129,121,129,122,129,102,129,5,130,71,130,130,132,119,132,61,132,49,132,117,132,102,132,107,132,73,132,108,132,91,132,60,132,53,132,97,132,99,132,105,132,109,132,70,132,94,134,92,134,95,134,249,134,19,135,8,135,7,135,0,135,254,134,251,134,2,135,3,135,6,135,10,135,89,136,223,136,212,136,217,136,220,136,216,136,221,136,225,136,202,136,213,136,210,136,156,137,227,137,107,138,114,138,115,138,102,138,105,138,112,138,135,138,124,138,99,138,160,138,113,138,133,138,109,138,98,138,110,138,108,138,121,138,123,138,62,138,104,138,98,140,138,140,137,140,202,140,199,140,200,140,196,140,178,140,195,140,194,140,197,140,225,141,223,141,232,141,239,141,243,141,250,141,234,141,228,141,230,141,178,142,3,143,9,143,254,142,10,143,159,143,178,143,75,144,74,144,83,144,66,144,84,144,60,144,85,144,80,144,71,144,79,144,78,144,77,144,81,144,62,144,65,144,18,145,23,145,108,145,106,145,105,145,201,145,55,146,87,146,56,146,61,146,64,146,62,146,91,146,75,146,100,146,81,146,52,146,73,146,77,146,69,146,57,146,63,146,90,146,152,149,152,150,148,150,149,150,205,150,203,150,201,150,202,150,247,150,251,150,249,150,246,150,86,151,116,151,118,151,16,152,17,152,19,152,10,152,18,152,12,152,252,152,244,152,253,152,254,152,179,153,177,153,180,153,225,154,233,156,130,158,14,159,19,159,32,159,231,80,238,80,229,80,214,80,237,80,218,80,213,80,207,80,209,80,241,80,206,80,233,80,98,81,243,81,131,82,130,82,49,83,173,83,254,85,0,86,27,86,23,86,253,85,20,86,6,86,9,86,13,86,14,86,247,85,22,86,31,86,8,86,16,86,246,85,24,87,22,87,117,88,126,88,131,88,147,88,138,88,121,88,133,88,125,88,253,88,37,89,34,89,36,89,106,89,105,89,225,90,230,90,233,90,215,90,214,90,216,90,227,90,117,91,222,91,231,91,225,91,229,91,230,91,232,91,226,91,228,91,223,91,13,92,98,92,132,93,135,93,91,94,99,94,85,94,87,94,84,94,211,94,214,94,10,95,70,95,112,95,185,95,71,97,63,97,75,97,119,97,98,97,99,97,95,97,90,97,88,97,117,97,42,98,135,100,88,100,84,100,164,100,120,100,95,100,122,100,81,100,103,100,52,100,109,100,123,100,114,101,161,101,215,101,214,101,162,102,168,102,157,102,156,105,168,105,149,105,193,105,174,105,211,105,203,105,155,105,183,105,187,105,171,105,180,105,208,105,205,105,173,105,204,105,166,105,195,105,163,105,73,107,76,107,51,108,51,111,20,111,254,110,19,111,244,110,41,111,62,111,32,111,44,111,15,111,2,111,34,111,255,110,239,110,6,111,49,111,56,111,50,111,35,111,21,111,43,111,47,111,136,111,42,111,236,110,1,111,242,110,204,110,247,110,148,113,153,113,125,113,138,113,132,113,146,113,62,114,146,114,150,114,68,115,80,115,100,116,99,116,106,116,112,116,109,116,4,117,145,117,39,118,13,118,11,118,9,118,19,118,225,118,227,118,132,119,125,119,127,119,97,119,193,120,159,120,167,120,179,120,169,120,163,120,142,121,143,121,141,121,46,122,49,122,170,122,169,122,237,122,239,122,161,123,149,123,139,123,117,123,151,123,157,123,148,123,143,123,184,123,135,123,132,123,185,124,189,124,190,124,187,125,176,125,156,125,189,125,190,125,160,125,202,125,180,125,178,125,177,125,186,125,162,125,191,125,181,125,184,125,173,125,210,125,199,125,172,125,112,127,224,127,225,127,223,127,94,128,90,128,135,128,80,129,128,129,143,129,136,129,138,129,127,129,130,129,231,129,250,129,7,130,20,130,30,130,75,130,201,132,191,132,198,132,196,132,153,132,158,132,178,132,156,132,203,132,184,132,192,132,211,132,144,132,188,132,209,132,202,132,63,135,28,135,59,135,34,135,37,135,52,135,24,135,85,135,55,135,41,135,243,136,2,137,244,136,249,136,248,136,253,136,232,136,26,137,239,136,166,138,140,138,158,138,163,138,141,138,161,138,147,138,164,138,170,138,165,138,168,138,152,138,145,138,154,138,167,138,106,140,141,140,140,140,211,140,209,140,210,140,107,141,153,141,149,141,252,141,20,143,18,143,21,143,19,143,163,143,96,144,88,144,92,144,99,144,89,144,94,144,98,144,93,144,91,144,25,145,24,145,30,145,117,145,120,145,119,145,116,145,120,146,128,146,133,146,152,146,150,146,123,146,147,146,156,146,168,146,124,146,145,146,161,149,168,149,169,149,163,149,165,149,164,149,153,150,156,150,155,150,204,150,210,150,0,151,124,151,133,151,246,151,23,152,24,152,175,152,177,152,3,153,5,153,12,153,9,153,193,153,175,154,176,154,230,154,65,155,66,155,244,156,246,156,243,156,188,158,59,159,74,159,4,81,0,81,251,80,245,80,249,80,2,81,8,81,9,81,5,81,220,81,135,82,136,82,137,82,141,82,138,82,240,82,178,83,46,86,59,86,57,86,50,86,63,86,52,86,41,86,83,86,78,86,87,86,116,86,54,86,47,86,48,86,128,88,159,88,158,88,179,88,156,88,174,88,169,88,166,88,109,89,9,91,251,90,11,91,245,90,12,91,8,91,238,91,236,91,233,91,235,91,100,92,101,92,157,93,148,93,98,94,95,94,97,94,226,94,218,94,223,94,221,94,227,94,224,94,72,95,113,95,183,95,181,95,118,97,103,97,110,97,93,97,85,97,130,97,124,97,112,97,107,97,126,97,167,97,144,97,171,97,142,97,172,97,154,97,164,97,148,97,174,97,46,98,105,100,111,100,121,100,158,100,178,100,136,100,144,100,176,100,165,100,147,100,149,100,169,100,146,100,174,100,173,100,171,100,154,100,172,100,153,100,162,100,179,100,117,101,119,101,120,101,174,102,171,102,180,102,177,102,35,106,31,106,232,105,1,106,30,106,25,106,253,105,33,106,19,106,10,106,243,105,2,106,5,106,237,105,17,106,80,107,78,107,164,107,197,107,198,107,63,111,124,111,132,111,81,111,102,111,84,111,134,111,109,111,91,111,120,111,110,111,142,111,122,111,112,111,100,111,151,111,88,111,213,110,111,111,96,111,95,111,159,113,172,113,177,113,168,113,86,114,155,114,78,115,87,115,105,116,139,116,131,116,126,116,128,116,127,117,32,118,41,118,31,118,36,118,38,118,33,118,34,118,154,118,186,118,228,118,142,119,135,119,140,119,145,119,139,119,203,120,197,120,186,120,202,120,190,120,213,120,188,120,208,120,63,122,60,122,64,122,61,122,55,122,59,122,175,122,174,122,173,123,177,123,196,123,180,123,198,123,199,123,193,123,160,123,204,123,202,124,224,125,244,125,239,125,251,125,216,125,236,125,221,125,232,125,227,125,218,125,222,125,233,125,158,125,217,125,242,125,249,125,117,127,119,127,175,127,233,127,38,128,155,129,156,129,157,129,160,129,154,129,152,129,23,133,61,133,26,133,238,132,44,133,45,133,19,133,17,133,35,133,33,133,20,133,236,132,37,133,255,132,6,133,130,135,116,135,118,135,96,135,102,135,120,135,104,135,89,135,87,135,76,135,83,135,91,136,93,136,16,137,7,137,18,137,19,137,21,137,10,137,188,138,210,138,199,138,196,138,149,138,203,138,248,138,178,138,201,138,194,138,191,138,176,138,214,138,205,138,182,138,185,138,219,138,76,140,78,140,108,140,224,140,222,140,230,140,228,140,236,140,237,140,226,140,227,140,220,140,234,140,225,140,109,141,159,141,163,141,43,142,16,142,29,142,34,142,15,142,41,142,31,142,33,142,30,142,186,142,29,143,27,143,31,143,41,143,38,143,42,143,28,143,30,143,37,143,105,144,110,144,104,144,109,144,119,144,48,145,45,145,39,145,49,145,135,145,137,145,139,145,131,145,197,146,187,146,183,146,234,146,172,146,228,146,193,146,179,146,188,146,210,146,199,146,240,146,178,146,173,149,177,149,4,151,6,151,7,151,9,151,96,151,141,151,139,151,143,151,33,152,43,152,28,152,179,152,10,153,19,153,18,153,24,153,221,153,208,153,223,153,219,153,209,153,213,153,210,153,217,153,183,154,238,154,239,154,39,155,69,155,68,155,119,155,111,155,6,157,9,157,3,157,169,158,190,158,206,158,168,88,82,159,18,81,24,81,20,81,16,81,21,81,128,81,170,81,221,81,145,82,147,82,243,82,89,86,107,86,121,86,105,86,100,86,120,86,106,86,104,86,101,86,113,86,111,86,108,86,98,86,118,86,193,88,190,88,199,88,197,88,110,89,29,91,52,91,120,91,240,91,14,92,74,95,178,97,145,97,169,97,138,97,205,97,182,97,190,97,202,97,200,97,48,98,197,100,193,100,203,100,187,100,188,100,218,100,196,100,199,100,194,100,205,100,191,100,210,100,212,100,190,100,116,101,198,102,201,102,185,102,196,102,199,102,184,102,61,106,56,106,58,106,89,106,107,106,88,106,57,106,68,106,98,106,97,106,75,106,71,106,53,106,95,106,72,106,89,107,119,107,5,108,194,111,177,111,161,111,195,111,164,111,193,111,167,111,179,111,192,111,185,111,182,111,166,111,160,111,180,111,190,113,201,113,208,113,210,113,200,113,213,113,185,113,206,113,217,113,220,113,195,113,196,113,104,115,156,116,163,116,152,116,159,116,158,116,226,116,12,117,13,117,52,118,56,118,58,118,231,118,229,118,160,119,158,119,159,119,165,119,232,120,218,120,236,120,231,120,166,121,77,122,78,122,70,122,76,122,75,122,186,122,217,123,17,124,201,123,228,123,219,123,225,123,233,123,230,123,213,124,214,124,10,126,17,126,8,126,27,126,35,126,30,126,29,126,9,126,16,126,121,127,178,127,240,127,241,127,238,127,40,128,179,129,169,129,168,129,251,129,8,130,88,130,89,130,74,133,89,133,72,133,104,133,105,133,67,133,73,133,109,133,106,133,94,133,131,135,159,135,158,135,162,135,141,135,97,136,42,137,50,137,37,137,43,137,33,137,170,137,166,137,230,138,250,138,235,138,241,138,0,139,220,138,231,138,238,138,254,138,1,139,2,139,247,138,237,138,243,138,246,138,252,138,107,140,109,140,147,140,244,140,68,142,49,142,52,142,66,142,57,142,53,142,59,143,47,143,56,143,51,143,168,143,166,143,117,144,116,144,120,144,114,144,124,144,122,144,52,145,146,145,32,147,54,147,248,146,51,147,47,147,34,147,252,146,43,147,4,147,26,147,16,147,38,147,33,147,21,147,46,147,25,147,187,149,167,150,168,150,170,150,213,150,14,151,17,151,22,151,13,151,19,151,15,151,91,151,92,151,102,151,152,151,48,152,56,152,59,152,55,152,45,152,57,152,36,152,16,153,40,153,30,153,27,153,33,153,26,153,237,153,226,153,241,153,184,154,188,154,251,154,237,154,40,155,145,155,21,157,35,157,38,157,40,157,18,157,27,157,216,158,212,158,141,159,156,159,42,81,31,81,33,81,50,81,245,82,142,86,128,86,144,86,133,86,135,86,143,86,213,88,211,88,209,88,206,88,48,91,42,91,36,91,122,91,55,92,104,92,188,93,186,93,189,93,184,93,107,94,76,95,189,95,201,97,194,97,199,97,230,97,203,97,50,98,52,98,206,100,202,100,216,100,224,100,240,100,230,100,236,100,241,100,226,100,237,100,130,101,131,101,217,102,214,102,128,106,148,106,132,106,162,106,156,106,219,106,163,106,126,106,151,106,144,106,160,106,92,107,174,107,218,107,8,108,216,111,241,111,223,111,224,111,219,111,228,111,235,111,239,111,128,111,236,111,225,111,233,111,213,111,238,111,240,111,231,113,223,113,238,113,230,113,229,113,237,113,236,113,244,113,224,113,53,114,70,114,112,115,114,115,169,116,176,116,166,116,168,116,70,118,66,118,76,118,234,118,179,119,170,119,176,119,172,119,167,119,173,119,239,119,247,120,250,120,244,120,239,120,1,121,167,121,170,121,87,122,191,122,7,124,13,124,254,123,247,123,12,124,224,123,224,124,220,124,222,124,226,124,223,124,217,124,221,124,46,126,62,126,70,126,55,126,50,126,67,126,43,126,61,126,49,126,69,126,65,126,52,126,57,126,72,126,53,126,63,126,47,126,68,127,243,127,252,127,113,128,114,128,112,128,111,128,115,128,198,129,195,129,186,129,194,129,192,129,191,129,189,129,201,129,190,129,232,129,9,130,113,130,170,133,132,133,126,133,156,133,145,133,148,133,175,133,155,133,135,133,168,133,138,133,103,134,192,135,209,135,179,135,210,135,198,135,171,135,187,135,186,135,200,135,203,135,59,137,54,137,68,137,56,137,61,137,172,137,14,139,23,139,25,139,27,139,10,139,32,139,29,139,4,139,16,139,65,140,63,140,115,140,250,140,253,140,252,140,248,140,251,140,168,141,73,142,75,142,72,142,74,142,68,143,62,143,66,143,69,143,63,143,127,144,125,144,132,144,129,144,130,144,128,144,57,145,163,145,158,145,156,145,77,147,130,147,40,147,117,147,74,147,101,147,75,147,24,147,126,147,108,147,91,147,112,147,90,147,84,147,202,149,203,149,204,149,200,149,198,149,177,150,184,150,214,150,28,151,30,151,160,151,211,151,70,152,182,152,53,153,1,154,255,153,174,155,171,155,170,155,173,155,59,157,63,157,139,158,207,158,222,158,220,158,221,158,219,158,62,159,75,159,226,83,149,86,174,86,217,88,216,88,56,91,93,95,227,97,51,98,244,100,242,100,254,100,6,101,250,100,251,100,247,100,183,101,220,102,38,103,179,106,172,106,195,106,187,106,184,106,194,106,174,106,175,106,95,107,120,107,175,107,9,112,11,112,254,111,6,112,250,111,17,112,15,112,251,113,252,113,254,113,248,113,119,115,117,115,167,116,191,116,21,117,86,118,88,118,82,118,189,119,191,119,187,119,188,119,14,121,174,121,97,122,98,122,96,122,196,122,197,122,43,124,39,124,42,124,30,124,35,124,33,124,231,124,84,126,85,126,94,126,90,126,97,126,82,126,89,126,72,127,249,127,251,127,119,128,118,128,205,129,207,129,10,130,207,133,169,133,205,133,208,133,201,133,176,133,186,133,185,133,166,133,239,135,236,135,242,135,224,135,134,137,178,137,244,137,40,139,57,139,44,139,43,139,80,140,5,141,89,142,99,142,102,142,100,142,95,142,85,142,192,142,73,143,77,143,135,144,131,144,136,144,171,145,172,145,208,145,148,147,138,147,150,147,162,147,179,147,174,147,172,147,176,147,152,147,154,147,151,147,212,149,214,149,208,149,213,149,226,150,220,150,217,150,219,150,222,150,36,151,163,151,166,151,173,151,249,151,77,152,79,152,76,152,78,152,83,152,186,152,62,153,63,153,61,153,46,153,165,153,14,154,193,154,3,155,6,155,79,155,78,155,77,155,202,155,201,155,253,155,200,155,192,155,81,157,93,157,96,157,224,158,21,159,44,159,51,81,165,86,222,88,223,88,226,88,245,91,144,159,236,94,242,97,247,97,246,97,245,97,0,101,15,101,224,102,221,102,229,106,221,106,218,106,211,106,27,112,31,112,40,112,26,112,29,112,21,112,24,112,6,114,13,114,88,114,162,114,120,115,122,115,189,116,202,116,227,116,135,117,134,117,95,118,97,118,199,119,25,121,177,121,107,122,105,122,62,124,63,124,56,124,61,124,55,124,64,124,107,126,109,126,121,126,105,126,106,126,133,127,115,126,182,127,185,127,184,127,216,129,233,133,221,133,234,133,213,133,228,133,229,133,247,133,251,135,5,136,13,136,249,135,254,135,96,137,95,137,86,137,94,137,65,139,92,139,88,139,73,139,90,139,78,139,79,139,70,139,89,139,8,141,10,141,124,142,114,142,135,142,118,142,108,142,122,142,116,142,84,143,78,143,173,143,138,144,139,144,177,145,174,145,225,147,209,147,223,147,195,147,200,147,220,147,221,147,214,147,226,147,205,147,216,147,228,147,215,147,232,147,220,149,180,150,227,150,42,151,39,151,97,151,220,151,251,151,94,152,88,152,91,152,188,152,69,153,73,153,22,154,25,154,13,155,232,155,231,155,214,155,219,155,137,157,97,157,114,157,106,157,108,157,146,158,151,158,147,158,180,158,248,82,168,86,183,86,182,86,180,86,188,86,228,88,64,91,67,91,125,91,246,91,201,93,248,97,250,97,24,101,20,101,25,101,230,102,39,103,236,106,62,112,48,112,50,112,16,114,123,115,207,116,98,118,101,118,38,121,42,121,44,121,43,121,199,122,246,122,76,124,67,124,77,124,239,124,240,124,174,143,125,126,124,126,130,126,76,127,0,128,218,129,102,130,251,133,249,133,17,134,250,133,6,134,11,134,7,134,10,134,20,136,21,136,100,137,186,137,248,137,112,139,108,139,102,139,111,139,95,139,107,139,15,141,13,141,137,142,129,142,133,142,130,142,180,145,203,145,24,148,3,148,253,147,225,149,48,151,196,152,82,153,81,153,168,153,43,154,48,154,55,154,53,154,19,156,13,156,121,158,181,158,232,158,47,159,95,159,99,159,97,159,55,81,56,81,193,86,192,86,194,86,20,89,108,92,205,93,252,97,254,97,29,101,28,101,149,101,233,102,251,106,4,107,250,106,178,107,76,112,27,114,167,114,214,116,212,116,105,118,211,119,80,124,143,126,140,126,188,127,23,134,45,134,26,134,35,136,34,136,33,136,31,136,106,137,108,137,189,137,116,139,119,139,125,139,19,141,138,142,141,142,139,142,95,143,175,143,186,145,46,148,51,148,53,148,58,148,56,148,50,148,43,148,226,149,56,151,57,151,50,151,255,151,103,152,101,152,87,153,69,154,67,154,64,154,62,154,207,154,84,155,81,155,45,156,37,156,175,157,180,157,194,157,184,157,157,158,239,158,25,159,92,159,102,159,103,159,60,81,59,81,200,86,202,86,201,86,127,91,212,93,210,93,78,95,255,97,36,101,10,107,97,107,81,112,88,112,128,115,228,116,138,117,110,118,108,118,179,121,96,124,95,124,126,128,125,128,223,129,114,137,111,137,252,137,128,139,22,141,23,141,145,142,147,142,97,143,72,145,68,148,81,148,82,148,61,151,62,151,195,151,193,151,107,152,85,153,85,154,77,154,210,154,26,155,73,156,49,156,62,156,59,156,211,157,215,157,52,159,108,159,106,159,148,159,204,86,214,93,0,98,35,101,43,101,42,101,236,102,16,107,218,116,202,122,100,124,99,124,101,124,147,126,150,126,148,126,226,129,56,134,63,134,49,136,138,139,144,144,143,144,99,148,96,148,100,148,104,151,111,152,92,153,90,154,91,154,87,154,211,154,212,154,209,154,84,156,87,156,86,156,229,157,159,158,244,158,209,86,233,88,44,101,94,112,113,118,114,118,215,119,80,127,136,127,54,136,57,136,98,136,147,139,146,139,150,139,119,130,27,141,192,145,106,148,66,151,72,151,68,151,198,151,112,152,95,154,34,155,88,155,95,156,249,157,250,157,124,158,125,158,7,159,119,159,114,159,243,94,22,107,99,112,108,124,110,124,59,136,192,137,161,142,193,145,114,148,112,148,113,152,94,153,214,154,35,155,204,158,100,112,218,119,154,139,119,148,201,151,98,154,101,154,156,126,156,139,170,142,197,145,125,148,126,148,124,148,119,156,120,156,247,158,84,140,127,148,26,158,40,114,106,154,49,155,27,158,30,158,114,124,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,54,78,63,78,133,78,160,78,130,81,150,81,171,81,249,82,56,83,105,83,182,83,10,89,128,91,219,93,122,94,127,94,244,94,80,95,97,95,52,101,224,101,146,117,118,118,181,143,182,150,168,0,198,2,253,48,254,48,157,48,158,48,0,0,0,0,5,48,6,48,7,48,252,48,59,255,61,255,61,39,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,231,33,184,33,185,33,207,49,204,0,90,78,138,0,2,82,145,68,176,159,136,81,177,159,7,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,255,228,255,7,255,2,255,49,50,22,33,33,33,155,48,156,48,128,46,132,46,134,46,135,46,136,46,138,46,140,46,141,46,149,46,156,46,157,46,165,46,167,46,170,46,172,46,174,46,182,46,188,46,190,46,198,46,202,46,204,46,205,46,207,46,214,46,215,46,222,46,227,46,0,0,0,0,0,0,131,2,80,2,91,2,84,2,117,2,83,1,248,0,75,1,138,2,106,2,66,78,92,78,245,81,26,83,130,83,7,78,12,78,71,78,141,78,215,86,12,250,110,92,115,95,15,78,135,81,14,78,46,78,147,78,194,78,201,78,200,78,152,81,252,82,108,83,185,83,32,87,3,89,44,89,16,92,255,93,225,101,179,107,204,107,20,108,63,114,49,78,60,78,232,78,220,78,233,78,225,78,221,78,218,78,12,82,28,83,76,83,34,87,35,87,23,89,47,89,129,91,132,91,18,92,59,92,116,92,115,92,4,94,128,94,130,94,201,95,9,98,80,98,21,108,54,108,67,108,63,108,59,108,174,114,176,114,138,115,184,121,138,128,30,150,14,79,24,79,44,79,245,78,20,79,241,78,0,79,247,78,8,79,29,79,2,79,5,79,34,79,19,79,4,79,244,78,18,79,177,81,19,82,9,82,16,82,166,82,34,83,31,83,77,83,138,83,7,84,225,86,223,86,46,87,42,87,52,87,60,89,128,89,124,89,133,89,123,89,126,89,119,89,127,89,86,91,21,92,37,92,124,92,122,92,123,92,126,92,223,93,117,94,132,94,2,95,26,95,116,95,213,95,212,95,207,95,92,98,94,98,100,98,97,98,102,98,98,98,89,98,96,98,90,98,101,98,239,101,238,101,62,103,57,103,56,103,59,103,58,103,63,103,60,103,51,103,24,108,70,108,82,108,92,108,79,108,74,108,84,108,75,108,76,108,113,112,94,114,180,114,181,114,142,115,42,117,127,118,117,122,81,127,120,130,124,130,128,130,125,130,127,130,77,134,126,137,153,144,151,144,152,144,155,144,148,144,34,150,36,150,32,150,35,150,86,79,59,79,98,79,73,79,83,79,100,79,62,79,103,79,82,79,95,79,65,79,88,79,45,79,51,79,63,79,97,79,143,81,185,81,28,82,30,82,33,82,173,82,174,82,9,83,99,83,114,83,142,83,143,83,48,84,55,84,42,84,84,84,69,84,25,84,28,84,37,84,24,84,61,84,79,84,65,84,40,84,36,84,71,84,238,86,231,86,229,86,65,87,69,87,76,87,73,87,75,87,82,87,6,89,64,89,166,89,152,89,160,89,151,89,142,89,162,89,144,89,143,89,167,89,161,89,142,91,146,91,40,92,42,92,141,92,143,92,136,92,139,92,137,92,146,92,138,92,134,92,147,92,149,92,224,93,10,94,14,94,139,94,137,94,140,94,136,94,141,94,5,95,29,95,120,95,118,95,210,95,209,95,208,95,237,95,232,95,238,95,243,95,225,95,228,95,227,95,250,95,239,95,247,95,251,95,0,96,244,95,58,98,131,98,140,98,142,98,143,98,148,98,135,98,113,98,123,98,122,98,112,98,129,98,136,98,119,98,125,98,114,98,116,98,55,101,240,101,244,101,243,101,242,101,245,101,69,103,71,103,89,103,85,103,76,103,72,103,93,103,77,103,90,103,75,103,208,107,25,108,26,108,120,108,103,108,107,108,132,108,139,108,143,108,113,108,111,108,105,108,154,108,109,108,135,108,149,108,156,108,102,108,115,108,101,108,123,108,142,108,116,112,122,112,99,114,191,114,189,114,195,114,198,114,193,114,186,114,197,114,149,115,151,115,147,115,148,115,146,115,58,117,57,117,148,117,149,117,129,118,61,121,52,128,149,128,153,128,144,128,146,128,156,128,144,130,143,130,133,130,142,130,145,130,147,130,138,130,131,130,132,130,120,140,201,143,191,143,159,144,161,144,165,144,158,144,167,144,160,144,48,150,40,150,47,150,45,150,51,78,152,79,124,79,133,79,125,79,128,79,135,79,118,79,116,79,137,79,132,79,119,79,76,79,151,79,106,79,154,79,121,79,129,79,120,79,144,79,156,79,148,79,158,79,146,79,130,79,149,79,107,79,110,79,158,81,188,81,190,81,53,82,50,82,51,82,70,82,49,82,188,82,10,83,11,83,60,83,146,83,148,83,135,84,127,84,129,84,145,84,130,84,136,84,107,84,122,84,126,84,101,84,108,84,116,84,102,84,141,84,111,84,97,84,96,84,152,84,99,84,103,84,100,84,247,86,249,86,111,87,114,87,109,87,107,87,113,87,112,87,118,87,128,87,117,87,123,87,115,87,116,87,98,87,104,87,125,87,12,89,69,89,181,89,186,89,207,89,206,89,178,89,204,89,193,89,182,89,188,89,195,89,214,89,177,89,189,89,192,89,200,89,180,89,199,89,98,91,101,91,147,91,149,91,68,92,71,92,174,92,164,92,160,92,181,92,175,92,168,92,172,92,159,92,163,92,173,92,162,92,170,92,167,92,157,92,165,92,182,92,176,92,166,92,23,94,20,94,25,94,40,95,34,95,35,95,36,95,84,95,130,95,126,95,125,95,222,95,229,95,45,96,38,96,25,96,50,96,11,96,52,96,10,96,23,96,51,96,26,96,30,96,44,96,34,96,13,96,16,96,46,96,19,96,17,96,12,96,9,96,28,96,20,98,61,98,173,98,180,98,209,98,190,98,170,98,182,98,202,98,174,98,179,98,175,98,187,98,169,98,176,98,184,98,61,101,168,101,187,101,9,102,252,101,4,102,18,102,8,102,251,101,3,102,11,102,13,102,5,102,253,101,17,102,16,102,246,102,10,103,133,103,108,103,142,103,146,103,118,103,123,103,152,103,134,103,132,103,116,103,141,103,140,103,122,103,159,103,145,103,153,103,131,103,125,103,129,103,120,103,121,103,148,103,37,107,128,107,126,107,222,107,29,108,147,108,236,108,235,108,238,108,217,108,182,108,212,108,173,108,231,108,183,108,208,108,194,108,186,108,195,108,198,108,237,108,242,108,210,108,221,108,180,108,138,108,157,108,128,108,222,108,192,108,48,109,205,108,199,108,176,108,249,108,207,108,233,108,209,108,148,112,152,112,133,112,147,112,134,112,132,112,145,112,150,112,130,112,154,112,131,112,106,114,214,114,203,114,216,114,201,114,220,114,210,114,212,114,218,114,204,114,209,114,164,115,161,115,173,115,166,115,162,115,160,115,172,115,157,115,221,116,232,116,63,117,64,117,62,117,140,117,152,117,175,118,243,118,241,118,240,118,245,118,248,119,252,119,249,119,251,119,250,119,247,119,66,121,63,121,197,121,120,122,123,122,251,122,117,124,253,124,53,128,143,128,174,128,163,128,184,128,181,128,173,128,32,130,160,130,192,130,171,130,154,130,152,130,155,130,181,130,167,130,174,130,188,130,158,130,186,130,180,130,168,130,161,130,169,130,194,130,164,130,195,130,182,130,162,130,112,134,111,134,109,134,110,134,86,140,210,143,203,143,211,143,205,143,214,143,213,143,215,143,178,144,180,144,175,144,179,144,176,144,57,150,61,150,60,150,58,150,67,150,205,79,197,79,211,79,178,79,201,79,203,79,193,79,212,79,220,79,217,79,187,79,179,79,219,79,199,79,214,79,186,79,192,79,185,79,236,79,68,82,73,82,192,82,194,82,61,83,124,83,151,83,150,83,153,83,152,83,186,84,161,84,173,84,165,84,207,84,195,84,13,131,183,84,174,84,214,84,182,84,197,84,198,84,160,84,112,84,188,84,162,84,190,84,114,84,222,84,176,84,181,87,158,87,159,87,164,87,140,87,151,87,157,87,155,87,148,87,152,87,143,87,153,87,165,87,154,87,149,87,244,88,13,89,83,89,225,89,222,89,238,89,0,90,241,89,221,89,250,89,253,89,252,89,246,89,228,89,242,89,247,89,219,89,233,89,243,89,245,89,224,89,254,89,244,89,237,89,168,91,76,92,208,92,216,92,204,92,215,92,203,92,219,92,222,92,218,92,201,92,199,92,202,92,214,92,211,92,212,92,207,92,200,92,198,92,206,92,223,92,248,92,249,93,33,94,34,94,35,94,32,94,36,94,176,94,164,94,162,94,155,94,163,94,165,94,7,95,46,95,86,95,134,95,55,96,57,96,84,96,114,96,94,96,69,96,83,96,71,96,73,96,91,96,76,96,64,96,66,96,95,96,36,96,68,96,88,96,102,96,110,96,66,98,67,98,207,98,13,99,11,99,245,98,14,99,3,99,235,98,249,98,15,99,12,99,248,98,246,98,0,99,19,99,20,99,250,98,21,99,251,98,240,98,65,101,67,101,170,101,191,101,54,102,33,102,50,102,53,102,28,102,38,102,34,102,51,102,43,102,58,102,29,102,52,102,57,102,46,102,15,103,16,103,193,103,242,103,200,103,186,103,220,103,187,103,248,103,216,103,192,103,183,103,197,103,235,103,228,103,223,103,181,103,205,103,179,103,247,103,246,103,238,103,227,103,194,103,185,103,206,103,231,103,240,103,178,103,252,103,198,103,237,103,204,103,174,103,230,103,219,103,250,103,201,103,202,103,195,103,234,103,203,103,40,107,130,107,132,107,182,107,214,107,216,107,224,107,32,108,33,108,40,109,52,109,45,109,31,109,60,109,63,109,18,109,10,109,218,108,51,109,4,109,25,109,58,109,26,109,17,109,0,109,29,109,66,109,1,109,24,109,55,109,3,109,15,109,64,109,7,109,32,109,44,109,8,109,34,109,9,109,16,109,183,112,159,112,190,112,177,112,176,112,161,112,180,112,181,112,169,112,65,114,73,114,74,114,108,114,112,114,115,114,110,114,202,114,228,114,232,114,235,114,223,114,234,114,230,114,227,114,133,115,204,115,194,115,200,115,197,115,185,115,182,115,181,115,180,115,235,115,191,115,199,115,190,115,195,115,198,115,184,115,203,115,236,116,238,116,46,117,71,117,72,117,167,117,170,117,121,118,196,118,8,119,3,119,4,119,5,119,10,119,247,118,251,118,250,118,231,119,232,119,6,120,17,120,18,120,5,120,16,120,15,120,14,120,9,120,3,120,19,120,74,121,76,121,75,121,69,121,68,121,213,121,205,121,207,121,214,121,206,121,128,122,126,122,209,122,0,123,1,123,122,124,120,124,121,124,127,124,128,124,129,124,3,125,8,125,1,125,88,127,145,127,141,127,190,127,7,128,14,128,15,128,20,128,55,128,216,128,199,128,224,128,209,128,200,128,194,128,208,128,197,128,227,128,217,128,220,128,202,128,213,128,201,128,207,128,215,128,230,128,205,128,255,129,33,130,148,130,217,130,254,130,249,130,7,131,232,130,0,131,213,130,58,131,235,130,214,130,244,130,236,130,225,130,242,130,245,130,12,131,251,130,246,130,240,130,234,130,228,130,224,130,250,130,243,130,237,130,119,134,116,134,124,134,115,134,65,136,78,136,103,136,106,136,105,136,211,137,4,138,7,138,114,141,227,143,225,143,238,143,224,143,241,144,189,144,191,144,213,144,197,144,190,144,199,144,203,144,200,144,212,145,211,145,84,150,79,150,81,150,83,150,74,150,78,150,30,80,5,80,7,80,19,80,34,80,48,80,27,80,245,79,244,79,51,80,55,80,44,80,246,79,247,79,23,80,28,80,32,80,39,80,53,80,47,80,49,80,14,80,90,81,148,81,147,81,202,81,196,81,197,81,200,81,206,81,97,82,90,82,82,82,94,82,95,82,85,82,98,82,205,82,14,83,158,83,38,85,226,84,23,85,18,85,231,84,243,84,228,84,26,85,255,84,4,85,8,85,235,84,17,85,5,85,241,84,10,85,251,84,247,84,248,84,224,84,14,85,3,85,11,85,1,87,2,87,204,87,50,88,213,87,210,87,186,87,198,87,189,87,188,87,184,87,182,87,191,87,199,87,208,87,185,87,193,87,14,89,74,89,25,90,22,90,45,90,46,90,21,90,15,90,23,90,10,90,30,90,51,90,108,91,167,91,173,91,172,91,3,92,86,92,84,92,236,92,255,92,238,92,241,92,247,92,0,93,249,92,41,94,40,94,168,94,174,94,170,94,172,94,51,95,48,95,103,95,93,96,90,96,103,96,65,96,162,96,136,96,128,96,146,96,129,96,157,96,131,96,149,96,155,96,151,96,135,96,156,96,142,96,25,98,70,98,242,98,16,99,86,99,44,99,68,99,69,99,54,99,67,99,228,99,57,99,75,99,74,99,60,99,41,99,65,99,52,99,88,99,84,99,89,99,45,99,71,99,51,99,90,99,81,99,56,99,87,99,64,99,72,99,74,101,70,101,198,101,195,101,196,101,194,101,74,102,95,102,71,102,81,102,18,103,19,103,31,104,26,104,73,104,50,104,51,104,59,104,75,104,79,104,22,104,49,104,28,104,53,104,43,104,45,104,47,104,78,104,68,104,52,104,29,104,18,104,20,104,38,104,40,104,46,104,77,104,58,104,37,104,32,104,44,107,47,107,45,107,49,107,52,107,109,107,130,128,136,107,230,107,228,107,232,107,227,107,226,107,231,107,37,108,122,109,99,109,100,109,118,109,13,109,97,109,146,109,88,109,98,109,109,109,111,109,145,109,141,109,239,109,127,109,134,109,94,109,103,109,96,109,151,109,112,109,124,109,95,109,130,109,152,109,47,109,104,109,139,109,126,109,128,109,132,109,22,109,131,109,123,109,125,109,117,109,144,109,220,112,211,112,209,112,221,112,203,112,57,127,226,112,215,112,210,112,222,112,224,112,212,112,205,112,197,112,198,112,199,112,218,112,206,112,225,112,66,114,120,114,119,114,118,114,0,115,250,114,244,114,254,114,246,114,243,114,251,114,1,115,211,115,217,115,229,115,214,115,188,115,231,115,227,115,233,115,220,115,210,115,219,115,212,115,221,115,218,115,215,115,216,115,232,115,222,116,223,116,244,116,245,116,33,117,91,117,95,117,176,117,193,117,187,117,196,117,192,117,191,117,182,117,186,117,138,118,201,118,29,119,27,119,16,119,19,119,18,119,35,119,17,119,21,119,25,119,26,119,34,119,39,119,35,120,44,120,34,120,53,120,47,120,40,120,46,120,43,120,33,120,41,120,51,120,42,120,49,120,84,121,91,121,79,121,92,121,83,121,82,121,81,121,235,121,236,121,224,121,238,121,237,121,234,121,220,121,222,121,221,121,134,122,137,122,133,122,139,122,140,122,138,122,135,122,216,122,16,123,4,123,19,123,5,123,15,123,8,123,10,123,14,123,9,123,18,123,132,124,145,124,138,124,140,124,136,124,141,124,133,124,30,125,29,125,17,125,14,125,24,125,22,125,19,125,31,125,18,125,15,125,12,125,92,127,97,127,94,127,96,127,93,127,91,127,150,127,146,127,195,127,194,127,192,127,22,128,62,128,57,128,250,128,242,128,249,128,245,128,1,129,251,128,0,129,1,130,47,130,37,130,51,131,45,131,68,131,25,131,81,131,37,131,86,131,63,131,65,131,38,131,28,131,34,131,66,131,78,131,27,131,42,131,8,131,60,131,77,131,22,131,36,131,32,131,55,131,47,131,41,131,71,131,69,131,76,131,83,131,30,131,44,131,75,131,39,131,72,131,83,134,82,134,162,134,168,134,150,134,141,134,145,134,158,134,135,134,151,134,134,134,139,134,154,134,133,134,165,134,153,134,161,134,167,134,149,134,152,134,142,134,157,134,144,134,148,134,67,136,68,136,109,136,117,136,118,136,114,136,128,136,113,136,127,136,111,136,131,136,126,136,116,136,124,136,18,138,71,140,87,140,123,140,164,140,163,140,118,141,120,141,181,141,183,141,182,141,209,142,211,142,254,143,245,143,2,144,255,143,251,143,4,144,252,143,246,143,214,144,224,144,217,144,218,144,227,144,223,144,229,144,216,144,219,144,215,144,220,144,228,144,80,145,78,145,79,145,213,145,226,145,218,145,92,150,95,150,188,150,227,152,223,154,47,155,127,78,112,80,106,80,97,80,94,80,96,80,83,80,75,80,93,80,114,80,72,80,77,80,65,80,91,80,74,80,98,80,21,80,69,80,95,80,105,80,107,80,99,80,100,80,70,80,64,80,110,80,115,80,87,80,81,80,208,81,107,82,109,82,108,82,110,82,214,82,211,82,45,83,156,83,117,85,118,85,60,85,77,85,80,85,52,85,42,85,81,85,98,85,54,85,53,85,48,85,82,85,69,85,12,85,50,85,101,85,78,85,57,85,72,85,45,85,59,85,64,85,75,85,10,87,7,87,251,87,20,88,226,87,246,87,220,87,244,87,0,88,237,87,253,87,8,88,248,87,11,88,243,87,207,87,7,88,238,87,227,87,242,87,229,87,236,87,225,87,14,88,252,87,16,88,231,87,1,88,12,88,241,87,233,87,240,87,13,88,4,88,92,89,96,90,88,90,85,90,103,90,94,90,56,90,53,90,109,90,80,90,95,90,101,90,108,90,83,90,100,90,87,90,67,90,93,90,82,90,68,90,91,90,72,90,142,90,62,90,77,90,57,90,76,90,112,90,105,90,71,90,81,90,86,90,66,90,92,90,114,91,110,91,193,91,192,91,89,92,30,93,11,93,29,93,26,93,32,93,12,93,40,93,13,93,38,93,37,93,15,93,48,93,18,93,35,93,31,93,46,93,62,94,52,94,177,94,180,94,185,94,178,94,179,94,54,95,56,95,155,95,150,95,159,95,138,96,144,96,134,96,190,96,176,96,186,96,211,96,212,96,207,96,228,96,217,96,221,96,200,96,177,96,219,96,183,96,202,96,191,96,195,96,205,96,192,96,50,99,101,99,138,99,130,99,125,99,189,99,158,99,173,99,157,99,151,99,171,99,142,99,111,99,135,99,144,99,110,99,175,99,117,99,156,99,109,99,174,99,124,99,164,99,59,99,159,99,120,99,133,99,129,99,145,99,141,99,112,99,83,101,205,101,101,102,97,102,91,102,89,102,92,102,98,102,24,103,121,104,135,104,144,104,156,104,109,104,110,104,174,104,171,104,86,105,111,104,163,104,172,104,169,104,117,104,116,104,178,104,143,104,119,104,146,104,124,104,107,104,114,104,170,104,128,104,113,104,126,104,155,104,150,104,139,104,160,104,137,104,164,104,120,104,123,104,145,104,140,104,138,104,125,104,54,107,51,107,55,107,56,107,145,107,143,107,141,107,142,107,140,107,42,108,192,109,171,109,180,109,179,109,116,110,172,109,233,109,226,109,183,109,246,109,212,109,0,110,200,109,224,109,223,109,214,109,190,109,229,109,220,109,221,109,219,109,244,109,202,109,189,109,237,109,240,109,186,109,213,109,194,109,207,109,201,109,208,109,242,109,211,109,253,109,215,109,205,109,227,109,187,109,250,112,13,113,247,112,23,113,244,112,12,113,240,112,4,113,243,112,16,113,252,112,255,112,6,113,19,113,0,113,248,112,246,112,11,113,2,113,14,113,126,114,123,114,124,114,127,114,29,115,23,115,7,115,17,115,24,115,10,115,8,115,255,114,15,115,30,115,136,115,246,115,248,115,245,115,4,116,1,116,253,115,7,116,0,116,250,115,252,115,255,115,12,116,11,116,244,115,8,116,100,117,99,117,206,117,210,117,207,117,203,117,204,117,209,117,208,117,143,118,137,118,211,118,57,119,47,119,45,119,49,119,50,119,52,119,51,119,61,119,37,119,59,119,53,119,72,120,82,120,73,120,77,120,74,120,76,120,38,120,69,120,80,120,100,121,103,121,105,121,106,121,99,121,107,121,97,121,187,121,250,121,248,121,246,121,247,121,143,122,148,122,144,122,53,123,71,123,52,123,37,123,48,123,34,123,36,123,51,123,24,123,42,123,29,123,49,123,43,123,45,123,47,123,50,123,56,123,26,123,35,123,148,124,152,124,150,124,163,124,53,125,61,125,56,125,54,125,58,125,69,125,44,125,41,125,65,125,71,125,62,125,63,125,74,125,59,125,40,125,99,127,149,127,156,127,157,127,155,127,202,127,203,127,205,127,208,127,209,127,199,127,207,127,201,127,31,128,30,128,27,128,71,128,67,128,72,128,24,129,37,129,25,129,27,129,45,129,31,129,44,129,30,129,33,129,21,129,39,129,29,129,34,129,17,130,56,130,51,130,58,130,52,130,50,130,116,130,144,131,163,131,168,131,141,131,122,131,115,131,164,131,116,131,143,131,129,131,149,131,153,131,117,131,148,131,169,131,125,131,131,131,140,131,157,131,155,131,170,131,139,131,126,131,165,131,175,131,136,131,151,131,176,131,127,131,166,131,135,131,174,131,118,131,154,131,89,134,86,134,191,134,183,134,194,134,193,134,197,134,186,134,176,134,200,134,185,134,179,134,184,134,204,134,180,134,187,134,188,134,195,134,189,134,190,134,82,136,137,136,149,136,168,136,162,136,170,136,154,136,145,136,161,136,159,136,152,136,167,136,153,136,155,136,151,136,164,136,172,136,140,136,147,136,142,136,130,137,214,137,217,137,213,137,48,138,39,138,44,138,30,138,57,140,59,140,92,140,93,140,125,140,165,140,125,141,123,141,121,141,188,141,194,141,185,141,191,141,193,141,216,142,222,142,221,142,220,142,215,142,224,142,225,142,36,144,11,144,17,144,28,144,12,144,33,144,239,144,234,144,240,144,244,144,242,144,243,144,212,144,235,144,236,144,233,144,86,145,88,145,90,145,83,145,85,145,236,145,244,145,241,145,243,145,248,145,228,145,249,145,234,145,235,145,247,145,232,145,238,145,122,149,134,149,136,149,124,150,109,150,107,150,113,150,111,150,191,150,106,151,4,152,229,152,151,153,155,80,149,80,148,80,158,80,139,80,163,80,131,80,140,80,142,80,157,80,104,80,156,80,146,80,130,80,135,80,95,81,212,81,18,83,17,83,164,83,167,83,145,85,168,85,165,85,173,85,119,85,69,86,162,85,147,85,136,85,143,85,181,85,129,85,163,85,146,85,164,85,125,85,140,85,166,85,127,85,149,85,161,85,142,85,12,87,41,88,55,88,25,88,30,88,39,88,35,88,40,88,245,87,72,88,37,88,28,88,27,88,51,88,63,88,54,88,46,88,57,88,56,88,45,88,44,88,59,88,97,89,175,90,148,90,159,90,122,90,162,90,158,90,120,90,166,90,124,90,165,90,172,90,149,90,174,90,55,90,132,90,138,90,151,90,131,90,139,90,169,90,123,90,125,90,140,90,156,90,143,90,147,90,157,90,234,91,205,91,203,91,212,91,209,91,202,91,206,91,12,92,48,92,55,93,67,93,107,93,65,93,75,93,63,93,53,93,81,93,78,93,85,93,51,93,58,93,82,93,61,93,49,93,89,93,66,93,57,93,73,93,56,93,60,93,50,93,54,93,64,93,69,93,68,94,65,94,88,95,166,95,165,95,171,95,201,96,185,96,204,96,226,96,206,96,196,96,20,97,242,96,10,97,22,97,5,97,245,96,19,97,248,96,252,96,254,96,193,96,3,97,24,97,29,97,16,97,255,96,4,97,11,97,74,98,148,99,177,99,176,99,206,99,229,99,232,99,239,99,195,99,157,100,243,99,202,99,224,99,246,99,213,99,242,99,245,99,97,100,223,99,190,99,221,99,220,99,196,99,216,99,211,99,194,99,199,99,204,99,203,99,200,99,240,99,215,99,217,99,50,101,103,101,106,101,100,101,92,101,104,101,101,101,140,101,157,101,158,101,174,101,208,101,210,101,124,102,108,102,123,102,128,102,113,102,121,102,106,102,114,102,1,103,12,105,211,104,4,105,220,104,42,105,236,104,234,104,241,104,15,105,214,104,247,104,235,104,228,104,246,104,19,105,16,105,243,104,225,104,7,105,204,104,8,105,112,105,180,104,17,105,239,104,198,104,20,105,248,104,208,104,253,104,252,104,232,104,11,105,10,105,23,105,206,104,200,104,221,104,222,104,230,104,244,104,209,104,6,105,212,104,233,104,21,105,37,105,199,104,57,107,59,107,63,107,60,107,148,107,151,107,153,107,149,107,189,107,240,107,242,107,243,107,48,108,252,109,70,110,71,110,31,110,73,110,136,110,60,110,61,110,69,110,98,110,43,110,63,110,65,110,93,110,115,110,28,110,51,110,75,110,64,110,81,110,59,110,3,110,46,110,94,110,104,110,92,110,97,110,49,110,40,110,96,110,113,110,107,110,57,110,34,110,48,110,83,110,101,110,39,110,120,110,100,110,119,110,85,110,121,110,82,110,102,110,53,110,54,110,90,110,32,113,30,113,47,113,251,112,46,113,49,113,35,113,37,113,34,113,50,113,31,113,40,113,58,113,27,113,75,114,90,114,136,114,137,114,134,114,133,114,139,114,18,115,11,115,48,115,34,115,49,115,51,115,39,115,50,115,45,115,38,115,35,115,53,115,12,115,46,116,44,116,48,116,43,116,22,116,26,116,33,116,45,116,49,116,36,116,35,116,29,116,41,116,32,116,50,116,251,116,47,117,111,117,108,117,231,117,218,117,225,117,230,117,221,117,223,117,228,117,215,117,149,118,146,118,218,118,70,119,71,119,68,119,77,119,69,119,74,119,78,119,75,119,76,119,222,119,236,119,96,120,100,120,101,120,92,120,109,120,113,120,106,120,110,120,112,120,105,120,104,120,94,120,98,120,116,121,115,121,114,121,112,121,2,122,10,122,3,122,12,122,4,122,153,122,230,122,228,122,74,123,59,123,68,123,72,123,76,123,78,123,64,123,88,123,69,123,162,124,158,124,168,124,161,124,88,125,111,125,99,125,83,125,86,125,103,125,106,125,79,125,109,125,92,125,107,125,82,125,84,125,105,125,81,125,95,125,78,125,62,127,63,127,101,127,102,127,162,127,160,127,161,127,215,127,81,128,79,128,80,128,254,128,212,128,67,129,74,129,82,129,79,129,71,129,61,129,77,129,58,129,230,129,238,129,247,129,248,129,249,129,4,130,60,130,61,130,63,130,117,130,59,131,207,131,249,131,35,132,192,131,232,131,18,132,231,131,228,131,252,131,246,131,16,132,198,131,200,131,235,131,227,131,191,131,1,132,221,131,229,131,216,131,255,131,225,131,203,131,206,131,214,131,245,131,201,131,9,132,15,132,222,131,17,132,6,132,194,131,243,131,213,131,250,131,199,131,209,131,234,131,19,132,195,131,236,131,238,131,196,131,251,131,215,131,226,131,27,132,219,131,254,131,216,134,226,134,230,134,211,134,227,134,218,134,234,134,221,134,235,134,220,134,236,134,233,134,215,134,232,134,209,134,72,136,86,136,85,136,186,136,215,136,185,136,184,136,192,136,190,136,182,136,188,136,183,136,189,136,178,136,1,137,201,136,149,137,152,137,151,137,221,137,218,137,219,137,78,138,77,138,57,138,89,138,64,138,87,138,88,138,68,138,69,138,82,138,72,138,81,138,74,138,76,138,79,138,95,140,129,140,128,140,186,140,190,140,176,140,185,140,181,140,132,141,128,141,137,141,216,141,211,141,205,141,199,141,214,141,220,141,207,141,213,141,217,141,200,141,215,141,197,141,239,142,247,142,250,142,249,142,230,142,238,142,229,142,245,142,231,142,232,142,246,142,235,142,241,142,236,142,244,142,233,142,45,144,52,144,47,144,6,145,44,145,4,145,255,144,252,144,8,145,249,144,251,144,1,145,0,145,7,145,5,145,3,145,97,145,100,145,95,145,98,145,96,145,1,146,10,146,37,146,3,146,26,146,38,146,15,146,12,146,0,146,18,146,255,145,253,145,6,146,4,146,39,146,2,146,28,146,36,146,25,146,23,146,5,146,22,146,123,149,141,149,140,149,144,149,135,150,126,150,136,150,137,150,131,150,128,150,194,150,200,150,195,150,241,150,240,150,108,151,112,151,110,151,7,152,169,152,235,152,230,156,249,158,131,78,132,78,182,78,189,80,191,80,198,80,174,80,196,80,202,80,180,80,200,80,194,80,176,80,193,80,186,80,177,80,203,80,201,80,182,80,184,80,215,81,122,82,120,82,123,82,124,82,195,85,219,85,204,85,208,85,203,85,202,85,221,85,192,85,212,85,196,85,233,85,191,85,210,85,141,85,207,85,213,85,226,85,214,85,200,85,242,85,205,85,217,85,194,85,20,87,83,88,104,88,100,88,79,88,77,88,73,88,111,88,85,88,78,88,93,88,89,88,101,88,91,88,61,88,99,88,113,88,252,88,199,90,196,90,203,90,186,90,184,90,177,90,181,90,176,90,191,90,200,90,187,90,198,90,183,90,192,90,202,90,180,90,182,90,205,90,185,90,144,90,214,91,216,91,217,91,31,92,51,92,113,93,99,93,74,93,101,93,114,93,108,93,94,93,104,93,103,93,98,93,240,93,79,94,78,94,74,94,77,94,75,94,197,94,204,94,198,94,203,94,199,94,64,95,175,95,173,95,247,96,73,97,74,97,43,97,69,97,54,97,50,97,46,97,70,97,47,97,79,97,41,97,64,97,32,98,104,145,35,98,37,98,36,98,197,99,241,99,235,99,16,100,18,100,9,100,32,100,36,100,51,100,67,100,31,100,21,100,24,100,57,100,55,100,34,100,35,100,12,100,38,100,48,100,40,100,65,100,53,100,47,100,10,100,26,100,64,100,37,100,39,100,11,100,231,99,27,100,46,100,33,100,14,100,111,101,146,101,211,101,134,102,140,102,149,102,144,102,139,102,138,102,153,102,148,102,120,102,32,103,102,105,95,105,56,105,78,105,98,105,113,105,63,105,69,105,106,105,57,105,66,105,87,105,89,105,122,105,72,105,73,105,53,105,108,105,51,105,61,105,101,105,240,104,120,105,52,105,105,105,64,105,111,105,68,105,118,105,88,105,65,105,116,105,76,105,59,105,75,105,55,105,92,105,79,105,81,105,50,105,82,105,47,105,123,105,60,105,70,107,69,107,67,107,66,107,72,107,65,107,155,107,13,250,251,107,252,107,249,107,247,107,248,107,155,110,214,110,200,110,143,110,192,110,159,110,147,110,148,110,160,110,177,110,185,110,198,110,210,110,189,110,193,110,158,110,201,110,183,110,176,110,205,110,166,110,207,110,178,110,190,110,195,110,220,110,216,110,153,110,146,110,142,110,141,110,164,110,161,110,191,110,179,110,208,110,202,110,151,110,174,110,163,110,71,113,84,113,82,113,99,113,96,113,65,113,93,113,98,113,114,113,120,113,106,113,97,113,66,113,88,113,67,113,75,113,112,113,95,113,80,113,83,113,68,113,77,113,90,113,79,114,141,114,140,114,145,114,144,114,142,114,60,115,66,115,59,115,58,115,64,115,74,115,73,115,68,116,74,116,75,116,82,116,81,116,87,116,64,116,79,116,80,116,78,116,66,116,70,116,77,116,84,116,225,116,255,116,254,116,253,116,29,117,121,117,119,117,131,105,239,117,15,118,3,118,247,117,254,117,252,117,249,117,248,117,16,118,251,117,246,117,237,117,245,117,253,117,153,118,181,118,221,118,85,119,95,119,96,119,82,119,86,119,90,119,105,119,103,119,84,119,89,119,109,119,224,119,135,120,154,120,148,120,143,120,132,120,149,120,133,120,134,120,161,120,131,120,121,120,153,120,128,120,150,120,123,120,124,121,130,121,125,121,121,121,17,122,24,122,25,122,18,122,23,122,21,122,34,122,19,122,27,122,16,122,163,122,162,122,158,122,235,122,102,123,100,123,109,123,116,123,105,123,114,123,101,123,115,123,113,123,112,123,97,123,120,123,118,123,99,123,178,124,180,124,175,124,136,125,134,125,128,125,141,125,127,125,133,125,122,125,142,125,123,125,131,125,124,125,140,125,148,125,132,125,125,125,146,125,109,127,107,127,103,127,104,127,108,127,166,127,165,127,167,127,219,127,220,127,33,128,100,129,96,129,119,129,92,129,105,129,91,129,98,129,114,129,33,103,94,129,118,129,103,129,111,129,68,129,97,129,29,130,73,130,68,130,64,130,66,130,69,130,241,132,63,132,86,132,118,132,121,132,143,132,141,132,101,132,81,132,64,132,134,132,103,132,48,132,77,132,125,132,90,132,89,132,116,132,115,132,93,132,7,133,94,132,55,132,58,132,52,132,122,132,67,132,120,132,50,132,69,132,41,132,217,131,75,132,47,132,66,132,45,132,95,132,112,132,57,132,78,132,76,132,82,132,111,132,197,132,142,132,59,132,71,132,54,132,51,132,104,132,126,132,68,132,43,132,96,132,84,132,110,132,80,132,11,135,4,135,247,134,12,135,250,134,214,134,245,134,77,135,248,134,14,135,9,135,1,135,246,134,13,135,5,135,214,136,203,136,205,136,206,136,222,136,219,136,218,136,204,136,208,136,133,137,155,137,223,137,229,137,228,137,225,137,224,137,226,137,220,137,230,137,118,138,134,138,127,138,97,138,63,138,119,138,130,138,132,138,117,138,131,138,129,138,116,138,122,138,60,140,75,140,74,140,101,140,100,140,102,140,134,140,132,140,133,140,204,140,104,141,105,141,145,141,140,141,142,141,143,141,141,141,147,141,148,141,144,141,146,141,240,141,224,141,236,141,241,141,238,141,208,141,233,141,227,141,226,141,231,141,242,141,235,141,244,141,6,143,255,142,1,143,0,143,5,143,7,143,8,143,2,143,11,143,82,144,63,144,68,144,73,144,61,144,16,145,13,145,15,145,17,145,22,145,20,145,11,145,14,145,110,145,111,145,72,146,82,146,48,146,58,146,102,146,51,146,101,146,94,146,131,146,46,146,74,146,70,146,109,146,108,146,79,146,96,146,103,146,111,146,54,146,97,146,112,146,49,146,84,146,99,146,80,146,114,146,78,146,83,146,76,146,86,146,50,146,159,149,156,149,158,149,155,149,146,150,147,150,145,150,151,150,206,150,250,150,253,150,248,150,245,150,115,151,119,151,120,151,114,151,15,152,13,152,14,152,172,152,246,152,249,152,175,153,178,153,176,153,181,153,173,154,171,154,91,155,234,156,237,156,231,156,128,158,253,158,230,80,212,80,215,80,232,80,243,80,219,80,234,80,221,80,228,80,211,80,236,80,240,80,239,80,227,80,224,80,216,81,128,82,129,82,233,82,235,82,48,83,172,83,39,86,21,86,12,86,18,86,252,85,15,86,28,86,1,86,19,86,2,86,250,85,29,86,4,86,255,85,249,85,137,88,124,88,144,88,152,88,134,88,129,88,127,88,116,88,139,88,122,88,135,88,145,88,142,88,118,88,130,88,136,88,123,88,148,88,143,88,254,88,107,89,220,90,238,90,229,90,213,90,234,90,218,90,237,90,235,90,243,90,226,90,224,90,219,90,236,90,222,90,221,90,217,90,232,90,223,90,119,91,224,91,227,91,99,92,130,93,128,93,125,93,134,93,122,93,129,93,119,93,138,93,137,93,136,93,126,93,124,93,141,93,121,93,127,93,88,94,89,94,83,94,216,94,209,94,215,94,206,94,220,94,213,94,217,94,210,94,212,94,68,95,67,95,111,95,182,95,44,97,40,97,65,97,94,97,113,97,115,97,82,97,83,97,114,97,108,97,128,97,116,97,84,97,122,97,91,97,101,97,59,97,106,97,97,97,86,97,41,98,39,98,43,98,43,100,77,100,91,100,93,100,116,100,118,100,114,100,115,100,125,100,117,100,102,100,166,100,78,100,130,100,94,100,92,100,75,100,83,100,96,100,80,100,127,100,63,100,108,100,107,100,89,100,101,100,119,100,115,101,160,101,161,102,160,102,159,102,5,103,4,103,34,103,177,105,182,105,201,105,160,105,206,105,150,105,176,105,172,105,188,105,145,105,153,105,142,105,167,105,141,105,169,105,190,105,175,105,191,105,196,105,189,105,164,105,212,105,185,105,202,105,154,105,207,105,179,105,147,105,170,105,161,105,158,105,217,105,151,105,144,105,194,105,181,105,165,105,198,105,74,107,77,107,75,107,158,107,159,107,160,107,195,107,196,107,254,107,206,110,245,110,241,110,3,111,37,111,248,110,55,111,251,110,46,111,9,111,78,111,25,111,26,111,39,111,24,111,59,111,18,111,237,110,10,111,54,111,115,111,249,110,238,110,45,111,64,111,48,111,60,111,53,111,235,110,7,111,14,111,67,111,5,111,253,110,246,110,57,111,28,111,252,110,58,111,31,111,13,111,30,111,8,111,33,111,135,113,144,113,137,113,128,113,133,113,130,113,143,113,123,113,134,113,129,113,151,113,68,114,83,114,151,114,149,114,147,114,67,115,77,115,81,115,76,115,98,116,115,116,113,116,117,116,114,116,103,116,110,116,0,117,2,117,3,117,125,117,144,117,22,118,8,118,12,118,21,118,17,118,10,118,20,118,184,118,129,119,124,119,133,119,130,119,110,119,128,119,111,119,126,119,131,119,178,120,170,120,180,120,173,120,168,120,126,120,171,120,158,120,165,120,160,120,172,120,162,120,164,120,152,121,138,121,139,121,150,121,149,121,148,121,147,121,151,121,136,121,146,121,144,121,43,122,74,122,48,122,47,122,40,122,38,122,168,122,171,122,172,122,238,122,136,123,156,123,138,123,145,123,144,123,150,123,141,123,140,123,155,123,142,123,133,123,152,123,132,82,153,123,164,123,130,123,187,124,191,124,188,124,186,124,167,125,183,125,194,125,163,125,170,125,193,125,192,125,197,125,157,125,206,125,196,125,198,125,203,125,204,125,175,125,185,125,150,125,188,125,159,125,166,125,174,125,169,125,161,125,201,125,115,127,226,127,227,127,229,127,222,127,36,128,93,128,92,128,137,129,134,129,131,129,135,129,141,129,140,129,139,129,21,130,151,132,164,132,161,132,159,132,186,132,206,132,194,132,172,132,174,132,171,132,185,132,180,132,193,132,205,132,170,132,154,132,177,132,208,132,157,132,167,132,187,132,162,132,148,132,199,132,204,132,155,132,169,132,175,132,168,132,214,132,152,132,182,132,207,132,160,132,215,132,212,132,210,132,219,132,176,132,145,132,97,134,51,135,35,135,40,135,107,135,64,135,46,135,30,135,33,135,25,135,27,135,67,135,44,135,65,135,62,135,70,135,32,135,50,135,42,135,45,135,60,135,18,135,58,135,49,135,53,135,66,135,38,135,39,135,56,135,36,135,26,135,48,135,17,135,247,136,231,136,241,136,242,136,250,136,254,136,238,136,252,136,246,136,251,136,240,136,236,136,235,136,157,137,161,137,159,137,158,137,233,137,235,137,232,137,171,138,153,138,139,138,146,138,143,138,150,138,61,140,104,140,105,140,213,140,207,140,215,140,150,141,9,142,2,142,255,141,13,142,253,141,10,142,3,142,7,142,6,142,5,142,254,141,0,142,4,142,16,143,17,143,14,143,13,143,35,145,28,145,32,145,34,145,31,145,29,145,26,145,36,145,33,145,27,145,122,145,114,145,121,145,115,145,165,146,164,146,118,146,155,146,122,146,160,146,148,146,170,146,141,146,166,146,154,146,171,146,121,146,151,146,127,146,163,146,238,146,142,146,130,146,149,146,162,146,125,146,136,146,161,146,138,146,134,146,140,146,153,146,167,146,126,146,135,146,169,146,157,146,139,146,45,146,158,150,161,150,255,150,88,151,125,151,122,151,126,151,131,151,128,151,130,151,123,151,132,151,129,151,127,151,206,151,205,151,22,152,173,152,174,152,2,153,0,153,7,153,157,153,156,153,195,153,185,153,187,153,186,153,194,153,189,153,199,153,177,154,227,154,231,154,62,155,63,155,96,155,97,155,95,155,241,156,242,156,245,156,167,158,255,80,3,81,48,81,248,80,6,81,7,81,246,80,254,80,11,81,12,81,253,80,10,81,139,82,140,82,241,82,239,82,72,86,66,86,76,86,53,86,65,86,74,86,73,86,70,86,88,86,90,86,64,86,51,86,61,86,44,86,62,86,56,86,42,86,58,86,26,87,171,88,157,88,177,88,160,88,163,88,175,88,172,88,165,88,161,88,255,88,255,90,244,90,253,90,247,90,246,90,3,91,248,90,2,91,249,90,1,91,7,91,5,91,15,91,103,92,153,93,151,93,159,93,146,93,162,93,147,93,149,93,160,93,156,93,161,93,154,93,158,93,105,94,93,94,96,94,92,94,243,125,219,94,222,94,225,94,73,95,178,95,139,97,131,97,121,97,177,97,176,97,162,97,137,97,155,97,147,97,175,97,173,97,159,97,146,97,170,97,161,97,141,97,102,97,179,97,45,98,110,100,112,100,150,100,160,100,133,100,151,100,156,100,143,100,139,100,138,100,140,100,163,100,159,100,104,100,177,100,152,100,118,101,122,101,121,101,123,101,178,101,179,101,181,102,176,102,169,102,178,102,183,102,170,102,175,102,0,106,6,106,23,106,229,105,248,105,21,106,241,105,228,105,32,106,255,105,236,105,226,105,27,106,29,106,254,105,39,106,242,105,238,105,20,106,247,105,231,105,64,106,8,106,230,105,251,105,13,106,252,105,235,105,9,106,4,106,24,106,37,106,15,106,246,105,38,106,7,106,244,105,22,106,81,107,165,107,163,107,162,107,166,107,1,108,0,108,255,107,2,108,65,111,38,111,126,111,135,111,198,111,146,111,141,111,137,111,140,111,98,111,79,111,133,111,90,111,150,111,118,111,108,111,130,111,85,111,114,111,82,111,80,111,87,111,148,111,147,111,93,111,0,111,97,111,107,111,125,111,103,111,144,111,83,111,139,111,105,111,127,111,149,111,99,111,119,111,106,111,123,111,178,113,175,113,155,113,176,113,160,113,154,113,169,113,181,113,157,113,165,113,158,113,164,113,161,113,170,113,156,113,167,113,179,113,152,114,154,114,88,115,82,115,94,115,95,115,96,115,93,115,91,115,97,115,90,115,89,115,98,115,135,116,137,116,138,116,134,116,129,116,125,116,133,116,136,116,124,116,121,116,8,117,7,117,126,117,37,118,30,118,25,118,29,118,28,118,35,118,26,118,40,118,27,118,156,118,157,118,158,118,155,118,141,119,143,119,137,119,136,119,205,120,187,120,207,120,204,120,209,120,206,120,212,120,200,120,195,120,196,120,201,120,154,121,161,121,160,121,156,121,162,121,155,121,118,107,57,122,178,122,180,122,179,122,183,123,203,123,190,123,172,123,206,123,175,123,185,123,202,123,181,123,197,124,200,124,204,124,203,124,247,125,219,125,234,125,231,125,215,125,225,125,3,126,250,125,230,125,246,125,241,125,240,125,238,125,223,125,118,127,172,127,176,127,173,127,237,127,235,127,234,127,236,127,230,127,232,127,100,128,103,128,163,129,159,129,158,129,149,129,162,129,153,129,151,129,22,130,79,130,83,130,82,130,80,130,78,130,81,130,36,133,59,133,15,133,0,133,41,133,14,133,9,133,13,133,31,133,10,133,39,133,28,133,251,132,43,133,250,132,8,133,12,133,244,132,42,133,242,132,21,133,247,132,235,132,243,132,252,132,18,133,234,132,233,132,22,133,254,132,40,133,29,133,46,133,2,133,253,132,30,133,246,132,49,133,38,133,231,132,232,132,240,132,239,132,249,132,24,133,32,133,48,133,11,133,25,133,47,133,98,134,86,135,99,135,100,135,119,135,225,135,115,135,88,135,84,135,91,135,82,135,97,135,90,135,81,135,94,135,109,135,106,135,80,135,78,135,95,135,93,135,111,135,108,135,122,135,110,135,92,135,101,135,79,135,123,135,117,135,98,135,103,135,105,135,90,136,5,137,12,137,20,137,11,137,23,137,24,137,25,137,6,137,22,137,17,137,14,137,9,137,162,137,164,137,163,137,237,137,240,137,236,137,207,138,198,138,184,138,211,138,209,138,212,138,213,138,187,138,215,138,190,138,192,138,197,138,216,138,195,138,186,138,189,138,217,138,62,140,77,140,143,140,229,140,223,140,217,140,232,140,218,140,221,140,231,140,160,141,156,141,161,141,155,141,32,142,35,142,37,142,36,142,46,142,21,142,27,142,22,142,17,142,25,142,38,142,39,142,20,142,18,142,24,142,19,142,28,142,23,142,26,142,44,143,36,143,24,143,26,143,32,143,35,143,22,143,23,143,115,144,112,144,111,144,103,144,107,144,47,145,43,145,41,145,42,145,50,145,38,145,46,145,133,145,134,145,138,145,129,145,130,145,132,145,128,145,208,146,195,146,196,146,192,146,217,146,182,146,207,146,241,146,223,146,216,146,233,146,215,146,221,146,204,146,239,146,194,146,232,146,202,146,200,146,206,146,230,146,205,146,213,146,201,146,224,146,222,146,231,146,209,146,211,146,181,146,225,146,198,146,180,146,124,149,172,149,171,149,174,149,176,149,164,150,162,150,211,150,5,151,8,151,2,151,90,151,138,151,142,151,136,151,208,151,207,151,30,152,29,152,38,152,41,152,40,152,32,152,27,152,39,152,178,152,8,153,250,152,17,153,20,153,22,153,23,153,21,153,220,153,205,153,207,153,211,153,212,153,206,153,201,153,214,153,216,153,203,153,215,153,204,153,179,154,236,154,235,154,243,154,242,154,241,154,70,155,67,155,103,155,116,155,113,155,102,155,118,155,117,155,112,155,104,155,100,155,108,155,252,156,250,156,253,156,255,156,247,156,7,157,0,157,249,156,251,156,8,157,5,157,4,157,131,158,211,158,15,159,16,159,28,81,19,81,23,81,26,81,17,81,222,81,52,83,225,83,112,86,96,86,110,86,115,86,102,86,99,86,109,86,114,86,94,86,119,86,28,87,27,87,200,88,189,88,201,88,191,88,186,88,194,88,188,88,198,88,23,91,25,91,27,91,33,91,20,91,19,91,16,91,22,91,40,91,26,91,32,91,30,91,239,91,172,93,177,93,169,93,167,93,181,93,176,93,174,93,170,93,168,93,178,93,173,93,175,93,180,93,103,94,104,94,102,94,111,94,233,94,231,94,230,94,232,94,229,94,75,95,188,95,157,97,168,97,150,97,197,97,180,97,198,97,193,97,204,97,186,97,191,97,184,97,140,97,215,100,214,100,208,100,207,100,201,100,189,100,137,100,195,100,219,100,243,100,217,100,51,101,127,101,124,101,162,101,200,102,190,102,192,102,202,102,203,102,207,102,189,102,187,102,186,102,204,102,35,103,52,106,102,106,73,106,103,106,50,106,104,106,62,106,93,106,109,106,118,106,91,106,81,106,40,106,90,106,59,106,63,106,65,106,106,106,100,106,80,106,79,106,84,106,111,106,105,106,96,106,60,106,94,106,86,106,85,106,77,106,78,106,70,106,85,107,84,107,86,107,167,107,170,107,171,107,200,107,199,107,4,108,3,108,6,108,173,111,203,111,163,111,199,111,188,111,206,111,200,111,94,111,196,111,189,111,158,111,202,111,168,111,4,112,165,111,174,111,186,111,172,111,170,111,207,111,191,111,184,111,162,111,201,111,171,111,205,111,175,111,178,111,176,111,197,113,194,113,191,113,184,113,214,113,192,113,193,113,203,113,212,113,202,113,199,113,207,113,189,113,216,113,188,113,198,113,218,113,219,113,157,114,158,114,105,115,102,115,103,115,108,115,101,115,107,115,106,115,127,116,154,116,160,116,148,116,146,116,149,116,161,116,11,117,128,117,47,118,45,118,49,118,61,118,51,118,60,118,53,118,50,118,48,118,187,118,230,118,154,119,157,119,161,119,156,119,155,119,162,119,163,119,149,119,153,119,151,119,221,120,233,120,229,120,234,120,222,120,227,120,219,120,225,120,226,120,237,120,223,120,224,120,164,121,68,122,72,122,71,122,182,122,184,122,181,122,177,122,183,122,222,123,227,123,231,123,221,123,213,123,229,123,218,123,232,123,249,123,212,123,234,123,226,123,220,123,235,123,216,123,223,123,210,124,212,124,215,124,208,124,209,124,18,126,33,126,23,126,12,126,31,126,32,126,19,126,14,126,28,126,21,126,26,126,34,126,11,126,15,126,22,126,13,126,20,126,37,126,36,126,67,127,123,127,124,127,122,127,177,127,239,127,42,128,41,128,108,128,177,129,166,129,174,129,185,129,181,129,171,129,176,129,172,129,180,129,178,129,183,129,167,129,242,129,85,130,86,130,87,130,86,133,69,133,107,133,77,133,83,133,97,133,88,133,64,133,70,133,100,133,65,133,98,133,68,133,81,133,71,133,99,133,62,133,91,133,113,133,78,133,110,133,117,133,85,133,103,133,96,133,140,133,102,133,93,133,84,133,101,133,108,133,99,134,101,134,100,134,155,135,143,135,151,135,147,135,146,135,136,135,129,135,150,135,152,135,121,135,135,135,163,135,133,135,144,135,145,135,157,135,132,135,148,135,156,135,154,135,137,135,30,137,38,137,48,137,45,137,46,137,39,137,49,137,34,137,41,137,35,137,47,137,44,137,31,137,241,137,224,138,226,138,242,138,244,138,245,138,221,138,20,139,228,138,223,138,240,138,200,138,222,138,225,138,232,138,255,138,239,138,251,138,145,140,146,140,144,140,245,140,238,140,241,140,240,140,243,140,108,141,110,141,165,141,167,141,51,142,62,142,56,142,64,142,69,142,54,142,60,142,61,142,65,142,48,142,63,142,189,142,54,143,46,143,53,143,50,143,57,143,55,143,52,143,118,144,121,144,123,144,134,144,250,144,51,145,53,145,54,145,147,145,144,145,145,145,141,145,143,145,39,147,30,147,8,147,31,147,6,147,15,147,122,147,56,147,60,147,27,147,35,147,18,147,1,147,70,147,45,147,14,147,13,147,203,146,29,147,250,146,37,147,19,147,249,146,247,146,52,147,2,147,36,147,255,146,41,147,57,147,53,147,42,147,20,147,12,147,11,147,254,146,9,147,0,147,251,146,22,147,188,149,205,149,190,149,185,149,186,149,182,149,191,149,181,149,189,149,169,150,212,150,11,151,18,151,16,151,153,151,151,151,148,151,240,151,248,151,53,152,47,152,50,152,36,153,31,153,39,153,41,153,158,153,238,153,236,153,229,153,228,153,240,153,227,153,234,153,233,153,231,153,185,154,191,154,180,154,187,154,246,154,250,154,249,154,247,154,51,155,128,155,133,155,135,155,124,155,126,155,123,155,130,155,147,155,146,155,144,155,122,155,149,155,125,155,136,155,37,157,23,157,32,157,30,157,20,157,41,157,29,157,24,157,34,157,16,157,25,157,31,157,136,158,134,158,135,158,174,158,173,158,213,158,214,158,250,158,18,159,61,159,38,81,37,81,34,81,36,81,32,81,41,81,244,82,147,86,140,86,141,86,134,86,132,86,131,86,126,86,130,86,127,86,129,86,214,88,212,88,207,88,210,88,45,91,37,91,50,91,35,91,44,91,39,91,38,91,47,91,46,91,123,91,241,91,242,91,183,93,108,94,106,94,190,95,187,95,195,97,181,97,188,97,231,97,224,97,229,97,228,97,232,97,222,97,239,100,233,100,227,100,235,100,228,100,232,100,129,101,128,101,182,101,218,101,210,102,141,106,150,106,129,106,165,106,137,106,159,106,155,106,161,106,158,106,135,106,147,106,142,106,149,106,131,106,168,106,164,106,145,106,127,106,166,106,154,106,133,106,140,106,146,106,91,107,173,107,9,108,204,111,169,111,244,111,212,111,227,111,220,111,237,111,231,111,230,111,222,111,242,111,221,111,226,111,232,111,225,113,241,113,232,113,242,113,228,113,240,113,226,113,115,115,110,115,111,115,151,116,178,116,171,116,144,116,170,116,173,116,177,116,165,116,175,116,16,117,17,117,18,117,15,117,132,117,67,118,72,118,73,118,71,118,164,118,233,118,181,119,171,119,178,119,183,119,182,119,180,119,177,119,168,119,240,119,243,120,253,120,2,121,251,120,252,120,242,120,5,121,249,120,254,120,4,121,171,121,168,121,92,122,91,122,86,122,88,122,84,122,90,122,190,122,192,122,193,122,5,124,15,124,242,123,0,124,255,123,251,123,14,124,244,123,11,124,243,123,2,124,9,124,3,124,1,124,248,123,253,123,6,124,240,123,241,123,16,124,10,124,232,124,45,126,60,126,66,126,51,126,72,152,56,126,42,126,73,126,64,126,71,126,41,126,76,126,48,126,59,126,54,126,68,126,58,126,69,127,127,127,126,127,125,127,244,127,242,127,44,128,187,129,196,129,204,129,202,129,197,129,199,129,188,129,233,129,91,130,90,130,92,130,131,133,128,133,143,133,167,133,149,133,160,133,139,133,163,133,123,133,164,133,154,133,158,133,119,133,124,133,137,133,161,133,122,133,120,133,87,133,142,133,150,133,134,133,141,133,153,133,157,133,129,133,162,133,130,133,136,133,133,133,121,133,118,133,152,133,144,133,159,133,104,134,190,135,170,135,173,135,197,135,176,135,172,135,185,135,181,135,188,135,174,135,201,135,195,135,194,135,204,135,183,135,175,135,196,135,202,135,180,135,182,135,191,135,184,135,189,135,222,135,178,135,53,137,51,137,60,137,62,137,65,137,82,137,55,137,66,137,173,137,175,137,174,137,242,137,243,137,30,139,24,139,22,139,17,139,5,139,11,139,34,139,15,139,18,139,21,139,7,139,13,139,8,139,6,139,28,139,19,139,26,139,79,140,112,140,114,140,113,140,111,140,149,140,148,140,249,140,111,141,78,142,77,142,83,142,80,142,76,142,71,142,67,143,64,143,133,144,126,144,56,145,154,145,162,145,155,145,153,145,159,145,161,145,157,145,160,145,161,147,131,147,175,147,100,147,86,147,71,147,124,147,88,147,92,147,118,147,73,147,80,147,81,147,96,147,109,147,143,147,76,147,106,147,121,147,87,147,85,147,82,147,79,147,113,147,119,147,123,147,97,147,94,147,99,147,103,147,128,147,78,147,89,147,199,149,192,149,201,149,195,149,197,149,183,149,174,150,176,150,172,150,32,151,31,151,24,151,29,151,25,151,154,151,161,151,156,151,158,151,157,151,213,151,212,151,241,151,65,152,68,152,74,152,73,152,69,152,67,152,37,153,43,153,44,153,42,153,51,153,50,153,47,153,45,153,49,153,48,153,152,153,163,153,161,153,2,154,250,153,244,153,247,153,249,153,248,153,246,153,251,153,253,153,254,153,252,153,3,154,190,154,254,154,253,154,1,155,252,154,72,155,154,155,168,155,158,155,155,155,166,155,161,155,165,155,164,155,134,155,162,155,160,155,175,155,51,157,65,157,103,157,54,157,46,157,47,157,49,157,56,157,48,157,69,157,66,157,67,157,62,157,55,157,64,157,61,157,245,127,45,157,138,158,137,158,141,158,176,158,200,158,218,158,251,158,255,158,36,159,35,159,34,159,84,159,160,159,49,81,45,81,46,81,152,86,156,86,151,86,154,86,157,86,153,86,112,89,60,91,105,92,106,92,192,93,109,94,110,94,216,97,223,97,237,97,238,97,241,97,234,97,240,97,235,97,214,97,233,97,255,100,4,101,253,100,248,100,1,101,3,101,252,100,148,101,219,101,218,102,219,102,216,102,197,106,185,106,189,106,225,106,198,106,186,106,182,106,183,106,199,106,180,106,173,106,94,107,201,107,11,108,7,112,12,112,13,112,1,112,5,112,20,112,14,112,255,111,0,112,251,111,38,112,252,111,247,111,10,112,1,114,255,113,249,113,3,114,253,113,118,115,184,116,192,116,181,116,193,116,190,116,182,116,187,116,194,116,20,117,19,117,92,118,100,118,89,118,80,118,83,118,87,118,90,118,166,118,189,118,236,118,194,119,186,119,255,120,12,121,19,121,20,121,9,121,16,121,18,121,17,121,173,121,172,121,95,122,28,124,41,124,25,124,32,124,31,124,45,124,29,124,38,124,40,124,34,124,37,124,48,124,92,126,80,126,86,126,99,126,88,126,98,126,95,126,81,126,96,126,87,126,83,126,181,127,179,127,247,127,248,127,117,128,209,129,210,129,208,129,95,130,94,130,180,133,198,133,192,133,195,133,194,133,179,133,181,133,189,133,199,133,196,133,191,133,203,133,206,133,200,133,197,133,177,133,182,133,210,133,36,134,184,133,183,133,190,133,105,134,231,135,230,135,226,135,219,135,235,135,234,135,229,135,223,135,243,135,228,135,212,135,220,135,211,135,237,135,216,135,227,135,164,135,215,135,217,135,1,136,244,135,232,135,221,135,83,137,75,137,79,137,76,137,70,137,80,137,81,137,73,137,42,139,39,139,35,139,51,139,48,139,53,139,71,139,47,139,60,139,62,139,49,139,37,139,55,139,38,139,54,139,46,139,36,139,59,139,61,139,58,139,66,140,117,140,153,140,152,140,151,140,254,140,4,141,2,141,0,141,92,142,98,142,96,142,87,142,86,142,94,142,101,142,103,142,91,142,90,142,97,142,93,142,105,142,84,142,70,143,71,143,72,143,75,143,40,145,58,145,59,145,62,145,168,145,165,145,167,145,175,145,170,145,181,147,140,147,146,147,183,147,155,147,157,147,137,147,167,147,142,147,170,147,158,147,166,147,149,147,136,147,153,147,159,147,141,147,177,147,145,147,178,147,164,147,168,147,180,147,163,147,165,147,210,149,211,149,209,149,179,150,215,150,218,150,194,93,223,150,216,150,221,150,35,151,34,151,37,151,172,151,174,151,168,151,171,151,164,151,170,151,162,151,165,151,215,151,217,151,214,151,216,151,250,151,80,152,81,152,82,152,184,152,65,153,60,153,58,153,15,154,11,154,9,154,13,154,4,154,17,154,10,154,5,154,7,154,6,154,192,154,220,154,8,155,4,155,5,155,41,155,53,155,74,155,76,155,75,155,199,155,198,155,195,155,191,155,193,155,181,155,184,155,211,155,182,155,196,155,185,155,189,155,92,157,83,157,79,157,74,157,91,157,75,157,89,157,86,157,76,157,87,157,82,157,84,157,95,157,88,157,90,157,142,158,140,158,223,158,1,159,0,159,22,159,37,159,43,159,42,159,41,159,40,159,76,159,85,159,52,81,53,81,150,82,247,82,180,83,171,86,173,86,166,86,167,86,170,86,172,86,218,88,221,88,219,88,18,89,61,91,62,91,63,91,195,93,112,94,191,95,251,97,7,101,16,101,13,101,9,101,12,101,14,101,132,101,222,101,221,101,222,102,231,106,224,106,204,106,209,106,217,106,203,106,223,106,220,106,208,106,235,106,207,106,205,106,222,106,96,107,176,107,12,108,25,112,39,112,32,112,22,112,43,112,33,112,34,112,35,112,41,112,23,112,36,112,28,112,42,112,12,114,10,114,7,114,2,114,5,114,165,114,166,114,164,114,163,114,161,114,203,116,197,116,183,116,195,116,22,117,96,118,201,119,202,119,196,119,241,119,29,121,27,121,33,121,28,121,23,121,30,121,176,121,103,122,104,122,51,124,60,124,57,124,44,124,59,124,236,124,234,124,118,126,117,126,120,126,112,126,119,126,111,126,122,126,114,126,116,126,104,126,75,127,74,127,131,127,134,127,183,127,253,127,254,127,120,128,215,129,213,129,100,130,97,130,99,130,235,133,241,133,237,133,217,133,225,133,232,133,218,133,215,133,236,133,242,133,248,133,216,133,223,133,227,133,220,133,209,133,240,133,230,133,239,133,222,133,226,133,0,136,250,135,3,136,246,135,247,135,9,136,12,136,11,136,6,136,252,135,8,136,255,135,10,136,2,136,98,137,90,137,91,137,87,137,97,137,92,137,88,137,93,137,89,137,136,137,183,137,182,137,246,137,80,139,72,139,74,139,64,139,83,139,86,139,84,139,75,139,85,139,81,139,66,139,82,139,87,139,67,140,119,140,118,140,154,140,6,141,7,141,9,141,172,141,170,141,173,141,171,141,109,142,120,142,115,142,106,142,111,142,123,142,194,142,82,143,81,143,79,143,80,143,83,143,180,143,64,145,63,145,176,145,173,145,222,147,199,147,207,147,194,147,218,147,208,147,249,147,236,147,204,147,217,147,169,147,230,147,202,147,212,147,238,147,227,147,213,147,196,147,206,147,192,147,210,147,231,147,125,149,218,149,219,149,225,150,41,151,43,151,44,151,40,151,38,151,179,151,183,151,182,151,221,151,222,151,223,151,92,152,89,152,93,152,87,152,191,152,189,152,187,152,190,152,72,153,71,153,67,153,166,153,167,153,26,154,21,154,37,154,29,154,36,154,27,154,34,154,32,154,39,154,35,154,30,154,28,154,20,154,194,154,11,155,10,155,14,155,12,155,55,155,234,155,235,155,224,155,222,155,228,155,230,155,226,155,240,155,212,155,215,155,236,155,220,155,217,155,229,155,213,155,225,155,218,155,119,157,129,157,138,157,132,157,136,157,113,157,128,157,120,157,134,157,139,157,140,157,125,157,107,157,116,157,117,157,112,157,105,157,133,157,115,157,123,157,130,157,111,157,121,157,127,157,135,157,104,157,148,158,145,158,192,158,252,158,45,159,64,159,65,159,77,159,86,159,87,159,88,159,55,83,178,86,181,86,179,86,227,88,69,91,198,93,199,93,238,94,239,94,192,95,193,95,249,97,23,101,22,101,21,101,19,101,223,101,232,102,227,102,228,102,243,106,240,106,234,106,232,106,249,106,241,106,238,106,239,106,60,112,53,112,47,112,55,112,52,112,49,112,66,112,56,112,63,112,58,112,57,112,64,112,59,112,51,112,65,112,19,114,20,114,168,114,125,115,124,115,186,116,171,118,170,118,190,118,237,118,204,119,206,119,207,119,205,119,242,119,37,121,35,121,39,121,40,121,36,121,41,121,178,121,110,122,108,122,109,122,247,122,73,124,72,124,74,124,71,124,69,124,238,124,123,126,126,126,129,126,128,126,186,127,255,127,121,128,219,129,217,129,11,130,104,130,105,130,34,134,255,133,1,134,254,133,27,134,0,134,246,133,4,134,9,134,5,134,12,134,253,133,25,136,16,136,17,136,23,136,19,136,22,136,99,137,102,137,185,137,247,137,96,139,106,139,93,139,104,139,99,139,101,139,103,139,109,139,174,141,134,142,136,142,132,142,89,143,86,143,87,143,85,143,88,143,90,143,141,144,67,145,65,145,183,145,181,145,178,145,179,145,11,148,19,148,251,147,32,148,15,148,20,148,254,147,21,148,16,148,40,148,25,148,13,148,245,147,0,148,247,147,7,148,14,148,22,148,18,148,250,147,9,148,248,147,10,148,255,147,252,147,12,148,246,147,17,148,6,148,222,149,224,149,223,149,46,151,47,151,185,151,187,151,253,151,254,151,96,152,98,152,99,152,95,152,193,152,194,152,80,153,78,153,89,153,76,153,75,153,83,153,50,154,52,154,49,154,44,154,42,154,54,154,41,154,46,154,56,154,45,154,199,154,202,154,198,154,16,155,18,155,17,155,11,156,8,156,247,155,5,156,18,156,248,155,64,156,7,156,14,156,6,156,23,156,20,156,9,156,159,157,153,157,164,157,157,157,146,157,152,157,144,157,155,157,160,157,148,157,156,157,170,157,151,157,161,157,154,157,162,157,168,157,158,157,163,157,191,157,169,157,150,157,166,157,167,157,153,158,155,158,154,158,229,158,228,158,231,158,230,158,48,159,46,159,91,159,96,159,94,159,93,159,89,159,145,159,58,81,57,81,152,82,151,82,195,86,189,86,190,86,72,91,71,91,203,93,207,93,241,94,253,97,27,101,2,107,252,106,3,107,248,106,0,107,67,112,68,112,74,112,72,112,73,112,69,112,70,112,29,114,26,114,25,114,126,115,23,117,106,118,208,119,45,121,49,121,47,121,84,124,83,124,242,124,138,126,135,126,136,126,139,126,134,126,141,126,77,127,187,127,48,128,221,129,24,134,42,134,38,134,31,134,35,134,28,134,25,134,39,134,46,134,33,134,32,134,41,134,30,134,37,134,41,136,29,136,27,136,32,136,36,136,28,136,43,136,74,136,109,137,105,137,110,137,107,137,250,137,121,139,120,139,69,139,122,139,123,139,16,141,20,141,175,141,142,142,140,142,94,143,91,143,93,143,70,145,68,145,69,145,185,145,63,148,59,148,54,148,41,148,61,148,60,148,48,148,57,148,42,148,55,148,44,148,64,148,49,148,229,149,228,149,227,149,53,151,58,151,191,151,225,151,100,152,201,152,198,152,192,152,88,153,86,153,57,154,61,154,70,154,68,154,66,154,65,154,58,154,63,154,205,154,21,155,23,155,24,155,22,155,58,155,82,155,43,156,29,156,28,156,44,156,35,156,40,156,41,156,36,156,33,156,183,157,182,157,188,157,193,157,199,157,202,157,207,157,190,157,197,157,195,157,187,157,181,157,206,157,185,157,186,157,172,157,200,157,177,157,173,157,204,157,179,157,205,157,178,157,122,158,156,158,235,158,238,158,237,158,27,159,24,159,26,159,49,159,78,159,101,159,100,159,146,159,185,78,198,86,197,86,203,86,113,89,75,91,76,91,213,93,209,93,242,94,33,101,32,101,38,101,34,101,11,107,8,107,9,107,13,108,85,112,86,112,87,112,82,112,30,114,31,114,169,114,127,115,216,116,213,116,217,116,215,116,109,118,173,118,53,121,180,121,112,122,113,122,87,124,92,124,89,124,91,124,90,124,244,124,241,124,145,126,79,127,135,127,222,129,107,130,52,134,53,134,51,134,44,134,50,134,54,134,44,136,40,136,38,136,42,136,37,136,113,137,191,137,190,137,251,137,126,139,132,139,130,139,134,139,133,139,127,139,21,141,149,142,148,142,154,142,146,142,144,142,150,142,151,142,96,143,98,143,71,145,76,148,80,148,74,148,75,148,79,148,71,148,69,148,72,148,73,148,70,148,63,151,227,151,106,152,105,152,203,152,84,153,91,153,78,154,83,154,84,154,76,154,79,154,72,154,74,154,73,154,82,154,80,154,208,154,25,155,43,155,59,155,86,155,85,155,70,156,72,156,63,156,68,156,57,156,51,156,65,156,60,156,55,156,52,156,50,156,61,156,54,156,219,157,210,157,222,157,218,157,203,157,208,157,220,157,209,157,223,157,233,157,217,157,216,157,214,157,245,157,213,157,221,157,182,158,240,158,53,159,51,159,50,159,66,159,107,159,149,159,162,159,61,81,153,82,232,88,231,88,114,89,77,91,216,93,47,136,79,95,1,98,3,98,4,98,41,101,37,101,150,101,235,102,17,107,18,107,15,107,202,107,91,112,90,112,34,114,130,115,129,115,131,115,112,118,212,119,103,124,102,124,149,126,108,130,58,134,64,134,57,134,60,134,49,134,59,134,62,134,48,136,50,136,46,136,51,136,118,137,116,137,115,137,254,137,140,139,142,139,139,139,136,139,69,140,25,141,152,142,100,143,99,143,188,145,98,148,85,148,93,148,87,148,94,148,196,151,197,151,0,152,86,154,89,154,30,155,31,155,32,155,82,156,88,156,80,156,74,156,77,156,75,156,85,156,89,156,76,156,78,156,251,157,247,157,239,157,227,157,235,157,248,157,228,157,246,157,225,157,238,157,230,157,242,157,240,157,226,157,236,157,244,157,243,157,232,157,237,157,194,158,208,158,242,158,243,158,6,159,28,159,56,159,55,159,54,159,67,159,79,159,113,159,112,159,110,159,111,159,211,86,205,86,78,91,109,92,45,101,237,102,238,102,19,107,95,112,97,112,93,112,96,112,35,114,219,116,229,116,213,119,56,121,183,121,182,121,106,124,151,126,137,127,109,130,67,134,56,136,55,136,53,136,75,136,148,139,149,139,158,142,159,142,160,142,157,142,190,145,189,145,194,145,107,148,104,148,105,148,229,150,70,151,67,151,71,151,199,151,229,151,94,154,213,154,89,155,99,156,103,156,102,156,98,156,94,156,96,156,2,158,254,157,7,158,3,158,6,158,5,158,0,158,1,158,9,158,255,157,253,157,4,158,160,158,30,159,70,159,116,159,117,159,118,159,212,86,46,101,184,101,24,107,25,107,23,107,26,107,98,112,38,114,170,114,216,119,217,119,57,121,105,124,107,124,246,124,154,126,152,126,155,126,153,126,224,129,225,129,70,134,71,134,72,134,121,137,122,137,124,137,123,137,255,137,152,139,153,139,165,142,164,142,163,142,110,148,109,148,111,148,113,148,115,148,73,151,114,152,95,153,104,156,110,156,109,156,11,158,13,158,16,158,15,158,18,158,17,158,161,158,245,158,9,159,71,159,120,159,123,159,122,159,121,159,30,87,102,112,111,124,60,136,178,141,166,142,195,145,116,148,120,148,118,148,117,148,96,154,116,156,115,156,113,156,117,156,20,158,19,158,246,158,10,159,164,159,104,112,101,112,247,124,106,134,62,136,61,136,63,136,158,139,156,140,169,142,201,142,75,151,115,152,116,152,204,152,97,153,171,153,100,154,102,154,103,154,36,155,21,158,23,158,72,159,7,98,30,107,39,114,76,134,168,142,130,148,128,148,129,148,105,154,104,154,46,155,25,158,41,114,75,134,159,139,131,148,121,156,183,158,117,118,107,154,122,156,29,158,105,112,106,112,164,158,126,159,73,159,152,159,129,120,185,146,207,136,187,88,82,96,167,124,250,90,84,37,102,37,87,37,96,37,108,37,99,37,90,37,105,37,93,37,82,37,100,37,85,37,94,37,106,37,97,37,88,37,103,37,91,37,83,37,101,37,86,37,95,37,107,37,98,37,89,37,104,37,92,37,81,37,80,37,109,37,110,37,112,37,111,37,147,37,0,0,0,0,0,0,0,48,1,48,2,48,183,0,37,32,38,32,168,0,3,48,173,0,21,32,37,34,60,255,60,34,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,177,0,215,0,247,0,96,34,100,34,101,34,30,34,52,34,176,0,50,32,51,32,3,33,43,33,224,255,225,255,229,255,66,38,64,38,32,34,165,34,18,35,2,34,7,34,97,34,82,34,167,0,59,32,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,146,33,144,33,145,33,147,33,148,33,19,48,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,39,34,40,34,226,255,210,33,212,33,0,34,3,34,180,0,94,255,199,2,216,2,221,2,218,2,217,2,184,0,219,2,161,0,191,0,208,2,46,34,17,34,15,34,164,0,9,33,48,32,193,37,192,37,183,37,182,37,100,38,96,38,97,38,101,38,103,38,99,38,153,34,200,37,163,37,208,37,209,37,146,37,164,37,165,37,168,37,167,37,166,37,169,37,104,38,15,38,14,38,28,38,30,38,182,0,32,32,33,32,149,33,151,33,153,33,150,33,152,33,109,38,105,38,106,38,108,38,127,50,28,50,22,33,199,51,34,33,194,51,216,51,33,33,172,32,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,2,255,3,255,4,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,230,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,49,49,50,49,51,49,52,49,53,49,54,49,55,49,56,49,57,49,58,49,59,49,60,49,61,49,62,49,63,49,64,49,65,49,66,49,67,49,68,49,69,49,70,49,71,49,72,49,73,49,74,49,75,49,76,49,77,49,78,49,79,49,80,49,81,49,82,49,83,49,84,49,85,49,86,49,87,49,88,49,89,49,90,49,91,49,92,49,93,49,94,49,95,49,96,49,97,49,98,49,99,49,100,49,101,49,102,49,103,49,104,49,105,49,106,49,107,49,108,49,109,49,110,49,111,49,112,49,113,49,114,49,115,49,116,49,117,49,118,49,119,49,120,49,121,49,122,49,123,49,124,49,125,49,126,49,127,49,128,49,129,49,130,49,131,49,132,49,133,49,134,49,135,49,136,49,137,49,138,49,139,49,140,49,141,49,142,49,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,0,0,0,0,0,0,0,0,0,0,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37,18,37,17,37,26,37,25,37,22,37,21,37,14,37,13,37,30,37,31,37,33,37,34,37,38,37,39,37,41,37,42,37,45,37,46,37,49,37,50,37,53,37,54,37,57,37,58,37,61,37,62,37,64,37,65,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,51,150,51,151,51,19,33,152,51,196,51,163,51,164,51,165,51,166,51,153,51,154,51,155,51,156,51,157,51,158,51,159,51,160,51,161,51,162,51,202,51,141,51,142,51,143,51,207,51,136,51,137,51,200,51,167,51,168,51,176,51,177,51,178,51,179,51,180,51,181,51,182,51,183,51,184,51,185,51,128,51,129,51,130,51,131,51,132,51,186,51,187,51,188,51,189,51,190,51,191,51,144,51,145,51,146,51,147,51,148,51,38,33,192,51,193,51,138,51,139,51,140,51,214,51,197,51,173,51,174,51,175,51,219,51,169,51,170,51,171,51,172,51,221,51,208,51,211,51,195,51,201,51,220,51,198,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,208,0,170,0,38,1,0,0,50,1,0,0,63,1,65,1,216,0,82,1,186,0,222,0,102,1,74,1,0,0,96,50,97,50,98,50,99,50,100,50,101,50,102,50,103,50,104,50,105,50,106,50,107,50,108,50,109,50,110,50,111,50,112,50,113,50,114,50,115,50,116,50,117,50,118,50,119,50,120,50,121,50,122,50,123,50,208,36,209,36,210,36,211,36,212,36,213,36,214,36,215,36,216,36,217,36,218,36,219,36,220,36,221,36,222,36,223,36,224,36,225,36,226,36,227,36,228,36,229,36,230,36,231,36,232,36,233,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,189,0,83,33,84,33,188,0,190,0,91,33,92,33,93,33,94,33,230,0,17,1,240,0,39,1,49,1,51,1,56,1,64,1,66,1,248,0,83,1,223,0,254,0,103,1,75,1,73,1,0,50,1,50,2,50,3,50,4,50,5,50,6,50,7,50,8,50,9,50,10,50,11,50,12,50,13,50,14,50,15,50,16,50,17,50,18,50,19,50,20,50,21,50,22,50,23,50,24,50,25,50,26,50,27,50,156,36,157,36,158,36,159,36,160,36,161,36,162,36,163,36,164,36,165,36,166,36,167,36,168,36,169,36,170,36,171,36,172,36,173,36,174,36,175,36,176,36,177,36,178,36,179,36,180,36,181,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,185,0,178,0,179,0,116,32,127,32,129,32,130,32,131,32,132,32,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,172,4,172,7,172,8,172,9,172,10,172,16,172,17,172,18,172,19,172,20,172,21,172,22,172,23,172,25,172,26,172,27,172,28,172,29,172,32,172,36,172,44,172,45,172,47,172,48,172,49,172,56,172,57,172,60,172,64,172,75,172,77,172,84,172,88,172,92,172,112,172,113,172,116,172,119,172,120,172,122,172,128,172,129,172,131,172,132,172,133,172,134,172,137,172,138,172,139,172,140,172,144,172,148,172,156,172,157,172,159,172,160,172,161,172,168,172,169,172,170,172,172,172,175,172,176,172,184,172,185,172,187,172,188,172,189,172,193,172,196,172,200,172,204,172,213,172,215,172,224,172,225,172,228,172,231,172,232,172,234,172,236,172,239,172,240,172,241,172,243,172,245,172,246,172,252,172,253,172,0,173,4,173,6,173,12,173,13,173,15,173,17,173,24,173,28,173,32,173,41,173,44,173,45,173,52,173,53,173,56,173,60,173,68,173,69,173,71,173,73,173,80,173,84,173,88,173,97,173,99,173,108,173,109,173,112,173,115,173,116,173,117,173,118,173,123,173,124,173,125,173,127,173,129,173,130,173,136,173,137,173,140,173,144,173,156,173,157,173,164,173,183,173,192,173,193,173,196,173,200,173,208,173,209,173,211,173,220,173,224,173,228,173,248,173,249,173,252,173,255,173,0,174,1,174,8,174,9,174,11,174,13,174,20,174,48,174,49,174,52,174,55,174,56,174,58,174,64,174,65,174,67,174,69,174,70,174,74,174,76,174,77,174,78,174,80,174,84,174,86,174,92,174,93,174,95,174,96,174,97,174,101,174,104,174,105,174,108,174,112,174,120,174,121,174,123,174,124,174,125,174,132,174,133,174,140,174,188,174,189,174,190,174,192,174,196,174,204,174,205,174,207,174,208,174,209,174,216,174,217,174,220,174,232,174,235,174,237,174,244,174,248,174,252,174,7,175,8,175,13,175,16,175,44,175,45,175,48,175,50,175,52,175,60,175,61,175,63,175,65,175,66,175,67,175,72,175,73,175,80,175,92,175,93,175,100,175,101,175,121,175,128,175,132,175,136,175,144,175,145,175,149,175,156,175,184,175,185,175,188,175,192,175,199,175,200,175,201,175,203,175,205,175,206,175,212,175,220,175,232,175,233,175,240,175,241,175,244,175,248,175,0,176,1,176,4,176,12,176,16,176,20,176,28,176,29,176,40,176,68,176,69,176,72,176,74,176,76,176,78,176,83,176,84,176,85,176,87,176,89,176,93,176,124,176,125,176,128,176,132,176,140,176,141,176,143,176,145,176,152,176,153,176,154,176,156,176,159,176,160,176,161,176,162,176,168,176,169,176,171,176,172,176,173,176,174,176,175,176,177,176,179,176,180,176,181,176,184,176,188,176,196,176,197,176,199,176,200,176,201,176,208,176,209,176,212,176,216,176,224,176,229,176,8,177,9,177,11,177,12,177,16,177,18,177,19,177,24,177,25,177,27,177,28,177,29,177,35,177,36,177,37,177,40,177,44,177,52,177,53,177,55,177,56,177,57,177,64,177,65,177,68,177,72,177,80,177,81,177,84,177,85,177,88,177,92,177,96,177,120,177,121,177,124,177,128,177,130,177,136,177,137,177,139,177,141,177,146,177,147,177,148,177,152,177,156,177,168,177,204,177,208,177,212,177,220,177,221,177,223,177,232,177,233,177,236,177,240,177,249,177,251,177,253,177,4,178,5,178,8,178,11,178,12,178,20,178,21,178,23,178,25,178,32,178,52,178,60,178,88,178,92,178,96,178,104,178,105,178,116,178,117,178,124,178,132,178,133,178,137,178,144,178,145,178,148,178,152,178,153,178,154,178,160,178,161,178,163,178,165,178,166,178,170,178,172,178,176,178,180,178,200,178,201,178,204,178,208,178,210,178,216,178,217,178,219,178,221,178,226,178,228,178,229,178,230,178,232,178,235,178,236,178,237,178,238,178,239,178,243,178,244,178,245,178,247,178,248,178,249,178,250,178,251,178,255,178,0,179,1,179,4,179,8,179,16,179,17,179,19,179,20,179,21,179,28,179,84,179,85,179,86,179,88,179,91,179,92,179,94,179,95,179,100,179,101,179,103,179,105,179,107,179,110,179,112,179,113,179,116,179,120,179,128,179,129,179,131,179,132,179,133,179,140,179,144,179,148,179,160,179,161,179,168,179,172,179,196,179,197,179,200,179,203,179,204,179,206,179,208,179,212,179,213,179,215,179,217,179,219,179,221,179,224,179,228,179,232,179,252,179,16,180,24,180,28,180,32,180,40,180,41,180,43,180,52,180,80,180,81,180,84,180,88,180,96,180,97,180,99,180,101,180,108,180,128,180,136,180,157,180,164,180,168,180,172,180,181,180,183,180,185,180,192,180,196,180,200,180,208,180,213,180,220,180,221,180,224,180,227,180,228,180,230,180,236,180,237,180,239,180,241,180,248,180,20,181,21,181,24,181,27,181,28,181,36,181,37,181,39,181,40,181,41,181,42,181,48,181,49,181,52,181,56,181,64,181,65,181,67,181,68,181,69,181,75,181,76,181,77,181,80,181,84,181,92,181,93,181,95,181,96,181,97,181,160,181,161,181,164,181,168,181,170,181,171,181,176,181,177,181,179,181,180,181,181,181,187,181,188,181,189,181,192,181,196,181,204,181,205,181,207,181,208,181,209,181,216,181,236,181,16,182,17,182,20,182,24,182,37,182,44,182,52,182,72,182,100,182,104,182,156,182,157,182,160,182,164,182,171,182,172,182,177,182,212,182,240,182,244,182,248,182,0,183,1,183,5,183,40,183,41,183,44,183,47,183,48,183,56,183,57,183,59,183,68,183,72,183,76,183,84,183,85,183,96,183,100,183,104,183,112,183,113,183,115,183,117,183,124,183,125,183,128,183,132,183,140,183,141,183,143,183,144,183,145,183,146,183,150,183,151,183,152,183,153,183,156,183,160,183,168,183,169,183,171,183,172,183,173,183,180,183,181,183,184,183,199,183,201,183,236,183,237,183,240,183,244,183,252,183,253,183,255,183,0,184,1,184,7,184,8,184,9,184,12,184,16,184,24,184,25,184,27,184,29,184,36,184,37,184,40,184,44,184,52,184,53,184,55,184,56,184,57,184,64,184,68,184,81,184,83,184,92,184,93,184,96,184,100,184,108,184,109,184,111,184,113,184,120,184,124,184,141,184,168,184,176,184,180,184,184,184,192,184,193,184,195,184,197,184,204,184,208,184,212,184,221,184,223,184,225,184,232,184,233,184,236,184,240,184,248,184,249,184,251,184,253,184,4,185,24,185,32,185,60,185,61,185,64,185,68,185,76,185,79,185,81,185,88,185,89,185,92,185,96,185,104,185,105,185,107,185,109,185,116,185,117,185,120,185,124,185,132,185,133,185,135,185,137,185,138,185,141,185,142,185,172,185,173,185,176,185,180,185,188,185,189,185,191,185,193,185,200,185,201,185,204,185,206,185,207,185,208,185,209,185,210,185,216,185,217,185,219,185,221,185,222,185,225,185,227,185,228,185,229,185,232,185,236,185,244,185,245,185,247,185,248,185,249,185,250,185,0,186,1,186,8,186,21,186,56,186,57,186,60,186,64,186,66,186,72,186,73,186,75,186,77,186,78,186,83,186,84,186,85,186,88,186,92,186,100,186,101,186,103,186,104,186,105,186,112,186,113,186,116,186,120,186,131,186,132,186,133,186,135,186,140,186,168,186,169,186,171,186,172,186,176,186,178,186,184,186,185,186,187,186,189,186,196,186,200,186,216,186,217,186,252,186,0,187,4,187,13,187,15,187,17,187,24,187,28,187,32,187,41,187,43,187,52,187,53,187,54,187,56,187,59,187,60,187,61,187,62,187,68,187,69,187,71,187,73,187,77,187,79,187,80,187,84,187,88,187,97,187,99,187,108,187,136,187,140,187,144,187,164,187,168,187,172,187,180,187,183,187,192,187,196,187,200,187,208,187,211,187,248,187,249,187,252,187,255,187,0,188,2,188,8,188,9,188,11,188,12,188,13,188,15,188,17,188,20,188,21,188,22,188,23,188,24,188,27,188,28,188,29,188,30,188,31,188,36,188,37,188,39,188,41,188,45,188,48,188,49,188,52,188,56,188,64,188,65,188,67,188,68,188,69,188,73,188,76,188,77,188,80,188,93,188,132,188,133,188,136,188,139,188,140,188,142,188,148,188,149,188,151,188,153,188,154,188,160,188,161,188,164,188,167,188,168,188,176,188,177,188,179,188,180,188,181,188,188,188,189,188,192,188,196,188,205,188,207,188,208,188,209,188,213,188,216,188,220,188,244,188,245,188,246,188,248,188,252,188,4,189,5,189,7,189,9,189,16,189,20,189,36,189,44,189,64,189,72,189,73,189,76,189,80,189,88,189,89,189,100,189,104,189,128,189,129,189,132,189,135,189,136,189,137,189,138,189,144,189,145,189,147,189,149,189,153,189,154,189,156,189,164,189,176,189,184,189,212,189,213,189,216,189,220,189,233,189,240,189,244,189,248,189,0,190,3,190,5,190,12,190,13,190,16,190,20,190,28,190,29,190,31,190,68,190,69,190,72,190,76,190,78,190,84,190,85,190,87,190,89,190,90,190,91,190,96,190,97,190,100,190,104,190,106,190,112,190,113,190,115,190,116,190,117,190,123,190,124,190,125,190,128,190,132,190,140,190,141,190,143,190,144,190,145,190,152,190,153,190,168,190,208,190,209,190,212,190,215,190,216,190,224,190,227,190,228,190,229,190,236,190,1,191,8,191,9,191,24,191,25,191,27,191,28,191,29,191,64,191,65,191,68,191,72,191,80,191,81,191,85,191,148,191,176,191,197,191,204,191,205,191,208,191,212,191,220,191,223,191,225,191,60,192,81,192,88,192,92,192,96,192,104,192,105,192,144,192,145,192,148,192,152,192,160,192,161,192,163,192,165,192,172,192,173,192,175,192,176,192,179,192,180,192,181,192,182,192,188,192,189,192,191,192,192,192,193,192,197,192,200,192,201,192,204,192,208,192,216,192,217,192,219,192,220,192,221,192,228,192,229,192,232,192,236,192,244,192,245,192,247,192,249,192,0,193,4,193,8,193,16,193,21,193,28,193,29,193,30,193,31,193,32,193,35,193,36,193,38,193,39,193,44,193,45,193,47,193,48,193,49,193,54,193,56,193,57,193,60,193,64,193,72,193,73,193,75,193,76,193,77,193,84,193,85,193,88,193,92,193,100,193,101,193,103,193,104,193,105,193,112,193,116,193,120,193,133,193,140,193,141,193,142,193,144,193,148,193,150,193,156,193,157,193,159,193,161,193,165,193,168,193,169,193,172,193,176,193,189,193,196,193,200,193,204,193,212,193,215,193,216,193,224,193,228,193,232,193,240,193,241,193,243,193,252,193,253,193,0,194,4,194,12,194,13,194,15,194,17,194,24,194,25,194,28,194,31,194,32,194,40,194,41,194,43,194,45,194,47,194,49,194,50,194,52,194,72,194,80,194,81,194,84,194,88,194,96,194,101,194,108,194,109,194,112,194,116,194,124,194,125,194,127,194,129,194,136,194,137,194,144,194,152,194,155,194,157,194,164,194,165,194,168,194,172,194,173,194,180,194,181,194,183,194,185,194,220,194,221,194,224,194,227,194,228,194,235,194,236,194,237,194,239,194,241,194,246,194,248,194,249,194,251,194,252,194,0,195,8,195,9,195,12,195,13,195,19,195,20,195,21,195,24,195,28,195,36,195,37,195,40,195,41,195,69,195,104,195,105,195,108,195,112,195,114,195,120,195,121,195,124,195,125,195,132,195,136,195,140,195,192,195,216,195,217,195,220,195,223,195,224,195,226,195,232,195,233,195,237,195,244,195,245,195,248,195,8,196,16,196,36,196,44,196,48,196,52,196,60,196,61,196,72,196,100,196,101,196,104,196,108,196,116,196,117,196,121,196,128,196,148,196,156,196,184,196,188,196,233,196,240,196,241,196,244,196,248,196,250,196,255,196,0,197,1,197,12,197,16,197,20,197,28,197,40,197,41,197,44,197,48,197,56,197,57,197,59,197,61,197,68,197,69,197,72,197,73,197,74,197,76,197,77,197,78,197,83,197,84,197,85,197,87,197,88,197,89,197,93,197,94,197,96,197,97,197,100,197,104,197,112,197,113,197,115,197,116,197,117,197,124,197,125,197,128,197,132,197,135,197,140,197,141,197,143,197,145,197,149,197,151,197,152,197,156,197,160,197,169,197,180,197,181,197,184,197,185,197,187,197,188,197,189,197,190,197,196,197,197,197,198,197,199,197,200,197,201,197,202,197,204,197,206,197,208,197,209,197,212,197,216,197,224,197,225,197,227,197,229,197,236,197,237,197,238,197,240,197,244,197,246,197,247,197,252,197,253,197,254,197,255,197,0,198,1,198,5,198,6,198,7,198,8,198,12,198,16,198,24,198,25,198,27,198,28,198,36,198,37,198,40,198,44,198,45,198,46,198,48,198,51,198,52,198,53,198,55,198,57,198,59,198,64,198,65,198,68,198,72,198,80,198,81,198,83,198,84,198,85,198,92,198,93,198,96,198,108,198,111,198,113,198,120,198,121,198,124,198,128,198,136,198,137,198,139,198,141,198,148,198,149,198,152,198,156,198,164,198,165,198,167,198,169,198,176,198,177,198,180,198,184,198,185,198,186,198,192,198,193,198,195,198,197,198,204,198,205,198,208,198,212,198,220,198,221,198,224,198,225,198,232,198,233,198,236,198,240,198,248,198,249,198,253,198,4,199,5,199,8,199,12,199,20,199,21,199,23,199,25,199,32,199,33,199,36,199,40,199,48,199,49,199,51,199,53,199,55,199,60,199,61,199,64,199,68,199,74,199,76,199,77,199,79,199,81,199,82,199,83,199,84,199,85,199,86,199,87,199,88,199,92,199,96,199,104,199,107,199,116,199,117,199,120,199,124,199,125,199,126,199,131,199,132,199,133,199,135,199,136,199,137,199,138,199,142,199,144,199,145,199,148,199,150,199,151,199,152,199,154,199,160,199,161,199,163,199,164,199,165,199,166,199,172,199,173,199,176,199,180,199,188,199,189,199,191,199,192,199,193,199,200,199,201,199,204,199,206,199,208,199,216,199,221,199,228,199,232,199,236,199,0,200,1,200,4,200,8,200,10,200,16,200,17,200,19,200,21,200,22,200,28,200,29,200,32,200,36,200,44,200,45,200,47,200,49,200,56,200,60,200,64,200,72,200,73,200,76,200,77,200,84,200,112,200,113,200,116,200,120,200,122,200,128,200,129,200,131,200,133,200,134,200,135,200,139,200,140,200,141,200,148,200,157,200,159,200,161,200,168,200,188,200,189,200,196,200,200,200,204,200,212,200,213,200,215,200,217,200,224,200,225,200,228,200,245,200,252,200,253,200,0,201,4,201,5,201,6,201,12,201,13,201,15,201,17,201,24,201,44,201,52,201,80,201,81,201,84,201,88,201,96,201,97,201,99,201,108,201,112,201,116,201,124,201,136,201,137,201,140,201,144,201,152,201,153,201,155,201,157,201,192,201,193,201,196,201,199,201,200,201,202,201,208,201,209,201,211,201,213,201,214,201,217,201,218,201,220,201,221,201,224,201,226,201,228,201,231,201,236,201,237,201,239,201,240,201,241,201,248,201,249,201,252,201,0,202,8,202,9,202,11,202,12,202,13,202,20,202,24,202,41,202,76,202,77,202,80,202,84,202,92,202,93,202,95,202,96,202,97,202,104,202,125,202,132,202,152,202,188,202,189,202,192,202,196,202,204,202,205,202,207,202,209,202,211,202,216,202,217,202,224,202,236,202,244,202,8,203,16,203,20,203,24,203,32,203,33,203,65,203,72,203,73,203,76,203,80,203,88,203,89,203,93,203,100,203,120,203,121,203,156,203,184,203,212,203,228,203,231,203,233,203,12,204,13,204,16,204,20,204,28,204,29,204,33,204,34,204,39,204,40,204,41,204,44,204,46,204,48,204,56,204,57,204,59,204,60,204,61,204,62,204,68,204,69,204,72,204,76,204,84,204,85,204,87,204,88,204,89,204,96,204,100,204,102,204,104,204,112,204,117,204,152,204,153,204,156,204,160,204,168,204,169,204,171,204,172,204,173,204,180,204,181,204,184,204,188,204,196,204,197,204,199,204,201,204,208,204,212,204,228,204,236,204,240,204,1,205,8,205,9,205,12,205,16,205,24,205,25,205,27,205,29,205,36,205,40,205,44,205,57,205,92,205,96,205,100,205,108,205,109,205,111,205,113,205,120,205,136,205,148,205,149,205,152,205,156,205,164,205,165,205,167,205,169,205,176,205,196,205,204,205,208,205,232,205,236,205,240,205,248,205,249,205,251,205,253,205,4,206,8,206,12,206,20,206,25,206,32,206,33,206,36,206,40,206,48,206,49,206,51,206,53,206,88,206,89,206,92,206,95,206,96,206,97,206,104,206,105,206,107,206,109,206,116,206,117,206,120,206,124,206,132,206,133,206,135,206,137,206,144,206,145,206,148,206,152,206,160,206,161,206,163,206,164,206,165,206,172,206,173,206,193,206,228,206,229,206,232,206,235,206,236,206,244,206,245,206,247,206,248,206,249,206,0,207,1,207,4,207,8,207,16,207,17,207,19,207,21,207,28,207,32,207,36,207,44,207,45,207,47,207,48,207,49,207,56,207,84,207,85,207,88,207,92,207,100,207,101,207,103,207,105,207,112,207,113,207,116,207,120,207,128,207,133,207,140,207,161,207,168,207,176,207,196,207,224,207,225,207,228,207,232,207,240,207,241,207,243,207,245,207,252,207,0,208,4,208,17,208,24,208,45,208,52,208,53,208,56,208,60,208,68,208,69,208,71,208,73,208,80,208,84,208,88,208,96,208,108,208,109,208,112,208,116,208,124,208,125,208,129,208,164,208,165,208,168,208,172,208,180,208,181,208,183,208,185,208,192,208,193,208,196,208,200,208,201,208,208,208,209,208,211,208,212,208,213,208,220,208,221,208,224,208,228,208,236,208,237,208,239,208,240,208,241,208,248,208,13,209,48,209,49,209,52,209,56,209,58,209,64,209,65,209,67,209,68,209,69,209,76,209,77,209,80,209,84,209,92,209,93,209,95,209,97,209,104,209,108,209,124,209,132,209,136,209,160,209,161,209,164,209,168,209,176,209,177,209,179,209,181,209,186,209,188,209,192,209,216,209,244,209,248,209,7,210,9,210,16,210,44,210,45,210,48,210,52,210,60,210,61,210,63,210,65,210,72,210,92,210,100,210,128,210,129,210,132,210,136,210,144,210,145,210,149,210,156,210,160,210,164,210,172,210,177,210,184,210,185,210,188,210,191,210,192,210,194,210,200,210,201,210,203,210,212,210,216,210,220,210,228,210,229,210,240,210,241,210,244,210,248,210,0,211,1,211,3,211,5,211,12,211,13,211,14,211,16,211,20,211,22,211,28,211,29,211,31,211,32,211,33,211,37,211,40,211,41,211,44,211,48,211,56,211,57,211,59,211,60,211,61,211,68,211,69,211,124,211,125,211,128,211,132,211,140,211,141,211,143,211,144,211,145,211,152,211,153,211,156,211,160,211,168,211,169,211,171,211,173,211,180,211,184,211,188,211,196,211,197,211,200,211,201,211,208,211,216,211,225,211,227,211,236,211,237,211,240,211,244,211,252,211,253,211,255,211,1,212,8,212,29,212,64,212,68,212,92,212,96,212,100,212,109,212,111,212,120,212,121,212,124,212,127,212,128,212,130,212,136,212,137,212,139,212,141,212,148,212,169,212,204,212,208,212,212,212,220,212,223,212,232,212,236,212,240,212,248,212,251,212,253,212,4,213,8,213,12,213,20,213,21,213,23,213,60,213,61,213,64,213,68,213,76,213,77,213,79,213,81,213,88,213,89,213,92,213,96,213,101,213,104,213,105,213,107,213,109,213,116,213,117,213,120,213,124,213,132,213,133,213,135,213,136,213,137,213,144,213,165,213,200,213,201,213,204,213,208,213,210,213,216,213,217,213,219,213,221,213,228,213,229,213,232,213,236,213,244,213,245,213,247,213,249,213,0,214,1,214,4,214,8,214,16,214,17,214,19,214,20,214,21,214,28,214,32,214,36,214,45,214,56,214,57,214,60,214,64,214,69,214,72,214,73,214,75,214,77,214,81,214,84,214,85,214,88,214,92,214,103,214,105,214,112,214,113,214,116,214,131,214,133,214,140,214,141,214,144,214,148,214,157,214,159,214,161,214,168,214,172,214,176,214,185,214,187,214,196,214,197,214,200,214,204,214,209,214,212,214,215,214,217,214,224,214,228,214,232,214,240,214,245,214,252,214,253,214,0,215,4,215,17,215,24,215,25,215,28,215,32,215,40,215,41,215,43,215,45,215,52,215,53,215,56,215,60,215,68,215,71,215,73,215,80,215,81,215,84,215,86,215,87,215,88,215,89,215,96,215,97,215,99,215,101,215,105,215,108,215,112,215,116,215,124,215,125,215,129,215,136,215,137,215,140,215,144,215,152,215,153,215,155,215,157,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,79,115,79,71,80,249,80,160,82,239,83,117,84,229,84,9,86,193,90,182,91,135,102,182,103,183,103,239,103,76,107,194,115,194,117,60,122,219,130,4,131,87,136,136,136,54,138,200,140,207,141,251,142,230,143,213,153,59,82,116,83,4,84,106,96,100,97,188,107,207,115,26,129,186,137,210,137,163,149,131,79,10,82,190,88,120,89,230,89,114,94,121,94,199,97,192,99,70,103,236,103,127,104,151,111,78,118,11,119,245,120,8,122,255,122,33,124,157,128,110,130,113,130,235,138,147,149,107,78,157,85,247,102,52,110,163,120,237,122,91,132,16,137,78,135,168,151,216,82,78,87,42,88,76,93,31,97,190,97,33,98,98,101,209,103,68,106,27,110,24,117,179,117,227,118,176,119,58,125,175,144,81,148,82,148,149,159,35,83,172,92,50,117,219,128,64,146,152,149,91,82,8,88,220,89,161,92,23,93,183,94,58,95,74,95,119,97,95,108,122,117,134,117,224,124,115,125,177,125,140,127,84,129,33,130,145,133,65,137,27,139,252,146,77,150,71,156,203,78,247,78,11,80,241,81,79,88,55,97,62,97,104,97,57,101,234,105,17,111,165,117,134,118,214,118,135,123,165,130,203,132,0,249,167,147,139,149,128,85,162,91,81,87,1,249,179,124,185,127,181,145,40,80,187,83,69,92,232,93,210,98,110,99,218,100,231,100,32,110,172,112,91,121,221,141,30,142,2,249,125,144,69,146,248,146,126,78,246,78,101,80,254,93,250,94,6,97,87,105,113,129,84,134,71,142,117,147,43,154,94,78,145,80,112,103,64,104,9,81,141,82,146,82,162,106,188,119,16,146,212,158,171,82,47,96,242,143,72,80,169,97,237,99,202,100,60,104,132,106,192,111,136,129,161,137,148,150,5,88,125,114,172,114,4,117,121,125,109,126,169,128,139,137,116,139,99,144,81,157,137,98,122,108,84,111,80,125,58,127,35,138,124,81,74,97,157,123,25,139,87,146,140,147,172,78,211,79,30,80,190,80,6,81,193,82,205,82,127,83,112,87,131,88,154,94,145,95,118,97,172,97,206,100,108,101,111,102,187,102,244,102,151,104,135,109,133,112,241,112,159,116,165,116,202,116,217,117,108,120,236,120,223,122,246,122,69,125,147,125,21,128,63,128,27,129,150,131,102,139,21,143,21,144,225,147,3,152,56,152,90,154,232,155,194,79,83,85,58,88,81,89,99,91,70,92,184,96,18,98,66,104,176,104,232,104,170,110,76,117,120,118,206,120,61,122,251,124,107,126,124,126,8,138,161,138,63,140,142,150,196,157,228,83,233,83,74,84,113,84,250,86,209,89,100,91,59,92,171,94,247,98,55,101,69,101,114,101,160,102,175,103,193,105,189,108,252,117,144,118,126,119,63,122,148,127,3,128,161,128,143,129,230,130,253,130,240,131,193,133,49,136,180,136,165,138,3,249,156,143,46,147,199,150,103,152,216,154,19,159,237,84,155,101,242,102,143,104,64,122,55,140,96,157,240,86,100,87,17,93,6,102,177,104,205,104,254,110,40,116,158,136,228,155,104,108,4,249,168,154,155,79,108,81,113,81,159,82,84,91,229,93,80,96,109,96,241,98,167,99,59,101,217,115,122,122,163,134,162,140,143,151,50,78,225,91,8,98,156,103,220,116,209,121,211,131,135,138,178,138,232,141,78,144,75,147,70,152,211,94,232,105,255,133,237,144,5,249,160,81,152,91,236,91,99,97,250,104,62,107,76,112,47,116,216,116,161,123,80,127,197,131,192,137,171,140,220,149,40,153,46,82,93,96,236,98,2,144,138,79,73,81,33,83,217,88,227,94,224,102,56,109,154,112,194,114,214,115,80,123,241,128,91,148,102,83,155,99,107,127,86,78,128,80,74,88,222,88,42,96,39,97,208,98,208,105,65,155,143,91,24,125,177,128,95,143,164,78,209,80,172,84,172,85,12,91,160,93,231,93,42,101,78,101,33,104,75,106,225,114,142,118,239,119,94,125,249,127,160,129,78,133,223,134,3,143,78,143,202,144,3,153,85,154,171,155,24,78,69,78,93,78,199,78,241,79,119,81,254,82,64,83,227,83,229,83,142,84,20,86,117,87,162,87,199,91,135,93,208,94,252,97,216,98,81,101,184,103,233,103,203,105,80,107,198,107,236,107,66,108,157,110,120,112,215,114,150,115,3,116,191,119,233,119,118,122,127,125,9,128,252,129,5,130,10,130,223,130,98,136,51,139,252,140,192,142,17,144,177,144,100,146,182,146,210,153,69,154,233,156,215,157,156,159,11,87,64,92,202,131,160,151,171,151,180,158,27,84,152,122,164,127,217,136,205,142,225,144,0,88,72,92,152,99,159,122,174,91,19,95,121,122,174,122,142,130,172,142,38,80,56,82,248,82,119,83,8,87,243,98,114,99,10,107,195,109,55,119,165,83,87,115,104,133,118,142,213,149,58,103,195,106,112,111,109,138,204,142,75,153,6,249,119,102,120,107,180,140,60,155,7,249,235,83,45,87,78,89,198,99,251,105,234,115,69,120,186,122,197,122,254,124,117,132,143,137,115,141,53,144,168,149,251,82,71,87,71,117,96,123,204,131,30,146,8,249,88,106,75,81,75,82,135,82,31,98,216,104,117,105,153,150,197,80,164,82,228,82,195,97,164,101,57,104,255,105,126,116,75,123,185,130,235,131,178,137,57,139,209,143,73,153,9,249,202,78,151,89,210,100,17,102,142,106,52,116,129,121,189,121,169,130,126,136,127,136,95,137,10,249,38,147,11,79,202,83,37,96,113,98,114,108,26,125,102,125,152,78,98,81,220,119,175,128,1,79,14,79,118,81,128,81,220,85,104,86,59,87,250,87,252,87,20,89,71,89,147,89,196,91,144,92,14,93,241,93,126,94,204,95,128,98,215,101,227,101,30,103,31,103,94,103,203,104,196,104,95,106,58,107,35,108,125,108,130,108,199,109,152,115,38,116,42,116,130,116,163,116,120,117,127,117,129,120,239,120,65,121,71,121,72,121,122,121,149,123,0,125,186,125,136,127,6,128,45,128,140,128,24,138,79,139,72,140,119,141,33,147,36,147,226,152,81,153,14,154,15,154,101,154,146,158,202,125,118,79,9,84,238,98,84,104,209,145,171,85,58,81,11,249,12,249,28,90,230,97,13,249,207,98,255,98,14,249,15,249,16,249,17,249,18,249,19,249,163,144,20,249,21,249,22,249,23,249,24,249,254,138,25,249,26,249,27,249,28,249,150,102,29,249,86,113,30,249,31,249,227,150,32,249,79,99,122,99,87,83,33,249,143,103,96,105,115,110,34,249,55,117,35,249,36,249,37,249,13,125,38,249,39,249,114,136,202,86,24,90,40,249,41,249,42,249,43,249,44,249,67,78,45,249,103,81,72,89,240,103,16,128,46,249,115,89,116,94,154,100,202,121,245,95,108,96,200,98,123,99,231,91,215,91,170,82,47,249,116,89,41,95,18,96,48,249,49,249,50,249,89,116,51,249,52,249,53,249,54,249,55,249,56,249,209,153,57,249,58,249,59,249,60,249,61,249,62,249,63,249,64,249,65,249,66,249,67,249,195,111,68,249,69,249,191,129,178,143,241,96,70,249,71,249,102,129,72,249,73,249,63,92,74,249,75,249,76,249,77,249,78,249,79,249,80,249,81,249,233,90,37,138,123,103,16,125,82,249,83,249,84,249,85,249,86,249,87,249,253,128,88,249,89,249,60,92,229,108,63,83,186,110,26,89,54,131,57,78,182,78,70,79,174,85,24,87,199,88,86,95,183,101,230,101,128,106,181,107,77,110,237,119,239,122,30,124,222,125,203,134,146,136,50,145,91,147,187,100,190,111,122,115,184,117,84,144,86,85,77,87,186,97,212,100,199,102,225,109,91,110,109,111,185,111,240,117,67,128,189,129,65,133,131,137,199,138,90,139,31,147,147,108,83,117,84,123,15,142,93,144,16,85,2,88,88,88,98,94,7,98,158,100,224,104,118,117,214,124,179,135,232,158,227,78,136,87,110,87,39,89,13,92,177,92,54,94,133,95,52,98,225,100,179,115,250,129,139,136,184,140,138,150,219,158,133,91,183,95,179,96,18,80,0,82,48,82,22,87,53,88,87,88,14,92,96,92,246,92,139,93,166,94,146,95,188,96,17,99,137,99,23,100,67,104,249,104,194,106,216,109,33,110,212,110,228,111,254,113,220,118,121,119,177,121,59,122,4,132,169,137,237,140,243,141,72,142,3,144,20,144,83,144,253,144,77,147,118,150,220,151,210,107,6,112,88,114,162,114,104,115,99,119,191,121,228,123,155,126,128,139,169,88,199,96,102,101,253,101,190,102,140,108,30,113,201,113,90,140,19,152,109,78,129,122,221,78,172,81,205,81,213,82,12,84,167,97,113,103,80,104,223,104,30,109,124,111,188,117,179,119,229,122,244,128,99,132,133,146,92,81,151,101,92,103,147,103,216,117,199,122,115,131,90,249,70,140,23,144,45,152,111,92,192,129,154,130,65,144,111,144,13,146,151,95,157,93,89,106,200,113,123,118,73,123,228,133,4,139,39,145,48,154,135,85,246,97,91,249,105,118,133,127,63,134,186,135,248,136,143,144,92,249,27,109,217,112,222,115,97,125,61,132,93,249,106,145,241,153,94,249,130,78,117,83,4,107,18,107,62,112,27,114,45,134,30,158,76,82,163,143,80,93,229,100,44,101,22,107,235,111,67,124,156,126,205,133,100,137,189,137,201,98,216,129,31,136,202,94,23,103,106,109,252,114,5,116,111,116,130,135,222,144,134,79,13,93,160,95,10,132,183,81,160,99,101,117,174,78,6,80,105,81,201,81,129,104,17,106,174,124,177,124,231,124,111,130,210,138,27,143,207,145,182,79,55,81,245,82,66,84,236,94,110,97,62,98,197,101,218,106,254,111,42,121,220,133,35,136,173,149,98,154,106,154,151,158,206,158,155,82,198,102,119,107,29,112,43,121,98,143,66,151,144,97,0,98,35,101,35,111,73,113,137,116,244,125,111,128,238,132,38,143,35,144,74,147,189,81,23,82,163,82,12,109,200,112,194,136,201,94,130,101,174,107,194,111,62,124,117,115,228,78,54,79,249,86,95,249,186,92,186,93,28,96,178,115,45,123,154,127,206,127,70,128,30,144,52,146,246,150,72,151,24,152,97,159,139,79,167,111,174,121,180,145,183,150,222,82,96,249,136,100,196,100,211,106,94,111,24,112,16,114,231,118,1,128,6,134,92,134,239,141,5,143,50,151,111,155,250,157,117,158,140,120,127,121,160,125,201,131,4,147,127,158,147,158,214,138,223,88,4,95,39,103,39,112,207,116,96,124,126,128,33,81,40,112,98,114,202,120,194,140,218,140,244,140,247,150,134,78,218,80,238,91,214,94,153,101,206,113,66,118,173,119,74,128,252,132,124,144,39,155,141,159,216,88,65,90,98,92,19,106,218,109,15,111,59,118,47,125,55,126,30,133,56,137,228,147,75,150,137,82,210,101,243,103,180,105,65,109,156,110,15,112,9,116,96,116,89,117,36,118,107,120,44,139,94,152,109,81,46,98,120,150,150,79,43,80,25,93,234,109,184,125,42,143,139,95,68,97,23,104,97,249,134,150,210,82,139,128,220,81,204,81,94,105,28,122,190,125,241,131,117,150,218,79,41,82,152,83,15,84,14,85,101,92,167,96,78,103,168,104,108,109,129,114,248,114,6,116,131,116,98,249,226,117,108,124,121,127,184,127,137,131,207,136,225,136,204,145,208,145,226,150,201,155,29,84,126,111,208,113,152,116,250,133,170,142,163,150,87,156,159,158,151,103,203,109,51,116,232,129,22,151,44,120,203,122,32,123,146,124,105,100,106,116,242,117,188,120,232,120,172,153,84,155,187,158,222,91,85,94,32,111,156,129,171,131,136,144,7,78,77,83,41,90,210,93,78,95,98,97,61,99,105,102,252,102,255,110,43,111,99,112,158,119,44,132,19,133,59,136,19,143,69,153,59,156,28,85,185,98,43,103,171,108,9,131,106,137,122,151,161,78,132,89,216,95,217,95,27,103,178,125,84,127,146,130,43,131,189,131,30,143,153,144,203,87,185,89,146,90,208,91,39,102,154,103,133,104,207,107,100,113,117,127,183,140,227,140,129,144,69,155,8,129,138,140,76,150,64,154,165,158,95,91,19,108,27,115,242,118,223,118,12,132,170,81,147,137,77,81,149,81,201,82,201,104,148,108,4,119,32,119,191,125,236,125,98,151,181,158,197,110,17,133,165,81,13,84,125,84,14,102,157,102,39,105,159,110,191,118,145,119,23,131,194,132,159,135,105,145,152,146,244,156,130,136,174,79,146,81,223,82,198,89,61,94,85,97,120,100,121,100,174,102,208,103,33,106,205,107,219,107,95,114,97,114,65,116,56,119,219,119,23,128,188,130,5,131,0,139,40,139,140,140,40,103,144,108,103,114,238,118,102,119,70,122,169,157,127,107,146,108,34,89,38,103,153,132,111,83,147,88,153,89,223,94,207,99,52,102,115,103,58,110,43,115,215,122,215,130,40,147,217,82,235,93,174,97,203,97,10,98,199,98,171,100,224,101,89,105,102,107,203,107,33,113,247,115,93,117,70,126,30,130,2,131,106,133,163,138,191,140,39,151,97,157,168,88,216,158,17,80,14,82,59,84,79,85,135,101,118,108,10,125,11,125,94,128,138,134,128,149,239,150,255,82,149,108,105,114,115,84,154,90,62,92,75,93,76,95,174,95,42,103,182,104,99,105,60,110,68,110,9,119,115,124,142,127,135,133,14,139,247,143,97,151,244,158,183,92,182,96,13,97,171,97,79,101,251,101,252,101,17,108,239,108,159,115,201,115,225,125,148,149,198,91,28,135,16,139,93,82,90,83,205,98,15,100,178,100,52,103,56,106,202,108,192,115,158,116,148,123,149,124,27,126,138,129,54,130,132,133,235,143,249,150,193,153,52,79,74,83,205,83,219,83,204,98,44,100,0,101,145,101,195,105,238,108,88,111,237,115,84,117,34,118,228,118,252,118,208,120,251,120,44,121,70,125,44,130,224,135,212,143,18,152,239,152,195,82,212,98,165,100,36,110,81,111,124,118,203,141,177,145,98,146,238,154,67,155,35,80,141,80,74,87,168,89,40,92,71,94,119,95,63,98,62,101,185,101,193,101,9,102,139,103,156,105,194,110,197,120,33,125,170,128,128,129,43,130,179,130,161,132,140,134,42,138,23,139,166,144,50,150,144,159,13,80,243,79,99,249,249,87,152,95,220,98,146,99,111,103,67,110,25,113,195,118,204,128,218,128,244,136,245,136,25,137,224,140,41,143,77,145,106,150,47,79,112,79,27,94,207,103,34,104,125,118,126,118,68,155,97,94,10,106,105,113,212,113,106,117,100,249,65,126,67,133,233,133,220,152,16,79,79,123,112,127,165,149,225,81,6,94,181,104,62,108,78,108,219,108,175,114,196,123,3,131,213,108,58,116,251,80,136,82,193,88,216,100,151,106,167,116,86,118,167,120,23,134,226,149,57,151,101,249,94,83,1,95,138,139,168,143,175,143,138,144,37,82,165,119,73,156,8,159,25,78,2,80,117,81,91,92,119,94,30,102,58,102,196,103,197,104,179,112,1,117,197,117,201,121,221,122,39,143,32,153,8,154,221,79,33,88,49,88,246,91,110,102,101,107,17,109,122,110,125,111,228,115,43,117,233,131,220,136,19,137,92,139,20,143,15,79,213,80,16,83,92,83,147,91,169,95,13,103,143,121,121,129,47,131,20,133,7,137,134,137,57,143,59,143,165,153,18,156,44,103,118,78,248,79,73,89,1,92,239,92,240,92,103,99,210,104,253,112,162,113,43,116,43,126,236,132,2,135,34,144,210,146,243,156,13,78,216,78,239,79,133,80,86,82,111,82,38,84,144,84,224,87,43,89,102,90,90,91,117,91,204,91,156,94,102,249,118,98,119,101,167,101,110,109,165,110,54,114,38,123,63,124,54,127,80,129,81,129,154,129,64,130,153,130,169,131,3,138,160,140,230,140,251,140,116,141,186,141,232,144,220,145,28,150,68,150,217,153,231,156,23,83,6,82,41,84,116,86,179,88,84,89,110,89,255,95,164,97,110,98,16,102,126,108,26,113,198,118,137,124,222,124,27,125,172,130,193,140,240,150,103,249,91,79,23,95,127,95,194,98,41,93,11,103,218,104,124,120,67,126,108,157,21,78,153,80,21,83,42,83,81,83,131,89,98,90,135,94,178,96,138,97,73,98,121,98,144,101,135,103,167,105,212,107,214,107,215,107,216,107,184,108,104,249,53,116,250,117,18,120,145,120,213,121,216,121,131,124,203,125,225,127,165,128,62,129,194,129,242,131,26,135,232,136,185,138,108,139,187,140,25,145,94,151,219,152,59,159,172,86,42,91,108,95,140,101,179,106,175,107,92,109,241,111,21,112,93,114,173,115,167,140,211,140,59,152,145,97,55,108,88,128,1,154,77,78,139,78,155,78,213,78,58,79,60,79,127,79,223,79,255,80,242,83,248,83,6,85,227,85,219,86,235,88,98,89,17,90,235,91,250,91,4,92,243,93,43,94,153,95,29,96,104,99,156,101,175,101,246,103,251,103,173,104,123,107,153,108,215,108,35,110,9,112,69,115,2,120,62,121,64,121,96,121,193,121,233,123,23,125,114,125,134,128,13,130,142,131,209,132,199,134,223,136,80,138,94,138,29,139,220,140,102,141,173,143,170,144,252,152,223,153,157,158,74,82,105,249,20,103,106,249,152,80,42,82,113,92,99,101,85,108,202,115,35,117,157,117,151,123,156,132,120,145,48,151,119,78,146,100,186,107,94,113,169,133,9,78,107,249,73,103,238,104,23,110,159,130,24,133,107,136,247,99,129,111,18,146,175,152,10,78,183,80,207,80,31,81,70,85,170,85,23,86,64,91,25,92,224,92,56,94,138,94,160,94,194,94,243,96,81,104,97,106,88,110,61,114,64,114,192,114,248,118,101,121,177,123,212,127,243,136,244,137,115,138,97,140,222,140,28,151,94,88,189,116,253,140,199,85,108,249,97,122,34,125,114,130,114,114,31,117,37,117,109,249,25,123,133,88,251,88,188,93,143,94,182,94,144,95,85,96,146,98,127,99,77,101,145,102,217,102,248,102,22,104,242,104,128,114,94,116,110,123,110,125,214,125,114,127,229,128,18,130,175,133,127,137,147,138,29,144,228,146,205,158,32,159,21,89,109,89,45,94,220,96,20,102,115,102,144,103,80,108,197,109,95,111,243,119,169,120,198,132,203,145,43,147,217,78,202,80,72,81,132,85,11,91,163,91,71,98,126,101,203,101,50,110,125,113,1,116,68,116,135,116,191,116,108,118,170,121,218,125,85,126,168,127,122,129,179,129,57,130,26,134,236,135,117,138,227,141,120,144,145,146,37,148,77,153,174,155,104,83,81,92,84,105,196,108,41,109,43,110,12,130,155,133,59,137,45,138,170,138,234,150,103,159,97,82,185,102,178,107,150,126,254,135,13,141,131,149,93,150,29,101,137,109,238,113,110,249,206,87,211,89,172,91,39,96,250,96,16,98,31,102,95,102,41,115,249,115,219,118,1,119,108,123,86,128,114,128,101,129,160,138,146,145,22,78,226,82,114,107,23,109,5,122,57,123,48,125,111,249,176,140,236,83,47,86,81,88,181,91,15,92,17,92,226,93,64,98,131,99,20,100,45,102,179,104,188,108,136,109,175,110,31,112,164,112,210,113,38,117,143,117,142,117,25,118,17,123,224,123,43,124,32,125,57,125,44,133,109,133,7,134,52,138,13,144,97,144,181,144,183,146,246,151,55,154,215,79,108,92,95,103,145,109,159,124,140,126,22,139,22,141,31,144,107,91,253,93,13,100,192,132,92,144,225,152,135,115,139,91,154,96,126,103,222,109,31,138,166,138,1,144,12,152,55,82,112,249,81,112,142,120,150,147,112,136,215,145,238,79,215,83,253,85,218,86,130,87,253,88,194,90,136,91,171,92,192,92,37,94,1,97,13,98,75,98,136,99,28,100,54,101,120,101,57,106,138,107,52,108,25,109,49,111,231,113,233,114,120,115,7,116,178,116,38,118,97,119,192,121,87,122,234,122,185,124,143,125,172,125,97,126,158,127,41,129,49,131,144,132,218,132,234,133,150,136,176,138,144,139,56,143,66,144,131,144,108,145,150,146,185,146,139,150,167,150,168,150,214,150,0,151,8,152,150,153,211,154,26,155,212,83,126,88,25,89,112,91,191,91,209,109,90,111,159,113,33,116,185,116,133,128,253,131,225,93,135,95,170,95,66,96,236,101,18,104,111,105,83,106,137,107,53,109,243,109,227,115,254,118,172,119,77,123,20,125,35,129,28,130,64,131,244,132,99,133,98,138,196,138,135,145,30,147,6,152,180,153,12,98,83,136,240,143,101,146,7,93,39,93,105,93,95,116,157,129,104,135,213,111,254,98,210,127,54,137,114,137,30,78,88,78,231,80,221,82,71,83,127,98,7,102,105,126,5,136,94,150,141,79,25,83,54,86,203,89,164,90,56,92,78,92,77,92,2,94,17,95,67,96,189,101,47,102,66,102,190,103,244,103,28,115,226,119,58,121,197,127,148,132,205,132,150,137,102,138,105,138,225,138,85,140,122,140,244,87,212,91,15,95,111,96,237,98,13,105,150,107,92,110,132,113,210,123,85,135,88,139,254,142,223,152,254,152,56,79,129,79,225,79,123,84,32,90,184,91,60,97,176,101,104,102,252,113,51,117,94,121,51,125,78,129,227,129,152,131,170,133,206,133,3,135,10,138,171,142,155,143,113,249,197,143,49,89,164,91,230,91,137,96,233,91,11,92,195,95,129,108,114,249,241,109,11,112,26,117,175,130,246,138,192,78,65,83,115,249,217,150,15,108,158,78,196,79,82,81,94,85,37,90,232,92,17,98,89,114,189,130,170,131,254,134,89,136,29,138,63,150,197,150,19,153,9,157,93,157,10,88,179,92,189,93,68,94,225,96,21,97,225,99,2,106,37,110,2,145,84,147,78,152,16,156,119,159,137,91,184,92,9,99,79,102,72,104,60,119,193,150,141,151,84,152,159,155,161,101,1,139,203,142,188,149,53,85,169,92,214,93,181,94,151,102,76,118,244,131,199,149,211,88,188,98,206,114,40,157,240,78,46,89,15,96,59,102,131,107,231,121,38,157,147,83,192,84,195,87,22,93,27,97,214,102,175,109,141,120,126,130,152,150,68,151,132,83,124,98,150,99,178,109,10,126,75,129,77,152,251,106,76,127,175,157,26,158,95,78,59,80,182,81,28,89,249,96,246,99,48,105,58,114,54,128,116,249,206,145,49,95,117,249,118,249,4,125,229,130,111,132,187,132,229,133,141,142,119,249,111,79,120,249,121,249,228,88,67,91,89,96,218,99,24,101,109,101,152,102,122,249,74,105,35,106,11,109,1,112,108,113,210,117,13,118,179,121,112,122,123,249,138,127,124,249,68,137,125,249,147,139,192,145,125,150,126,249,10,153,4,87,161,95,188,101,1,111,0,118,166,121,158,138,173,153,90,155,108,159,4,81,182,97,145,98,141,106,198,129,67,80,48,88,102,95,9,113,0,138,250,138,124,91,22,134,250,79,60,81,180,86,68,89,169,99,249,109,170,93,109,105,134,81,136,78,89,79,127,249,128,249,129,249,130,89,130,249,131,249,95,107,93,108,132,249,181,116,22,121,133,249,7,130,69,130,57,131,63,143,93,143,134,249,24,153,135,249,136,249,137,249,166,78,138,249,223,87,121,95,19,102,139,249,140,249,171,117,121,126,111,139,141,249,6,144,91,154,165,86,39,88,248,89,31,90,180,91,142,249,246,94,143,249,144,249,80,99,59,99,145,249,61,105,135,108,191,108,142,109,147,109,245,109,20,111,146,249,223,112,54,113,89,113,147,249,195,113,213,113,148,249,79,120,111,120,149,249,117,123,227,125,150,249,47,126,151,249,77,136,223,142,152,249,153,249,154,249,91,146,155,249,246,156,156,249,157,249,158,249,133,96,133,109,159,249,177,113,160,249,161,249,177,149,173,83,162,249,163,249,164,249,211,103,165,249,142,112,48,113,48,116,118,130,210,130,166,249,187,149,229,154,125,158,196,102,167,249,193,113,73,132,168,249,169,249,75,88,170,249,171,249,184,93,113,95,172,249,32,102,142,102,121,105,174,105,56,108,243,108,54,110,65,111,218,111,27,112,47,112,80,113,223,113,112,115,173,249,91,116,174,249,212,116,200,118,78,122,147,126,175,249,176,249,241,130,96,138,206,143,177,249,72,147,178,249,25,151,179,249,180,249,66,78,42,80,181,249,8,82,225,83,243,102,109,108,202,111,10,115,127,119,98,122,174,130,221,133,2,134,182,249,212,136,99,138,125,139,107,140,183,249,179,146,184,249,19,151,16,152,148,78,13,79,201,79,178,80,72,83,62,84,51,84,218,85,98,88,186,88,103,89,27,90,228,91,159,96,185,249,202,97,86,101,255,101,100,102,167,104,90,108,179,111,207,112,172,113,82,115,125,123,8,135,164,138,50,156,7,159,75,92,131,108,68,115,137,115,58,146,171,110,101,116,31,118,105,122,21,126,10,134,64,81,197,88,193,100,238,116,21,117,112,118,193,127,149,144,205,150,84,153,38,110,230,116,169,122,170,122,229,129,217,134,120,135,27,138,73,90,140,91,155,91,161,104,0,105,99,109,169,115,19,116,44,116,151,120,233,125,235,127,24,129,85,129,158,131,76,140,46,150,17,152,240,102,128,95,250,101,137,103,106,108,139,115,45,80,3,90,106,107,238,119,22,89,108,93,205,93,37,115,79,117,186,249,187,249,229,80,249,81,47,88,45,89,150,89,218,89,229,91,188,249,189,249,162,93,215,98,22,100,147,100,254,100,190,249,220,102,191,249,72,106,192,249,255,113,100,116,193,249,136,122,175,122,71,126,94,126,0,128,112,129,194,249,239,135,129,137,32,139,89,144,195,249,128,144,82,153,126,97,50,107,116,109,31,126,37,137,177,143,209,79,173,80,151,81,199,82,199,87,137,88,185,91,184,94,66,97,149,105,140,109,103,110,182,110,148,113,98,116,40,117,44,117,115,128,56,131,201,132,10,142,148,147,222,147,196,249,142,78,81,79,118,80,42,81,200,83,203,83,243,83,135,91,211,91,36,92,26,97,130,97,244,101,91,114,151,115,64,116,194,118,80,121,145,121,185,121,6,125,189,127,139,130,213,133,94,134,194,143,71,144,245,144,234,145,133,150,232,150,233,150,214,82,103,95,237,101,49,102,47,104,92,113,54,122,193,144,10,152,145,78,197,249,82,106,158,107,144,111,137,113,24,128,184,130,83,133,75,144,149,150,242,150,251,151,26,133,49,155,144,78,138,113,196,150,67,81,159,83,225,84,19,87,18,87,163,87,155,90,196,90,195,91,40,96,63,97,244,99,133,108,57,109,114,110,144,110,48,114,63,115,87,116,209,130,129,136,69,143,96,144,198,249,98,150,88,152,27,157,8,103,138,141,94,146,77,79,73,80,222,80,113,83,13,87,212,89,1,90,9,92,112,97,144,102,45,110,50,114,75,116,239,125,195,128,14,132,102,132,63,133,95,135,91,136,24,137,2,139,85,144,203,151,79,155,115,78,145,79,18,81,106,81,199,249,47,85,169,85,122,91,165,91,124,94,125,94,190,94,160,96,223,96,8,97,9,97,196,99,56,101,9,103,200,249,212,103,218,103,201,249,97,105,98,105,185,108,39,109,202,249,56,110,203,249,225,111,54,115,55,115,204,249,92,116,49,117,205,249,82,118,206,249,207,249,173,125,254,129,56,132,213,136,152,138,219,138,237,138,48,142,66,142,74,144,62,144,122,144,73,145,201,145,110,147,208,249,209,249,9,88,210,249,211,107,137,128,178,128,211,249,212,249,65,81,107,89,57,92,213,249,214,249,100,111,167,115,228,128,7,141,215,249,23,146,143,149,216,249,217,249,218,249,219,249,127,128,14,98,28,112,104,125,141,135,220,249,160,87,105,96,71,97,183,107,190,138,128,146,177,150,89,78,31,84,235,109,45,133,112,150,243,151,238,152,214,99,227,108,145,144,221,81,201,97,186,129,249,157,157,79,26,80,0,81,156,91,15,97,255,97,236,100,5,105,197,107,145,117,227,119,169,127,100,130,143,133,251,135,99,136,188,138,112,139,171,145,140,78,229,78,10,79,221,249,222,249,55,89,232,89,223,249,242,93,27,95,91,95,33,96,224,249,225,249,226,249,227,249,62,114,229,115,228,249,112,117,205,117,229,249,251,121,230,249,12,128,51,128,132,128,225,130,81,131,231,249,232,249,189,140,179,140,135,144,233,249,234,249,244,152,12,153,235,249,236,249,55,112,202,118,202,127,204,127,252,127,26,139,186,78,193,78,3,82,112,83,237,249,189,84,224,86,251,89,197,91,21,95,205,95,110,110,238,249,239,249,106,125,53,131,240,249,147,134,141,138,241,249,109,151,119,151,242,249,243,249,0,78,90,79,126,79,249,88,229,101,162,110,56,144,176,147,185,153,251,78,236,88,138,89,217,89,65,96,244,249,245,249,20,122,246,249,79,131,195,140,101,81,68,83,247,249,248,249,249,249,205,78,105,82,85,91,191,130,212,78,58,82,168,84,201,89,255,89,80,91,87,91,92,91,99,96,72,97,203,110,153,112,110,113,134,115,247,116,181,117,193,120,43,125,5,128,234,129,40,131,23,133,201,133,238,138,199,140,204,150,92,79,250,82,188,86,171,101,40,102,124,112,184,112,53,114,189,125,141,130,76,145,192,150,114,157,113,91,231,104,152,107,122,111,222,118,145,92,171,102,91,111,180,123,42,124,54,136,220,150,8,78,215,78,32,83,52,88,187,88,239,88,108,89,7,92,51,94,132,94,53,95,140,99,178,102,86,103,31,106,163,106,12,107,63,111,70,114,250,249,80,115,139,116,224,122,167,124,120,129,223,129,231,129,138,131,108,132,35,133,148,133,207,133,221,136,19,141,172,145,119,149,156,150,141,81,201,84,40,87,176,91,77,98,80,103,61,104,147,104,61,110,211,110,125,112,33,126,193,136,161,140,9,143,75,159,78,159,45,114,143,123,205,138,26,147,71,79,78,79,50,81,128,84,208,89,149,94,181,98,117,103,110,105,23,106,174,108,26,110,217,114,42,115,189,117,184,123,53,125,231,130,249,131,87,132,247,133,91,138,175,140,135,142,25,144,184,144,206,150,95,159,227,82,10,84,225,90,194,91,88,100,117,101,244,110,196,114,251,249,132,118,77,122,27,123,77,124,62,126,223,127,123,131,43,139,202,140,100,141,225,141,95,142,234,143,249,143,105,144,209,147,67,79,122,79,179,80,104,81,120,81,77,82,106,82,97,88,124,88,96,89,8,92,85,92,219,94,155,96,48,98,19,104,191,107,8,108,177,111,78,113,32,116,48,117,56,117,81,117,114,118,76,123,139,123,173,123,198,123,143,126,110,138,62,143,73,143,63,146,147,146,34,147,43,148,251,150,90,152,107,152,30,153,7,82,42,98,152,98,89,109,100,118,202,122,192,123,118,125,96,83,190,92,151,94,56,111,185,112,152,124,17,151,142,155,222,158,165,99,122,100,118,135,1,78,149,78,173,78,92,80,117,80,72,84,195,89,154,91,64,94,173,94,247,94,129,95,197,96,58,99,63,101,116,101,204,101,118,102,120,102,254,103,104,105,137,106,99,107,64,108,192,109,232,109,31,110,94,110,30,112,161,112,142,115,253,115,58,117,91,119,135,120,142,121,11,122,125,122,190,124,142,125,71,130,2,138,234,138,158,140,45,145,74,145,216,145,102,146,204,146,32,147,6,151,86,151,92,151,2,152,14,159,54,82,145,82,124,85,36,88,29,94,31,95,140,96,208,99,175,104,223,111,109,121,44,123,205,129,186,133,253,136,248,138,68,142,141,145,100,150,155,150,61,151,76,152,74,159,206,79,70,81,203,81,169,82,50,86,20,95,107,95,170,99,205,100,233,101,65,102,250,102,249,102,29,103,157,104,215,104,253,105,21,111,110,111,103,113,229,113,42,114,170,116,58,119,86,121,90,121,223,121,32,122,149,122,151,124,223,124,68,125,112,126,135,128,251,133,164,134,84,138,191,138,153,141,129,142,32,144,109,144,227,145,59,150,213,150,229,156,207,101,7,124,179,141,195,147,88,91,10,92,82,83,217,98,29,115,39,80,151,91,158,95,176,96,107,97,213,104,217,109,46,116,46,122,66,125,156,125,49,126,107,129,42,142,53,142,126,147,24,148,80,79,80,87,230,93,167,94,43,99,106,127,59,78,79,79,143,79,90,80,221,89,196,128,106,84,104,84,254,85,79,89,153,91,222,93,218,94,93,102,49,103,241,103,42,104,232,108,50,109,74,110,141,111,183,112,224,115,135,117,76,124,2,125,44,125,162,125,31,130,219,134,59,138,133,138,112,141,138,142,51,143,49,144,78,145,82,145,68,148,208,153,249,122,165,124,202,79,1,81,198,81,200,87,239,91,251,92,89,102,61,106,90,109,150,110,236,111,12,113,111,117,227,122,34,136,33,144,117,144,203,150,255,153,1,131,45,78,242,78,70,136,205,145,125,83,219,106,107,105,65,108,122,132,158,88,142,97,254,102,239,98,221,112,17,117,199,117,82,126,184,132,73,139,8,141,75,78,234,83,171,84,48,87,64,87,215,95,1,99,7,99,111,100,47,101,232,101,122,102,157,103,179,103,98,107,96,108,154,108,44,111,229,119,37,120,73,121,87,121,25,125,162,128,2,129,243,129,157,130,183,130,24,135,140,138,252,249,4,141,190,141,114,144,244,118,25,122,55,122,84,126,119,128,7,85,212,85,117,88,47,99,34,100,73,102,75,102,109,104,155,105,132,107,37,109,177,110,205,115,104,116,161,116,91,117,185,117,225,118,30,119,139,119,230,121,9,126,29,126,251,129,47,133,151,136,58,138,209,140,235,142,176,143,50,144,173,147,99,150,115,150,7,151,132,79,241,83,234,89,201,90,25,94,78,104,198,116,190,117,233,121,146,122,163,129,237,134,234,140,204,141,237,143,159,101,21,103,253,249,247,87,87,111,221,125,47,143,246,147,198,150,181,95,242,97,132,111,20,78,152,79,31,80,201,83,223,85,111,93,238,93,33,107,100,107,203,120,154,123,254,249,73,142,202,142,110,144,73,99,62,100,64,119,132,122,47,147,127,148,106,159,176,100,175,111,230,113,168,116,218,116,196,122,18,124,130,126,178,124,152,126,154,139,10,141,125,148,16,153,76,153,57,82,223,91,230,100,45,103,46,125,237,80,195,83,121,88,88,97,89,97,250,97,172,101,217,122,146,139,150,139,9,80,33,80,117,82,49,85,60,90,224,94,112,95,52,97,94,101,12,102,54,102,162,102,205,105,196,110,50,111,22,115,33,118,147,122,57,129,89,130,214,131,188,132,181,80,240,87,192,91,232,91,105,95,161,99,38,120,181,125,220,131,33,133,199,145,245,145,138,81,245,103,86,123,172,140,196,81,187,89,189,96,85,134,28,80,255,249,84,82,58,92,125,97,26,98,211,98,242,100,165,101,204,110,32,118,10,129,96,142,95,150,187,150,223,78,67,83,152,85,41,89,221,93,197,100,201,108,250,109,148,115,127,122,27,130,166,133,228,140,16,142,119,144,231,145,225,149,33,150,198,151,248,81,242,84,134,85,185,95,164,100,136,111,180,125,31,143,77,143,53,148,201,80,22,92,190,108,251,109,27,117,187,119,61,124,100,124,121,138,194,138,30,88,190,89,22,94,119,99,82,114,138,117,107,119,220,138,188,140,18,143,243,94,116,102,248,109,125,128,193,131,203,138,81,151,214,155,0,250,67,82,255,102,149,109,239,110,224,125,230,138,46,144,94,144,212,154,29,82,127,82,232,84,148,97,132,98,219,98,162,104,18,105,90,105,53,106,146,112,38,113,93,120,1,121,14,121,210,121,13,122,150,128,120,130,213,130,73,131,73,133,130,140,133,141,98,145,139,145,174,145,195,79,209,86,237,113,215,119,0,135,248,137,248,91,214,95,81,103,168,144,226,83,90,88,245,91,164,96,129,97,96,100,61,126,112,128,37,133,131,146,174,100,172,80,20,93,0,103,156,88,189,98,168,99,14,105,120,105,30,106,107,110,186,118,203,121,187,130,41,132,207,138,168,141,253,143,18,145,75,145,156,145,16,147,24,147,154,147,219,150,54,154,13,156,17,78,92,117,93,121,250,122,81,123,201,123,46,126,196,132,89,142,116,142,248,142,16,144,37,102,63,105,67,116,250,81,46,103,220,158,69,81,224,95,150,108,242,135,93,136,119,136,180,96,181,129,3,132,5,141,214,83,57,84,52,86,54,90,49,92,138,112,224,127,90,128,6,129,237,129,163,141,137,145,95,154,242,157,116,80,196,78,160,83,251,96,44,110,100,92,136,79,36,80,228,85,217,92,95,94,101,96,148,104,187,108,196,109,190,113,212,117,244,117,97,118,26,122,73,122,199,125,251,125,110,127,244,129,169,134,28,143,201,150,179,153,82,159,71,82,197,82,237,152,170,137,3,78,210,103,6,111,181,79,226,91,149,103,136,108,120,109,27,116,39,120,221,145,124,147,196,135,228,121,49,122,235,95,214,78,164,84,62,85,174,88,165,89,240,96,83,98,214,98,54,103,85,105,53,130,64,150,177,153,221,153,44,80,83,83,68,85,124,87,1,250,88,98,2,250,226,100,107,102,221,103,193,111,239,111,34,116,56,116,23,138,56,148,81,84,6,86,102,87,72,95,154,97,78,107,88,112,173,112,187,125,149,138,106,89,43,129,162,99,8,119,61,128,170,140,84,88,45,100,187,105,149,91,17,94,111,110,3,250,105,133,76,81,240,83,42,89,32,96,75,97,134,107,112,108,240,108,30,123,206,128,212,130,198,141,176,144,177,152,4,250,199,100,164,111,145,100,4,101,78,81,16,84,31,87,14,138,95,97,118,104,5,250,219,117,82,123,113,125,26,144,6,88,204,105,127,129,42,137,0,144,57,152,120,80,87,89,172,89,149,98,15,144,42,155,93,97,121,114,214,149,97,87,70,90,244,93,138,98,173,100,250,100,119,103,226,108,62,109,44,114,54,116,52,120,119,127,173,130,219,141,23,152,36,82,66,87,127,103,72,114,227,116,169,140,166,143,17,146,42,150,107,81,237,83,76,99,105,79,4,85,150,96,87,101,155,108,127,109,76,114,253,114,23,122,135,137,157,140,109,95,142,111,249,112,168,129,14,97,191,79,79,80,65,98,71,114,199,123,232,125,233,127,77,144,173,151,25,154,182,140,106,87,115,94,176,103,13,132,85,138,32,84,22,91,99,94,226,94,10,95,131,101,186,128,61,133,137,149,91,150,72,79,5,83,13,83,15,83,134,84,250,84,3,87,3,94,22,96,155,98,177,98,85,99,6,250,225,108,102,109,177,117,50,120,222,128,47,129,222,130,97,132,178,132,141,136,18,137,11,144,234,146,253,152,145,155,69,94,180,102,221,102,17,112,6,114,7,250,245,79,125,82,106,95,83,97,83,103,25,106,2,111,226,116,104,121,104,136,121,140,199,152,196,152,67,154,193,84,31,122,83,105,247,138,74,140,168,152,174,153,124,95,171,98,178,117,174,118,171,136,127,144,66,150,57,83,60,95,197,95,204,108,204,115,98,117,139,117,70,123,254,130,157,153,79,78,60,144,11,78,85,79,166,83,15,89,200,94,48,102,179,108,85,116,119,131,102,135,192,140,80,144,30,151,21,156,209,88,120,91,80,134,20,139,180,157,210,91,104,96,141,96,241,101,87,108,34,111,163,111,26,112,85,127,240,127,145,149,146,149,80,150,211,151,114,82,68,143,253,81,43,84,184,84,99,85,138,85,187,106,181,109,216,125,102,130,156,146,119,150,121,158,8,84,200,84,210,118,228,134,164,149,212,149,92,150,162,78,9,79,238,89,230,90,247,93,82,96,151,98,109,103,65,104,134,108,47,110,56,127,155,128,42,130,8,250,9,250,5,152,165,78,85,80,179,84,147,87,90,89,105,91,179,91,200,97,119,105,119,109,35,112,249,135,227,137,114,138,231,138,130,144,237,153,184,154,190,82,56,104,22,80,120,94,79,103,71,131,76,136,171,78,17,84,174,86,230,115,21,145,255,151,9,153,87,153,153,153,83,86,159,88,91,134,49,138,178,97,246,106,123,115,210,142,71,107,170,150,87,154,85,89,0,114,107,141,105,151,212,79,244,92,38,95,248,97,91,102,235,108,171,112,132,115,185,115,254,115,41,119,77,119,67,125,98,125,35,126,55,130,82,136,10,250,226,140,73,146,111,152,81,91,116,122,64,136,1,152,204,90,224,79,84,83,62,89,253,92,62,99,121,109,249,114,5,129,7,129,162,131,207,146,48,152,168,78,68,81,17,82,139,87,98,95,194,108,206,110,5,112,80,112,175,112,146,113,233,115,105,116,74,131,162,135,97,136,8,144,162,144,163,147,168,153,110,81,87,95,224,96,103,97,179,102,89,133,74,142,175,145,139,151,78,78,146,78,124,84,213,88,250,88,125,89,181,92,39,95,54,98,72,98,10,102,103,102,235,107,105,109,207,109,86,110,248,110,148,111,224,111,233,111,93,112,208,114,37,116,90,116,224,116,147,118,92,121,202,124,30,126,225,128,166,130,107,132,191,132,78,134,95,134,116,135,119,139,106,140,172,147,0,152,101,152,209,96,22,98,119,145,90,90,15,102,247,109,62,110,63,116,66,155,253,95,218,96,15,123,196,84,24,95,94,108,211,108,42,109,216,112,5,125,121,134,12,138,59,157,22,83,140,84,5,91,58,106,107,112,117,117,141,121,190,121,177,130,239,131,113,138,65,139,168,140,116,151,11,250,244,100,43,101,186,120,187,120,107,122,56,78,154,85,80,89,166,91,123,94,163,96,219,99,97,107,101,102,83,104,25,110,101,113,176,116,8,125,132,144,105,154,37,156,59,109,209,110,62,115,65,140,202,149,240,81,76,94,168,95,77,96,246,96,48,97,76,97,67,102,68,102,165,105,193,108,95,110,201,110,98,111,76,113,156,116,135,118,193,123,39,124,82,131,87,135,81,144,141,150,195,158,47,83,222,86,251,94,138,95,98,96,148,96,247,97,102,102,3,103,156,106,238,109,174,111,112,112,106,115,106,126,190,129,52,131,212,134,168,138,196,140,131,82,114,115,150,91,107,106,4,148,238,84,134,86,93,91,72,101,133,101,201,102,159,104,141,109,198,109,59,114,180,128,117,145,77,154,175,79,25,80,154,83,14,84,60,84,137,85,197,85,63,94,140,95,61,103,102,113,221,115,5,144,219,82,243,82,100,88,206,88,4,113,143,113,251,113,176,133,19,138,136,102,168,133,167,85,132,102,74,113,49,132,73,83,153,85,193,107,89,95,189,95,238,99,137,102,71,113,241,138,29,143,190,158,17,79,58,100,203,112,102,117,103,134,100,96,78,139,248,157,71,81,246,81,8,83,54,109,248,128,209,158,21,102,35,107,152,112,213,117,3,84,121,92,7,125,22,138,32,107,61,107,70,107,56,84,112,96,61,109,213,127,8,130,214,80,222,81,156,85,107,86,205,86,236,89,9,91,12,94,153,97,152,97,49,98,94,102,230,102,153,113,185,113,186,113,167,114,167,121,0,122,178,127,112,138,0,0,0,0,0,0,1,0,160,0,167,0,168,0,169,0,175,0,176,0,178,0,183,0,184,0,198,0,215,0,216,0,230,0,247,0,248,0,162,0,163,0,165,0,196,0,197,0,198,0,199,0,201,0,214,0,215,0,216,0,220,0,224,0,226,0,228,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,238,0,239,0,242,0,244,0,246,0,248,0,249,0,251,0,252,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,46,1,47,1,48,1,49,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,74,1,75,1,76,1,77,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,146,1,160,1,161,1,175,1,176,1,24,2,25,2,26,2,27,2,198,2,199,2,216,2,217,2,219,2,220,2,221,2,0,3,1,3,3,3,9,3,35,3,122,3,132,3,133,3,134,3,136,3,137,3,138,3,140,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,1,4,2,4,3,4,4,4,5,4,6,4,7,4,8,4,9,4,10,4,11,4,12,4,14,4,15,4,16,4,17,4,18,4,19,4,20,4,21,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,81,4,82,4,83,4,84,4,85,4,86,4,87,4,88,4,89,4,90,4,91,4,92,4,94,4,95,4,144,4,145,4,176,5,177,5,178,5,179,5,180,5,181,5,182,5,183,5,184,5,185,5,187,5,188,5,189,5,190,5,191,5,192,5,193,5,194,5,195,5,208,5,209,5,210,5,211,5,212,5,213,5,214,5,215,5,216,5,217,5,218,5,219,5,220,5,221,5,222,5,223,5,224,5,225,5,226,5,227,5,228,5,229,5,230,5,231,5,232,5,233,5,234,5,240,5,241,5,242,5,243,5,244,5,12,6,27,6,31,6,33,6,34,6,35,6,36,6,37,6,38,6,39,6,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,48,6,49,6,50,6,51,6,52,6,53,6,54,6,55,6,56,6,57,6,58,6,64,6,65,6,66,6,67,6,68,6,69,6,70,6,71,6,72,6,73,6,74,6,75,6,76,6,77,6,78,6,79,6,80,6,81,6,82,6,121,6,126,6,134,6,136,6,145,6,152,6,169,6,175,6,186,6,190,6,193,6,210,6,1,14,2,14,3,14,4,14,5,14,6,14,7,14,8,14,9,14,10,14,11,14,12,14,13,14,14,14,15,14,16,14,17,14,18,14,19,14,20,14,21,14,22,14,23,14,24,14,25,14,26,14,27,14,28,14,29,14,30,14,31,14,32,14,33,14,34,14,35,14,36,14,37,14,38,14,39,14,40,14,41,14,42,14,43,14,44,14,45,14,46,14,47,14,48,14,49,14,50,14,51,14,52,14,53,14,54,14,55,14,56,14,57,14,58,14,63,14,64,14,65,14,66,14,67,14,68,14,69,14,70,14,71,14,72,14,73,14,74,14,75,14,76,14,77,14,78,14,79,14,80,14,81,14,82,14,83,14,84,14,85,14,86,14,87,14,88,14,89,14,90,14,91,14,2,30,3,30,10,30,11,30,30,30,31,30,64,30,65,30,86,30,87,30,96,30,97,30,106,30,107,30,128,30,129,30,130,30,131,30,132,30,133,30,242,30,243,30,12,32,13,32,14,32,15,32,19,32,20,32,21,32,23,32,24,32,25,32,26,32,28,32,29,32,30,32,32,32,33,32,34,32,38,32,48,32,57,32,58,32,170,32,171,32,172,32,175,32,167,32,22,33,34,33,25,34,26,34,72,34,100,34,101,34,32,35,33,35,0,37,2,37,12,37,16,37,20,37,24,37,28,37,36,37,44,37,52,37,60,37,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,128,37,132,37,136,37,140,37,144,37,145,37,146,37,147,37,160,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,117,110,0,77,111,110,0,84,117,101,0,87,101,100,0,84,104,117,0,70,114,105,0,83,97,116,0,83,117,110,100,97,121,0,77,111,110,100,97,121,0,84,117,101,115,100,97,121,0,87,101,100,110,101,115,100,97,121,0,84,104,117,114,115,100,97,121,0,70,114,105,100,97,121,0,83,97,116,117,114,100,97,121,0,74,97,110,0,70,101,98,0,77,97,114,0,65,112,114,0,77,97,121,0,74,117,110,0,74,117,108,0,65,117,103,0,83,101,112,0,79,99,116,0,78,111,118,0,68,101,99,0,74,97,110,117,97,114,121,0,70,101,98,114,117,97,114,121,0,77,97,114,99,104,0,65,112,114,105,108,0,77,97,121,0,74,117,110,101,0,74,117,108,121,0,65,117,103,117,115,116,0,83,101,112,116,101,109,98,101,114,0,79,99,116,111,98,101,114,0,78,111,118,101,109,98,101,114,0,68,101,99,101,109,98,101,114,0,65,77,0,80,77,0,37,97,32,37,98,32,37,101,32,37,84,32,37,89,0,37,109,47,37,100,47,37,121,0,37,72,58,37,77,58,37,83,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,37,109,47,37,100,47,37,121,0,48,49,50,51,52,53,54,55,56,57,0,37,97,32,37,98,32,37,101,32,37,84,32,37,89,0,37,72,58,37,77,58,37,83,0,0,0,0,0,94,91,121,89,93,0,94,91,110,78,93,0,121,101,115,0,110,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,16,0,0,0,28,0,0,0,72,111,115,116,32,110,111,116,32,102,111,117,110,100,0,84,114,121,32,97,103,97,105,110,0,78,111,110,45,114,101,99,111,118,101,114,97,98,108,101,32,101,114,114,111,114,0,65,100,100,114,101,115,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,15,255,50,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,11,255,35,4,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,30,2,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,255,5,5,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,3,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,10,0,0,0,1,0,0,0,2,0,0,0,28,0,0,0,86,85,114,80,109,88,68,54,113,47,110,86,83,83,112,55,112,78,68,104,67,82,57,48,55,49,73,102,73,82,101,0,85,0,105,49,68,55,48,57,118,102,97,109,117,108,105,109,108,71,99,113,48,113,113,51,85,118,117,85,97,115,118,69,97,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,0,0,0,0,0,104,112,114,79,66,110,97,101,108,111,104,101,83,114,101,100,68,121,114,99,116,98,117,111,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,0,1,54,55,56,57,58,59,60,61,62,63,64,64,64,64,64,64,64,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,64,64,64,64,64,64,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,64,64,64,64,64,46,47,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,0,0,16,0,0,0,16,0,16,0,16,0,16,0,16,0,0,16,16,0,0,16,16,0,16,16,16,0,16,16,16,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,0,0,32,0,0,0,32,0,32,0,32,0,32,0,32,0,0,32,32,0,0,32,32,0,32,32,32,0,32,32,32,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,0,0,64,0,0,0,64,0,64,0,64,0,64,0,64,0,0,64,64,0,0,64,64,0,64,64,64,0,64,64,64,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,0,0,128,0,0,0,128,0,128,0,128,0,128,0,128,0,0,128,128,0,0,128,128,0,128,128,128,0,128,128,128,0,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,0,1,0,1,0,1,0,0,1,1,0,1,1,1,0,0,0,0,1,1,0,0,1,0,1,0,1,1,1,0,1,0,0,1,1,1,0,1,1,0,1,1,1,1,1,1,1,0,0,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,0,2,0,2,0,2,0,0,2,2,0,2,2,2,0,0,0,0,2,2,0,0,2,0,2,0,2,2,2,0,2,0,0,2,2,2,0,2,2,0,2,2,2,2,2,2,2,0,0,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,0,4,0,4,0,4,0,0,4,4,0,4,4,4,0,0,0,0,4,4,0,0,4,0,4,0,4,4,4,0,4,0,0,4,4,4,0,4,4,0,4,4,4,4,4,4,4,0,0,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,0,8,0,8,0,8,0,0,8,8,0,8,8,8,0,0,0,0,8,8,0,0,8,0,8,0,8,8,8,0,8,0,0,8,8,8,0,8,8,0,8,8,8,8,8,8,8,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,16,0,0,0,16,0,0,0,16,16,0,0,16,16,0,16,0,0,0,16,0,0,0,16,0,16,0,16,0,16,0,16,16,0,0,16,16,0,0,16,16,16,0,16,16,16,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,32,0,0,0,32,0,0,0,32,32,0,0,32,32,0,32,0,0,0,32,0,0,0,32,0,32,0,32,0,32,0,32,32,0,0,32,32,0,0,32,32,32,0,32,32,32,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,64,0,0,0,64,0,0,0,64,64,0,0,64,64,0,64,0,0,0,64,0,0,0,64,0,64,0,64,0,64,0,64,64,0,0,64,64,0,0,64,64,64,0,64,64,64,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,128,0,0,0,128,0,0,0,128,128,0,0,128,128,0,128,0,0,0,128,0,0,0,128,0,128,0,128,0,128,0,128,128,0,0,128,128,0,0,128,128,128,0,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,1,0,0,0,1,0,0,0,1,1,0,0,1,1,0,1,0,0,0,1,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,0,0,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,2,0,0,0,2,0,0,0,2,2,0,0,2,2,0,2,0,0,0,2,0,0,0,2,0,2,0,2,0,2,0,2,2,0,0,2,2,0,0,2,2,2,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,4,0,0,0,4,0,0,0,4,4,0,0,4,4,0,4,0,0,0,4,0,0,0,4,0,4,0,4,0,4,0,4,4,0,0,4,4,0,0,4,4,4,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,8,0,0,0,8,0,0,0,8,8,0,0,8,8,0,8,0,0,0,8,0,0,0,8,0,8,0,8,0,8,0,8,8,0,0,8,8,0,0,8,8,8,0,8,8,8,1,1,2,2,2,2,2,2,1,2,2,2,2,2,2,1,0,0,0,0,0,0,2,0,1,0,0,0,1,0,2,0,0,0,8,0,0,0,10,0,1,0,8,0,1,0,10,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,64,0,0,0,64,16,0,0,64,0,0,0,64,16,0,0,0,0,0,0,0,0,64,0,32,0,0,0,32,0,64,0,0,128,0,0,0,128,64,0,32,128,0,0,32,128,64,0,0,0,0,0,0,0,16,0,0,8,0,0,0,8,16,0,0,0,0,0,0,0,16,0,0,8,0,0,0,8,16,0,0,0,0,0,0,0,32,0,0,0,2,0,0,0,34,0,2,0,0,0,2,0,32,0,2,0,2,0,2,0,34,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,4,0,0,0,4,0,0,0,4,0,16,0,4,0,16,0,0,0,0,0,0,64,0,0,0,8,0,0,0,72,0,0,0,0,0,0,0,64,0,0,0,8,0,0,0,72,0,0,0,0,0,0,0,0,64,0,0,128,0,0,0,128,64,0,8,0,0,0,8,0,64,0,8,128,0,0,8,128,64,0,0,0,0,0,16,0,0,0,0,64,0,0,16,64,0,0,0,0,4,0,16,0,4,0,0,64,4,0,16,64,4,0,0,1,0,0,16,1,0,0,0,65,0,0,16,65,0,0,0,1,4,0,16,1,4,0,0,65,4,0,16,65,4,0,0,0,0,0,0,0,128,0,2,0,0,0,2,0,128,0,0,2,0,0,0,2,128,0,2,2,0,0,2,2,128,0,0,0,32,0,0,0,160,0,2,0,32,0,2,0,160,0,0,2,32,0,0,2,160,0,2,2,32,0,2,2,160,0,0,0,0,0,0,32,0,0,4,0,0,0,4,32,0,0,0,4,0,0,0,36,0,0,4,4,0,0,4,36,0,0,0,0,0,0,0,32,0,0,4,0,0,0,4,32,0,0,0,4,0,0,0,36,0,0,4,4,0,0,4,36,0,0,0,0,0,0,0,0,1,0,8,0,0,0,8,0,1,0,128,0,0,0,128,0,1,0,136,0,0,0,136,0,1,0,0,0,0,0,0,0,1,0,8,0,0,0,8,0,1,0,128,0,0,0,128,0,1,0,136,0,0,0,136,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,32,0,0,0,32,0,0,128,32,0,0,128,32,0,0,1,0,0,0,1,0,0,0,129,0,0,0,129,0,0,0,1,32,0,0,1,32,0,0,129,32,0,0,129,32,0,0,0,0,0,0,16,0,0,0,0,0,128,0,16,0,128,0,0,0,1,0,16,0,1,0,0,0,129,0,16,0,129,0,0,2,0,0,16,2,0,0,0,2,128,0,16,2,128,0,0,2,1,0,16,2,1,0,0,2,129,0,16,2,129,0,0,0,0,0,0,4,0,0,0,16,0,0,0,20,0,0,0,0,8,0,0,4,8,0,0,16,8,0,0,20,8,0,32,0,0,0,32,4,0,0,32,16,0,0,32,20,0,0,32,0,8,0,32,4,8,0,32,16,8,0,32,20,8,0,0,0,0,0,0,1,0,0,0,0,4,0,0,1,4,0,0,0,0,0,0,1,0,0,0,0,4,0,0,1,4,0,64,0,0,0,64,1,0,0,64,0,4,0,64,1,4,0,64,0,0,0,64,1,0,0,64,0,4,0,64,1,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,0,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,0,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,0,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,0,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,0,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,0,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,0,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,0,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,0,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,0,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,0,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,0,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,0,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,0,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,0,130,128,0,0,0,0,0,0,128,0,0,2,130,128,0,2,128,128,0,2,130,0,0,2,0,0,0,0,128,0,0,0,2,0,0,0,130,128,0,2,130,128,0,0,2,0,0,2,2,128,0,2,128,128,0,0,0,128,0,2,0,0,0,2,2,0,0,0,2,128,0,0,2,128,0,0,130,0,0,0,130,0,0,0,128,128,0,0,128,128,0,2,2,128,0,2,128,0,0,2,0,128,0,2,0,128,0,2,128,0,0,0,0,0,0,2,2,0,0,2,130,0,0,0,0,128,0,0,128,0,0,2,130,128,0,2,0,0,0,0,128,128,0,0,130,128,0,0,0,128,0,0,0,128,0,0,2,0,0,2,128,128,0,0,128,0,0,0,130,0,0,2,0,128,0,0,2,0,0,2,0,0,0,2,2,128,0,2,130,0,0,2,130,128,0,2,128,0,0,0,128,128,0,2,2,128,0,2,0,128,0,2,2,0,0,2,130,0,0,0,130,128,0,2,2,0,0,0,2,128,0,0,2,128,0,0,0,0,0,2,128,0,0,0,130,0,0,0,0,0,0,2,128,128,0,16,64,8,64,0,64,0,64,0,64,0,0,16,64,8,0,0,0,8,0,16,0,0,0,16,0,8,64,16,64,0,64,16,0,0,64,16,64,8,64,0,64,8,64,0,0,0,64,0,64,0,64,0,0,8,0,16,0,0,0,16,0,8,64,0,64,8,0,16,0,8,0,16,64,0,64,0,0,0,0,0,0,0,64,0,64,0,0,16,64,8,0,0,0,8,64,16,0,8,0,16,0,0,64,0,0,0,0,0,64,8,0,16,64,0,0,0,64,8,64,0,0,8,64,16,64,0,0,0,0,0,0,16,64,8,0,16,0,8,64,0,0,8,0,16,64,0,64,0,0,8,64,0,64,8,64,0,64,0,0,0,0,8,64,0,64,0,64,16,0,0,0,16,64,8,64,16,64,8,0,16,0,0,0,0,64,0,0,0,0,0,64,16,64,0,0,0,64,8,64,0,0,8,0,16,0,0,64,16,0,8,0,16,64,0,64,16,0,0,64,16,0,8,0,0,64,8,0,0,0,0,0,0,64,0,64,16,64,0,0,0,0,0,64,16,0,8,64,16,64,8,64,0,64,8,0,4,1,0,0,0,1,1,4,0,0,0,0,4,0,1,4,0,1,0,4,0,0,0,0,4,1,1,0,0,1,0,4,4,0,1,0,4,0,0,4,4,0,0,4,0,0,1,0,4,1,1,4,4,0,1,0,0,0,1,4,4,1,0,0,0,0,0,4,4,0,0,0,0,1,1,4,0,1,0,0,0,1,1,0,0,0,1,4,4,0,1,4,4,1,1,0,4,1,0,4,0,1,1,0,0,0,1,0,4,1,0,4,4,0,0,0,4,1,1,4,0,1,0,0,0,0,0,4,0,1,1,4,0,0,0,4,4,0,1,0,4,1,0,0,0,0,1,0,0,1,1,4,0,1,0,4,0,0,0,0,0,1,0,0,4,0,1,0,4,1,1,4,0,1,0,4,4,0,0,4,0,1,0,0,0,0,0,0,4,0,1,4,4,1,0,4,0,0,1,0,0,0,0,4,4,1,1,4,4,0,0,0,4,1,1,0,0,1,1,0,4,0,0,4,0,0,1,4,4,1,0,4,4,1,0,0,0,0,1,4,4,1,1,0,4,0,0,0,4,0,1,4,0,1,1,0,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,0,64,0,64,128,0,0,64,128,0,16,0,128,0,0,0,0,0,16,64,0,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,64,0,64,0,0,0,64,128,0,0,0,128,0,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,128,64,16,0,0,64,0,64,128,0,0,0,128,64,16,0,0,64,0,64,0,0,16,0,0,64,16,64,0,64,16,64,128,64,0,0,128,64,0,64,0,0,0,64,128,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,0,0,0,0,0,16,64,0,64,16,0,0,64,0,64,0,64,0,64,128,0,0,0,128,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,128,64,0,0,128,0,0,0,128,0,16,0,0,0,0,64,128,0,16,0,128,64,16,64,0,64,0,64,128,0,16,0,128,64,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,0,64,16,64,0,128,0,0,0,128,0,4,1,0,0,4,1,128,0,0,33,0,0,4,0,128,0,0,0,0,0,0,32,0,0,4,1,128,0,4,32,0,0,4,0,128,0,0,1,128,0,4,32,128,0,0,33,0,0,4,33,128,0,4,0,0,0,0,32,0,0,0,1,0,0,4,32,0,0,4,32,0,0,0,0,128,0,0,32,128,0,4,33,128,0,4,33,128,0,0,1,0,0,4,33,128,0,0,32,0,0,0,0,0,0,0,33,128,0,4,1,0,0,0,1,0,0,0,33,128,0,4,0,0,0,4,0,128,0,0,33,128,0,0,0,0,0,0,1,0,0,0,32,0,0,4,1,128,0,0,33,128,0,4,32,128,0,0,1,0,0,0,32,0,0,4,33,128,0,4,1,128,0,4,32,128,0,0,0,0,0,0,1,0,0,4,33,128,0,4,33,128,0,4,0,0,0,0,33,128,0,4,33,0,0,4,1,0,0,0,0,0,0,4,32,0,0,0,33,128,0,4,0,128,0,0,1,128,0,0,32,0,0,4,0,0,0,0,0,0,0,4,32,128,0,4,1,128,0,0,32,8,0,0,16,0,0,32,16,0,32,0,0,8,32,32,16,0,0,32,16,8,0,0,0,8,32,32,16,0,0,32,0,0,32,0,16,8,32,32,0,0,0,32,0,8,0,0,16,8,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,0,0,0,0,8,0,32,0,8,32,0,16,0,32,0,0,0,32,32,0,8,32,0,16,8,0,0,0,8,0,32,16,8,0,32,16,0,0,0,0,8,32,32,0,0,32,32,16,8,32,0,0,0,32,32,0,0,32,32,16,0,0,0,16,0,32,0,16,8,0,0,0,8,0,32,16,0,32,32,0,8,32,32,16,0,0,32,0,8,32,0,0,8,0,0,16,0,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,8,0,0,16,8,32,32,16,0,32,32,0,0,0,32,16,8,32,32,0,0,32,32,16,0,0,0,0,8,0,32,16,8,0,0,0,0,32,0,0,0,0,32,16,8,32,32,0,0,32,0,0,8,0,32,0,8,32,0,16,0,0,0,0,0,32,32,16,0,0,0,16,8,0,32,0,8,32,0,16,0,0,16,0,1,0,16,2,1,4,0,2,0,0,0,0,0,4,0,0,1,4,0,2,1,4,16,0,0,4,16,2,1,4,16,2,0,0,16,0,0,0,0,0,1,0,0,2,1,0,0,0,0,0,0,2,1,0,16,2,1,4,0,0,0,4,0,2,1,4,16,0,1,0,16,0,0,4,0,2,1,0,0,2,0,0,16,2,0,4,16,2,1,0,16,0,0,0,16,2,0,4,0,0,1,4,0,0,1,4,16,2,0,4,16,0,1,0,0,0,0,0,0,2,0,4,16,0,0,0,0,2,0,4,16,0,0,0,16,0,1,4,0,2,1,4,0,2,1,0,16,2,1,0,16,2,1,0,0,0,1,0,16,0,0,0,0,2,0,4,0,2,0,0,16,0,0,4,16,2,1,4,0,0,1,4,16,0,0,4,16,2,1,4,0,0,1,0,0,2,1,4,16,2,0,0,16,2,0,4,16,0,0,0,0,0,1,0,0,0,1,4,16,2,0,0,0,0,1,4,16,0,0,0,16,2,0,4,0,0,1,0,0,2,0,4,0,2,0,4,0,0,1,0,16,0,32,8,0,8,0,8,0,0,0,0,2,0,32,8,2,8,0,0,0,8,32,8,0,8,32,0,0,0,0,0,0,8,32,0,2,0,0,0,2,8,32,8,2,8,0,8,2,0,0,8,2,8,32,8,2,0,0,8,0,0,32,0,0,0,0,0,2,8,32,0,0,8,0,8,0,8,32,8,0,0,0,8,2,0,32,0,2,0,32,0,2,8,0,8,2,8,32,8,0,0,0,0,0,0,0,0,0,0,32,0,2,8,32,0,0,8,0,8,0,8,32,8,2,0,0,0,2,0,32,8,2,0,0,0,2,0,0,8,2,8,0,8,0,0,32,0,0,0,32,0,2,8,0,8,0,0,32,8,2,0,0,8,0,8,32,0,0,0,32,0,0,8,0,0,2,8,32,0,2,8,0,0,0,8,0,0,2,0,32,8,0,8,0,0,0,0,32,8,2,8,32,0,2,0,32,0,0,8,0,0,2,8,0,8,0,8,32,8,0,8,0,0,0,0,32,8,2,8,0,8,2,0,0,8,2,0,32,8,0,0,32,8,0,0,32,0,2,0,0,0,0,8,0,8,2,8,0,0,0,0,0,0,0,64,0,0,64,0,0,0,64,64,0,64,0,0,0,64,0,64,0,64,64,0,0,64,64,64,64,0,0,0,64,0,0,64,64,0,64,0,64,0,64,64,64,64,0,0,64,64,0,64,64,64,64,0,64,64,64,64,0,0,0,0,0,0,0,16,0,0,16,0,0,0,16,16,0,16,0,0,0,16,0,16,0,16,16,0,0,16,16,16,16,0,0,0,16,0,0,16,16,0,16,0,16,0,16,16,16,16,0,0,16,16,0,16,16,16,16,0,16,16,16,16,0,0,0,0,0,0,0,4,0,0,4,0,0,0,4,4,0,4,0,0,0,4,0,4,0,4,4,0,0,4,4,4,4,0,0,0,4,0,0,4,4,0,4,0,4,0,4,4,4,4,0,0,4,4,0,4,4,4,4,0,4,4,4,4,0,0,0,0,0,0,0,1,0,0,1,0,0,0,1,1,0,1,0,0,0,1,0,1,0,1,1,0,0,1,1,1,1,0,0,0,1,0,0,1,1,0,1,0,1,0,1,1,1,1,0,0,1,1,0,1,1,1,1,0,1,1,1,1,0,0,0,0,0,0,0,128,0,0,128,0,0,0,128,128,0,128,0,0,0,128,0,128,0,128,128,0,0,128,128,128,128,0,0,0,128,0,0,128,128,0,128,0,128,0,128,128,128,128,0,0,128,128,0,128,128,128,128,0,128,128,128,128,0,0,0,0,0,0,0,32,0,0,32,0,0,0,32,32,0,32,0,0,0,32,0,32,0,32,32,0,0,32,32,32,32,0,0,0,32,0,0,32,32,0,32,0,32,0,32,32,32,32,0,0,32,32,0,32,32,32,32,0,32,32,32,32,0,0,0,0,0,0,0,8,0,0,8,0,0,0,8,8,0,8,0,0,0,8,0,8,0,8,8,0,0,8,8,8,8,0,0,0,8,0,0,8,8,0,8,0,8,0,8,8,8,8,0,0,8,8,0,8,8,8,8,0,8,8,8,8,0,0,0,0,0,0,0,2,0,0,2,0,0,0,2,2,0,2,0,0,0,2,0,2,0,2,2,0,0,2,2,2,2,0,0,0,2,0,0,2,2,0,2,0,2,0,2,2,2,2,0,0,2,2,0,2,2,2,2,0,2,2,2,2,88,121,48,49,64,35,1,2,128,127,255,13,10,129,9,32,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,53,36,114,111,117,110,100,115,61,49,50,51,52,36,97,98,99,48,49,50,51,52,53,54,55,56,57,36,0,0,0,36,53,36,114,111,117,110,100,115,61,49,50,51,52,36,97,98,99,48,49,50,51,52,53,54,55,56,57,36,51,86,102,68,106,80,116,48,53,86,72,70,110,52,55,67,47,111,106,70,90,54,75,82,80,89,114,79,106,106,49,108,76,98,72,46,100,107,70,51,98,90,54,0,0,0,0,0,0,0,0,0,10,20,21,1,11,12,22,2,3,13,23,24,4,14,15,25,5,6,16,26,27,7,17,18,28,8,9,19,29,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,88,121,48,49,64,35,1,2,128,127,255,13,10,129,9,32,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,36,114,111,117,110,100,115,61,49,50,51,52,36,97,98,99,48,49,50,51,52,53,54,55,56,57,36,0,0,0,36,54,36,114,111,117,110,100,115,61,49,50,51,52,36,97,98,99,48,49,50,51,52,53,54,55,56,57,36,66,67,112,116,56,122,76,114,99,47,82,99,121,117,88,109,67,68,79,69,49,65,76,113,77,88,66,50,77,72,54,110,49,103,56,57,49,72,104,70,106,56,46,119,55,76,120,71,118,46,70,84,107,113,113,54,86,120,99,47,107,109,51,89,48,106,69,48,106,50,52,106,89,53,80,73,118,47,111,79,117,54,114,101,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,22,43,1,44,2,23,3,24,45,25,46,4,47,5,26,6,27,48,28,49,7,50,8,29,9,30,51,31,52,10,53,11,32,12,33,54,34,55,13,56,14,35,15,36,57,37,58,16,59,17,38,18,39,60,40,61,19,62,20,41,0,34,174,40,215,152,47,138,66,205,101,239,35,145,68,55,113,47,59,77,236,207,251,192,181,188,219,137,129,165,219,181,233,56,181,72,243,91,194,86,57,25,208,5,182,241,17,241,89,155,79,25,175,164,130,63,146,24,129,109,218,213,94,28,171,66,2,3,163,152,170,7,216,190,111,112,69,1,91,131,18,140,178,228,78,190,133,49,36,226,180,255,213,195,125,12,85,111,137,123,242,116,93,190,114,177,150,22,59,254,177,222,128,53,18,199,37,167,6,220,155,148,38,105,207,116,241,155,193,210,74,241,158,193,105,155,228,227,37,79,56,134,71,190,239,181,213,140,139,198,157,193,15,101,156,172,119,204,161,12,36,117,2,43,89,111,44,233,45,131,228,166,110,170,132,116,74,212,251,65,189,220,169,176,92,181,83,17,131,218,136,249,118,171,223,102,238,82,81,62,152,16,50,180,45,109,198,49,168,63,33,251,152,200,39,3,176,228,14,239,190,199,127,89,191,194,143,168,61,243,11,224,198,37,167,10,147,71,145,167,213,111,130,3,224,81,99,202,6,112,110,14,10,103,41,41,20,252,47,210,70,133,10,183,39,38,201,38,92,56,33,27,46,237,42,196,90,252,109,44,77,223,179,149,157,19,13,56,83,222,99,175,139,84,115,10,101,168,178,119,60,187,10,106,118,230,174,237,71,46,201,194,129,59,53,130,20,133,44,114,146,100,3,241,76,161,232,191,162,1,48,66,188,75,102,26,168,145,151,248,208,112,139,75,194,48,190,84,6,163,81,108,199,24,82,239,214,25,232,146,209,16,169,101,85,36,6,153,214,42,32,113,87,133,53,14,244,184,209,187,50,112,160,106,16,200,208,210,184,22,193,164,25,83,171,65,81,8,108,55,30,153,235,142,223,76,119,72,39,168,72,155,225,181,188,176,52,99,90,201,197,179,12,28,57,203,138,65,227,74,170,216,78,115,227,99,119,79,202,156,91,163,184,178,214,243,111,46,104,252,178,239,93,238,130,143,116,96,47,23,67,111,99,165,120,114,171,240,161,20,120,200,132,236,57,100,26,8,2,199,140,40,30,99,35,250,255,190,144,233,189,130,222,235,108,80,164,21,121,198,178,247,163,249,190,43,83,114,227,242,120,113,198,156,97,38,234,206,62,39,202,7,194,192,33,199,184,134,209,30,235,224,205,214,125,218,234,120,209,110,238,127,79,125,245,186,111,23,114,170,103,240,6,166,152,200,162,197,125,99,10,174,13,249,190,4,152,63,17,27,71,28,19,53,11,113,27,132,125,4,35,245,119,219,40,147,36,199,64,123,171,202,50,188,190,201,21,10,190,158,60,76,13,16,156,196,103,29,67,182,66,62,203,190,212,197,76,42,126,101,252,156,41,127,89,236,250,214,58,171,111,203,95,23,88,71,74,140,25,68,108,88,121,48,49,64,35,1,2,128,127,255,13,10,129,9,32,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,49,36,97,98,99,100,48,49,50,51,36,57,81,99,103,56,68,121,118,105,101,107,86,51,116,68,71,77,90,121,110,74,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,47,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,164,106,215,86,183,199,232,219,112,32,36,238,206,189,193,175,15,124,245,42,198,135,71,19,70,48,168,1,149,70,253,216,152,128,105,175,247,68,139,177,91,255,255,190,215,92,137,34,17,144,107,147,113,152,253,142,67,121,166,33,8,180,73,98,37,30,246,64,179,64,192,81,90,94,38,170,199,182,233,93,16,47,214,83,20,68,2,129,230,161,216,200,251,211,231,230,205,225,33,214,7,55,195,135,13,213,244,237,20,90,69,5,233,227,169,248,163,239,252,217,2,111,103,138,76,42,141,66,57,250,255,129,246,113,135,34,97,157,109,12,56,229,253,68,234,190,164,169,207,222,75,96,75,187,246,112,188,191,190,198,126,155,40,250,39,161,234,133,48,239,212,5,29,136,4,57,208,212,217,229,153,219,230,248,124,162,31,101,86,172,196,68,34,41,244,151,255,42,67,167,35,148,171,57,160,147,252,195,89,91,101,146,204,12,143,125,244,239,255,209,93,132,133,79,126,168,111,224,230,44,254,20,67,1,163,161,17,8,78,130,126,83,247,53,242,58,189,187,210,215,42,145,211,134,235,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,10,10,0,0,0,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,76,0,0,106,76,76,76,0,106,0,0,0,0,0,106,106,0,0,0,0,106,0,0,106,0,0,0,0,0,0,0,0,104,104,0,104,0,0,0,0,0,108,0,0,76,0,0,108,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,116,109,112,47,116,109,112,102,105,108,101,95,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,47,116,109,112,47,116,109,112,110,97,109,95,88,88,88,88,88,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,32,101,114,114,111,114,0,78,111,32,109,97,116,99,104,0,73,110,118,97,108,105,100,32,114,101,103,101,120,112,0,85,110,107,110,111,119,110,32,99,111,108,108,97,116,105,110,103,32,101,108,101,109,101,110,116,0,85,110,107,110,111,119,110,32,99,104,97,114,97,99,116,101,114,32,99,108,97,115,115,32,110,97,109,101,0,84,114,97,105,108,105,110,103,32,98,97,99,107,115,108,97,115,104,0,73,110,118,97,108,105,100,32,98,97,99,107,32,114,101,102,101,114,101,110,99,101,0,77,105,115,115,105,110,103,32,39,93,39,0,77,105,115,115,105,110,103,32,39,41,39,0,77,105,115,115,105,110,103,32,39,125,39,0,73,110,118,97,108,105,100,32,99,111,110,116,101,110,116,115,32,111,102,32,123,125,0,73,110,118,97,108,105,100,32,99,104,97,114,97,99,116,101,114,32,114,97,110,103,101,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,82,101,112,101,116,105,116,105,111,110,32,110,111,116,32,112,114,101,99,101,100,101,100,32,98,121,32,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,0,0,0,116,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,87,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,83,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,115,105,103,110,97,108,0,72,97,110,103,117,112,0,73,110,116,101,114,114,117,112,116,0,81,117,105,116,0,73,108,108,101,103,97,108,32,105,110,115,116,114,117,99,116,105,111,110,0,84,114,97,99,101,47,98,114,101,97,107,112,111,105,110,116,32,116,114,97,112,0,65,98,111,114,116,101,100,0,66,117,115,32,101,114,114,111,114,0,65,114,105,116,104,109,101,116,105,99,32,101,120,99,101,112,116,105,111,110,0,75,105,108,108,101,100,0,85,115,101,114,32,100,101,102,105,110,101,100,32,115,105,103,110,97,108,32,49,0,83,101,103,109,101,110,116,97,116,105,111,110,32,102,97,117,108,116,0,85,115,101,114,32,100,101,102,105,110,101,100,32,115,105,103,110,97,108,32,50,0,66,114,111,107,101,110,32,112,105,112,101,0,65,108,97,114,109,32,99,108,111,99,107,0,84,101,114,109,105,110,97,116,101,100,0,83,116,97,99,107,32,102,97,117,108,116,0,67,104,105,108,100,32,112,114,111,99,101,115,115,32,115,116,97,116,117,115,0,67,111,110,116,105,110,117,101,100,0,83,116,111,112,112,101,100,32,40,115,105,103,110,97,108,41,0,83,116,111,112,112,101,100,0,83,116,111,112,112,101,100,32,40,116,116,121,32,105,110,112,117,116,41,0,83,116,111,112,112,101,100,32,40,116,116,121,32,111,117,116,112,117,116,41,0,85,114,103,101,110,116,32,73,47,79,32,99,111,110,100,105,116,105,111,110,0,67,80,85,32,116,105,109,101,32,108,105,109,105,116,32,101,120,99,101,101,100,101,100,0,70,105,108,101,32,115,105,122,101,32,108,105,109,105,116,32,101,120,99,101,101,100,101,100,0,86,105,114,116,117,97,108,32,116,105,109,101,114,32,101,120,112,105,114,101,100,0,80,114,111,102,105,108,105,110,103,32,116,105,109,101,114,32,101,120,112,105,114,101,100,0,87,105,110,100,111,119,32,99,104,97,110,103,101,100,0,73,47,79,32,112,111,115,115,105,98,108,101,0,80,111,119,101,114,32,102,97,105,108,117,114,101,0,66,97,100,32,115,121,115,116,101,109,32,99,97,108,108,0,82,84,51,50,0,82,84,51,51,0,82,84,51,52,0,82,84,51,53,0,82,84,51,54,0,82,84,51,55,0,82,84,51,56,0,82,84,51,57,0,82,84,52,48,0,82,84,52,49,0,82,84,52,50,0,82,84,52,51,0,82,84,52,52,0,82,84,52,53,0,82,84,52,54,0,82,84,52,55,0,82,84,52,56,0,82,84,52,57,0,82,84,53,48,0,82,84,53,49,0,82,84,53,50,0,82,84,53,51,0,82,84,53,52,0,82,84,53,53,0,82,84,53,54,0,82,84,53,55,0,82,84,53,56,0,82,84,53,57,0,82,84,54,48,0,82,84,54,49,0,82,84,54,50,0,82,84,54,51,0,82,84,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,18,19,20,21,22,23,24,25,26,27,28,29,30,31,16,16,32,16,16,16,33,34,35,36,37,38,39,16,16,40,16,16,16,16,16,16,16,16,16,16,16,41,42,16,16,43,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,44,16,45,46,47,48,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,49,16,16,50,51,16,52,16,16,16,16,16,16,16,16,53,16,16,16,16,16,54,55,16,16,16,16,56,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,57,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,58,59,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,255,191,182,0,0,0,0,0,0,0,31,0,255,7,0,0,0,0,0,248,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,192,191,159,61,0,0,0,128,2,0,0,0,255,255,255,7,0,0,0,0,0,0,0,0,0,0,192,255,1,0,0,0,0,0,0,248,15,0,0,0,192,251,239,62,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,127,7,0,0,0,0,0,0,20,254,33,254,0,12,0,0,0,2,0,0,0,0,0,0,16,30,32,0,0,12,0,0,0,6,0,0,0,0,0,0,16,134,57,2,0,0,0,35,0,6,0,0,0,0,0,0,16,190,33,0,0,12,0,0,0,2,0,0,0,0,0,0,144,30,32,64,0,12,0,0,0,4,0,0,0,0,0,0,0,1,32,0,0,0,0,0,0,0,0,0,0,0,0,0,192,193,61,96,0,12,0,0,0,0,0,0,0,0,0,0,144,64,48,0,0,12,0,0,0,0,0,0,0,0,0,0,0,30,32,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,4,92,0,0,0,0,0,0,0,0,0,0,0,242,7,128,127,0,0,0,0,0,0,0,0,0,0,0,0,242,27,0,63,0,0,0,0,0,0,0,0,0,3,0,0,160,2,0,0,0,0,0,0,254,127,223,224,255,254,255,255,255,31,64,0,0,0,0,0,0,0,0,0,0,0,0,224,253,102,0,0,0,195,1,0,30,0,100,32,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,28,0,0,0,12,0,0,0,12,0,0,0,0,0,0,0,176,63,64,254,15,32,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,1,4,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,64,127,229,31,248,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,208,23,4,0,0,0,0,248,15,0,3,0,0,0,60,11,0,0,0,0,0,0,64,163,3,0,0,0,0,0,0,240,207,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,255,253,33,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,127,0,0,240,0,248,0,0,0,124,0,0,0,0,0,0,31,252,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,247,63,0,0,0,128,0,0,0,0,0,0,0,0,0,0,3,0,68,8,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,255,255,3,0,0,0,0,0,192,63,0,0,128,255,3,0,0,0,0,0,7,0,0,0,0,0,200,19,0,0,0,0,0,0,0,0,0,0,0,0,0,126,102,0,8,16,0,0,0,0,0,0,0,0,0,0,0,0,157,193,2,0,0,0,0,48,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,33,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,110,240,0,0,0,0,0,135,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,255,127,0,0,0,0,0,0,0,3,0,0,0,0,0,120,38,0,0,0,0,0,0,0,0,7,0,0,0,128,239,31,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,192,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,248,255,231,15,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,18,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,19,16,16,16,16,16,16,16,16,16,16,20,21,22,23,24,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,25,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,26,16,16,16,16,27,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,28,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,16,16,16,29,30,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,31,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,251,255,255,255,255,255,255,255,255,255,255,15,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,255,15,255,255,255,255,255,255,255,127,254,255,255,255,255,255,255,255,255,255,127,254,255,255,255,255,255,255,255,255,255,255,255,255,224,255,255,255,255,63,254,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,7,255,255,255,255,15,0,255,255,255,255,255,127,255,255,255,255,255,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,255,127,248,255,255,255,255,255,15,0,0,255,3,0,0,255,255,255,255,247,255,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,255,255,255,255,255,7,255,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,32,2,32,2,32,2,32,2,32,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,96,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,4,192,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,8,216,4,192,4,192,4,192,4,192,4,192,4,192,4,192,8,213,8,213,8,213,8,213,8,213,8,213,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,8,197,4,192,4,192,4,192,4,192,4,192,4,192,8,214,8,214,8,214,8,214,8,214,8,214,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,8,198,4,192,4,192,4,192,4,192,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,67,46,85,84,70,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,127,127,127,127,127,127,127,127,127,127,127,0,0,136,106,63,36,211,8,163,133,46,138,25,19,68,115,112,3,34,56,9,164,208,49,159,41,152,250,46,8,137,108,78,236,230,33,40,69,119,19,208,56,207,102,84,190,108,12,233,52,183,41,172,192,221,80,124,201,181,213,132,63,23,9,71,181,217,213,22,146,27,251,121,137,166,11,49,209,172,181,223,152,219,114,253,47,183,223,26,208,237,175,225,184,150,126,38,106,69,144,124,186,153,127,44,241,71,153,161,36,247,108,145,179,226,242,1,8,22,252,142,133,216,32,105,99,105,78,87,113,163,254,88,164,126,61,147,244,143,116,149,13,88,182,142,114,88,205,139,113,238,74,21,130,29,164,84,123,181,89,90,194,57,213,48,156,19,96,242,42,35,176,209,197,240,133,96,40,24,121,65,202,239,56,219,184,176,220,121,142,14,24,58,96,139,14,158,108,62,138,30,176,193,119,21,215,39,75,49,189,218,47,175,120,96,92,96,85,243,37,85,230,148,171,85,170,98,152,72,87,64,20,232,99,106,57,202,85,182,16,171,42,52,92,204,180,206,232,65,17,175,134,84,161,147,233,114,124,17,20,238,179,42,188,111,99,93,197,169,43,246,49,24,116,22,62,92,206,30,147,135,155,51,186,214,175,92,207,36,108,129,83,50,122,119,134,149,40,152,72,143,59,175,185,75,107,27,232,191,196,147,33,40,102,204,9,216,97,145,169,33,251,96,172,124,72,50,128,236,93,93,93,132,239,177,117,133,233,2,35,38,220,136,27,101,235,129,62,137,35,197,172,150,211,243,111,109,15,57,66,244,131,130,68,11,46,4,32,132,164,74,240,200,105,94,155,31,158,66,104,198,33,154,108,233,246,97,156,12,103,240,136,211,171,210,160,81,106,104,47,84,216,40,167,15,150,163,51,81,171,108,11,239,110,228,59,122,19,80,240,59,186,152,42,251,126,29,101,241,161,118,1,175,57,62,89,202,102,136,14,67,130,25,134,238,140,180,159,111,69,195,165,132,125,190,94,139,59,216,117,111,224,115,32,193,133,159,68,26,64,166,106,193,86,98,170,211,78,6,119,63,54,114,223,254,27,61,2,155,66,36,215,208,55,72,18,10,208,211,234,15,219,155,192,241,73,201,114,83,7,123,27,153,128,216,121,212,37,247,222,232,246,26,80,254,227,59,76,121,182,189,224,108,151,186,6,192,4,182,79,169,193,196,96,159,64,194,158,92,94,99,36,106,25,175,111,251,104,181,83,108,62,235,178,57,19,111,236,82,59,31,81,252,109,44,149,48,155,68,69,129,204,9,189,94,175,4,208,227,190,253,74,51,222,7,40,15,102,179,75,46,25,87,168,203,192,15,116,200,69,57,95,11,210,219,251,211,185,189,192,121,85,10,50,96,26,198,0,161,214,121,114,44,64,254,37,159,103,204,163,31,251,248,233,165,142,248,34,50,219,223,22,117,60,21,107,97,253,200,30,80,47,171,82,5,173,250,181,61,50,96,135,35,253,72,123,49,83,130,223,0,62,187,87,92,158,160,140,111,202,46,86,135,26,219,105,23,223,246,168,66,213,195,255,126,40,198,50,103,172,115,85,79,140,176,39,91,105,200,88,202,187,93,163,255,225,160,17,240,184,152,61,250,16,184,131,33,253,108,181,252,74,91,211,209,45,121,228,83,154,101,69,248,182,188,73,142,210,144,151,251,75,218,242,221,225,51,126,203,164,65,19,251,98,232,198,228,206,218,202,32,239,1,76,119,54,254,158,126,208,180,31,241,43,77,218,219,149,152,145,144,174,113,142,173,234,160,213,147,107,208,209,142,208,224,37,199,175,47,91,60,142,183,148,117,142,251,226,246,143,100,43,18,242,18,184,136,136,28,240,13,144,160,94,173,79,28,195,143,104,145,241,207,209,173,193,168,179,24,34,47,47,119,23,14,190,254,45,117,234,161,31,2,139,15,204,160,229,232,116,111,181,214,243,172,24,153,226,137,206,224,79,168,180,183,224,19,253,129,59,196,124,217,168,173,210,102,162,95,22,5,119,149,128,20,115,204,147,119,20,26,33,101,32,173,230,134,250,181,119,245,66,84,199,207,53,157,251,12,175,205,235,160,137,62,123,211,27,65,214,73,126,30,174,45,14,37,0,94,179,113,32,187,0,104,34,175,224,184,87,155,54,100,36,30,185,9,240,29,145,99,85,170,166,223,89,137,67,193,120,127,83,90,217,162,91,125,32,197,185,229,2,118,3,38,131,169,207,149,98,104,25,200,17,65,74,115,78,202,45,71,179,74,169,20,123,82,0,81,27,21,41,83,154,63,87,15,214,228,198,155,188,118,164,96,43,0,116,230,129,181,111,186,8,31,233,27,87,107,236,150,242,21,217,13,42,33,101,99,182,182,249,185,231,46,5,52,255,100,86,133,197,93,45,176,83,161,143,159,169,153,71,186,8,106,7,133,110,233,112,122,75,68,41,179,181,46,9,117,219,35,38,25,196,176,166,110,173,125,223,167,73,184,96,238,156,102,178,237,143,113,140,170,236,255,23,154,105,108,82,100,86,225,158,177,194,165,2,54,25,41,76,9,117,64,19,89,160,62,58,24,228,154,152,84,63,101,157,66,91,214,228,143,107,214,63,247,153,7,156,210,161,245,48,232,239,230,56,45,77,193,93,37,240,134,32,221,76,38,235,112,132,198,233,130,99,94,204,30,2,63,107,104,9,201,239,186,62,20,24,151,60,161,112,106,107,132,53,127,104,134,226,160,82,5,83,156,183,55,7,80,170,28,132,7,62,92,174,222,127,236,68,125,142,184,242,22,87,55,218,58,176,13,12,80,240,4,31,28,240,255,179,0,2,26,245,12,174,178,116,181,60,88,122,131,37,189,33,9,220,249,19,145,209,246,47,169,124,115,71,50,148,1,71,245,34,129,229,229,58,220,218,194,55,52,118,181,200,167,221,243,154,70,97,68,169,14,3,208,15,62,199,200,236,65,30,117,164,153,205,56,226,47,14,234,59,161,187,128,50,49,179,62,24,56,139,84,78,8,185,109,79,3,13,66,111,191,4,10,246,144,18,184,44,121,124,151,36,114,176,121,86,175,137,175,188,31,119,154,222,16,8,147,217,18,174,139,179,46,63,207,220,31,114,18,85,36,113,107,46,230,221,26,80,135,205,132,159,24,71,88,122,23,218,8,116,188,154,159,188,140,125,75,233,58,236,122,236,250,29,133,219,102,67,9,99,210,195,100,196,71,24,28,239,8,217,21,50,55,59,67,221,22,186,194,36,67,77,161,18,81,196,101,42,2,0,148,80,221,228,58,19,158,248,223,113,85,78,49,16,214,119,172,129,155,25,17,95,241,86,53,4,107,199,163,215,59,24,17,60,9,165,36,89,237,230,143,242,250,251,241,151,44,191,186,158,110,60,21,30,112,69,227,134,177,111,233,234,10,94,14,134,179,42,62,90,28,231,31,119,250,6,61,78,185,220,101,41,15,29,231,153,214,137,62,128,37,200,102,82,120,201,76,46,106,179,16,156,186,14,21,198,120,234,226,148,83,60,252,165,244,45,10,30,167,78,247,242,61,43,29,54,15,38,57,25,96,121,194,25,8,167,35,82,182,18,19,247,110,254,173,235,102,31,195,234,149,69,188,227,131,200,123,166,209,55,127,177,40,255,140,1,239,221,50,195,165,90,108,190,133,33,88,101,2,152,171,104,15,165,206,238,59,149,47,219,173,125,239,42,132,47,110,91,40,182,33,21,112,97,7,41,117,71,221,236,16,21,159,97,48,168,204,19,150,189,97,235,30,254,52,3,207,99,3,170,144,92,115,181,57,162,112,76,11,158,158,213,20,222,170,203,188,134,204,238,167,44,98,96,171,92,171,156,110,132,243,178,175,30,139,100,202,240,189,25,185,105,35,160,80,187,90,101,50,90,104,64,179,180,42,60,213,233,158,49,247,184,33,192,25,11,84,155,153,160,95,135,126,153,247,149,168,125,61,98,154,136,55,248,119,45,227,151,95,147,237,17,129,18,104,22,41,136,53,14,214,31,230,199,161,223,222,150,153,186,88,120,165,132,245,87,99,114,34,27,255,195,131,155,150,70,194,26,235,10,179,205,84,48,46,83,228,72,217,143,40,49,188,109,239,242,235,88,234,255,198,52,97,237,40,254,115,60,124,238,217,20,74,93,227,183,100,232,20,93,16,66,224,19,62,32,182,226,238,69,234,171,170,163,21,79,108,219,208,79,203,250,66,244,66,199,181,187,106,239,29,59,79,101,5,33,205,65,158,121,30,216,199,77,133,134,106,71,75,228,80,98,129,61,242,161,98,207,70,38,141,91,160,131,136,252,163,182,199,193,195,36,21,127,146,116,203,105,11,138,132,71,133,178,146,86,0,191,91,9,157,72,25,173,116,177,98,20,0,14,130,35,42,141,66,88,234,245,85,12,62,244,173,29,97,112,63,35,146,240,114,51,65,126,147,141,241,236,95,214,219,59,34,108,89,55,222,124,96,116,238,203,167,242,133,64,110,50,119,206,132,128,7,166,158,80,248,25,85,216,239,232,53,151,217,97,170,167,105,169,194,6,12,197,252,171,4,90,220,202,11,128,46,122,68,158,132,52,69,195,5,103,213,253,201,158,30,14,211,219,115,219,205,136,85,16,121,218,95,103,64,67,103,227,101,52,196,197,216,56,62,113,158,248,40,61,32,255,109,241,231,33,62,21,74,61,176,143,43,159,227,230,247,173,131,219,104,90,61,233,247,64,129,148,28,38,76,246,52,41,105,148,247,32,21,65,247,212,2,118,46,107,244,188,104,0,162,212,113,36,8,212,106,244,32,51,183,212,183,67,175,97,0,80,46,246,57,30,70,69,36,151,116,79,33,20,64,136,139,191,29,252,149,77,175,145,181,150,211,221,244,112,69,47,160,102,236,9,188,191,133,151,189,3,208,109,172,127,4,133,203,49,179,39,235,150,65,57,253,85,230,71,37,218,154,10,202,171,37,120,80,40,244,41,4,83,218,134,44,10,251,109,182,233,98,20,220,104,0,105,72,215,164,192,14,104,238,141,161,39,162,254,63,79,140,173,135,232,6,224,140,181,182,214,244,122,124,30,206,170,236,95,55,211,153,163,120,206,66,42,107,64,53,158,254,32,185,133,243,217,171,215,57,238,139,78,18,59,247,250,201,29,86,24,109,75,49,102,163,38,178,151,227,234,116,250,110,58,50,67,91,221,247,231,65,104,251,32,120,202,78,245,10,251,151,179,254,216,172,86,64,69,39,149,72,186,58,58,83,85,135,141,131,32,183,169,107,254,75,149,150,208,188,103,168,85,88,154,21,161,99,41,169,204,51,219,225,153,86,74,42,166,249,37,49,63,28,126,244,94,124,49,41,144,2,232,248,253,112,47,39,4,92,21,187,128,227,44,40,5,72,21,193,149,34,109,198,228,63,19,193,72,220,134,15,199,238,201,249,7,15,31,4,65,164,121,71,64,23,110,136,93,235,81,95,50,209,192,155,213,143,193,188,242,100,53,17,65,52,120,123,37,96,156,42,96,163,232,248,223,27,108,99,31,194,180,18,14,158,50,225,2,209,79,102,175,21,129,209,202,224,149,35,107,225,146,62,51,98,11,36,59,34,185,190,238,14,162,178,133,153,13,186,230,140,12,114,222,40,247,162,45,69,120,18,208,253,148,183,149,98,8,125,100,240,245,204,231,111,163,73,84,250,72,125,135,39,253,157,195,30,141,62,243,65,99,71,10,116,255,46,153,171,110,111,58,55,253,248,244,96,220,18,168,248,221,235,161,76,225,27,153,13,107,110,219,16,85,123,198,55,44,103,109,59,212,101,39,4,232,208,220,199,13,41,241,163,255,0,204,146,15,57,181,11,237,15,105,251,159,123,102,156,125,219,206,11,207,145,160,163,94,21,217,136,47,19,187,36,173,91,81,191,121,148,123,235,214,59,118,179,46,57,55,121,89,17,204,151,226,38,128,45,49,46,244,167,173,66,104,59,43,106,198,204,76,117,18,28,241,46,120,55,66,18,106,231,81,146,183,230,187,161,6,80,99,251,75,24,16,107,26,250,237,202,17,216,189,37,61,201,195,225,226,89,22,66,68,134,19,18,10,110,236,12,217,42,234,171,213,78,103,175,100,95,168,134,218,136,233,191,190,254,195,228,100,87,128,188,157,134,192,247,240,248,123,120,96,77,96,3,96,70,131,253,209,176,31,56,246,4,174,69,119,204,252,54,215,51,107,66,131,113,171,30,240,135,65,128,176,95,94,0,60,190,87,160,119,36,174,232,189,153,66,70,85,97,46,88,191,143,244,88,78,162,253,221,242,56,239,116,244,194,189,137,135,195,249,102,83,116,142,179,200,85,242,117,180,185,217,252,70,97,38,235,122,132,223,29,139,121,14,106,132,226,149,95,145,142,89,110,70,112,87,180,32,145,85,213,140,76,222,2,201,225,172,11,185,208,5,130,187,72,98,168,17,158,169,116,117,182,25,127,183,9,220,169,224,161,9,45,102,51,70,50,196,2,31,90,232,140,190,240,9,37,160,153,74,16,254,110,29,29,61,185,26,223,164,165,11,15,242,134,161,105,241,104,40,131,218,183,220,254,6,57,87,155,206,226,161,82,127,205,79,1,94,17,80,250,131,6,167,196,181,2,160,39,208,230,13,39,140,248,154,65,134,63,119,6,76,96,195,181,6,168,97,40,122,23,240,224,134,245,192,170,88,96,0,98,125,220,48,215,158,230,17,99,234,56,35,148,221,194,83,52,22,194,194,86,238,203,187,222,182,188,144,161,125,252,235,118,29,89,206,9,228,5,111,136,1,124,75,61,10,114,57,36,124,146,124,95,114,227,134,185,157,77,114,180,91,193,26,252,184,158,211,120,85,84,237,181,165,252,8,211,124,61,216,196,15,173,77,94,239,80,30,248,230,97,177,217,20,133,162,60,19,81,108,231,199,213,111,196,78,225,86,206,191,42,54,55,200,198,221,52,50,154,215,18,130,99,146,142,250,14,103,224,0,96,64,55,206,57,58,207,245,250,211,55,119,194,171,27,45,197,90,158,103,176,92,66,55,163,79,64,39,130,211,190,155,188,153,157,142,17,213,21,115,15,191,126,28,45,214,123,196,0,199,107,27,140,183,69,144,161,33,190,177,110,178,180,110,54,106,47,171,72,87,121,110,148,188,210,118,163,198,200,194,73,101,238,248,15,83,125,222,141,70,29,10,115,213,198,77,208,76,219,187,57,41,80,70,186,169,232,38,149,172,4,227,94,190,240,213,250,161,154,81,45,106,226,140,239,99,34,238,134,154,184,194,137,192,246,46,36,67,170,3,30,165,164,208,242,156,186,97,192,131,77,106,233,155,80,21,229,143,214,91,100,186,249,162,38,40,225,58,58,167,134,149,169,75,233,98,85,239,211,239,47,199,218,247,82,247,105,111,4,63,89,10,250,119,21,169,228,128,1,134,176,135,173,230,9,155,147,229,62,59,90,253,144,233,151,215,52,158,217,183,240,44,81,139,43,2,58,172,213,150,125,166,125,1,214,62,207,209,40,45,125,124,207,37,159,31,155,184,242,173,114,180,214,90,76,245,136,90,113,172,41,224,230,165,25,224,253,172,176,71,155,250,147,237,141,196,211,232,204,87,59,40,41,102,213,248,40,46,19,121,145,1,95,120,85,96,117,237,68,14,150,247,140,94,211,227,212,109,5,21,186,109,244,136,37,97,161,3,189,240,100,5,21,158,235,195,162,87,144,60,236,26,39,151,42,7,58,169,155,109,63,27,245,33,99,30,251,102,156,245,25,243,220,38,40,217,51,117,245,253,85,177,130,52,86,3,187,60,186,138,17,119,81,40,248,217,10,194,103,81,204,171,95,146,173,204,81,23,232,77,142,220,48,56,98,88,157,55,145,249,32,147,194,144,122,234,206,123,62,251,100,206,33,81,50,190,79,119,126,227,182,168,70,61,41,195,105,83,222,72,128,230,19,100,16,8,174,162,36,178,109,221,253,45,133,105,102,33,7,9,10,70,154,179,221,192,69,100,207,222,108,88,174,200,32,28,221,247,190,91,64,141,88,27,127,1,210,204,187,227,180,107,126,106,162,221,69,255,89,58,68,10,53,62,213,205,180,188,168,206,234,114,187,132,100,250,174,18,102,141,71,111,60,191,99,228,155,210,158,93,47,84,27,119,194,174,112,99,78,246,141,13,14,116,87,19,91,231,113,22,114,248,93,125,83,175,8,203,64,64,204,226,180,78,106,70,210,52,132,175,21,1,40,4,176,225,29,58,152,149,180,159,184,6,72,160,110,206,130,59,63,111,130,171,32,53,75,29,26,1,248,39,114,39,177,96,21,97,220,63,147,231,43,121,58,187,189,37,69,52,225,57,136,160,75,121,206,81,183,201,50,47,201,186,31,160,126,200,28,224,246,209,199,188,195,17,1,207,199,170,232,161,73,135,144,26,154,189,79,212,203,222,218,208,56,218,10,213,42,195,57,3,103,54,145,198,124,49,249,141,79,43,177,224,183,89,158,247,58,187,245,67,255,25,213,242,156,69,217,39,44,34,151,191,42,252,230,21,113,252,145,15,37,21,148,155,97,147,229,250,235,156,182,206,89,100,168,194,209,168,186,18,94,7,193,182,12,106,5,227,101,80,210,16,66,164,3,203,14,110,236,224,59,219,152,22,190,160,152,76,100,233,120,50,50,149,31,159,223,146,211,224,43,52,160,211,30,242,113,137,65,116,10,27,140,52,163,75,32,113,190,197,216,50,118,195,141,159,53,223,46,47,153,155,71,111,11,230,29,241,227,15,84,218,76,229,145,216,218,30,207,121,98,206,111,126,62,205,102,177,24,22,5,29,44,253,197,210,143,132,153,34,251,246,87,243,35,245,35,118,50,166,49,53,168,147,2,205,204,86,98,129,240,172,181,235,117,90,151,54,22,110,204,115,210,136,146,98,150,222,208,73,185,129,27,144,80,76,20,86,198,113,189,199,198,230,10,20,122,50,6,208,225,69,154,123,242,195,253,83,170,201,0,15,168,98,226,191,37,187,246,210,189,53,5,105,18,113,34,2,4,178,124,207,203,182,43,156,118,205,192,62,17,83,211,227,64,22,96,189,171,56,240,173,71,37,156,32,56,186,118,206,70,247,197,161,175,119,96,96,117,32,78,254,203,133,216,141,232,138,176,249,170,122,126,170,249,76,92,194,72,25,140,138,251,2,228,106,195,1,249,225,235,214,105,248,212,144,160,222,92,166,45,37,9,63,159,230,8,194,50,97,78,183,91,226,119,206,227,223,143,87,230,114,195,58,95,112,137,0,255,9,47,15,64,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,255,0,0,0,255,255,255,255,8,0,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,109,230,236,222,5,0,11,0,1,0,47,100,101,118,47,108,111,103,0,0,112,114,111,103,33,10,0,108,105,98,107,46,107,102,117,110,99,49,32,45,62,32,37,100,10,0,109,97,120,32,115,121,115,116,101,109,32,98,121,116,101,115,32,61,32,37,49,48,108,117,10,0,115,121,115,116,101,109,32,98,121,116,101,115,32,32,32,32,32,61,32,37,49,48,108,117,10,0,105,110,32,117,115,101,32,98,121,116,101,115,32,32,32,32,32,61,32,37,49,48,108,117,10,0,76,79,71,78,65,77,69,0,47,112,114,111,99,47,115,101,108,102,47,102,100,47,0,47,100,101,118,47,116,116,121,0,88,88,88,88,88,88,0,67,0,76,67,95,65,76,76,0,76,65,78,71,0,67,46,85,84,70,45,56,0,80,79,83,73,88,0,77,85,83,76,95,76,79,67,80,65,84,72,0,37,42,46,42,102,0,45,43,32,32,32,48,88,48,120,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,105,110,102,0,73,78,70,0,78,65,78,0,109,101,115,115,97,103,101,115,0,8,10,7,10,11,11,80,108,117,114,97,108,45,70,111,114,109,115,58,0,110,112,108,117,114,97,108,115,61,0,112,108,117,114,97,108,61,0,110,33,61,49,59,0,1,2,3,3,4,4,4,4,5,5,6,6,6,0,124,38,61,33,62,60,43,45,42,37,47,124,38,61,61,61,61,0,1,2,4,7,3,6,5,0,8,4,4,8,4,4,8,2,4,0,195,138,204,132,195,138,204,140,195,170,204,132,195,170,204,140,0,65,83,67,73,73,0,85,84,70,45,56,0,46,0,0,116,111,117,112,112,101,114,0,116,111,108,111,119,101,114,0,111,112,116,105,111,110,115,0,110,100,111,116,115,58,0,97,116,116,101,109,112,116,115,58,0,116,105,109,101,111,117,116,58,0,100,111,109,97,105,110,0,115,101,97,114,99,104,0,49,50,55,46,48,46,48,46,49,0,47,101,116,99,47,115,101,114,118,105,99,101,115,0,47,117,100,112,0,47,116,99,112,0,47,101,116,99,47,114,101,115,111,108,118,46,99,111,110,102,0,110,97,109,101,115,101,114,118,101,114,0,37,100,46,37,100,46,37,100,46,37,100,46,105,110,45,97,100,100,114,46,97,114,112,97,0,105,112,54,46,97,114,112,97,0,37,115,37,115,37,115,0,116,99,112,0,117,100,112,0,37,46,50,88,0,58,37,46,50,88,0,47,101,116,99,47,104,111,115,116,115,0,37,100,46,37,100,46,37,100,46,37,100,0,0,0,0,0,0,0,0,0,0,0,255,255,0,37,120,58,37,120,58,37,120,58,37,120,58,37,120,58,37,120,58,37,120,58,37,120,0,37,120,58,37,120,58,37,120,58,37,120,58,37,120,58,37,120,58,37,100,46,37,100,46,37,100,46,37,100,0,58,48,0,47,100,101,118,47,115,104,109,47,0,36,50,97,36,48,48,36,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,117,0,56,98,32,208,193,210,207,204,216,0,255,163,51,52,255,255,255,163,51,52,53,0,95,48,46,46,46,47,57,90,122,0,128,120,0,128,255,128,1,32,127,129,128,128,13,10,255,127,32,129,32,116,101,115,116,0,95,48,46,46,46,47,57,90,122,88,55,105,83,74,78,100,50,49,115,85,0,128,120,50,50,47,119,75,53,50,90,75,71,65,0,120,0,36,53,36,0,36,53,36,37,115,37,46,42,115,36,0,36,54,36,0,114,111,117,110,100,115,61,0,114,111,117,110,100,115,61,37,117,36,0,36,54,36,37,115,37,46,42,115,36,0,36,49,36,97,98,99,100,48,49,50,51,36,0,42,0,36,49,36,0,0,6,12,1,7,13,2,8,14,3,9,15,4,10,5,105,110,102,105,110,105,116,121,0,110,97,110,0,37,46,42,102,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,0,37,46,42,101,0,37,46,42,103,0,37,42,115,0,40,110,117,108,108,41,0,35,0,43,0,45,0,48,0,37,37,37,115,37,115,37,115,37,115,37,115,42,46,42,37,99,37,99,0,37,46,42,115,37,46,48,100,37,115,37,99,37,37,108,108,110,0,37,42,0,114,119,97,0,119,43,0,47,116,109,112,0,116,101,109,112,0,37,115,0,9,0,10,0,13,0,12,0,7,0,27,0,91,91,58,97,108,110,117,109,58,93,95,93,0,91,94,91,58,97,108,110,117,109,58,93,95,93,0,91,91,58,115,112,97,99,101,58,93,93,0,91,94,91,58,115,112,97,99,101,58,93,93,0,91,91,58,100,105,103,105,116,58,93,93,0,91,94,91,58,100,105,103,105,116,58,93,93,0,37,42,91,94,10,93,37,42,91,10,93,0,32,37,110,37,42,115,37,110,32,37,110,37,42,115,37,110,32,37,110,37,42,115,37,110,32,37,110,37,42,115,37,110,32,37,100,32,37,100,0,37,115,9,37,115,9,37,115,9,37,115,9,37,100,9,37,100,10,0,47,100,101,118,47,112,116,115,47,37,100,0,77,83,71,86,69,82,66,0,69,82,82,79,82,58,32,0,87,65,82,78,73,78,71,58,32,0,73,78,70,79,58,32,0,72,65,76,84,58,32,0,58,32,0,10,84,79,32,70,73,88,58,32,0,32,0,37,115,37,115,37,115,37,115,37,115,37,115,37,115,37,115,10,0,108,97,98,101,108,0,115,101,118,101,114,105,116,121,0,116,101,120,116,0,97,99,116,105,111,110,0,116,97,103,0,37,98,32,37,101,32,37,84,0,91,0,93,0,60,37,100,62,37,115,32,37,110,37,115,37,115,37,46,48,100,37,115,58,32,0,47,100,101,118,47,99,111,110,115,111,108,101,0,37,46,42,115,0,47,100,101,118,47,112,116,109,120,0,47,0,80,87,68,0,46,0,58,32,111,112,116,105,111,110,32,100,111,101,115,32,110,111,116,32,116,97,107,101,32,97,110,32,97,114,103,117,109,101,110,116,58,32,0,58,32,111,112,116,105,111,110,32,114,101,113,117,105,114,101,115,32,97,110,32,97,114,103,117,109,101,110,116,58,32,0,58,32,117,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,58,32,0,58,32,111,112,116,105,111,110,32,105,115,32,97,109,98,105,103,117,111,117,115,58,32,0,49,46,49,46,49,53,0], "i8", ALLOC_NONE, GLOBAL_BASE);





/* no memory initializer */
var tempDoublePtr = STATICTOP; STATICTOP += 16;

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}


  
  
  function _emscripten_get_now() { abort() }
  
  function _emscripten_get_now_is_monotonic() {
      // return whether emscripten_get_now is guaranteed monotonic; the Date.now
      // implementation is not :(
      return ENVIRONMENT_IS_NODE || (typeof dateNow !== 'undefined') ||
          ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now']);
    }
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  function ___setErrNo(value) {
      if (Module['___errno_location']) HEAP32[((Module['___errno_location']())>>2)]=value;
      else err('failed to set errno from JS');
      return value;
    }function _clock_gettime(clk_id, tp) {
      // int clock_gettime(clockid_t clk_id, struct timespec *tp);
      var now;
      if (clk_id === 0) {
        now = Date.now();
      } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
        now = _emscripten_get_now();
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      HEAP32[((tp)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((tp)+(4))>>2)]=((now % 1000)*1000*1000)|0; // nanoseconds
      return 0;
    }function ___clock_gettime() {
  return _clock_gettime.apply(null, arguments)
  }

  
  
   
  
   
  
     

  function ___lock() {}

  function ___map_file(pathname, size) {
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }

  
    

  
  
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up; up--) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var i = 0;
          try {
            if (offset === 0 && length === 0) {
              // musl implements an fflush using a write of a NULL buffer of size 0
              stream.tty.ops.flush(stream.tty);
            } else {
              while (i < length) {
                stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
                i++;
              }
            }
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              // we will read data by chunks of BUFSIZE
              var BUFSIZE = 256;
              var buf = new Buffer(BUFSIZE);
              var bytesRead = 0;
  
              var isPosixPlatform = (process.platform != 'win32'); // Node doesn't offer a direct check, so test by exclusion
  
              var fd = process.stdin.fd;
              if (isPosixPlatform) {
                // Linux and Mac cannot use process.stdin.fd (which isn't set up as sync)
                var usingDevice = false;
                try {
                  fd = fs.openSync('/dev/stdin', 'r');
                  usingDevice = true;
                } catch (e) {}
              }
  
              try {
                bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
              } catch(e) {
                // Cross-platform differences: on Windows, reading EOF throws an exception, but on other OSes,
                // reading EOF returns 0. Uniformize behavior by treating the EOF exception to return 0.
                if (e.toString().indexOf('EOF') != -1) bytesRead = 0;
                else throw e;
              }
  
              if (usingDevice) { fs.closeSync(fd); }
              if (bytesRead > 0) {
                result = buf.slice(0, bytesRead).toString('utf-8');
              } else {
                result = null;
              }
  
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            out(UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val); // val == 0 would cut text output off in the middle.
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            out(UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            err(UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val);
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            err(UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap,
                msync: MEMFS.stream_ops.msync
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.length which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.length : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
  
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) {
              assert(position === 0, 'canOwn must imply no weird position inside the file');
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
  
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else {
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        },msync:function (stream, buffer, offset, length, mmapFlags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          if (mmapFlags & 2) {
            // MAP_PRIVATE calls need not to be synced back to underlying fs
            return 0;
          }
  
          var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
          // should we check if bytesWritten and length are the same?
          return 0;
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        if (!req) {
          return callback("Unable to connect to IndexedDB");
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          if (!fileStore.indexNames.contains('timestamp')) {
            fileStore.createIndex('timestamp', 'timestamp', { unique: false });
          }
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          try {
            var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
            transaction.onerror = function(e) {
              callback(this.error);
              e.preventDefault();
            };
  
            var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
            var index = store.index('timestamp');
  
            index.openKeyCursor().onsuccess = function(event) {
              var cursor = event.target.result;
  
              if (!cursor) {
                return callback(null, { type: 'remote', db: db, entries: entries });
              }
  
              entries[cursor.primaryKey] = { timestamp: cursor.key };
  
              cursor.continue();
            };
          } catch (e) {
            return callback(e);
          }
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function(e) {
          done(this.error);
          e.preventDefault();
        };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
        var flags = process["binding"]("constants");
        // Node.js 4 compatibility: it has no namespaces for constants
        if (flags["fs"]) {
          flags = flags["fs"];
        }
        NODEFS.flagsForNodeMap = {
          "1024": flags["O_APPEND"],
          "64": flags["O_CREAT"],
          "128": flags["O_EXCL"],
          "0": flags["O_RDONLY"],
          "2": flags["O_RDWR"],
          "4096": flags["O_SYNC"],
          "512": flags["O_TRUNC"],
          "1": flags["O_WRONLY"]
        };
      },bufferFrom:function (arrayBuffer) {
        // Node.js < 4.5 compatibility: Buffer.from does not support ArrayBuffer
        // Buffer.from before 4.5 was just a method inherited from Uint8Array
        // Buffer.alloc has been added with Buffer.from together, so check it instead
        return Buffer.alloc ? Buffer.from(arrayBuffer) : new Buffer(arrayBuffer);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // Node.js on Windows never represents permission bit 'x', so
            // propagate read bits to execute bits
            stat.mode = stat.mode | ((stat.mode & 292) >> 2);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsForNode:function (flags) {
        flags &= ~0x200000 /*O_PATH*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x800 /*O_NONBLOCK*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x8000 /*O_LARGEFILE*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x80000 /*O_CLOEXEC*/; // Some applications may pass it; it makes no sense for a single process.
        var newFlags = 0;
        for (var k in NODEFS.flagsForNodeMap) {
          if (flags & k) {
            newFlags |= NODEFS.flagsForNodeMap[k];
            flags ^= k;
          }
        }
  
        if (!flags) {
          return newFlags;
        } else {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            path = fs.readlinkSync(path);
            path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
            return path;
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsForNode(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // Node.js < 6 compatibility: node errors on 0 length reads
          if (length === 0) return 0;
          try {
            return fs.readSync(stream.nfd, NODEFS.bufferFrom(buffer.buffer), offset, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },write:function (stream, buffer, offset, length, position) {
          try {
            return fs.writeSync(stream.nfd, NODEFS.bufferFrom(buffer.buffer), offset, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var WORKERFS={DIR_MODE:16895,FILE_MODE:33279,reader:null,mount:function (mount) {
        assert(ENVIRONMENT_IS_WORKER);
        if (!WORKERFS.reader) WORKERFS.reader = new FileReaderSync();
        var root = WORKERFS.createNode(null, '/', WORKERFS.DIR_MODE, 0);
        var createdParents = {};
        function ensureParent(path) {
          // return the parent node, creating subdirs as necessary
          var parts = path.split('/');
          var parent = root;
          for (var i = 0; i < parts.length-1; i++) {
            var curr = parts.slice(0, i+1).join('/');
            // Issue 4254: Using curr as a node name will prevent the node
            // from being found in FS.nameTable when FS.open is called on
            // a path which holds a child of this node,
            // given that all FS functions assume node names
            // are just their corresponding parts within their given path,
            // rather than incremental aggregates which include their parent's
            // directories.
            if (!createdParents[curr]) {
              createdParents[curr] = WORKERFS.createNode(parent, parts[i], WORKERFS.DIR_MODE, 0);
            }
            parent = createdParents[curr];
          }
          return parent;
        }
        function base(path) {
          var parts = path.split('/');
          return parts[parts.length-1];
        }
        // We also accept FileList here, by using Array.prototype
        Array.prototype.forEach.call(mount.opts["files"] || [], function(file) {
          WORKERFS.createNode(ensureParent(file.name), base(file.name), WORKERFS.FILE_MODE, 0, file, file.lastModifiedDate);
        });
        (mount.opts["blobs"] || []).forEach(function(obj) {
          WORKERFS.createNode(ensureParent(obj["name"]), base(obj["name"]), WORKERFS.FILE_MODE, 0, obj["data"]);
        });
        (mount.opts["packages"] || []).forEach(function(pack) {
          pack['metadata'].files.forEach(function(file) {
            var name = file.filename.substr(1); // remove initial slash
            WORKERFS.createNode(ensureParent(name), base(name), WORKERFS.FILE_MODE, 0, pack['blob'].slice(file.start, file.end));
          });
        });
        return root;
      },createNode:function (parent, name, mode, dev, contents, mtime) {
        var node = FS.createNode(parent, name, mode);
        node.mode = mode;
        node.node_ops = WORKERFS.node_ops;
        node.stream_ops = WORKERFS.stream_ops;
        node.timestamp = (mtime || new Date).getTime();
        assert(WORKERFS.FILE_MODE !== WORKERFS.DIR_MODE);
        if (mode === WORKERFS.FILE_MODE) {
          node.size = contents.size;
          node.contents = contents;
        } else {
          node.size = 4096;
          node.contents = {};
        }
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          return {
            dev: 1,
            ino: undefined,
            mode: node.mode,
            nlink: 1,
            uid: 0,
            gid: 0,
            rdev: undefined,
            size: node.size,
            atime: new Date(node.timestamp),
            mtime: new Date(node.timestamp),
            ctime: new Date(node.timestamp),
            blksize: 4096,
            blocks: Math.ceil(node.size / 4096),
          };
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rename:function (oldNode, newDir, newName) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },unlink:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rmdir:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readdir:function (node) {
          var entries = ['.', '..'];
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newName, oldPath) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readlink:function (node) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          if (position >= stream.node.size) return 0;
          var chunk = stream.node.contents.slice(position, position + length);
          var ab = WORKERFS.reader.readAsArrayBuffer(chunk);
          buffer.set(new Uint8Array(ab), offset);
          return chunk.size;
        },write:function (stream, buffer, offset, length, position) {
          throw new FS.ErrnoError(ERRNO_CODES.EIO);
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.size;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        }}};
  
  var _stdin=STATICTOP; STATICTOP += 16;;
  
  var _stdout=STATICTOP; STATICTOP += 16;;
  
  var _stderr=STATICTOP; STATICTOP += 16;;var FS={root:null,mounts:[],devices:{},streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},filesystems:null,syncFSRequests:0,handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
  
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var perms = ['r', 'w', 'rw'][flag & 3];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if (FS.flagsToPermissionString(flags) !== 'r' || // opening for write
              (flags & 512)) { // TODO: check for O_SEARCH? (== search for dir only)
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        FS.syncFSRequests++;
  
        if (FS.syncFSRequests > 1) {
          console.log('warning: ' + FS.syncFSRequests + ' FS.syncfs operations in flight at once, probably just doing extra work');
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function doCallback(err) {
          assert(FS.syncFSRequests > 0);
          FS.syncFSRequests--;
          return callback(err);
        }
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return doCallback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            doCallback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdirTree:function (path, mode) {
        var dirs = path.split('/');
        var d = '';
        for (var i = 0; i < dirs.length; ++i) {
          if (!dirs[i]) continue;
          d += '/' + dirs[i];
          try {
            FS.mkdir(d, mode);
          } catch(e) {
            if (e.errno != ERRNO_CODES.EEXIST) throw e;
          }
        }
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // According to POSIX, we should map EISDIR to EPERM, but
          // we instead do what Linux does (and we must, as we use
          // the musl linux libc).
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return PATH.resolve(FS.getPath(link.parent), link.node_ops.readlink(link));
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // if asked only for a directory, then this must be one
        if ((flags & 65536) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            console.log("FS.trackingDelegate error on read file: " + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        if (FS.isClosed(stream)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (stream.getdents) stream.getdents = null; // free readdir state
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
        stream.fd = null;
      },isClosed:function (stream) {
        return stream.fd === null;
      },llseek:function (stream, offset, whence) {
        if (FS.isClosed(stream)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (FS.isClosed(stream)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = typeof position !== 'undefined';
        if (!seeking) {
          position = stream.position;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (FS.isClosed(stream)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = typeof position !== 'undefined';
        if (!seeking) {
          position = stream.position;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (FS.isClosed(stream)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },msync:function (stream, buffer, offset, length, mmapFlags) {
        if (!stream || !stream.stream_ops.msync) {
          return 0;
        }
        return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
      },munmap:function (stream) {
        return 0;
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = UTF8ArrayToString(buf, 0);
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        var stream = FS.open(path, opts.flags, opts.mode);
        if (typeof data === 'string') {
          var buf = new Uint8Array(lengthBytesUTF8(data)+1);
          var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
          FS.write(stream, buf, 0, actualNumBytes, undefined, opts.canOwn);
        } else if (ArrayBuffer.isView(data)) {
          FS.write(stream, data, 0, data.byteLength, undefined, opts.canOwn);
        } else {
          throw new Error('Unsupported data type');
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (lookup.node === null) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function(stream, buffer, offset, length, pos) { return length; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto')['randomBytes'](1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { abort("random_device"); /*Math.random() is not safe for random number generation, so this fallback random_device implementation aborts... see kripken/emscripten/pull/7096 */ };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createSpecialDirectories:function () {
        // create /proc/self/fd which allows /proc/self/fd/6 => readlink gives the name of the stream for fd 6 (see test_unistd_ttyname)
        FS.mkdir('/proc');
        FS.mkdir('/proc/self');
        FS.mkdir('/proc/self/fd');
        FS.mount({
          mount: function() {
            var node = FS.createNode('/proc/self', 'fd', 16384 | 511 /* 0777 */, 73);
            node.node_ops = {
              lookup: function(parent, name) {
                var fd = +name;
                var stream = FS.getStream(fd);
                if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
                var ret = {
                  parent: null,
                  mount: { mountpoint: 'fake' },
                  node_ops: { readlink: function() { return stream.path } }
                };
                ret.parent = ret; // make it look like a simple root node
                return ret;
              }
            };
            return node;
          }
        }, {}, '/proc/self/fd');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
          // Node.js compatibility: assigning on this.stack fails on Node 4 (but fixed on Node 8)
          if (this.stack) Object.defineProperty(this, "stack", { value: (new Error).stack, writable: true });
          if (this.stack) this.stack = demangleAll(this.stack);
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
        FS.createSpecialDirectories();
  
        FS.filesystems = {
          'MEMFS': MEMFS,
          'IDBFS': IDBFS,
          'NODEFS': NODEFS,
          'WORKERFS': WORKERFS,
        };
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        // force-flush all streams, so we get musl std streams printed out
        var fflush = Module['_fflush'];
        if (fflush) fflush(0);
        // close all of our streams
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";
  
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          if (usesGzip || !datalength) {
            // if the server uses gzip or doesn't supply the length, we have to download the whole file to get the (uncompressed) length
            chunkSize = datalength = 1; // this will force getter(0)/doXHR do download the whole file
            datalength = this.getter(0).length;
            chunkSize = datalength;
            console.log("LazyFiles on gzip forces download of the whole file when length is accessed");
          }
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperties(lazyArray, {
            length: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._length;
              }
            },
            chunkSize: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._chunkSize;
              }
            }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperties(node, {
          usedBytes: {
            get: function() { return this.contents.length; }
          }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
        Browser.init(); // XXX perhaps this method should move onto Browser?
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        var dep = getUniqueRunDependency('cp ' + fullname); // might have several active requests for the same fullname
        function processData(byteArray) {
          function finish(byteArray) {
            if (preFinish) preFinish();
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency(dep);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency(dep);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency(dep);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};var SYSCALLS={DEFAULT_POLLMASK:5,mappings:{},umask:511,calculateAt:function (dirfd, path) {
        if (path[0] !== '/') {
          // relative path
          var dir;
          if (dirfd === -100) {
            dir = FS.cwd();
          } else {
            var dirstream = FS.getStream(dirfd);
            if (!dirstream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
            dir = dirstream.path;
          }
          path = PATH.join2(dir, path);
        }
        return path;
      },doStat:function (func, path, buf) {
        try {
          var stat = func(path);
        } catch (e) {
          if (e && e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
            // an error occurred while trying to look up the path; we should just report ENOTDIR
            return -ERRNO_CODES.ENOTDIR;
          }
          throw e;
        }
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=(stat.atime.getTime() / 1000)|0;
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=(stat.mtime.getTime() / 1000)|0;
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=(stat.ctime.getTime() / 1000)|0;
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      },doMsync:function (addr, stream, len, flags) {
        var buffer = new Uint8Array(HEAPU8.subarray(addr, addr + len));
        FS.msync(stream, buffer, 0, len, flags);
      },doMkdir:function (path, mode) {
        // remove a trailing slash, if one - /a/b/ has basename of '', but
        // we want to create b in the context of this function
        path = PATH.normalize(path);
        if (path[path.length-1] === '/') path = path.substr(0, path.length-1);
        FS.mkdir(path, mode, 0);
        return 0;
      },doMknod:function (path, mode, dev) {
        // we don't want this in the JS API as it uses mknod to create all nodes.
        switch (mode & 61440) {
          case 32768:
          case 8192:
          case 24576:
          case 4096:
          case 49152:
            break;
          default: return -ERRNO_CODES.EINVAL;
        }
        FS.mknod(path, mode, dev);
        return 0;
      },doReadlink:function (path, buf, bufsize) {
        if (bufsize <= 0) return -ERRNO_CODES.EINVAL;
        var ret = FS.readlink(path);
  
        var len = Math.min(bufsize, lengthBytesUTF8(ret));
        var endChar = HEAP8[buf+len];
        stringToUTF8(ret, buf, bufsize+1);
        // readlink is one of the rare functions that write out a C string, but does never append a null to the output buffer(!)
        // stringToUTF8() always appends a null byte, so restore the character under the null byte after the write.
        HEAP8[buf+len] = endChar;
  
        return len;
      },doAccess:function (path, amode) {
        if (amode & ~7) {
          // need a valid mode
          return -ERRNO_CODES.EINVAL;
        }
        var node;
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
        var perms = '';
        if (amode & 4) perms += 'r';
        if (amode & 2) perms += 'w';
        if (amode & 1) perms += 'x';
        if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
          return -ERRNO_CODES.EACCES;
        }
        return 0;
      },doDup:function (path, flags, suggestFD) {
        var suggest = FS.getStream(suggestFD);
        if (suggest) FS.close(suggest);
        return FS.open(path, flags, 0, suggestFD, suggestFD).fd;
      },doReadv:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.read(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
          if (curr < len) break; // nothing more to read
        }
        return ret;
      },doWritev:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.write(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
        }
        return ret;
      },varargs:0,get:function (varargs) {
        SYSCALLS.varargs += 4;
        var ret = HEAP32[(((SYSCALLS.varargs)-(4))>>2)];
        return ret;
      },getStr:function () {
        var ret = Pointer_stringify(SYSCALLS.get());
        return ret;
      },getStreamFromFD:function () {
        var stream = FS.getStream(SYSCALLS.get());
        if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return stream;
      },getSocketFromFD:function () {
        var socket = SOCKFS.getSocket(SYSCALLS.get());
        if (!socket) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return socket;
      },getSocketAddress:function (allowNull) {
        var addrp = SYSCALLS.get(), addrlen = SYSCALLS.get();
        if (allowNull && addrp === 0) return null;
        var info = __read_sockaddr(addrp, addrlen);
        if (info.errno) throw new FS.ErrnoError(info.errno);
        info.addr = DNS.lookup_addr(info.addr) || info.addr;
        return info;
      },get64:function () {
        var low = SYSCALLS.get(), high = SYSCALLS.get();
        if (low >= 0) assert(high === 0);
        else assert(high === -1);
        return low;
      },getZero:function () {
        assert(SYSCALLS.get() === 0);
      }};function ___syscall10(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // unlink
      var path = SYSCALLS.getStr();
      FS.unlink(path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // some webservers (azure) does not support subprotocol header
              if (runtimeConfig && null === Module['websocket']['subprotocol']) {
                subProtocols = 'null';
                opts = undefined;
              }
  
              // If node we use the ws library.
              var WebSocketConstructor;
              if (ENVIRONMENT_IS_NODE) {
                WebSocketConstructor = require('ws');
              } else if (ENVIRONMENT_IS_WEB) {
                WebSocketConstructor = window['WebSocket'];
              } else {
                WebSocketConstructor = WebSocket;
              }
              ws = new WebSocketConstructor(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
  
            // An empty ArrayBuffer will emit a pseudo disconnect event
            // as recv/recvmsg will return zero which indicates that a socket
            // has performed a shutdown although the connection has not been disconnected yet.
            if (data.byteLength == 0) {
              return;
            }
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port;
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          if (ArrayBuffer.isView(buffer)) {
            offset += buffer.byteOffset;
            buffer = buffer.buffer;
          }
  
          var data;
            data = buffer.slice(offset, offset + length);
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};
  
  
  function __inet_pton4_raw(str) {
      var b = str.split('.');
      for (var i = 0; i < 4; i++) {
        var tmp = Number(b[i]);
        if (isNaN(tmp)) return null;
        b[i] = tmp;
      }
      return (b[0] | (b[1] << 8) | (b[2] << 16) | (b[3] << 24)) >>> 0;
    }
  
  function __inet_pton6_raw(str) {
      var words;
      var w, offset, z, i;
      /* http://home.deds.nl/~aeron/regex/ */
      var valid6regx = /^((?=.*::)(?!.*::.+::)(::)?([\dA-F]{1,4}:(:|\b)|){5}|([\dA-F]{1,4}:){6})((([\dA-F]{1,4}((?!\3)::|:\b|$))|(?!\2\3)){2}|(((2[0-4]|1\d|[1-9])?\d|25[0-5])\.?\b){4})$/i
      var parts = [];
      if (!valid6regx.test(str)) {
        return null;
      }
      if (str === "::") {
        return [0, 0, 0, 0, 0, 0, 0, 0];
      }
      // Z placeholder to keep track of zeros when splitting the string on ":"
      if (str.indexOf("::") === 0) {
        str = str.replace("::", "Z:"); // leading zeros case
      } else {
        str = str.replace("::", ":Z:");
      }
  
      if (str.indexOf(".") > 0) {
        // parse IPv4 embedded stress
        str = str.replace(new RegExp('[.]', 'g'), ":");
        words = str.split(":");
        words[words.length-4] = parseInt(words[words.length-4]) + parseInt(words[words.length-3])*256;
        words[words.length-3] = parseInt(words[words.length-2]) + parseInt(words[words.length-1])*256;
        words = words.slice(0, words.length-2);
      } else {
        words = str.split(":");
      }
  
      offset = 0; z = 0;
      for (w=0; w < words.length; w++) {
        if (typeof words[w] === 'string') {
          if (words[w] === 'Z') {
            // compressed zeros - write appropriate number of zero words
            for (z = 0; z < (8 - words.length+1); z++) {
              parts[w+z] = 0;
            }
            offset = z-1;
          } else {
            // parse hex to field to 16-bit value and write it in network byte-order
            parts[w+offset] = _htons(parseInt(words[w],16));
          }
        } else {
          // parsed IPv4 words
          parts[w+offset] = words[w];
        }
      }
      return [
        (parts[1] << 16) | parts[0],
        (parts[3] << 16) | parts[2],
        (parts[5] << 16) | parts[4],
        (parts[7] << 16) | parts[6]
      ];
    }var DNS={address_map:{id:1,addrs:{},names:{}},lookup_name:function (name) {
        // If the name is already a valid ipv4 / ipv6 address, don't generate a fake one.
        var res = __inet_pton4_raw(name);
        if (res !== null) {
          return name;
        }
        res = __inet_pton6_raw(name);
        if (res !== null) {
          return name;
        }
  
        // See if this name is already mapped.
        var addr;
  
        if (DNS.address_map.addrs[name]) {
          addr = DNS.address_map.addrs[name];
        } else {
          var id = DNS.address_map.id++;
          assert(id < 65535, 'exceeded max address mappings of 65535');
  
          addr = '172.29.' + (id & 0xff) + '.' + (id & 0xff00);
  
          DNS.address_map.names[addr] = name;
          DNS.address_map.addrs[name] = addr;
        }
  
        return addr;
      },lookup_addr:function (addr) {
        if (DNS.address_map.names[addr]) {
          return DNS.address_map.names[addr];
        }
  
        return null;
      }};
  
  
  var Sockets={BUFFER_SIZE:10240,MAX_BUFFER_SIZE:10485760,nextFd:1,fds:{},nextport:1,maxport:65535,peer:null,connections:{},portmap:{},localAddr:4261412874,addrPool:[33554442,50331658,67108874,83886090,100663306,117440522,134217738,150994954,167772170,184549386,201326602,218103818,234881034]};
  
  function __inet_ntop4_raw(addr) {
      return (addr & 0xff) + '.' + ((addr >> 8) & 0xff) + '.' + ((addr >> 16) & 0xff) + '.' + ((addr >> 24) & 0xff)
    }
  
  function __inet_ntop6_raw(ints) {
      //  ref:  http://www.ietf.org/rfc/rfc2373.txt - section 2.5.4
      //  Format for IPv4 compatible and mapped  128-bit IPv6 Addresses
      //  128-bits are split into eight 16-bit words
      //  stored in network byte order (big-endian)
      //  |                80 bits               | 16 |      32 bits        |
      //  +-----------------------------------------------------------------+
      //  |               10 bytes               |  2 |      4 bytes        |
      //  +--------------------------------------+--------------------------+
      //  +               5 words                |  1 |      2 words        |
      //  +--------------------------------------+--------------------------+
      //  |0000..............................0000|0000|    IPv4 ADDRESS     | (compatible)
      //  +--------------------------------------+----+---------------------+
      //  |0000..............................0000|FFFF|    IPv4 ADDRESS     | (mapped)
      //  +--------------------------------------+----+---------------------+
      var str = "";
      var word = 0;
      var longest = 0;
      var lastzero = 0;
      var zstart = 0;
      var len = 0;
      var i = 0;
      var parts = [
        ints[0] & 0xffff,
        (ints[0] >> 16),
        ints[1] & 0xffff,
        (ints[1] >> 16),
        ints[2] & 0xffff,
        (ints[2] >> 16),
        ints[3] & 0xffff,
        (ints[3] >> 16)
      ];
  
      // Handle IPv4-compatible, IPv4-mapped, loopback and any/unspecified addresses
  
      var hasipv4 = true;
      var v4part = "";
      // check if the 10 high-order bytes are all zeros (first 5 words)
      for (i = 0; i < 5; i++) {
        if (parts[i] !== 0) { hasipv4 = false; break; }
      }
  
      if (hasipv4) {
        // low-order 32-bits store an IPv4 address (bytes 13 to 16) (last 2 words)
        v4part = __inet_ntop4_raw(parts[6] | (parts[7] << 16));
        // IPv4-mapped IPv6 address if 16-bit value (bytes 11 and 12) == 0xFFFF (6th word)
        if (parts[5] === -1) {
          str = "::ffff:";
          str += v4part;
          return str;
        }
        // IPv4-compatible IPv6 address if 16-bit value (bytes 11 and 12) == 0x0000 (6th word)
        if (parts[5] === 0) {
          str = "::";
          //special case IPv6 addresses
          if(v4part === "0.0.0.0") v4part = ""; // any/unspecified address
          if(v4part === "0.0.0.1") v4part = "1";// loopback address
          str += v4part;
          return str;
        }
      }
  
      // Handle all other IPv6 addresses
  
      // first run to find the longest contiguous zero words
      for (word = 0; word < 8; word++) {
        if (parts[word] === 0) {
          if (word - lastzero > 1) {
            len = 0;
          }
          lastzero = word;
          len++;
        }
        if (len > longest) {
          longest = len;
          zstart = word - longest + 1;
        }
      }
  
      for (word = 0; word < 8; word++) {
        if (longest > 1) {
          // compress contiguous zeros - to produce "::"
          if (parts[word] === 0 && word >= zstart && word < (zstart + longest) ) {
            if (word === zstart) {
              str += ":";
              if (zstart === 0) str += ":"; //leading zeros case
            }
            continue;
          }
        }
        // converts 16-bit words from big-endian to little-endian before converting to hex string
        str += Number(_ntohs(parts[word] & 0xffff)).toString(16);
        str += word < 7 ? ":" : "";
      }
      return str;
    }function __read_sockaddr(sa, salen) {
      // family / port offsets are common to both sockaddr_in and sockaddr_in6
      var family = HEAP16[((sa)>>1)];
      var port = _ntohs(HEAP16[(((sa)+(2))>>1)]);
      var addr;
  
      switch (family) {
        case 2:
          if (salen !== 16) {
            return { errno: ERRNO_CODES.EINVAL };
          }
          addr = HEAP32[(((sa)+(4))>>2)];
          addr = __inet_ntop4_raw(addr);
          break;
        case 10:
          if (salen !== 28) {
            return { errno: ERRNO_CODES.EINVAL };
          }
          addr = [
            HEAP32[(((sa)+(8))>>2)],
            HEAP32[(((sa)+(12))>>2)],
            HEAP32[(((sa)+(16))>>2)],
            HEAP32[(((sa)+(20))>>2)]
          ];
          addr = __inet_ntop6_raw(addr);
          break;
        default:
          return { errno: ERRNO_CODES.EAFNOSUPPORT };
      }
  
      return { family: family, addr: addr, port: port };
    }
  
  function __write_sockaddr(sa, family, addr, port) {
      switch (family) {
        case 2:
          addr = __inet_pton4_raw(addr);
          HEAP16[((sa)>>1)]=family;
          HEAP32[(((sa)+(4))>>2)]=addr;
          HEAP16[(((sa)+(2))>>1)]=_htons(port);
          break;
        case 10:
          addr = __inet_pton6_raw(addr);
          HEAP32[((sa)>>2)]=family;
          HEAP32[(((sa)+(8))>>2)]=addr[0];
          HEAP32[(((sa)+(12))>>2)]=addr[1];
          HEAP32[(((sa)+(16))>>2)]=addr[2];
          HEAP32[(((sa)+(20))>>2)]=addr[3];
          HEAP16[(((sa)+(2))>>1)]=_htons(port);
          HEAP32[(((sa)+(4))>>2)]=0;
          HEAP32[(((sa)+(24))>>2)]=0;
          break;
        default:
          return { errno: ERRNO_CODES.EAFNOSUPPORT };
      }
      // kind of lame, but let's match _read_sockaddr's interface
      return {};
    }function ___syscall102(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // socketcall
      var call = SYSCALLS.get(), socketvararg = SYSCALLS.get();
      // socketcalls pass the rest of the arguments in a struct
      SYSCALLS.varargs = socketvararg;
      switch (call) {
        case 1: { // socket
          var domain = SYSCALLS.get(), type = SYSCALLS.get(), protocol = SYSCALLS.get();
          var sock = SOCKFS.createSocket(domain, type, protocol);
          assert(sock.stream.fd < 64); // XXX ? select() assumes socket fd values are in 0..63
          return sock.stream.fd;
        }
        case 2: { // bind
          var sock = SYSCALLS.getSocketFromFD(), info = SYSCALLS.getSocketAddress();
          sock.sock_ops.bind(sock, info.addr, info.port);
          return 0;
        }
        case 3: { // connect
          var sock = SYSCALLS.getSocketFromFD(), info = SYSCALLS.getSocketAddress();
          sock.sock_ops.connect(sock, info.addr, info.port);
          return 0;
        }
        case 4: { // listen
          var sock = SYSCALLS.getSocketFromFD(), backlog = SYSCALLS.get();
          sock.sock_ops.listen(sock, backlog);
          return 0;
        }
        case 5: { // accept
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          var newsock = sock.sock_ops.accept(sock);
          if (addr) {
            var res = __write_sockaddr(addr, newsock.family, DNS.lookup_name(newsock.daddr), newsock.dport);
            assert(!res.errno);
          }
          return newsock.stream.fd;
        }
        case 6: { // getsockname
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          // TODO: sock.saddr should never be undefined, see TODO in websocket_sock_ops.getname
          var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(sock.saddr || '0.0.0.0'), sock.sport);
          assert(!res.errno);
          return 0;
        }
        case 7: { // getpeername
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          if (!sock.daddr) {
            return -ERRNO_CODES.ENOTCONN; // The socket is not connected.
          }
          var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(sock.daddr), sock.dport);
          assert(!res.errno);
          return 0;
        }
        case 11: { // sendto
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), length = SYSCALLS.get(), flags = SYSCALLS.get(), dest = SYSCALLS.getSocketAddress(true);
          if (!dest) {
            // send, no address provided
            return FS.write(sock.stream, HEAP8,message, length);
          } else {
            // sendto an address
            return sock.sock_ops.sendmsg(sock, HEAP8,message, length, dest.addr, dest.port);
          }
        }
        case 12: { // recvfrom
          var sock = SYSCALLS.getSocketFromFD(), buf = SYSCALLS.get(), len = SYSCALLS.get(), flags = SYSCALLS.get(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          var msg = sock.sock_ops.recvmsg(sock, len);
          if (!msg) return 0; // socket is closed
          if (addr) {
            var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(msg.addr), msg.port);
            assert(!res.errno);
          }
          HEAPU8.set(msg.buffer, buf);
          return msg.buffer.byteLength;
        }
        case 14: { // setsockopt
          return -ERRNO_CODES.ENOPROTOOPT; // The option is unknown at the level indicated.
        }
        case 15: { // getsockopt
          var sock = SYSCALLS.getSocketFromFD(), level = SYSCALLS.get(), optname = SYSCALLS.get(), optval = SYSCALLS.get(), optlen = SYSCALLS.get();
          // Minimal getsockopt aimed at resolving https://github.com/kripken/emscripten/issues/2211
          // so only supports SOL_SOCKET with SO_ERROR.
          if (level === 1) {
            if (optname === 4) {
              HEAP32[((optval)>>2)]=sock.error;
              HEAP32[((optlen)>>2)]=4;
              sock.error = null; // Clear the error (The SO_ERROR option obtains and then clears this field).
              return 0;
            }
          }
          return -ERRNO_CODES.ENOPROTOOPT; // The option is unknown at the level indicated.
        }
        case 16: { // sendmsg
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), flags = SYSCALLS.get();
          var iov = HEAP32[(((message)+(8))>>2)];
          var num = HEAP32[(((message)+(12))>>2)];
          // read the address and port to send to
          var addr, port;
          var name = HEAP32[((message)>>2)];
          var namelen = HEAP32[(((message)+(4))>>2)];
          if (name) {
            var info = __read_sockaddr(name, namelen);
            if (info.errno) return -info.errno;
            port = info.port;
            addr = DNS.lookup_addr(info.addr) || info.addr;
          }
          // concatenate scatter-gather arrays into one message buffer
          var total = 0;
          for (var i = 0; i < num; i++) {
            total += HEAP32[(((iov)+((8 * i) + 4))>>2)];
          }
          var view = new Uint8Array(total);
          var offset = 0;
          for (var i = 0; i < num; i++) {
            var iovbase = HEAP32[(((iov)+((8 * i) + 0))>>2)];
            var iovlen = HEAP32[(((iov)+((8 * i) + 4))>>2)];
            for (var j = 0; j < iovlen; j++) {  
              view[offset++] = HEAP8[(((iovbase)+(j))>>0)];
            }
          }
          // write the buffer
          return sock.sock_ops.sendmsg(sock, view, 0, total, addr, port);
        }
        case 17: { // recvmsg
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), flags = SYSCALLS.get();
          var iov = HEAP32[(((message)+(8))>>2)];
          var num = HEAP32[(((message)+(12))>>2)];
          // get the total amount of data we can read across all arrays
          var total = 0;
          for (var i = 0; i < num; i++) {
            total += HEAP32[(((iov)+((8 * i) + 4))>>2)];
          }
          // try to read total data
          var msg = sock.sock_ops.recvmsg(sock, total);
          if (!msg) return 0; // socket is closed
  
          // TODO honor flags:
          // MSG_OOB
          // Requests out-of-band data. The significance and semantics of out-of-band data are protocol-specific.
          // MSG_PEEK
          // Peeks at the incoming message.
          // MSG_WAITALL
          // Requests that the function block until the full amount of data requested can be returned. The function may return a smaller amount of data if a signal is caught, if the connection is terminated, if MSG_PEEK was specified, or if an error is pending for the socket.
  
          // write the source address out
          var name = HEAP32[((message)>>2)];
          if (name) {
            var res = __write_sockaddr(name, sock.family, DNS.lookup_name(msg.addr), msg.port);
            assert(!res.errno);
          }
          // write the buffer out to the scatter-gather arrays
          var bytesRead = 0;
          var bytesRemaining = msg.buffer.byteLength;
          for (var i = 0; bytesRemaining > 0 && i < num; i++) {
            var iovbase = HEAP32[(((iov)+((8 * i) + 0))>>2)];
            var iovlen = HEAP32[(((iov)+((8 * i) + 4))>>2)];
            if (!iovlen) {
              continue;
            }
            var length = Math.min(iovlen, bytesRemaining);
            var buf = msg.buffer.subarray(bytesRead, bytesRead + length);
            HEAPU8.set(buf, iovbase + bytesRead);
            bytesRead += length;
            bytesRemaining -= length;
          }
  
          // TODO set msghdr.msg_flags
          // MSG_EOR
          // End of record was received (if supported by the protocol).
          // MSG_OOB
          // Out-of-band data was received.
          // MSG_TRUNC
          // Normal data was truncated.
          // MSG_CTRUNC
  
          return bytesRead;
        }
        default: abort('unsupported socketcall syscall ' + call);
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall114(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // wait4
      abort('cannot wait on child processes');
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall118(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fsync
      var stream = SYSCALLS.getStreamFromFD();
      return 0; // we can't do anything synchronously; the in-memory FS is already synced to
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall12(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // chdir
      var path = SYSCALLS.getStr();
      FS.chdir(path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall121(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setdomainname
      return -ERRNO_CODES.EPERM;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall122(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // uname
      var buf = SYSCALLS.get();
      if (!buf) return -ERRNO_CODES.EFAULT
      var layout = {"sysname":0,"nodename":65,"domainname":325,"machine":260,"version":195,"release":130,"__size__":390};
      function copyString(element, value) {
        var offset = layout[element];
        writeAsciiToMemory(value, buf + offset);
      }
      copyString('sysname', 'Emscripten');
      copyString('nodename', 'emscripten');
      copyString('release', '1.0');
      copyString('version', '#1');
      copyString('machine', 'x86-JS');
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall125(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mprotect
      return 0; // let's not and say we did
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  var PROCINFO={ppid:1,pid:42,sid:42,pgid:42};function ___syscall132(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getpgid
      var pid = SYSCALLS.get();
      if (pid && pid !== PROCINFO.pid) return -ERRNO_CODES.ESRCH;
      return PROCINFO.pgid;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall133(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fchdir
      var stream = SYSCALLS.getStreamFromFD();
      FS.chdir(stream.path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall14(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mknod
      var path = SYSCALLS.getStr(), mode = SYSCALLS.get(), dev = SYSCALLS.get();
      return SYSCALLS.doMknod(path, mode, dev);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall140(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // llseek
      var stream = SYSCALLS.getStreamFromFD(), offset_high = SYSCALLS.get(), offset_low = SYSCALLS.get(), result = SYSCALLS.get(), whence = SYSCALLS.get();
      // NOTE: offset_high is unused - Emscripten's off_t is 32-bit
      var offset = offset_low;
      FS.llseek(stream, offset, whence);
      HEAP32[((result)>>2)]=stream.position;
      if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null; // reset readdir state
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall142(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // newselect
      // readfds are supported,
      // writefds checks socket open status
      // exceptfds not supported
      // timeout is always 0 - fully async
      var nfds = SYSCALLS.get(), readfds = SYSCALLS.get(), writefds = SYSCALLS.get(), exceptfds = SYSCALLS.get(), timeout = SYSCALLS.get();
  
      assert(nfds <= 64, 'nfds must be less than or equal to 64');  // fd sets have 64 bits // TODO: this could be 1024 based on current musl headers
      assert(!exceptfds, 'exceptfds not supported');
  
      var total = 0;
      
      var srcReadLow = (readfds ? HEAP32[((readfds)>>2)] : 0),
          srcReadHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0);
      var srcWriteLow = (writefds ? HEAP32[((writefds)>>2)] : 0),
          srcWriteHigh = (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0);
      var srcExceptLow = (exceptfds ? HEAP32[((exceptfds)>>2)] : 0),
          srcExceptHigh = (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      var dstReadLow = 0,
          dstReadHigh = 0;
      var dstWriteLow = 0,
          dstWriteHigh = 0;
      var dstExceptLow = 0,
          dstExceptHigh = 0;
  
      var allLow = (readfds ? HEAP32[((readfds)>>2)] : 0) |
                   (writefds ? HEAP32[((writefds)>>2)] : 0) |
                   (exceptfds ? HEAP32[((exceptfds)>>2)] : 0);
      var allHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0) |
                    (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0) |
                    (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      function check(fd, low, high, val) {
        return (fd < 32 ? (low & val) : (high & val));
      }
  
      for (var fd = 0; fd < nfds; fd++) {
        var mask = 1 << (fd % 32);
        if (!(check(fd, allLow, allHigh, mask))) {
          continue;  // index isn't in the set
        }
  
        var stream = FS.getStream(fd);
        if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  
        var flags = SYSCALLS.DEFAULT_POLLMASK;
  
        if (stream.stream_ops.poll) {
          flags = stream.stream_ops.poll(stream);
        }
  
        if ((flags & 1) && check(fd, srcReadLow, srcReadHigh, mask)) {
          fd < 32 ? (dstReadLow = dstReadLow | mask) : (dstReadHigh = dstReadHigh | mask);
          total++;
        }
        if ((flags & 4) && check(fd, srcWriteLow, srcWriteHigh, mask)) {
          fd < 32 ? (dstWriteLow = dstWriteLow | mask) : (dstWriteHigh = dstWriteHigh | mask);
          total++;
        }
        if ((flags & 2) && check(fd, srcExceptLow, srcExceptHigh, mask)) {
          fd < 32 ? (dstExceptLow = dstExceptLow | mask) : (dstExceptHigh = dstExceptHigh | mask);
          total++;
        }
      }
  
      if (readfds) {
        HEAP32[((readfds)>>2)]=dstReadLow;
        HEAP32[(((readfds)+(4))>>2)]=dstReadHigh;
      }
      if (writefds) {
        HEAP32[((writefds)>>2)]=dstWriteLow;
        HEAP32[(((writefds)+(4))>>2)]=dstWriteHigh;
      }
      if (exceptfds) {
        HEAP32[((exceptfds)>>2)]=dstExceptLow;
        HEAP32[(((exceptfds)+(4))>>2)]=dstExceptHigh;
      }
      
      return total;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall144(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // msync
      var addr = SYSCALLS.get(), len = SYSCALLS.get(), flags = SYSCALLS.get();
      var info = SYSCALLS.mappings[addr];
      if (!info) return 0;
      SYSCALLS.doMsync(addr, FS.getStream(info.fd), len, info.flags);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall145(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readv
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doReadv(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall146(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // writev
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doWritev(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall147(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getsid
      var pid = SYSCALLS.get();
      if (pid && pid !== PROCINFO.pid) return -ERRNO_CODES.ESRCH;
      return PROCINFO.sid;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall148(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fdatasync
      var stream = SYSCALLS.getStreamFromFD();
      return 0; // we can't do anything synchronously; the in-memory FS is already synced to
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall15(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // chmod
      var path = SYSCALLS.getStr(), mode = SYSCALLS.get();
      FS.chmod(path, mode);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  function ___syscall153(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // munlockall
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }function ___syscall150() {
  return ___syscall153.apply(null, arguments)
  }

  function ___syscall151() {
  return ___syscall153.apply(null, arguments)
  }

  function ___syscall152() {
  return ___syscall153.apply(null, arguments)
  }


  function ___syscall163(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mremap
      return -ERRNO_CODES.ENOMEM; // never succeed
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall168(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // poll
      var fds = SYSCALLS.get(), nfds = SYSCALLS.get(), timeout = SYSCALLS.get();
      var nonzero = 0;
      for (var i = 0; i < nfds; i++) {
        var pollfd = fds + 8 * i;
        var fd = HEAP32[((pollfd)>>2)];
        var events = HEAP16[(((pollfd)+(4))>>1)];
        var mask = 32;
        var stream = FS.getStream(fd);
        if (stream) {
          mask = SYSCALLS.DEFAULT_POLLMASK;
          if (stream.stream_ops.poll) {
            mask = stream.stream_ops.poll(stream);
          }
        }
        mask &= events | 8 | 16;
        if (mask) nonzero++;
        HEAP16[(((pollfd)+(6))>>1)]=mask;
      }
      return nonzero;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall180(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pread64
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get(), zero = SYSCALLS.getZero(), offset = SYSCALLS.get64();
      return FS.read(stream, HEAP8,buf, count, offset);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall181(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pwrite64
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get(), zero = SYSCALLS.getZero(), offset = SYSCALLS.get64();
      return FS.write(stream, HEAP8,buf, count, offset);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall183(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getcwd
      var buf = SYSCALLS.get(), size = SYSCALLS.get();
      if (size === 0) return -ERRNO_CODES.EINVAL;
      var cwd = FS.cwd();
      var cwdLengthInBytes = lengthBytesUTF8(cwd);
      if (size < cwdLengthInBytes + 1) return -ERRNO_CODES.ERANGE;
      stringToUTF8(cwd, buf, size);
      return buf;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall191(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ugetrlimit
      var resource = SYSCALLS.get(), rlim = SYSCALLS.get();
      HEAP32[((rlim)>>2)]=-1;  // RLIM_INFINITY
      HEAP32[(((rlim)+(4))>>2)]=-1;  // RLIM_INFINITY
      HEAP32[(((rlim)+(8))>>2)]=-1;  // RLIM_INFINITY
      HEAP32[(((rlim)+(12))>>2)]=-1;  // RLIM_INFINITY
      return 0; // just report no limits
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall192(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mmap2
      var addr = SYSCALLS.get(), len = SYSCALLS.get(), prot = SYSCALLS.get(), flags = SYSCALLS.get(), fd = SYSCALLS.get(), off = SYSCALLS.get()
      off <<= 12; // undo pgoffset
      var ptr;
      var allocated = false;
      if (fd === -1) {
        ptr = _memalign(PAGE_SIZE, len);
        if (!ptr) return -ERRNO_CODES.ENOMEM;
        _memset(ptr, 0, len);
        allocated = true;
      } else {
        var info = FS.getStream(fd);
        if (!info) return -ERRNO_CODES.EBADF;
        var res = FS.mmap(info, HEAPU8, addr, len, off, prot, flags);
        ptr = res.ptr;
        allocated = res.allocated;
      }
      SYSCALLS.mappings[ptr] = { malloc: ptr, len: len, allocated: allocated, fd: fd, flags: flags };
      return ptr;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall193(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // truncate64
      var path = SYSCALLS.getStr(), zero = SYSCALLS.getZero(), length = SYSCALLS.get64();
      FS.truncate(path, length);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall194(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ftruncate64
      var fd = SYSCALLS.get(), zero = SYSCALLS.getZero(), length = SYSCALLS.get64();
      FS.ftruncate(fd, length);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall195(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_stat64
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall196(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_lstat64
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.lstat, path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall197(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_fstat64
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, stream.path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall198(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // lchown32
      var path = SYSCALLS.getStr(), owner = SYSCALLS.get(), group = SYSCALLS.get();
      FS.chown(path, owner, group); // XXX we ignore the 'l' aspect, and do the same as chown
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  function ___syscall202(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getgid32
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }function ___syscall199() {
  return ___syscall202.apply(null, arguments)
  }

  function ___syscall20(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getpid
      return PROCINFO.pid;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall200() {
  return ___syscall202.apply(null, arguments)
  }

  function ___syscall201() {
  return ___syscall202.apply(null, arguments)
  }


  function ___syscall205(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getgroups32
      var size = SYSCALLS.get(), list = SYSCALLS.get();
      if (size < 1) return -ERRNO_CODES.EINVAL;
      HEAP32[((list)>>2)]=0;
      return 1;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall207(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fchown32
      var fd = SYSCALLS.get(), owner = SYSCALLS.get(), group = SYSCALLS.get();
      FS.fchown(fd, owner, group);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  function ___syscall211(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getresgid32
      var ruid = SYSCALLS.get(), euid = SYSCALLS.get(), suid = SYSCALLS.get();
      HEAP32[((ruid)>>2)]=0;
      HEAP32[((euid)>>2)]=0;
      HEAP32[((suid)>>2)]=0;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }function ___syscall209() {
  return ___syscall211.apply(null, arguments)
  }


  function ___syscall212(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // chown32
      var path = SYSCALLS.getStr(), owner = SYSCALLS.get(), group = SYSCALLS.get();
      FS.chown(path, owner, group);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall218(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mincore
      return -ERRNO_CODES.ENOSYS; // unsupported feature
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall219(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // madvise
      return 0; // advice is welcome, but ignored
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall220(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_getdents64
      var stream = SYSCALLS.getStreamFromFD(), dirp = SYSCALLS.get(), count = SYSCALLS.get();
      if (!stream.getdents) {
        stream.getdents = FS.readdir(stream.path);
      }
      var pos = 0;
      while (stream.getdents.length > 0 && pos + 268 <= count) {
        var id;
        var type;
        var name = stream.getdents.pop();
        if (name[0] === '.') {
          id = 1;
          type = 4; // DT_DIR
        } else {
          var child = FS.lookupNode(stream.node, name);
          id = child.id;
          type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
                 FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
                 FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
                 8;                             // DT_REG, regular file.
        }
        HEAP32[((dirp + pos)>>2)]=id;
        HEAP32[(((dirp + pos)+(4))>>2)]=stream.position;
        HEAP16[(((dirp + pos)+(8))>>1)]=268;
        HEAP8[(((dirp + pos)+(10))>>0)]=type;
        stringToUTF8(name, dirp + pos + 11, 256);
        pos += 268;
      }
      return pos;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall221(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fcntl64
      var stream = SYSCALLS.getStreamFromFD(), cmd = SYSCALLS.get();
      switch (cmd) {
        case 0: {
          var arg = SYSCALLS.get();
          if (arg < 0) {
            return -ERRNO_CODES.EINVAL;
          }
          var newStream;
          newStream = FS.open(stream.path, stream.flags, 0, arg);
          return newStream.fd;
        }
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4: {
          var arg = SYSCALLS.get();
          stream.flags |= arg;
          return 0;
        }
        case 12:
        case 12: {
          var arg = SYSCALLS.get();
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        }
        case 13:
        case 14:
        case 13:
        case 14:
          return 0; // Pretend that the locking is successful.
        case 16:
        case 8:
          return -ERRNO_CODES.EINVAL; // These are for sockets. We don't have them fully implemented yet.
        case 9:
          // musl trusts getown return values, due to a bug where they must be, as they overlap with errors. just return -1 here, so fnctl() returns that, and we set errno ourselves.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default: {
          return -ERRNO_CODES.EINVAL;
        }
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall268(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // statfs64
      var path = SYSCALLS.getStr(), size = SYSCALLS.get(), buf = SYSCALLS.get();
      assert(size === 64);
      // NOTE: None of the constants here are true. We're just returning safe and
      //       sane values.
      HEAP32[(((buf)+(4))>>2)]=4096;
      HEAP32[(((buf)+(40))>>2)]=4096;
      HEAP32[(((buf)+(8))>>2)]=1000000;
      HEAP32[(((buf)+(12))>>2)]=500000;
      HEAP32[(((buf)+(16))>>2)]=500000;
      HEAP32[(((buf)+(20))>>2)]=FS.nextInode;
      HEAP32[(((buf)+(24))>>2)]=1000000;
      HEAP32[(((buf)+(28))>>2)]=42;
      HEAP32[(((buf)+(44))>>2)]=2;  // ST_NOSUID
      HEAP32[(((buf)+(36))>>2)]=255;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall269(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fstatfs64
      var stream = SYSCALLS.getStreamFromFD(), size = SYSCALLS.get(), buf = SYSCALLS.get();
      return ___syscall([268, 0, size, buf], 0);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall272(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fadvise64_64
      return 0; // your advice is important to us (but we can't use it)
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall29(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pause
      return -ERRNO_CODES.EINTR; // we can't pause
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall295(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // openat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), flags = SYSCALLS.get(), mode = SYSCALLS.get();
      path = SYSCALLS.calculateAt(dirfd, path);
      return FS.open(path, flags, mode).fd;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall296(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mkdirat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), mode = SYSCALLS.get();
      path = SYSCALLS.calculateAt(dirfd, path);
      return SYSCALLS.doMkdir(path, mode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall297(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mknodat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), mode = SYSCALLS.get(), dev = SYSCALLS.get();
      path = SYSCALLS.calculateAt(dirfd, path);
      return SYSCALLS.doMknod(path, mode, dev);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall298(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fchownat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), owner = SYSCALLS.get(), group = SYSCALLS.get(), flags = SYSCALLS.get();
      assert(flags === 0);
      path = SYSCALLS.calculateAt(dirfd, path);
      FS.chown(path, owner, group);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall3(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // read
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get();
      return FS.read(stream, HEAP8,buf, count);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall300(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fstatat64
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), buf = SYSCALLS.get(), flags = SYSCALLS.get();
      var nofollow = flags & 256;
      flags = flags & (~256);
      assert(!flags, flags);
      path = SYSCALLS.calculateAt(dirfd, path);
      return SYSCALLS.doStat(nofollow ? FS.lstat : FS.stat, path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall301(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // unlinkat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), flags = SYSCALLS.get();
      path = SYSCALLS.calculateAt(dirfd, path);
      if (flags === 0) {
        FS.unlink(path);
      } else if (flags === 512) {
        FS.rmdir(path);
      } else {
        abort('Invalid flags passed to unlinkat');
      }
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall302(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // renameat
      var olddirfd = SYSCALLS.get(), oldpath = SYSCALLS.getStr(), newdirfd = SYSCALLS.get(), newpath = SYSCALLS.getStr();
      oldpath = SYSCALLS.calculateAt(olddirfd, oldpath);
      newpath = SYSCALLS.calculateAt(newdirfd, newpath);
      FS.rename(oldpath, newpath);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall303(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // linkat
      return -ERRNO_CODES.EMLINK; // no hardlinks for us
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall304(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // symlinkat
      var target = SYSCALLS.get(), newdirfd = SYSCALLS.get(), linkpath = SYSCALLS.get();
      linkpath = SYSCALLS.calculateAt(newdirfd, linkpath);
      FS.symlink(target, linkpath);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall305(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readlinkat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), buf = SYSCALLS.get(), bufsize = SYSCALLS.get();
      path = SYSCALLS.calculateAt(dirfd, path);
      return SYSCALLS.doReadlink(path, buf, bufsize);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall306(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fchmodat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), mode = SYSCALLS.get(), flags = SYSCALLS.get();
      assert(flags === 0);
      path = SYSCALLS.calculateAt(dirfd, path);
      FS.chmod(path, mode);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall308(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pselect
      return -ERRNO_CODES.ENOSYS; // unsupported feature
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall320(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // utimensat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), times = SYSCALLS.get(), flags = SYSCALLS.get();
      assert(flags === 0);
      path = SYSCALLS.calculateAt(dirfd, path);
      var seconds = HEAP32[((times)>>2)];
      var nanoseconds = HEAP32[(((times)+(4))>>2)];
      var atime = (seconds*1000) + (nanoseconds/(1000*1000));
      times += 8;
      seconds = HEAP32[((times)>>2)];
      nanoseconds = HEAP32[(((times)+(4))>>2)];
      var mtime = (seconds*1000) + (nanoseconds/(1000*1000));
      FS.utime(path, atime, mtime);
      return 0;  
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall324(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fallocate
      var stream = SYSCALLS.getStreamFromFD(), mode = SYSCALLS.get(), offset = SYSCALLS.get64(), len = SYSCALLS.get64();
      assert(mode === 0);
      FS.allocate(stream, offset, len);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall33(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // access
      var path = SYSCALLS.getStr(), amode = SYSCALLS.get();
      return SYSCALLS.doAccess(path, amode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall330(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // dup3
      var old = SYSCALLS.getStreamFromFD(), suggestFD = SYSCALLS.get(), flags = SYSCALLS.get();
      assert(!flags);
      if (old.fd === suggestFD) return -ERRNO_CODES.EINVAL;
      return SYSCALLS.doDup(old.path, old.flags, suggestFD);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall331(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pipe2
      return -ERRNO_CODES.ENOSYS; // unsupported feature
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall333(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // preadv
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get(), offset = SYSCALLS.get();
      return SYSCALLS.doReadv(stream, iov, iovcnt, offset);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall334(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pwritev
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get(), offset = SYSCALLS.get();
      return SYSCALLS.doWritev(stream, iov, iovcnt, offset);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall337(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // recvmmsg
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall34(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // nice
      var inc = SYSCALLS.get();
      return -ERRNO_CODES.EPERM; // no meaning to nice for our single-process environment
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall340(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // prlimit64
      var pid = SYSCALLS.get(), resource = SYSCALLS.get(), new_limit = SYSCALLS.get(), old_limit = SYSCALLS.get();
      if (old_limit) { // just report no limits
        HEAP32[((old_limit)>>2)]=-1;  // RLIM_INFINITY
        HEAP32[(((old_limit)+(4))>>2)]=-1;  // RLIM_INFINITY
        HEAP32[(((old_limit)+(8))>>2)]=-1;  // RLIM_INFINITY
        HEAP32[(((old_limit)+(12))>>2)]=-1;  // RLIM_INFINITY
      }
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall345(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // sendmmsg
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall36(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // sync
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall38(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // rename
      var old_path = SYSCALLS.getStr(), new_path = SYSCALLS.getStr();
      FS.rename(old_path, new_path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall39(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mkdir
      var path = SYSCALLS.getStr(), mode = SYSCALLS.get();
      return SYSCALLS.doMkdir(path, mode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall4(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // write
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get();
      return FS.write(stream, HEAP8,buf, count);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall40(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // rmdir
      var path = SYSCALLS.getStr();
      FS.rmdir(path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall41(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // dup
      var old = SYSCALLS.getStreamFromFD();
      return FS.open(old.path, old.flags, 0).fd;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  var PIPEFS={BUCKET_BUFFER_SIZE:8192,mount:function (mount) {
        // Do not pollute the real root directory or its child nodes with pipes
        // Looks like it is OK to create another pseudo-root node not linked to the FS.root hierarchy this way
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createPipe:function () {
        var pipe = {
          buckets: []
        };
  
        pipe.buckets.push({
          buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
          offset: 0,
          roffset: 0
        });
  
        var rName = PIPEFS.nextname();
        var wName = PIPEFS.nextname();
        var rNode = FS.createNode(PIPEFS.root, rName, 4096, 0);
        var wNode = FS.createNode(PIPEFS.root, wName, 4096, 0);
  
        rNode.pipe = pipe;
        wNode.pipe = pipe;
  
        var readableStream = FS.createStream({
          path: rName,
          node: rNode,
          flags: FS.modeStringToFlags('r'),
          seekable: false,
          stream_ops: PIPEFS.stream_ops
        });
        rNode.stream = readableStream;
  
        var writableStream = FS.createStream({
          path: wName,
          node: wNode,
          flags: FS.modeStringToFlags('w'),
          seekable: false,
          stream_ops: PIPEFS.stream_ops
        });
        wNode.stream = writableStream;
  
        return {
          readable_fd: readableStream.fd,
          writable_fd: writableStream.fd
        };
      },stream_ops:{poll:function (stream) {
          var pipe = stream.node.pipe;
  
          if ((stream.flags & 2097155) === 1) {
            return (256 | 4);
          } else {
            if (pipe.buckets.length > 0) {
              for (var i = 0; i < pipe.buckets.length; i++) {
                var bucket = pipe.buckets[i];
                if (bucket.offset - bucket.roffset > 0) {
                  return (64 | 1);
                }
              }
            }
          }
  
          return 0;
        },ioctl:function (stream, request, varargs) {
          return ERRNO_CODES.EINVAL;
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var pipe = stream.node.pipe;
          var currentLength = 0;
  
          for (var i = 0; i < pipe.buckets.length; i++) {
            var bucket = pipe.buckets[i];
            currentLength += bucket.offset - bucket.roffset;
          }
  
          assert(buffer instanceof ArrayBuffer || ArrayBuffer.isView(buffer));
          var data = buffer.subarray(offset, offset + length);
  
          if (length <= 0) {
            return 0;
          }
          if (currentLength == 0) {
            // Behave as if the read end is always non-blocking
            throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
          }
          var toRead = Math.min(currentLength, length);
  
          var totalRead = toRead;
          var toRemove = 0;
  
          for (var i = 0; i < pipe.buckets.length; i++) {
            var currBucket = pipe.buckets[i];
            var bucketSize = currBucket.offset - currBucket.roffset;
  
            if (toRead <= bucketSize) {
              var tmpSlice = currBucket.buffer.subarray(currBucket.roffset, currBucket.offset);
              if (toRead < bucketSize) {
                tmpSlice = tmpSlice.subarray(0, toRead);
                currBucket.roffset += toRead;
              } else {
                toRemove++;
              }
              data.set(tmpSlice);
              break;
            } else {
              var tmpSlice = currBucket.buffer.subarray(currBucket.roffset, currBucket.offset);
              data.set(tmpSlice);
              data = data.subarray(tmpSlice.byteLength);
              toRead -= tmpSlice.byteLength;
              toRemove++;
            }
          }
  
          if (toRemove && toRemove == pipe.buckets.length) {
            // Do not generate excessive garbage in use cases such as
            // write several bytes, read everything, write several bytes, read everything...
            toRemove--;
            pipe.buckets[toRemove].offset = 0;
            pipe.buckets[toRemove].roffset = 0;
          }
  
          pipe.buckets.splice(0, toRemove);
  
          return totalRead;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var pipe = stream.node.pipe;
  
          assert(buffer instanceof ArrayBuffer || ArrayBuffer.isView(buffer));
          var data = buffer.subarray(offset, offset + length);
  
          var dataLen = data.byteLength;
          if (dataLen <= 0) {
            return 0;
          }
  
          var currBucket = null;
  
          if (pipe.buckets.length == 0) {
            currBucket = {
              buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
              offset: 0,
              roffset: 0
            };
            pipe.buckets.push(currBucket);
          } else {
            currBucket = pipe.buckets[pipe.buckets.length - 1];
          }
  
          assert(currBucket.offset <= PIPEFS.BUCKET_BUFFER_SIZE);
  
          var freeBytesInCurrBuffer = PIPEFS.BUCKET_BUFFER_SIZE - currBucket.offset;
          if (freeBytesInCurrBuffer >= dataLen) {
            currBucket.buffer.set(data, currBucket.offset);
            currBucket.offset += dataLen;
            return dataLen;
          } else if (freeBytesInCurrBuffer > 0) {
            currBucket.buffer.set(data.subarray(0, freeBytesInCurrBuffer), currBucket.offset);
            currBucket.offset += freeBytesInCurrBuffer;
            data = data.subarray(freeBytesInCurrBuffer, data.byteLength);
          }
  
          var numBuckets = (data.byteLength / PIPEFS.BUCKET_BUFFER_SIZE) | 0;
          var remElements = data.byteLength % PIPEFS.BUCKET_BUFFER_SIZE;
  
          for (var i = 0; i < numBuckets; i++) {
            var newBucket = {
              buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
              offset: PIPEFS.BUCKET_BUFFER_SIZE,
              roffset: 0
            };
            pipe.buckets.push(newBucket);
            newBucket.buffer.set(data.subarray(0, PIPEFS.BUCKET_BUFFER_SIZE));
            data = data.subarray(PIPEFS.BUCKET_BUFFER_SIZE, data.byteLength);
          }
  
          if (remElements > 0) {
            var newBucket = {
              buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
              offset: data.byteLength,
              roffset: 0
            };
            pipe.buckets.push(newBucket);
            newBucket.buffer.set(data);
          }
  
          return dataLen;
        },close:function (stream) {
          var pipe = stream.node.pipe;
          pipe.buckets = null;
        }},nextname:function () {
        if (!PIPEFS.nextname.current) {
          PIPEFS.nextname.current = 0;
        }
        return 'pipe[' + (PIPEFS.nextname.current++) + ']';
      }};function ___syscall42(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // pipe
      var fdPtr = SYSCALLS.get();
  
      if (fdPtr == 0) {
        throw new FS.ErrnoError(ERRNO_CODES.EFAULT);
      }
  
      var res = PIPEFS.createPipe();
  
      HEAP32[((fdPtr)>>2)]=res.readable_fd;
      HEAP32[(((fdPtr)+(4))>>2)]=res.writable_fd;
  
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall5(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // open
      var pathname = SYSCALLS.getStr(), flags = SYSCALLS.get(), mode = SYSCALLS.get() // optional TODO
      var stream = FS.open(pathname, flags, mode);
      return stream.fd;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall51(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // acct
      return -ERRNO_CODES.ENOSYS; // unsupported features
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall54(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ioctl
      var stream = SYSCALLS.getStreamFromFD(), op = SYSCALLS.get();
      switch (op) {
        case 21509:
        case 21505: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        case 21510:
        case 21511:
        case 21512:
        case 21506:
        case 21507:
        case 21508: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0; // no-op, not actually adjusting terminal settings
        }
        case 21519: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          var argp = SYSCALLS.get();
          HEAP32[((argp)>>2)]=0;
          return 0;
        }
        case 21520: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return -ERRNO_CODES.EINVAL; // not supported
        }
        case 21531: {
          var argp = SYSCALLS.get();
          return FS.ioctl(stream, op, argp);
        }
        case 21523: {
          // TODO: in theory we should write to the winsize struct that gets
          // passed in, but for now musl doesn't read anything on it
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        case 21524: {
          // TODO: technically, this ioctl call should change the window size.
          // but, since emscripten doesn't have any concept of a terminal window
          // yet, we'll just silently throw it away as we do TIOCGWINSZ
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        default: abort('bad ioctl syscall ' + op);
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall57(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setpgid
      var pid = SYSCALLS.get(), pgid = SYSCALLS.get();
      if (pid && pid !== PROCINFO.pid) return -ERRNO_CODES.ESRCH;
      if (pgid && pgid !== PROCINFO.pgid) return -ERRNO_CODES.EPERM;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall6(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // close
      var stream = SYSCALLS.getStreamFromFD();
      FS.close(stream);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall60(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // umask
      var mask = SYSCALLS.get();
      var old = SYSCALLS.umask;
      SYSCALLS.umask = mask;
      return old;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall63(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // dup2
      var old = SYSCALLS.getStreamFromFD(), suggestFD = SYSCALLS.get();
      if (old.fd === suggestFD) return suggestFD;
      return SYSCALLS.doDup(old.path, old.flags, suggestFD);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall64(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getppid
      return PROCINFO.ppid;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall66(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setsid
      return 0; // no-op
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall75(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setrlimit
      return 0; // no-op
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall77(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getrusage
      var who = SYSCALLS.get(), usage = SYSCALLS.get();
      _memset(usage, 0, 136);
      HEAP32[((usage)>>2)]=1; // fake some values
      HEAP32[(((usage)+(4))>>2)]=2;
      HEAP32[(((usage)+(8))>>2)]=3;
      HEAP32[(((usage)+(12))>>2)]=4;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall83(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // symlink
      var target = SYSCALLS.getStr(), linkpath = SYSCALLS.getStr();
      FS.symlink(target, linkpath);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall85(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readlink
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get(), bufsize = SYSCALLS.get();
      return SYSCALLS.doReadlink(path, buf, bufsize);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall9(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // link
      var oldpath = SYSCALLS.get(), newpath = SYSCALLS.get();
      return -ERRNO_CODES.EMLINK; // no hardlinks for us
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall91(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // munmap
      var addr = SYSCALLS.get(), len = SYSCALLS.get();
      // TODO: support unmmap'ing parts of allocations
      var info = SYSCALLS.mappings[addr];
      if (!info) return 0;
      if (len === info.len) {
        var stream = FS.getStream(info.fd);
        SYSCALLS.doMsync(addr, stream, len, info.flags)
        FS.munmap(stream);
        SYSCALLS.mappings[addr] = null;
        if (info.allocated) {
          _free(info.malloc);
        }
      }
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall94(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fchmod
      var fd = SYSCALLS.get(), mode = SYSCALLS.get();
      FS.fchmod(fd, mode);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall96(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getpriority
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall97(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setpriority
      return -ERRNO_CODES.EPERM;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

   

  function ___unlock() {}

  function ___wait() {}

  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      exit(status);
    }

   

   

   


  function _fork() {
      // pid_t fork(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fork.html
      // We don't support multiple processes.
      ___setErrNo(ERRNO_CODES.EAGAIN);
      return -1;
    }

  
  var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocateUTF8(ENV[name]);
      return _getenv.ret;
    }

  function _getnameinfo(sa, salen, node, nodelen, serv, servlen, flags) {
      var info = __read_sockaddr(sa, salen);
      if (info.errno) {
        return -6;
      }
      var port = info.port;
      var addr = info.addr;
  
      var overflowed = false;
  
      if (node && nodelen) {
        var lookup;
        if ((flags & 1) || !(lookup = DNS.lookup_addr(addr))) {
          if (flags & 8) {
            return -2;
          }
        } else {
          addr = lookup;
        }
        var numBytesWrittenExclNull = stringToUTF8(addr, node, nodelen);
  
        if (numBytesWrittenExclNull+1 >= nodelen) {
          overflowed = true;
        }
      }
  
      if (serv && servlen) {
        port = '' + port;
        var numBytesWrittenExclNull = stringToUTF8(port, serv, servlen);
  
        if (numBytesWrittenExclNull+1 >= servlen) {
          overflowed = true;
        }
      }
  
      if (overflowed) {
        // Note: even when we overflow, getnameinfo() is specced to write out the truncated results.
        return -12;
      }
  
      return 0;
    }

  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
      var yday = ((date.getTime() - start) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }



  function _inet_addr(ptr) {
      var addr = __inet_pton4_raw(Pointer_stringify(ptr));
      if (addr === null) {
        return -1;
      }
      return addr;
    }

  function _kfunc1() {
  if (!Module['_kfunc1']) abort("external function 'kfunc1' is missing. perhaps a side module was not linked in? if this function was expected to arrive from a system library, try to build the MAIN_MODULE with EMCC_FORCE_STDLIBS=1 in the environment");return Module['_kfunc1'].apply(null, arguments);
  }

   

   

  function _llvm_copysign_f32(x, y) {
      return y < 0 || (y === 0 && 1/y < 0) ? -Math_abs(x) : Math_abs(x);
    }

  function _llvm_copysign_f64(x, y) {
      return y < 0 || (y === 0 && 1/y < 0) ? -Math_abs(x) : Math_abs(x);
    }

   

   

  function _llvm_stackrestore(p) {
      var self = _llvm_stacksave;
      var ret = self.LLVM_SAVEDSTACKS[p];
      self.LLVM_SAVEDSTACKS.splice(p, 1);
      stackRestore(ret);
    }

  function _llvm_stacksave() {
      var self = _llvm_stacksave;
      if (!self.LLVM_SAVEDSTACKS) {
        self.LLVM_SAVEDSTACKS = [];
      }
      self.LLVM_SAVEDSTACKS.push(stackSave());
      return self.LLVM_SAVEDSTACKS.length-1;
    }

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 

   

   

  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now']) {
        var start = self['performance']['now']();
        while (self['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }

  function _pthread_cleanup_pop() {
      assert(_pthread_cleanup_push.level == __ATEXIT__.length, 'cannot pop if something else added meanwhile!');
      __ATEXIT__.pop();
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

  function _pthread_cleanup_push(routine, arg) {
      __ATEXIT__.push(function() { Module['dynCall_vi'](routine, arg) })
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

  function _pthread_setcancelstate() { return 0; }

  function _pthread_sigmask() { return 0; }

  
    


   

   

  function _setitimer() {
      throw 'setitimer() is not implemented yet';
    }

  function _sigfillset(set) {
      HEAP32[((set)>>2)]=-1>>>0;
      return 0;
    }

  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
  
      var tm_zone = HEAP32[(((tm)+(40))>>2)];
  
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)],
        tm_gmtoff: HEAP32[(((tm)+(36))>>2)],
        tm_zone: tm_zone ? Pointer_stringify(tm_zone) : ''
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S'                  // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else {
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls((year/100)|0,2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year.
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes
          // January 4th, which is also the week that includes the first Thursday of the year, and
          // is also the first week that contains at least four days in the year.
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of
          // the last week of the preceding year; thus, for Saturday 2nd January 1999,
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th,
          // or 31st is a Monday, it and any following days are part of week 1 of the following year.
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
  
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          var twelveHour = date.tm_hour;
          if (twelveHour == 0) twelveHour = 12;
          else if (twelveHour > 12) twelveHour -= 12;
          return leadingNulls(twelveHour, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour >= 0 && date.tm_hour < 12) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53].
          // The first Sunday of January is the first day of week 1;
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week)
          // as a decimal number [01,53]. If the week containing 1 January has four
          // or more days in the new year, then it is considered week 1.
          // Otherwise, it is the last week of the previous year, and the next week is week 1.
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          }
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53].
          // The first Monday of January is the first day of week 1;
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ).
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich).
          var off = date.tm_gmtoff;
          var ahead = off >= 0;
          off = Math.abs(off) / 60;
          // convert from minutes into hhmm format (which means 60 minutes = 100 units)
          off = (off / 60)*100 + (off % 60);
          return (ahead ? '+' : '-') + String("0000" + off).slice(-4);
        },
        '%Z': function(date) {
          return date.tm_zone;
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      }
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  
  function _wait(stat_loc) {
      // pid_t wait(int *stat_loc);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/wait.html
      // Makes no sense in a single-process environment.
      ___setErrNo(ERRNO_CODES.ECHILD);
      return -1;
    }function _waitpid() {
  return _wait.apply(null, arguments)
  }




  var __impure_ptr=STATICTOP; STATICTOP += 16;;

  var ___dso_handle=STATICTOP; STATICTOP += 16;;



  function _utime(path, times) {
      // int utime(const char *path, const struct utimbuf *times);
      // http://pubs.opengroup.org/onlinepubs/009695399/basedefs/utime.h.html
      var time;
      if (times) {
        // NOTE: We don't keep track of access timestamps.
        var offset = 4;
        time = HEAP32[(((times)+(offset))>>2)];
        time *= 1000;
      } else {
        time = Date.now();
      }
      path = Pointer_stringify(path);
      try {
        FS.utime(path, time, time);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }


  function _utimes(path, times) {
      var time;
      if (times) {
        var offset = 8 + 0;
        time = HEAP32[(((times)+(offset))>>2)] * 1000;
        offset = 8 + 4;
        time += HEAP32[(((times)+(offset))>>2)] / 1000;
      } else {
        time = Date.now();
      }
      path = Pointer_stringify(path);
      try {
        FS.utime(path, time, time);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _flock(fd, operation) {
      // int flock(int fd, int operation);
      // Pretend to succeed
      return 0;
    }


  function _chroot(path) {
      // int chroot(const char *path);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/chroot.html
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    }


  function _fpathconf(fildes, name) {
      // long fpathconf(int fildes, int name);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/encrypt.html
      // NOTE: The first parameter is ignored, so pathconf == fpathconf.
      // The constants here aren't real values. Just mimicking glibc.
      switch (name) {
        case 0:
          return 32000;
        case 1:
        case 2:
        case 3:
          return 255;
        case 4:
        case 5:
        case 16:
        case 17:
        case 18:
          return 4096;
        case 6:
        case 7:
        case 20:
          return 1;
        case 8:
          return 0;
        case 9:
        case 10:
        case 11:
        case 12:
        case 14:
        case 15:
        case 19:
          return -1;
        case 13:
          return 64;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function _pathconf() {
  return _fpathconf.apply(null, arguments)
  }


  function _confstr(name, buf, len) {
      // size_t confstr(int name, char *buf, size_t len);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/confstr.html
      var value;
      switch (name) {
        case 0:
          value = ENV['PATH'] || '/';
          break;
        case 1:
          // Mimicking glibc.
          value = 'POSIX_V6_ILP32_OFF32\nPOSIX_V6_ILP32_OFFBIG';
          break;
        case 2:
          // This JS implementation was tested against this glibc version.
          value = 'glibc 2.14';
          break;
        case 3:
          // We don't support pthreads.
          value = '';
          break;
        case 1118:
        case 1122:
        case 1124:
        case 1125:
        case 1126:
        case 1128:
        case 1129:
        case 1130:
          value = '';
          break;
        case 1116:
        case 1117:
        case 1121:
          value = '-m32';
          break;
        case 1120:
          value = '-m32 -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64';
          break;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return 0;
      }
      if (len == 0 || buf == 0) {
        return value.length + 1;
      } else {
        var length = Math.min(len, value.length);
        for (var i = 0; i < length; i++) {
          HEAP8[(((buf)+(i))>>0)]=value.charCodeAt(i);
        }
        if (len > length) HEAP8[(((buf)+(i++))>>0)]=0;
        return i;
      }
    }

  function _execl(/* ... */) {
      // int execl(const char *path, const char *arg0, ... /*, (char *)0 */);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/exec.html
      // We don't support executing external code.
      ___setErrNo(ERRNO_CODES.ENOEXEC);
      return -1;
    }

  function _execle() {
  return _execl.apply(null, arguments)
  }

  function _execlp() {
  return _execl.apply(null, arguments)
  }

  function _execv() {
  return _execl.apply(null, arguments)
  }

  function _execve() {
  return _execl.apply(null, arguments)
  }

  function _execvp() {
  return _execl.apply(null, arguments)
  }

  function ___execvpe() {
  return _execl.apply(null, arguments)
  }

  function _fexecve() {
  return _execl.apply(null, arguments)
  }



  function _vfork() {
  return _fork.apply(null, arguments)
  }

  function _posix_spawn() {
  return _fork.apply(null, arguments)
  }

  function _posix_spawnp() {
  return _fork.apply(null, arguments)
  }

  
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 85:
          var maxHeapSize = 2*1024*1024*1024 - 16777216;
          maxHeapSize = HEAPU8.length;
          return maxHeapSize / PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 79:
          return 0;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }function _setgroups(ngroups, gidset) {
      // int setgroups(int ngroups, const gid_t *gidset);
      // https://developer.apple.com/library/mac/#documentation/Darwin/Reference/ManPages/man2/setgroups.2.html
      if (ngroups < 1 || ngroups > _sysconf(3)) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        // We have just one process/user/group, so it makes no sense to set groups.
        ___setErrNo(ERRNO_CODES.EPERM);
        return -1;
      }
    }

  function _getpagesize() {
      // int getpagesize(void);
      return PAGE_SIZE;
    }




   

  function _system(command) {
      // int system(const char *command);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/system.html
      // Can't call external programs.
      ___setErrNo(ERRNO_CODES.EAGAIN);
      return -1;
    }



  var _abs=Math_abs;


  function _exit(status) {
      __exit(status);
    }

  function __Exit(status) {
      __exit(status);
    }

  function __ZSt9terminatev() {
      _exit(-1234);
    }


  function _atexit(func, arg) {
      warnOnce('atexit() called, but EXIT_RUNTIME is not set, so atexits() will not be called. set EXIT_RUNTIME to 1 (see the FAQ)');
      __ATEXIT__.unshift({ func: func, arg: arg });
    }

  function ___cxa_atexit() {
  return _atexit.apply(null, arguments)
  }

  function ___cxa_thread_atexit() {
  return _atexit.apply(null, arguments)
  }

  function ___cxa_thread_atexit_impl() {
  return _atexit.apply(null, arguments)
  }

  function _abort() {
      Module['abort']();
    }

  function ___buildEnvironment(environ) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = ENV['LOGNAME'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C.UTF-8';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = getMemory(TOTAL_ENV_SIZE);
        envPtr = getMemory(MAX_ENV_VALUES * 4);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in ENV) {
        if (typeof ENV[key] === 'string') {
          var line = key + '=' + ENV[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }





  function _clearenv() {
      // int clearenv (void);
      // http://www.gnu.org/s/hello/manual/libc/Environment-Access.html#index-clearenv-3107
      ENV = {};
      ___buildEnvironment(__get_environ());
      return 0;
    }


  function _setenv(envname, envval, overwrite) {
      // int setenv(const char *envname, const char *envval, int overwrite);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/setenv.html
      if (envname === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = Pointer_stringify(envname);
      var val = Pointer_stringify(envval);
      if (name === '' || name.indexOf('=') !== -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      if (ENV.hasOwnProperty(name) && !overwrite) return 0;
      ENV[name] = val;
      ___buildEnvironment(__get_environ());
      return 0;
    }


  function _unsetenv(name) {
      // int unsetenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/unsetenv.html
      if (name === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      name = Pointer_stringify(name);
      if (name === '' || name.indexOf('=') !== -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      if (ENV.hasOwnProperty(name)) {
        delete ENV[name];
        ___buildEnvironment(__get_environ());
      }
      return 0;
    }


  function _putenv(string) {
      // int putenv(char *string);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/putenv.html
      // WARNING: According to the standard (and the glibc implementation), the
      //          string is taken by reference so future changes are reflected.
      //          We copy it instead, possibly breaking some uses.
      if (string === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      string = Pointer_stringify(string);
      var splitPoint = string.indexOf('=')
      if (string === '' || string.indexOf('=') === -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = string.slice(0, splitPoint);
      var value = string.slice(splitPoint + 1);
      if (!(name in ENV) || ENV[name] !== value) {
        ENV[name] = value;
        ___buildEnvironment(__get_environ());
      }
      return 0;
    }

  function _getloadavg(loadavg, nelem) {
      // int getloadavg(double loadavg[], int nelem);
      // http://linux.die.net/man/3/getloadavg
      var limit = Math.min(nelem, 3);
      var doubleSize = 8;
      for (var i = 0; i < limit; i++) {
        HEAPF64[(((loadavg)+(i * doubleSize))>>3)]=0.1;
      }
      return limit;
    }

  function _arc4random() {
  return _rand.apply(null, arguments)
  }



  var _llvm_memcpy_i32=_memcpy;

  var _llvm_memcpy_i64=_memcpy;

  var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;

  var _llvm_memcpy_p0i8_p0i8_i64=_memcpy;


  var _llvm_memmove_i32=_memmove;

  var _llvm_memmove_i64=_memmove;

  var _llvm_memmove_p0i8_p0i8_i32=_memmove;

  var _llvm_memmove_p0i8_p0i8_i64=_memmove;


  var _llvm_memset_i32=_memset;

  var _llvm_memset_p0i8_i32=_memset;

  var _llvm_memset_p0i8_i64=_memset;

  function ___builtin_prefetch(){}

  function _llvm_va_end() {}

  function _llvm_va_copy(ppdest, ppsrc) {
      // copy the list start
      HEAP8[((ppdest)>>0)]=HEAP8[((ppsrc)>>0)];HEAP8[(((ppdest)+(1))>>0)]=HEAP8[(((ppsrc)+(1))>>0)];HEAP8[(((ppdest)+(2))>>0)]=HEAP8[(((ppsrc)+(2))>>0)];HEAP8[(((ppdest)+(3))>>0)]=HEAP8[(((ppsrc)+(3))>>0)];
  
      // copy the list's current offset (will be advanced with each call to va_arg)
      HEAP8[((ppdest+4)>>0)]=HEAP8[((ppsrc+4)>>0)];HEAP8[(((ppdest+4)+(1))>>0)]=HEAP8[(((ppsrc+4)+(1))>>0)];HEAP8[(((ppdest+4)+(2))>>0)]=HEAP8[(((ppsrc+4)+(2))>>0)];HEAP8[(((ppdest+4)+(3))>>0)]=HEAP8[(((ppsrc+4)+(3))>>0)];
    }



  function _llvm_bswap_i64(l, h) {
      var retl = _llvm_bswap_i32(h)>>>0;
      var reth = _llvm_bswap_i32(l)>>>0;
      return ((setTempRet0(reth),retl)|0);
    }

   

   

   


  function _llvm_cttz_i64(l, h) {
      var ret = _llvm_cttz_i32(l);
      if (ret == 32) ret += _llvm_cttz_i32(h);
      return ((setTempRet0(0),ret)|0);
    }

   

   

  function _llvm_trap() {
      abort('trap!');
    }

  function _llvm_prefetch(){}

  function ___assert_fail(condition, filename, line, func) {
      abort('Assertion failed: ' + Pointer_stringify(condition) + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function']);
    }

  function ___assert_func(filename, line, func, condition) {
      abort('Assertion failed: ' + (condition ? Pointer_stringify(condition) : 'unknown condition') + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function']);
    }

  var EXCEPTIONS={last:0,caught:[],infos:{},deAdjust:function (adjusted) {
        if (!adjusted || EXCEPTIONS.infos[adjusted]) return adjusted;
        for (var key in EXCEPTIONS.infos) {
          var ptr = +key; // the iteration key is a string, and if we throw this, it must be an integer as that is what we look for
          var info = EXCEPTIONS.infos[ptr];
          if (info.adjusted === adjusted) {
            return ptr;
          }
        }
        return adjusted;
      },addRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount++;
      },decRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        assert(info.refcount > 0);
        info.refcount--;
        // A rethrown exception can reach refcount 0; it must not be discarded
        // Its next handler will clear the rethrown flag and addRef it, prior to
        // final decRef and destruction here
        if (info.refcount === 0 && !info.rethrown) {
          if (info.destructor) {
            Module['dynCall_vi'](info.destructor, ptr);
          }
          delete EXCEPTIONS.infos[ptr];
          ___cxa_free_exception(ptr);
        }
      },clearRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount = 0;
      }};

  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }

  function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
        err('exception during cxa_free_exception: ' + e);
      }
    }

  function ___cxa_increment_exception_refcount(ptr) {
      EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
    }

  function ___cxa_decrement_exception_refcount(ptr) {
      EXCEPTIONS.decRef(EXCEPTIONS.deAdjust(ptr));
    }

  
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }
  
  
  function ___resumeException(ptr) {
      if (!EXCEPTIONS.last) { EXCEPTIONS.last = ptr; }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
    }function ___cxa_find_matching_catch() {
      var thrown = EXCEPTIONS.last;
      if (!thrown) {
        // just pass through the null ptr
        return ((setTempRet0(0),0)|0);
      }
      var info = EXCEPTIONS.infos[thrown];
      var throwntype = info.type;
      if (!throwntype) {
        // just pass through the thrown ptr
        return ((setTempRet0(0),thrown)|0);
      }
      var typeArray = Array.prototype.slice.call(arguments);
  
      var pointer = Module['___cxa_is_pointer_type'](throwntype);
      // can_catch receives a **, add indirection
      if (!___cxa_find_matching_catch.buffer) ___cxa_find_matching_catch.buffer = _malloc(4);
      HEAP32[((___cxa_find_matching_catch.buffer)>>2)]=thrown;
      thrown = ___cxa_find_matching_catch.buffer;
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (typeArray[i] && Module['___cxa_can_catch'](typeArray[i], throwntype, thrown)) {
          thrown = HEAP32[((thrown)>>2)]; // undo indirection
          info.adjusted = thrown;
          return ((setTempRet0(typeArray[i]),thrown)|0);
        }
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      thrown = HEAP32[((thrown)>>2)]; // undo indirection
      return ((setTempRet0(throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      EXCEPTIONS.infos[ptr] = {
        ptr: ptr,
        adjusted: ptr,
        type: type,
        destructor: destructor,
        refcount: 0,
        caught: false,
        rethrown: false
      };
      EXCEPTIONS.last = ptr;
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
    }

  
  function ___cxa_end_catch() {
      // Clear state flag.
      Module['setThrew'](0);
      // Call destructor if one is registered then clear it.
      var ptr = EXCEPTIONS.caught.pop();
      if (ptr) {
        EXCEPTIONS.decRef(EXCEPTIONS.deAdjust(ptr));
        EXCEPTIONS.last = 0; // XXX in decRef?
      }
    }function ___cxa_rethrow() {
      var ptr = EXCEPTIONS.caught.pop();
      ptr = EXCEPTIONS.deAdjust(ptr);
      if (!EXCEPTIONS.infos[ptr].rethrown) {
        // Only pop if the corresponding push was through rethrow_primary_exception
        EXCEPTIONS.caught.push(ptr)
        EXCEPTIONS.infos[ptr].rethrown = true;
      }
      EXCEPTIONS.last = ptr;
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
    }

  function _llvm_eh_exception() {
      return EXCEPTIONS.last;
    }

  var _llvm_eh_selector__jsargs=true;

  function _llvm_eh_selector(unused_exception_value, personality/*, varargs*/) {
      var type = EXCEPTIONS.last;
      for (var i = 2; i < arguments.length; i++) {
        if (arguments[i] ==  type) return type;
      }
      return 0;
    }

  function _llvm_eh_typeid_for(type) {
      return type;
    }

  function ___cxa_begin_catch(ptr) {
      var info = EXCEPTIONS.infos[ptr];
      if (info && !info.caught) {
        info.caught = true;
        __ZSt18uncaught_exceptionv.uncaught_exception--;
      }
      if (info) info.rethrown = false;
      EXCEPTIONS.caught.push(ptr);
      EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
      return ptr;
    }


  function ___cxa_get_exception_ptr(ptr) {
      // TODO: use info.adjusted?
      return ptr;
    }


  function ___cxa_uncaught_exception() {
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }

  function ___cxa_call_unexpected(exception) {
      err('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }

  function ___cxa_current_primary_exception() {
      var ret = EXCEPTIONS.caught[EXCEPTIONS.caught.length-1] || 0;
      if (ret) EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ret));
      return ret;
    }

  function ___cxa_rethrow_primary_exception(ptr) {
      if (!ptr) return;
      EXCEPTIONS.caught.push(ptr);
      EXCEPTIONS.infos[ptr].rethrown = true;
      ___cxa_rethrow();
    }

  function _terminate() {
  return ___cxa_call_unexpected.apply(null, arguments)
  }

  function ___gxx_personality_v0() {
    }

  function ___gcc_personality_v0() {
    }





  function ___cxa_pure_virtual() {
      ABORT = true;
      throw 'Pure virtual function called!';
    }

  function _llvm_flt_rounds() {
      return -1; // 'indeterminable' for FLT_ROUNDS
    }

  function _llvm_objectsize_i32() { return -1 }

   

  function _llvm_mono_load_i8_p0i8(ptr) {
      return HEAP8[((ptr)>>0)];
    }

  function _llvm_mono_store_i8_p0i8(value, ptr) {
      HEAP8[((ptr)>>0)]=value;
    }

  function _llvm_mono_load_i16_p0i16(ptr) {
      return HEAP16[((ptr)>>1)];
    }

  function _llvm_mono_store_i16_p0i16(value, ptr) {
      HEAP16[((ptr)>>1)]=value;
    }

  function _llvm_mono_load_i32_p0i32(ptr) {
      return HEAP32[((ptr)>>2)];
    }

  function _llvm_mono_store_i32_p0i32(value, ptr) {
      HEAP32[((ptr)>>2)]=value;
    }

  var _cos=Math_cos;

  var _cosf=Math_cos;

  var _cosl=Math_cos;

  var _sin=Math_sin;

  var _sinf=Math_sin;

  var _sinl=Math_sin;

  var _tan=Math_tan;

  var _tanf=Math_tan;

  var _tanl=Math_tan;

  var _acos=Math_acos;

  var _acosf=Math_acos;

  var _acosl=Math_acos;

  var _asin=Math_asin;

  var _asinf=Math_asin;

  var _asinl=Math_asin;

  var _atan=Math_atan;

  var _atanf=Math_atan;

  var _atanl=Math_atan;

  var _atan2=Math_atan2;

  var _atan2f=Math_atan2;

  var _atan2l=Math_atan2;

  var _exp=Math_exp;

  var _expf=Math_exp;

  var _expl=Math_exp;

  var _log=Math_log;

  var _logf=Math_log;

  var _logl=Math_log;

  var _sqrt=Math_sqrt;

  var _sqrtf=Math_sqrt;

  var _sqrtl=Math_sqrt;

  var _fabs=Math_abs;

  var _fabsf=Math_abs;

  var _fabsl=Math_abs;

  var _llvm_fabs_f32=Math_abs;

  var _llvm_fabs_f64=Math_abs;

  var _ceil=Math_ceil;

  var _ceilf=Math_ceil;

  var _ceill=Math_ceil;

  var _floor=Math_floor;

  var _floorf=Math_floor;

  var _floorl=Math_floor;

  var _pow=Math_pow;

  var _powf=Math_pow;

  var _powl=Math_pow;

  var _llvm_sqrt_f32=Math_sqrt;

  var _llvm_sqrt_f64=Math_sqrt;

  var _llvm_pow_f32=Math_pow;

  var _llvm_pow_f64=Math_pow;

  var _llvm_powi_f32=Math_pow;

  var _llvm_powi_f64=Math_pow;

  var _llvm_log_f32=Math_log;

  var _llvm_log_f64=Math_log;

  var _llvm_exp_f32=Math_exp;

  var _llvm_exp_f64=Math_exp;

  var _llvm_cos_f32=Math_cos;

  var _llvm_cos_f64=Math_cos;

  var _llvm_sin_f32=Math_sin;

  var _llvm_sin_f64=Math_sin;

  var _llvm_trunc_f32=Math_trunc;

  var _llvm_trunc_f64=Math_trunc;

  var _llvm_ceil_f32=Math_ceil;

  var _llvm_ceil_f64=Math_ceil;

  var _llvm_floor_f32=Math_floor;

  var _llvm_floor_f64=Math_floor;

  function _llvm_exp2_f32(x) {
      return Math.pow(2, x);
    }

  function _llvm_exp2_f64() {
  return _llvm_exp2_f32.apply(null, arguments)
  }

  function _llvm_log2_f32(x) {
      return Math.log(x) / Math.LN2; // TODO: Math.log2, when browser support is there
    }

  function _llvm_log2_f64() {
  return _llvm_log2_f32.apply(null, arguments)
  }

  function _llvm_log10_f32(x) {
      return Math.log(x) / Math.LN10; // TODO: Math.log10, when browser support is there
    }

  function _llvm_log10_f64() {
  return _llvm_log10_f32.apply(null, arguments)
  }





   

   


   

   

   

   

   

   



  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }

  var DLFCN={error:null,errorMsg:null};


  
  var LDSO=undefined;function _dlopen(filenameAddr, flag) {
      // void *dlopen(const char *file, int mode);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlopen.html
      var searchpaths = [];
      var filename;
      if (filenameAddr === 0) {
        filename = '__self__';
      } else {
        filename = Pointer_stringify(filenameAddr);
  
        var isValidFile = function (filename) {
          var target = FS.findObject(filename);
          return target && !target.isFolder && !target.isDevice;
        };
  
        if (!isValidFile(filename)) {
          if (ENV['LD_LIBRARY_PATH']) {
            searchpaths = ENV['LD_LIBRARY_PATH'].split(':');
          }
  
          for (var ident in searchpaths) {
            var searchfile = PATH.join2(searchpaths[ident], filename);
            if (isValidFile(searchfile)) {
              filename = searchfile;
              break;
            }
          }
        }
      }
  
      // We don't care about RTLD_NOW and RTLD_LAZY.
      var flags = {
        global:   Boolean(flag & 256),  // RTLD_GLOBAL
        nodelete: Boolean(flag & 4096), // RTLD_NODELETE
  
        fs: FS, // load libraries from provided filesystem
      }
  
      try {
        handle = loadDynamicLibrary(filename, flags)
      } catch (e) {
        err('Error in loading dynamic library ' + filename + ": " + e);
        DLFCN.errorMsg = 'Could not load dynamic lib: ' + filename + '\n' + e;
        return 0;
      }
  
      return handle;
    }


  function _dlclose(handle) {
      // int dlclose(void *handle);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlclose.html
      if (!$LDSO.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlclose() unopened handle: ' + handle;
        return 1;
      } else {
        var lib_record = $LDSO.loadedLibs[handle];
        if (--lib_record.refcount == 0) {
          if (lib_record.module.cleanups) {
            lib_record.module.cleanups.forEach(function(cleanup) { cleanup() });
          }
          delete $LDSO.loadedLibNames[lib_record.name];
          delete $LDSO.loadedLibs[handle];
        }
        return 0;
      }
    }


  function _dlsym(handle, symbol) {
      // void *dlsym(void *restrict handle, const char *restrict name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlsym.html
      symbol = Pointer_stringify(symbol);
  
      if (!$LDSO.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlsym() from an unopened handle: ' + handle;
        return 0;
      } else {
        var lib = $LDSO.loadedLibs[handle];
        symbol = '_' + symbol;
        if (!lib.module.hasOwnProperty(symbol)) {
          DLFCN.errorMsg = ('Tried to lookup unknown symbol "' + symbol +
                                 '" in dynamic lib: ' + lib.name);
          return 0;
        } else {
          var result = lib.module[symbol];
          if (typeof result === 'function') {
            // convert the exported function into a function pointer using our generic
            // JS mechanism.
            return addFunction(result);
          }
          return result;
        }
      }
    }


  function _dlerror() {
      // char *dlerror(void);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlerror.html
      if (DLFCN.errorMsg === null) {
        return 0;
      } else {
        if (DLFCN.error) _free(DLFCN.error);
        var msgArr = intArrayFromString(DLFCN.errorMsg);
        DLFCN.error = allocate(msgArr, 'i8', ALLOC_NORMAL);
        DLFCN.errorMsg = null;
        return DLFCN.error;
      }
    }


  function _dladdr(addr, info) {
      // report all function pointers as coming from this program itself XXX not really correct in any way
      var fname = allocate(intArrayFromString(Module['thisProgram'] || './this.program'), 'i8', ALLOC_NORMAL); // XXX leak
      HEAP32[((info)>>2)]=fname;
      HEAP32[(((info)+(4))>>2)]=0;
      HEAP32[(((info)+(8))>>2)]=0;
      HEAP32[(((info)+(12))>>2)]=0;
      return 1;
    }

  function _getpwuid(uid) {
      return 0; // NULL
    }

  function _clock() {
      if (_clock.start === undefined) _clock.start = Date.now();
      return ((Date.now() - _clock.start) * (1000000 / 1000))|0;
    }


  function _difftime(time1, time0) {
      return time1 - time0;
    }

  var ___tm_current=STATICTOP; STATICTOP += 48;;


  var ___tm_formatted=STATICTOP; STATICTOP += 48;;

  
  function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      // timezone is specified as seconds west of UTC ("The external variable
      // `timezone` shall be set to the difference, in seconds, between
      // Coordinated Universal Time (UTC) and local standard time."), the same
      // as returned by getTimezoneOffset().
      // See http://pubs.opengroup.org/onlinepubs/009695399/functions/tzset.html
      HEAP32[((__get_timezone())>>2)]=(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__get_daylight())>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      function extractZone(date) {
        var match = date.toTimeString().match(/\(([A-Za-z ]+)\)$/);
        return match ? match[1] : "GMT";
      };
      var winterName = extractZone(winter);
      var summerName = extractZone(summer);
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      if (summer.getTimezoneOffset() < winter.getTimezoneOffset()) {
        // Northern hemisphere
        HEAP32[((__get_tzname())>>2)]=winterNamePtr;
        HEAP32[(((__get_tzname())+(4))>>2)]=summerNamePtr;
      } else {
        HEAP32[((__get_tzname())>>2)]=summerNamePtr;
        HEAP32[(((__get_tzname())+(4))>>2)]=winterNamePtr;
      }
    }function _mktime(tmPtr) {
      _tzset();
      var date = new Date(HEAP32[(((tmPtr)+(20))>>2)] + 1900,
                          HEAP32[(((tmPtr)+(16))>>2)],
                          HEAP32[(((tmPtr)+(12))>>2)],
                          HEAP32[(((tmPtr)+(8))>>2)],
                          HEAP32[(((tmPtr)+(4))>>2)],
                          HEAP32[((tmPtr)>>2)],
                          0);
  
      // There's an ambiguous hour when the time goes back; the tm_isdst field is
      // used to disambiguate it.  Date() basically guesses, so we fix it up if it
      // guessed wrong, or fill in tm_isdst with the guess if it's -1.
      var dst = HEAP32[(((tmPtr)+(32))>>2)];
      var guessedOffset = date.getTimezoneOffset();
      var start = new Date(date.getFullYear(), 0, 1);
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dstOffset = Math.min(winterOffset, summerOffset); // DST is in December in South
      if (dst < 0) {
        // Attention: some regions don't have DST at all.
        HEAP32[(((tmPtr)+(32))>>2)]=Number(summerOffset != winterOffset && dstOffset == guessedOffset);
      } else if ((dst > 0) != (dstOffset == guessedOffset)) {
        var nonDstOffset = Math.max(winterOffset, summerOffset);
        var trueOffset = dst > 0 ? dstOffset : nonDstOffset;
        // Don't try setMinutes(date.getMinutes() + ...) -- it's messed up.
        date.setTime(date.getTime() + (trueOffset - guessedOffset)*60000);
      }
  
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
  
      return (date.getTime() / 1000)|0;
    }

  function _timelocal() {
  return _mktime.apply(null, arguments)
  }

  function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }


  function _timegm(tmPtr) {
      _tzset();
      var time = Date.UTC(HEAP32[(((tmPtr)+(20))>>2)] + 1900,
                          HEAP32[(((tmPtr)+(16))>>2)],
                          HEAP32[(((tmPtr)+(12))>>2)],
                          HEAP32[(((tmPtr)+(8))>>2)],
                          HEAP32[(((tmPtr)+(4))>>2)],
                          HEAP32[((tmPtr)>>2)],
                          0);
      var date = new Date(time);
  
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
      var yday = ((date.getTime() - start) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
  
      return (date.getTime() / 1000)|0;
    }

  
  function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=-(date.getTimezoneOffset() * 60);
  
      // Attention: DST is in December in South, and some regions don't have DST at all.
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dst = (summerOffset != winterOffset && date.getTimezoneOffset() == Math.min(winterOffset, summerOffset))|0;
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      var zonePtr = HEAP32[(((__get_tzname())+(dst ? 4 : 0))>>2)];
      HEAP32[(((tmPtr)+(40))>>2)]=zonePtr;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }


  
  function _asctime_r(tmPtr, buf) {
      var date = {
        tm_sec: HEAP32[((tmPtr)>>2)],
        tm_min: HEAP32[(((tmPtr)+(4))>>2)],
        tm_hour: HEAP32[(((tmPtr)+(8))>>2)],
        tm_mday: HEAP32[(((tmPtr)+(12))>>2)],
        tm_mon: HEAP32[(((tmPtr)+(16))>>2)],
        tm_year: HEAP32[(((tmPtr)+(20))>>2)],
        tm_wday: HEAP32[(((tmPtr)+(24))>>2)]
      };
      var days = [ "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" ];
      var months = [ "Jan", "Feb", "Mar", "Apr", "May", "Jun",
                     "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" ];
      var s = days[date.tm_wday] + ' ' + months[date.tm_mon] +
          (date.tm_mday < 10 ? '  ' : ' ') + date.tm_mday +
          (date.tm_hour < 10 ? ' 0' : ' ') + date.tm_hour +
          (date.tm_min < 10 ? ':0' : ':') + date.tm_min +
          (date.tm_sec < 10 ? ':0' : ':') + date.tm_sec +
          ' ' + (1900 + date.tm_year) + "\n";
  
      // asctime_r is specced to behave in an undefined manner if the algorithm would attempt
      // to write out more than 26 bytes (including the null terminator).
      // See http://pubs.opengroup.org/onlinepubs/9699919799/functions/asctime.html
      // Our undefined behavior is to truncate the write to at most 26 bytes, including null terminator.
      stringToUTF8(s, buf, 26);
      return buf;
    }function _asctime(tmPtr) {
      return _asctime_r(tmPtr, ___tm_formatted);
    }


  
  function _ctime_r(time, buf) {
      var stack = stackSave();
      var rv = _asctime_r(_localtime_r(time, stackAlloc(44)), buf);
      stackRestore(stack);
      return rv;
    }function _ctime(timer) {
      return _ctime_r(timer, ___tm_current);
    }


  function _dysize(year) {
      var leap = ((year % 4 == 0) && ((year % 100 != 0) || (year % 400 == 0)));
      return leap ? 366 : 365;
    }



  function _stime(when) {
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }








  function _strftime_l(s, maxsize, format, tm) {
      return _strftime(s, maxsize, format, tm); // no locale support yet
    }

  function _strptime(buf, format, tm) {
      // char *strptime(const char *restrict buf, const char *restrict format, struct tm *restrict tm);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strptime.html
      var pattern = Pointer_stringify(format);
  
      // escape special characters
      // TODO: not sure we really need to escape all of these in JS regexps
      var SPECIAL_CHARS = '\\!@#$^&*()+=-[]/{}|:<>?,.';
      for (var i=0, ii=SPECIAL_CHARS.length; i<ii; ++i) {
        pattern = pattern.replace(new RegExp('\\'+SPECIAL_CHARS[i], 'g'), '\\'+SPECIAL_CHARS[i]);
      }
  
      // reduce number of matchers
      var EQUIVALENT_MATCHERS = {
        '%A':  '%a',
        '%B':  '%b',
        '%c':  '%a %b %d %H:%M:%S %Y',
        '%D':  '%m\\/%d\\/%y',
        '%e':  '%d',
        '%F':  '%Y-%m-%d',
        '%h':  '%b',
        '%R':  '%H\\:%M',
        '%r':  '%I\\:%M\\:%S\\s%p',
        '%T':  '%H\\:%M\\:%S',
        '%x':  '%m\\/%d\\/(?:%y|%Y)',
        '%X':  '%H\\:%M\\:%S'
      };
      for (var matcher in EQUIVALENT_MATCHERS) {
        pattern = pattern.replace(matcher, EQUIVALENT_MATCHERS[matcher]);
      }
  
      // TODO: take care of locale
  
      var DATE_PATTERNS = {
        /* weeday name */     '%a': '(?:Sun(?:day)?)|(?:Mon(?:day)?)|(?:Tue(?:sday)?)|(?:Wed(?:nesday)?)|(?:Thu(?:rsday)?)|(?:Fri(?:day)?)|(?:Sat(?:urday)?)',
        /* month name */      '%b': '(?:Jan(?:uary)?)|(?:Feb(?:ruary)?)|(?:Mar(?:ch)?)|(?:Apr(?:il)?)|May|(?:Jun(?:e)?)|(?:Jul(?:y)?)|(?:Aug(?:ust)?)|(?:Sep(?:tember)?)|(?:Oct(?:ober)?)|(?:Nov(?:ember)?)|(?:Dec(?:ember)?)',
        /* century */         '%C': '\\d\\d',
        /* day of month */    '%d': '0[1-9]|[1-9](?!\\d)|1\\d|2\\d|30|31',
        /* hour (24hr) */     '%H': '\\d(?!\\d)|[0,1]\\d|20|21|22|23',
        /* hour (12hr) */     '%I': '\\d(?!\\d)|0\\d|10|11|12',
        /* day of year */     '%j': '00[1-9]|0?[1-9](?!\\d)|0?[1-9]\\d(?!\\d)|[1,2]\\d\\d|3[0-6]\\d',
        /* month */           '%m': '0[1-9]|[1-9](?!\\d)|10|11|12',
        /* minutes */         '%M': '0\\d|\\d(?!\\d)|[1-5]\\d',
        /* whitespace */      '%n': '\\s',
        /* AM/PM */           '%p': 'AM|am|PM|pm|A\\.M\\.|a\\.m\\.|P\\.M\\.|p\\.m\\.',
        /* seconds */         '%S': '0\\d|\\d(?!\\d)|[1-5]\\d|60',
        /* week number */     '%U': '0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53',
        /* week number */     '%W': '0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53',
        /* weekday number */  '%w': '[0-6]',
        /* 2-digit year */    '%y': '\\d\\d',
        /* 4-digit year */    '%Y': '\\d\\d\\d\\d',
        /* % */               '%%': '%',
        /* whitespace */      '%t': '\\s',
      };
  
      var MONTH_NUMBERS = {JAN: 0, FEB: 1, MAR: 2, APR: 3, MAY: 4, JUN: 5, JUL: 6, AUG: 7, SEP: 8, OCT: 9, NOV: 10, DEC: 11};
      var DAY_NUMBERS_SUN_FIRST = {SUN: 0, MON: 1, TUE: 2, WED: 3, THU: 4, FRI: 5, SAT: 6};
      var DAY_NUMBERS_MON_FIRST = {MON: 0, TUE: 1, WED: 2, THU: 3, FRI: 4, SAT: 5, SUN: 6};
  
      for (var datePattern in DATE_PATTERNS) {
        pattern = pattern.replace(datePattern, '('+datePattern+DATE_PATTERNS[datePattern]+')');
      }
  
      // take care of capturing groups
      var capture = [];
      for (var i=pattern.indexOf('%'); i>=0; i=pattern.indexOf('%')) {
        capture.push(pattern[i+1]);
        pattern = pattern.replace(new RegExp('\\%'+pattern[i+1], 'g'), '');
      }
  
      var matches = new RegExp('^'+pattern, "i").exec(Pointer_stringify(buf))
      // out(Pointer_stringify(buf)+ ' is matched by '+((new RegExp('^'+pattern)).source)+' into: '+JSON.stringify(matches));
  
      function initDate() {
        function fixup(value, min, max) {
          return (typeof value !== 'number' || isNaN(value)) ? min : (value>=min ? (value<=max ? value: max): min);
        };
        return {
          year: fixup(HEAP32[(((tm)+(20))>>2)] + 1900 , 1970, 9999),
          month: fixup(HEAP32[(((tm)+(16))>>2)], 0, 11),
          day: fixup(HEAP32[(((tm)+(12))>>2)], 1, 31),
          hour: fixup(HEAP32[(((tm)+(8))>>2)], 0, 23),
          min: fixup(HEAP32[(((tm)+(4))>>2)], 0, 59),
          sec: fixup(HEAP32[((tm)>>2)], 0, 59)
        };
      };
  
      if (matches) {
        var date = initDate();
        var value;
  
        function getMatch(symbol) {
          var pos = capture.indexOf(symbol);
          // check if symbol appears in regexp
          if (pos >= 0) {
            // return matched value or null (falsy!) for non-matches
            return matches[pos+1];
          }
          return;
        }
  
        // seconds
        if ((value=getMatch('S'))) {
          date.sec = parseInt(value);
        }
  
        // minutes
        if ((value=getMatch('M'))) {
          date.min = parseInt(value);
        }
  
        // hours
        if ((value=getMatch('H'))) {
          // 24h clock
          date.hour = parseInt(value);
        } else if ((value = getMatch('I'))) {
          // AM/PM clock
          var hour = parseInt(value);
          if ((value=getMatch('p'))) {
            hour += value.toUpperCase()[0] === 'P' ? 12 : 0;
          }
          date.hour = hour;
        }
  
        // year
        if ((value=getMatch('Y'))) {
          // parse from four-digit year
          date.year = parseInt(value);
        } else if ((value=getMatch('y'))) {
          // parse from two-digit year...
          var year = parseInt(value);
          if ((value=getMatch('C'))) {
            // ...and century
            year += parseInt(value)*100;
          } else {
            // ...and rule-of-thumb
            year += year<69 ? 2000 : 1900;
          }
          date.year = year;
        }
  
        // month
        if ((value=getMatch('m'))) {
          // parse from month number
          date.month = parseInt(value)-1;
        } else if ((value=getMatch('b'))) {
          // parse from month name
          date.month = MONTH_NUMBERS[value.substring(0,3).toUpperCase()] || 0;
          // TODO: derive month from day in year+year, week number+day of week+year
        }
  
        // day
        if ((value=getMatch('d'))) {
          // get day of month directly
          date.day = parseInt(value);
        } else if ((value=getMatch('j'))) {
          // get day of month from day of year ...
          var day = parseInt(value);
          var leapYear = __isLeapYear(date.year);
          for (var month=0; month<12; ++month) {
            var daysUntilMonth = __arraySum(leapYear ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, month-1);
            if (day<=daysUntilMonth+(leapYear ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[month]) {
              date.day = day-daysUntilMonth;
            }
          }
        } else if ((value=getMatch('a'))) {
          // get day of month from weekday ...
          var weekDay = value.substring(0,3).toUpperCase();
          if ((value=getMatch('U'))) {
            // ... and week number (Sunday being first day of week)
            // Week number of the year (Sunday as the first day of the week) as a decimal number [00,53].
            // All days in a new year preceding the first Sunday are considered to be in week 0.
            var weekDayNumber = DAY_NUMBERS_SUN_FIRST[weekDay];
            var weekNumber = parseInt(value);
  
            // January 1st
            var janFirst = new Date(date.year, 0, 1);
            var endDate;
            if (janFirst.getDay() === 0) {
              // Jan 1st is a Sunday, and, hence in the 1st CW
              endDate = __addDays(janFirst, weekDayNumber+7*(weekNumber-1));
            } else {
              // Jan 1st is not a Sunday, and, hence still in the 0th CW
              endDate = __addDays(janFirst, 7-janFirst.getDay()+weekDayNumber+7*(weekNumber-1));
            }
            date.day = endDate.getDate();
            date.month = endDate.getMonth();
          } else if ((value=getMatch('W'))) {
            // ... and week number (Monday being first day of week)
            // Week number of the year (Monday as the first day of the week) as a decimal number [00,53].
            // All days in a new year preceding the first Monday are considered to be in week 0.
            var weekDayNumber = DAY_NUMBERS_MON_FIRST[weekDay];
            var weekNumber = parseInt(value);
  
            // January 1st
            var janFirst = new Date(date.year, 0, 1);
            var endDate;
            if (janFirst.getDay()===1) {
              // Jan 1st is a Monday, and, hence in the 1st CW
               endDate = __addDays(janFirst, weekDayNumber+7*(weekNumber-1));
            } else {
              // Jan 1st is not a Monday, and, hence still in the 0th CW
              endDate = __addDays(janFirst, 7-janFirst.getDay()+1+weekDayNumber+7*(weekNumber-1));
            }
  
            date.day = endDate.getDate();
            date.month = endDate.getMonth();
          }
        }
  
        /*
        tm_sec  int seconds after the minute  0-61*
        tm_min  int minutes after the hour  0-59
        tm_hour int hours since midnight  0-23
        tm_mday int day of the month  1-31
        tm_mon  int months since January  0-11
        tm_year int years since 1900
        tm_wday int days since Sunday 0-6
        tm_yday int days since January 1  0-365
        tm_isdst  int Daylight Saving Time flag
        */
  
        var fullDate = new Date(date.year, date.month, date.day, date.hour, date.min, date.sec, 0);
        HEAP32[((tm)>>2)]=fullDate.getSeconds();
        HEAP32[(((tm)+(4))>>2)]=fullDate.getMinutes();
        HEAP32[(((tm)+(8))>>2)]=fullDate.getHours();
        HEAP32[(((tm)+(12))>>2)]=fullDate.getDate();
        HEAP32[(((tm)+(16))>>2)]=fullDate.getMonth();
        HEAP32[(((tm)+(20))>>2)]=fullDate.getFullYear()-1900;
        HEAP32[(((tm)+(24))>>2)]=fullDate.getDay();
        HEAP32[(((tm)+(28))>>2)]=__arraySum(__isLeapYear(fullDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, fullDate.getMonth()-1)+fullDate.getDate()-1;
        HEAP32[(((tm)+(32))>>2)]=0;
  
        // we need to convert the matched sequence into an integer array to take care of UTF-8 characters > 0x7F
        // TODO: not sure that intArrayFromString handles all unicode characters correctly
        return buf+intArrayFromString(matches[0]).length-1;
      }
  
      return 0;
    }

  function _strptime_l(buf, format, tm) {
      return _strptime(buf, format, tm); // no locale support yet
    }

  function _getdate(string) {
      // struct tm *getdate(const char *string);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getdate.html
      // TODO: Implement.
      return 0;
    }

  function _timespec_get(ts, base) {
      //int timespec_get(struct timespec *ts, int base);
      if (base !== 1) {
        // There is no other implemented value than TIME_UTC; all other values are considered erroneous.
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _clock_gettime(0, ts);
      return ret < 0 ? 0 : base;
    }



  function _clock_settime(clk_id, tp) {
      // int clock_settime(clockid_t clk_id, const struct timespec *tp);
      // Nothing.
      ___setErrNo(clk_id === 0 ? ERRNO_CODES.EPERM
                                                               : ERRNO_CODES.EINVAL);
      return -1;
    }

  
  function _emscripten_get_now_res() { // return resolution of get_now, in nanoseconds
      if (ENVIRONMENT_IS_NODE) {
        return 1; // nanoseconds
      } else if (typeof dateNow !== 'undefined' ||
                 ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now'])) {
        return 1000; // microseconds (1/1000 of a millisecond)
      } else {
        return 1000*1000; // milliseconds
      }
    }function _clock_getres(clk_id, res) {
      // int clock_getres(clockid_t clk_id, struct timespec *res);
      var nsec;
      if (clk_id === 0) {
        nsec = 1000 * 1000; // educated guess that it's milliseconds
      } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
        nsec = _emscripten_get_now_res();
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      HEAP32[((res)>>2)]=(nsec/1000000000)|0;
      HEAP32[(((res)+(4))>>2)]=nsec // resolution is nanoseconds
      return 0;
    }

  function _clock_getcpuclockid(pid, clk_id) {
      if (pid < 0) return ERRNO_CODES.ESRCH;
      if (pid !== 0 && pid !== PROCINFO.pid) return ERRNO_CODES.ENOSYS;
      if (clk_id) HEAP32[((clk_id)>>2)]=2;
      return 0;
    }

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((ptr)+(4))>>2)]=((now % 1000)*1000)|0; // microseconds
      return 0;
    }

  function _ftime(p) {
      var millis = Date.now();
      HEAP32[((p)>>2)]=(millis/1000)|0;
      HEAP16[(((p)+(4))>>1)]=millis % 1000;
      HEAP16[(((p)+(6))>>1)]=0; // Obsolete field
      HEAP16[(((p)+(8))>>1)]=0; // Obsolete field
      return 0;
    }

  function _times(buffer) {
      // clock_t times(struct tms *buffer);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/times.html
      // NOTE: This is fake, since we can't calculate real CPU time usage in JS.
      if (buffer !== 0) {
        _memset(buffer, 0, 16);
      }
      return 0;
    }

  function _makedev(maj, min) {
      return ((maj) << 8 | (min));
    }

  function _gnu_dev_makedev() {
  return _makedev.apply(null, arguments)
  }

  function _major(dev) {
      return ((dev) >> 8);
    }

  function _gnu_dev_major() {
  return _major.apply(null, arguments)
  }

  function _minor(dev) {
      return ((dev) & 0xff);
    }

  function _gnu_dev_minor() {
  return _minor.apply(null, arguments)
  }

   

   

  function _longjmp(env, value) {
      Module['setThrew'](env, value || 1);
      throw 'longjmp';
    }

  function _emscripten_longjmp(env, value) {
      _longjmp(env, value);
    }


  function _waitid() {
  return _wait.apply(null, arguments)
  }


  function _wait3() {
  return _wait.apply(null, arguments)
  }

  function _wait4() {
  return _wait.apply(null, arguments)
  }




  function _sched_yield() {
      return 0;
    }


  var _in6addr_any=allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);

  var _in6addr_loopback=allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1], "i8", ALLOC_STATIC);




  function __inet_pton6(src, dst) {
      var ints = __inet_pton6_raw(Pointer_stringify(src));
      if (ints === null) {
        return 0;
      }
      for (var i = 0; i < 4; i++) {
        HEAP32[(((dst)+(i*4))>>2)]=ints[i];
      }
      return 1;
    }






  
  function _gethostbyname(name) {
      name = Pointer_stringify(name);
  
      // generate hostent
      var ret = _malloc(20); // XXX possibly leaked, as are others here
      var nameBuf = _malloc(name.length+1);
      stringToUTF8(name, nameBuf, name.length+1);
      HEAP32[((ret)>>2)]=nameBuf;
      var aliasesBuf = _malloc(4);
      HEAP32[((aliasesBuf)>>2)]=0;
      HEAP32[(((ret)+(4))>>2)]=aliasesBuf;
      var afinet = 2;
      HEAP32[(((ret)+(8))>>2)]=afinet;
      HEAP32[(((ret)+(12))>>2)]=4;
      var addrListBuf = _malloc(12);
      HEAP32[((addrListBuf)>>2)]=addrListBuf+8;
      HEAP32[(((addrListBuf)+(4))>>2)]=0;
      HEAP32[(((addrListBuf)+(8))>>2)]=__inet_pton4_raw(DNS.lookup_name(name));
      HEAP32[(((ret)+(16))>>2)]=addrListBuf;
      return ret;
    }function _gethostbyaddr(addr, addrlen, type) {
      if (type !== 2) {
        ___setErrNo(ERRNO_CODES.EAFNOSUPPORT);
        // TODO: set h_errno
        return null;
      }
      addr = HEAP32[((addr)>>2)]; // addr is in_addr
      var host = __inet_ntop4_raw(addr);
      var lookup = DNS.lookup_addr(host);
      if (lookup) {
        host = lookup;
      }
      var hostp = allocate(intArrayFromString(host), 'i8', ALLOC_STACK);
      return _gethostbyname(hostp);
    }




  function _gethostbyname_r(name, ret, buf, buflen, out, err) {
      var data = _gethostbyname(name);
      _memcpy(ret, data, 20);
      _free(data);
      HEAP32[((err)>>2)]=0;
      HEAP32[((out)>>2)]=ret;
      return 0;
    }


  function _getaddrinfo(node, service, hint, out) {
      // Note getaddrinfo currently only returns a single addrinfo with ai_next defaulting to NULL. When NULL
      // hints are specified or ai_family set to AF_UNSPEC or ai_socktype or ai_protocol set to 0 then we
      // really should provide a linked list of suitable addrinfo values.
      var addrs = [];
      var canon = null;
      var addr = 0;
      var port = 0;
      var flags = 0;
      var family = 0;
      var type = 0;
      var proto = 0;
      var ai, last;
  
      function allocaddrinfo(family, type, proto, canon, addr, port) {
        var sa, salen, ai;
        var res;
  
        salen = family === 10 ?
          28 :
          16;
        addr = family === 10 ?
          __inet_ntop6_raw(addr) :
          __inet_ntop4_raw(addr);
        sa = _malloc(salen);
        res = __write_sockaddr(sa, family, addr, port);
        assert(!res.errno);
  
        ai = _malloc(32);
        HEAP32[(((ai)+(4))>>2)]=family;
        HEAP32[(((ai)+(8))>>2)]=type;
        HEAP32[(((ai)+(12))>>2)]=proto;
        HEAP32[(((ai)+(24))>>2)]=canon;
        HEAP32[(((ai)+(20))>>2)]=sa;
        if (family === 10) {
          HEAP32[(((ai)+(16))>>2)]=28;
        } else {
          HEAP32[(((ai)+(16))>>2)]=16;
        }
        HEAP32[(((ai)+(28))>>2)]=0;
  
        return ai;
      }
  
      if (hint) {
        flags = HEAP32[((hint)>>2)];
        family = HEAP32[(((hint)+(4))>>2)];
        type = HEAP32[(((hint)+(8))>>2)];
        proto = HEAP32[(((hint)+(12))>>2)];
      }
      if (type && !proto) {
        proto = type === 2 ? 17 : 6;
      }
      if (!type && proto) {
        type = proto === 17 ? 2 : 1;
      }
  
      // If type or proto are set to zero in hints we should really be returning multiple addrinfo values, but for
      // now default to a TCP STREAM socket so we can at least return a sensible addrinfo given NULL hints.
      if (proto === 0) {
        proto = 6;
      }
      if (type === 0) {
        type = 1;
      }
  
      if (!node && !service) {
        return -2;
      }
      if (flags & ~(1|2|4|
          1024|8|16|32)) {
        return -1;
      }
      if (hint !== 0 && (HEAP32[((hint)>>2)] & 2) && !node) {
        return -1;
      }
      if (flags & 32) {
        // TODO
        return -2;
      }
      if (type !== 0 && type !== 1 && type !== 2) {
        return -7;
      }
      if (family !== 0 && family !== 2 && family !== 10) {
        return -6;
      }
  
      if (service) {
        service = Pointer_stringify(service);
        port = parseInt(service, 10);
  
        if (isNaN(port)) {
          if (flags & 1024) {
            return -2;
          }
          // TODO support resolving well-known service names from:
          // http://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.txt
          return -8;
        }
      }
  
      if (!node) {
        if (family === 0) {
          family = 2;
        }
        if ((flags & 1) === 0) {
          if (family === 2) {
            addr = _htonl(2130706433);
          } else {
            addr = [0, 0, 0, 1];
          }
        }
        ai = allocaddrinfo(family, type, proto, null, addr, port);
        HEAP32[((out)>>2)]=ai;
        return 0;
      }
  
      //
      // try as a numeric address
      //
      node = Pointer_stringify(node);
      addr = __inet_pton4_raw(node);
      if (addr !== null) {
        // incoming node is a valid ipv4 address
        if (family === 0 || family === 2) {
          family = 2;
        }
        else if (family === 10 && (flags & 8)) {
          addr = [0, 0, _htonl(0xffff), addr];
          family = 10;
        } else {
          return -2;
        }
      } else {
        addr = __inet_pton6_raw(node);
        if (addr !== null) {
          // incoming node is a valid ipv6 address
          if (family === 0 || family === 10) {
            family = 10;
          } else {
            return -2;
          }
        }
      }
      if (addr != null) {
        ai = allocaddrinfo(family, type, proto, node, addr, port);
        HEAP32[((out)>>2)]=ai;
        return 0;
      }
      if (flags & 4) {
        return -2;
      }
  
      //
      // try as a hostname
      //
      // resolve the hostname to a temporary fake address
      node = DNS.lookup_name(node);
      addr = __inet_pton4_raw(node);
      if (family === 0) {
        family = 2;
      } else if (family === 10) {
        addr = [0, 0, _htonl(0xffff), addr];
      }
      ai = allocaddrinfo(family, type, proto, null, addr, port);
      HEAP32[((out)>>2)]=ai;
      return 0;
    }


  var GAI_ERRNO_MESSAGES={};

  function _gai_strerror(val) {
      var buflen = 256;
  
      // On first call to gai_strerror we initialise the buffer and populate the error messages.
      if (!_gai_strerror.buffer) {
          _gai_strerror.buffer = _malloc(buflen);
  
          GAI_ERRNO_MESSAGES['0'] = 'Success';
          GAI_ERRNO_MESSAGES['' + -1] = 'Invalid value for \'ai_flags\' field';
          GAI_ERRNO_MESSAGES['' + -2] = 'NAME or SERVICE is unknown';
          GAI_ERRNO_MESSAGES['' + -3] = 'Temporary failure in name resolution';
          GAI_ERRNO_MESSAGES['' + -4] = 'Non-recoverable failure in name res';
          GAI_ERRNO_MESSAGES['' + -6] = '\'ai_family\' not supported';
          GAI_ERRNO_MESSAGES['' + -7] = '\'ai_socktype\' not supported';
          GAI_ERRNO_MESSAGES['' + -8] = 'SERVICE not supported for \'ai_socktype\'';
          GAI_ERRNO_MESSAGES['' + -10] = 'Memory allocation failure';
          GAI_ERRNO_MESSAGES['' + -11] = 'System error returned in \'errno\'';
          GAI_ERRNO_MESSAGES['' + -12] = 'Argument buffer overflow';
      }
  
      var msg = 'Unknown error';
  
      if (val in GAI_ERRNO_MESSAGES) {
        if (GAI_ERRNO_MESSAGES[val].length > buflen - 1) {
          msg = 'Message too long'; // EMSGSIZE message. This should never occur given the GAI_ERRNO_MESSAGES above.
        } else {
          msg = GAI_ERRNO_MESSAGES[val];
        }
      }
  
      writeAsciiToMemory(msg, _gai_strerror.buffer);
      return _gai_strerror.buffer;
    }

  var Protocols={list:[],map:{}};

  function _setprotoent(stayopen) {
      // void setprotoent(int stayopen);
  
      // Allocate and populate a protoent structure given a name, protocol number and array of aliases
      function allocprotoent(name, proto, aliases) {
        // write name into buffer
        var nameBuf = _malloc(name.length + 1);
        writeAsciiToMemory(name, nameBuf);
  
        // write aliases into buffer
        var j = 0;
        var length = aliases.length;
        var aliasListBuf = _malloc((length + 1) * 4); // Use length + 1 so we have space for the terminating NULL ptr.
  
        for (var i = 0; i < length; i++, j += 4) {
          var alias = aliases[i];
          var aliasBuf = _malloc(alias.length + 1);
          writeAsciiToMemory(alias, aliasBuf);
          HEAP32[(((aliasListBuf)+(j))>>2)]=aliasBuf;
        }
        HEAP32[(((aliasListBuf)+(j))>>2)]=0; // Terminating NULL pointer.
  
        // generate protoent
        var pe = _malloc(12);
        HEAP32[((pe)>>2)]=nameBuf;
        HEAP32[(((pe)+(4))>>2)]=aliasListBuf;
        HEAP32[(((pe)+(8))>>2)]=proto;
        return pe;
      };
  
      // Populate the protocol 'database'. The entries are limited to tcp and udp, though it is fairly trivial
      // to add extra entries from /etc/protocols if desired - though not sure if that'd actually be useful.
      var list = Protocols.list;
      var map  = Protocols.map;
      if (list.length === 0) {
          var entry = allocprotoent('tcp', 6, ['TCP']);
          list.push(entry);
          map['tcp'] = map['6'] = entry;
          entry = allocprotoent('udp', 17, ['UDP']);
          list.push(entry);
          map['udp'] = map['17'] = entry;
      }
  
      _setprotoent.index = 0;
    }

  function _endprotoent() {
      // void endprotoent(void);
      // We're not using a real protocol database so we don't do a real close.
    }

  function _getprotoent(number) {
      // struct protoent *getprotoent(void);
      // reads the  next  entry  from  the  protocols 'database' or return NULL if 'eof'
      if (_setprotoent.index === Protocols.list.length) {
        return 0;
      } else {
        var result = Protocols.list[_setprotoent.index++];
        return result;
      }
    }

  function _getprotobyname(name) {
      // struct protoent *getprotobyname(const char *);
      name = Pointer_stringify(name);
      _setprotoent(true);
      var result = Protocols.map[name];
      return result;
    }

  function _getprotobynumber(number) {
      // struct protoent *getprotobynumber(int proto);
      _setprotoent(true);
      var result = Protocols.map[number];
      return result;
    }


  function _getpwnam() { throw 'getpwnam: TODO' }

  function _setpwent() { throw 'setpwent: TODO' }

  function _getpwent() { throw 'getpwent: TODO' }

  function _endpwent() { throw 'endpwent: TODO' }

  function _emscripten_run_script(ptr) {
      eval(Pointer_stringify(ptr));
    }

  function _emscripten_run_script_int(ptr) {
      return eval(Pointer_stringify(ptr))|0;
    }

  function _emscripten_run_script_string(ptr) {
      var s = eval(Pointer_stringify(ptr)) + '';
      var me = _emscripten_run_script_string;
      var len = lengthBytesUTF8(s);
      if (!me.bufferSize || me.bufferSize < len+1) {
        if (me.bufferSize) _free(me.buffer);
        me.bufferSize = len+1;
        me.buffer = _malloc(me.bufferSize);
      }
      stringToUTF8(s, me.buffer, me.bufferSize);
      return me.buffer;
    }

  function _emscripten_random() {
      return Math.random();
    }




  function __emscripten_traverse_stack(args) {
      if (!args || !args.callee || !args.callee.name) {
        return [null, '', ''];
      }
  
      var funstr = args.callee.toString();
      var funcname = args.callee.name;
      var str = '(';
      var first = true;
      for (var i in args) {
        var a = args[i];
        if (!first) {
          str += ", ";
        }
        first = false;
        if (typeof a === 'number' || typeof a === 'string') {
          str += a;
        } else {
          str += '(' + typeof a + ')';
        }
      }
      str += ')';
      var caller = args.callee.caller;
      args = caller ? caller.arguments : [];
      if (first)
        str = '';
      return [args, funcname, str];
    }

  function _emscripten_get_callstack_js(flags) {
      var callstack = jsStackTrace();
  
      // Find the symbols in the callstack that corresponds to the functions that report callstack information, and remove everyhing up to these from the output.
      var iThisFunc = callstack.lastIndexOf('_emscripten_log');
      var iThisFunc2 = callstack.lastIndexOf('_emscripten_get_callstack');
      var iNextLine = callstack.indexOf('\n', Math.max(iThisFunc, iThisFunc2))+1;
      callstack = callstack.slice(iNextLine);
  
      // If user requested to see the original source stack, but no source map information is available, just fall back to showing the JS stack.
      if (flags & 8/*EM_LOG_C_STACK*/ && typeof emscripten_source_map === 'undefined') {
        warnOnce('Source map information is not available, emscripten_log with EM_LOG_C_STACK will be ignored. Build with "--pre-js $EMSCRIPTEN/src/emscripten-source-map.min.js" linker flag to add source map loading to code.');
        flags ^= 8/*EM_LOG_C_STACK*/;
        flags |= 16/*EM_LOG_JS_STACK*/;
      }
  
      var stack_args = null;
      if (flags & 128 /*EM_LOG_FUNC_PARAMS*/) {
        // To get the actual parameters to the functions, traverse the stack via the unfortunately deprecated 'arguments.callee' method, if it works:
        stack_args = __emscripten_traverse_stack(arguments);
        while (stack_args[1].indexOf('_emscripten_') >= 0)
          stack_args = __emscripten_traverse_stack(stack_args[0]);
      }
  
      // Process all lines:
      var lines = callstack.split('\n');
      callstack = '';
      var newFirefoxRe = new RegExp('\\s*(.*?)@(.*?):([0-9]+):([0-9]+)'); // New FF30 with column info: extract components of form '       Object._main@http://server.com:4324:12'
      var firefoxRe = new RegExp('\\s*(.*?)@(.*):(.*)(:(.*))?'); // Old FF without column info: extract components of form '       Object._main@http://server.com:4324'
      var chromeRe = new RegExp('\\s*at (.*?) \\\((.*):(.*):(.*)\\\)'); // Extract components of form '    at Object._main (http://server.com/file.html:4324:12)'
  
      for (var l in lines) {
        var line = lines[l];
  
        var jsSymbolName = '';
        var file = '';
        var lineno = 0;
        var column = 0;
  
        var parts = chromeRe.exec(line);
        if (parts && parts.length == 5) {
          jsSymbolName = parts[1];
          file = parts[2];
          lineno = parts[3];
          column = parts[4];
        } else {
          parts = newFirefoxRe.exec(line);
          if (!parts) parts = firefoxRe.exec(line);
          if (parts && parts.length >= 4) {
            jsSymbolName = parts[1];
            file = parts[2];
            lineno = parts[3];
            column = parts[4]|0; // Old Firefox doesn't carry column information, but in new FF30, it is present. See https://bugzilla.mozilla.org/show_bug.cgi?id=762556
          } else {
            // Was not able to extract this line for demangling/sourcemapping purposes. Output it as-is.
            callstack += line + '\n';
            continue;
          }
        }
  
        // Try to demangle the symbol, but fall back to showing the original JS symbol name if not available.
        var cSymbolName = (flags & 32/*EM_LOG_DEMANGLE*/) ? demangle(jsSymbolName) : jsSymbolName;
        if (!cSymbolName) {
          cSymbolName = jsSymbolName;
        }
  
        var haveSourceMap = false;
  
        if (flags & 8/*EM_LOG_C_STACK*/) {
          var orig = emscripten_source_map.originalPositionFor({line: lineno, column: column});
          haveSourceMap = (orig && orig.source);
          if (haveSourceMap) {
            if (flags & 64/*EM_LOG_NO_PATHS*/) {
              orig.source = orig.source.substring(orig.source.replace(/\\/g, "/").lastIndexOf('/')+1);
            }
            callstack += '    at ' + cSymbolName + ' (' + orig.source + ':' + orig.line + ':' + orig.column + ')\n';
          }
        }
        if ((flags & 16/*EM_LOG_JS_STACK*/) || !haveSourceMap) {
          if (flags & 64/*EM_LOG_NO_PATHS*/) {
            file = file.substring(file.replace(/\\/g, "/").lastIndexOf('/')+1);
          }
          callstack += (haveSourceMap ? ('     = '+jsSymbolName) : ('    at '+cSymbolName)) + ' (' + file + ':' + lineno + ':' + column + ')\n';
        }
  
        // If we are still keeping track with the callstack by traversing via 'arguments.callee', print the function parameters as well.
        if (flags & 128 /*EM_LOG_FUNC_PARAMS*/ && stack_args[0]) {
          if (stack_args[1] == jsSymbolName && stack_args[2].length > 0) {
            callstack = callstack.replace(/\s+$/, '');
            callstack += ' with values: ' + stack_args[1] + stack_args[2] + '\n';
          }
          stack_args = __emscripten_traverse_stack(stack_args[0]);
        }
      }
      // Trim extra whitespace at the end of the output.
      callstack = callstack.replace(/\s+$/, '');
      return callstack;
    }

  function _emscripten_get_callstack(flags, str, maxbytes) {
      var callstack = _emscripten_get_callstack_js(flags);
      // User can query the required amount of bytes to hold the callstack.
      if (!str || maxbytes <= 0) {
        return lengthBytesUTF8(callstack)+1;
      }
      // Output callstack string as C string to HEAP.
      var bytesWrittenExcludingNull = stringToUTF8(callstack, str, maxbytes);
  
      // Return number of bytes written, including null.
      return bytesWrittenExcludingNull+1;
    }

  function _emscripten_log_js(flags, str) {
      if (flags & 24/*EM_LOG_C_STACK | EM_LOG_JS_STACK*/) {
        str = str.replace(/\s+$/, ''); // Ensure the message and the callstack are joined cleanly with exactly one newline.
        str += (str.length > 0 ? '\n' : '') + _emscripten_get_callstack_js(flags);
      }
  
      if (flags & 1 /*EM_LOG_CONSOLE*/) {
        if (flags & 4 /*EM_LOG_ERROR*/) {
          console.error(str);
        } else if (flags & 2 /*EM_LOG_WARN*/) {
          console.warn(str);
        } else {
          console.log(str);
        }
      } else if (flags & 6 /*EM_LOG_ERROR|EM_LOG_WARN*/) {
        err(str);
      } else {
        out(str);
      }
    }

  
  function __formatString(format, varargs) {
      assert((varargs & 3) === 0);
      var textIndex = format;
      var argIndex = varargs;
      // This must be called before reading a double or i64 vararg. It will bump the pointer properly.
      // It also does an assert on i32 values, so it's nice to call it before all varargs calls.
      function prepVararg(ptr, type) {
        if (type === 'double' || type === 'i64') {
          // move so the load is aligned
          if (ptr & 7) {
            assert((ptr & 7) === 4);
            ptr += 4;
          }
        } else {
          assert((ptr & 3) === 0);
        }
        return ptr;
      }
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        argIndex = prepVararg(argIndex, type);
        if (type === 'double') {
          ret = HEAPF64[((argIndex)>>3)];
          argIndex += 8;
        } else if (type == 'i64') {
          ret = [HEAP32[((argIndex)>>2)],
                 HEAP32[(((argIndex)+(4))>>2)]];
          argIndex += 8;
        } else {
          assert((argIndex & 3) === 0);
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[((argIndex)>>2)];
          argIndex += 4;
        }
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && typeof i64Math === 'object') argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && typeof i64Math === 'object') argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && typeof i64Math === 'object') {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _emscripten_log(flags, varargs) {
      // Extract the (optionally-existing) printf format specifier field from varargs.
      var format = HEAP32[((varargs)>>2)];
      varargs += 4;
      var str = '';
      if (format) {
        var result = __formatString(format, varargs);
        for(var i = 0 ; i < result.length; ++i) {
          str += String.fromCharCode(result[i]);
        }
      }
      _emscripten_log_js(flags, str);
    }

  function _emscripten_get_compiler_setting(name) {
      name = Pointer_stringify(name);
  
      var ret = getCompilerSetting(name);
      if (typeof ret === 'number') return ret;
  
      if (!_emscripten_get_compiler_setting.cache) _emscripten_get_compiler_setting.cache = {};
      var cache = _emscripten_get_compiler_setting.cache;
      var fullname = name + '__str';
      var fullret = cache[fullname];
      if (fullret) return fullret;
      return cache[fullname] = allocate(intArrayFromString(ret + ''), 'i8', ALLOC_NORMAL);
    }

  function _emscripten_debugger() {
      debugger;
    }

  function _emscripten_print_double(x, to, max) {
      var str = x + '';
      if (to) return stringToUTF8(str, to, max);
      else return lengthBytesUTF8(str);
    }










  function ___ubsan_handle_float_cast_overflow(id, post) {
      abort('Undefined behavior! ubsan_handle_float_cast_overflow: ' + [id, post]);
    }

  function ___ubsan_handle_pointer_overflow(id, post) {
      abort('Undefined behavior! ubsan_handle_pointer_overflow: ' + [id, post]);
    }

  function ___ubsan_handle_type_mismatch_v1(id, post) {
      abort('Undefined behavior! ubsan_handle_type_mismatch_v1: ' + [id, post]);
    }

  function ___ubsan_handle_add_overflow(id, post) {
      abort('Undefined behavior! ubsan_handle_add_overflow: ' + [id, post]);
    }


  function __Unwind_Backtrace(func, arg) {
      var trace = _emscripten_get_callstack_js();
      var parts = trace.split('\n');
      for (var i = 0; i < parts.length; i++) {
        var ret = Module['dynCall_iii'](func, 0, arg);
        if (ret !== 0) return;
      }
    }

  function __Unwind_GetIPInfo() {
      abort('Unwind_GetIPInfo');
    }

  function __Unwind_FindEnclosingFunction() {
      return 0; // we cannot succeed
    }

  function __Unwind_RaiseException(ex) {
      err('Warning: _Unwind_RaiseException is not correctly implemented');
      return ___cxa_throw(ex, 0, 0);
    }

  function __Unwind_DeleteException(ex) {
      err('TODO: Unwind_DeleteException');
    }

  function _emscripten_autodebug_i64(line, valuel, valueh) {
      out('AD:' + [line, valuel, valueh]);
    }

  function _emscripten_autodebug_i32(line, value) {
      out('AD:' + [line, value]);
    }

  function _emscripten_autodebug_i16(line, value) {
      out('AD:' + [line, value]);
    }

  function _emscripten_autodebug_i8(line, value) {
      out('AD:' + [line, value]);
    }

  function _emscripten_autodebug_float(line, value) {
      out('AD:' + [line, value]);
    }

  function _emscripten_autodebug_double(line, value) {
      out('AD:' + [line, value]);
    }

  var _emscripten_prep_setjmp=true;

  var _emscripten_cleanup_setjmp=true;

  var _emscripten_check_longjmp=true;

  var _emscripten_get_longjmp_result=true;

  var _emscripten_setjmp=true;

  var _emscripten_preinvoke=true;

  var _emscripten_postinvoke=true;

  var _emscripten_resume=true;

  var _emscripten_landingpad=true;

  var _getHigh32=true;

  var _setHigh32=true;

  var _FtoILow=true;

  var _FtoIHigh=true;

  var _DtoILow=true;

  var _DtoIHigh=true;

  var _BDtoILow=true;

  var _BDtoIHigh=true;

  var _SItoF=true;

  var _UItoF=true;

  var _SItoD=true;

  var _UItoD=true;

  var _BItoD=true;

  var _llvm_dbg_value=true;

  var _llvm_debugtrap=true;

  var _llvm_ctlz_i32=true;

  var _emscripten_asm_const=true;

  var _emscripten_asm_const_int=true;

  var _emscripten_asm_const_double=true;

  var _emscripten_asm_const_int_sync_on_main_thread=true;

  var _emscripten_asm_const_double_sync_on_main_thread=true;

  var _emscripten_asm_const_async_on_main_thread=true;



   



   


  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        console.error('emscripten_set_main_loop_timing: Cannot set timing mode for main loop since a main loop does not exist! Call emscripten_set_main_loop first to set one up.');
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setTimeout() {
          var timeUntilNextTick = Math.max(0, Browser.mainLoop.tickStartTime + value - _emscripten_get_now())|0;
          setTimeout(Browser.mainLoop.runner, timeUntilNextTick); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_rAF() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      } else if (mode == 2 /*EM_TIMING_SETIMMEDIATE*/) {
        if (typeof setImmediate === 'undefined') {
          // Emulate setImmediate. (note: not a complete polyfill, we don't emulate clearImmediate() to keep code size to minimum, since not needed)
          var setImmediates = [];
          var emscriptenMainLoopMessageId = 'setimmediate';
          function Browser_setImmediate_messageHandler(event) {
            // When called in current thread or Worker, the main loop ID is structured slightly different to accommodate for --proxy-to-worker runtime listening to Worker events,
            // so check for both cases.
            if (event.data === emscriptenMainLoopMessageId || event.data.target === emscriptenMainLoopMessageId) {
              event.stopPropagation();
              setImmediates.shift()();
            }
          }
          addEventListener("message", Browser_setImmediate_messageHandler, true);
          setImmediate = function Browser_emulated_setImmediate(func) {
            setImmediates.push(func);
            if (ENVIRONMENT_IS_WORKER) {
              if (Module['setImmediates'] === undefined) Module['setImmediates'] = [];
              Module['setImmediates'].push(func);
              postMessage({target: emscriptenMainLoopMessageId}); // In --proxy-to-worker, route the message via proxyClient.js
            } else postMessage(emscriptenMainLoopMessageId, "*"); // On the main thread, can just send the message to itself.
          }
        }
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setImmediate() {
          setImmediate(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'immediate';
      }
      return 0;
    }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg, noSetTiming) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var browserIterationFunc;
      if (typeof arg !== 'undefined') {
        browserIterationFunc = function() {
          Module['dynCall_vi'](func, arg);
        };
      } else {
        browserIterationFunc = function() {
          Module['dynCall_v'](func);
        };
      }
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
  
          // catches pause/resume main loop from blocker execution
          if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        } else if (Browser.mainLoop.timingMode == 0/*EM_TIMING_SETTIMEOUT*/) {
          Browser.mainLoop.tickStartTime = _emscripten_get_now();
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
  
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          err('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(browserIterationFunc);
  
        checkStackCookie();
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (!noSetTiming) {
        if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
        else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
        Browser.mainLoop.scheduler();
      }
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg, true /* do not set timing and call scheduler, we will do it on the next lines */);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
          Browser.mainLoop.scheduler();
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) err('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullscreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          assert(typeof url == 'string', 'createObjectURL must return a url as a string');
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            assert(typeof url == 'string', 'createObjectURL must return a url as a string');
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
  
        // Canvas event setup
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === Module['canvas'] ||
                                document['mozPointerLockElement'] === Module['canvas'] ||
                                document['webkitPointerLockElement'] === Module['canvas'] ||
                                document['msPointerLockElement'] === Module['canvas'];
        }
        var canvas = Module['canvas'];
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
  
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && Module['canvas'].requestPointerLock) {
                Module['canvas'].requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullscreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullscreen:function (lockPointer, resizeCanvas, vrDevice) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        Browser.vrDevice = vrDevice;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        if (typeof Browser.vrDevice === 'undefined') Browser.vrDevice = null;
  
        var canvas = Module['canvas'];
        function fullscreenChange() {
          Browser.isFullscreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['fullscreenElement'] || document['mozFullScreenElement'] ||
               document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.exitFullscreen = document['exitFullscreen'] ||
                                    document['cancelFullScreen'] ||
                                    document['mozCancelFullScreen'] ||
                                    document['msExitFullscreen'] ||
                                    document['webkitCancelFullScreen'] ||
                                    function() {};
            canvas.exitFullscreen = canvas.exitFullscreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullscreen = true;
            if (Browser.resizeCanvas) {
              Browser.setFullscreenCanvasSize();
            } else {
              Browser.updateCanvasDimensions(canvas);
            }
          } else {
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
  
            if (Browser.resizeCanvas) {
              Browser.setWindowedCanvasSize();
            } else {
              Browser.updateCanvasDimensions(canvas);
            }
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullscreen);
          if (Module['onFullscreen']) Module['onFullscreen'](Browser.isFullscreen);
        }
  
        if (!Browser.fullscreenHandlersInstalled) {
          Browser.fullscreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullscreenChange, false);
          document.addEventListener('mozfullscreenchange', fullscreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullscreenChange, false);
          document.addEventListener('MSFullscreenChange', fullscreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
  
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullscreen = canvasContainer['requestFullscreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullscreen'] ? function() { canvasContainer['webkitRequestFullscreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null) ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
  
        if (vrDevice) {
          canvasContainer.requestFullscreen({ vrDisplay: vrDevice });
        } else {
          canvasContainer.requestFullscreen();
        }
      },requestFullScreen:function (lockPointer, resizeCanvas, vrDevice) {
          err('Browser.requestFullScreen() is deprecated. Please call Browser.requestFullscreen instead.');
          Browser.requestFullScreen = function(lockPointer, resizeCanvas, vrDevice) {
            return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
          }
          return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },allowAsyncCallbacks:true,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function () {
        Browser.allowAsyncCallbacks = false;
      },resumeAsyncCallbacks:function () { // marks future callbacks as ok to execute, and synchronously runs any remaining ones right now
        Browser.allowAsyncCallbacks = true;
        if (Browser.queuedAsyncCallbacks.length > 0) {
          var callbacks = Browser.queuedAsyncCallbacks;
          Browser.queuedAsyncCallbacks = [];
          callbacks.forEach(function(func) {
            func();
          });
        }
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } // drop it on the floor otherwise, next interval will kick in
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll':
            delta = event.detail;
            break;
          case 'mousewheel':
            delta = event.wheelDelta;
            break;
          case 'wheel':
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
  
          // check if SDL is available
          if (typeof SDL != "undefined") {
            Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
            Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
            // just add the mouse delta to the current absolut mouse position
            // FIXME: ideally this should be clamped against the canvas size and zero
            Browser.mouseX += Browser.mouseMovementX;
            Browser.mouseY += Browser.mouseMovementY;
          }
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          // If this assert lands, it's likely because the browser doesn't support scrollX or pageXOffset
          // and we have no viable fallback.
          assert((typeof scrollX !== 'undefined') && (typeof scrollY !== 'undefined'), 'Unable to retrieve scroll position, mouse positions likely broken.');
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
  
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              var last = Browser.touches[touch.identifier];
              if (!last) last = coords;
              Browser.lastTouches[touch.identifier] = last;
              Browser.touches[touch.identifier] = coords;
            }
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        var dep = !noRunDep ? getUniqueRunDependency('al ' + url) : '';
        Module['readAsync'](url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (dep) removeRunDependency(dep);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (dep) addRunDependency(dep);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullscreenCanvasSize:function () {
        // check if SDL is available
        if (typeof SDL != "undefined") {
          var flags = HEAPU32[((SDL.screen)>>2)];
          flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
          HEAP32[((SDL.screen)>>2)]=flags
        }
        Browser.updateCanvasDimensions(Module['canvas']);
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available
        if (typeof SDL != "undefined") {
          var flags = HEAPU32[((SDL.screen)>>2)];
          flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
          HEAP32[((SDL.screen)>>2)]=flags
        }
        Browser.updateCanvasDimensions(Module['canvas']);
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['fullscreenElement'] || document['mozFullScreenElement'] ||
             document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};


  function _emscripten_async_wget(url, file, onload, onerror) {
      Module['noExitRuntime'] = true;
  
      var _url = Pointer_stringify(url);
      var _file = Pointer_stringify(file);
      _file = PATH.resolve(FS.cwd(), _file);
      function doCallback(callback) {
        if (callback) {
          var stack = stackSave();
          Module['dynCall_vi'](callback, allocate(intArrayFromString(_file), 'i8', ALLOC_STACK));
          stackRestore(stack);
        }
      }
      var destinationDirectory = PATH.dirname(_file);
      FS.createPreloadedFile(
        destinationDirectory,
        PATH.basename(_file),
        _url, true, true,
        function() {
          doCallback(onload);
        },
        function() {
          doCallback(onerror);
        },
        false, // dontCreateFile
        false, // canOwn
        function() { // preFinish
          // if a file exists there, we overwrite it
          try {
            FS.unlink(_file);
          } catch (e) {}
          // if the destination directory does not yet exist, create it
          FS.mkdirTree(destinationDirectory);
        }
      );
    }


  function _emscripten_async_wget_data(url, arg, onload, onerror) {
      Browser.asyncLoad(Pointer_stringify(url), function(byteArray) {
        var buffer = _malloc(byteArray.length);
        HEAPU8.set(byteArray, buffer);
        Module['dynCall_viii'](onload, arg, buffer, byteArray.length);
        _free(buffer);
      }, function() {
        if (onerror) Module['dynCall_vi'](onerror, arg);
      }, true /* no need for run dependency, this is async but will not do any prepare etc. step */ );
    }


  function _emscripten_async_wget2(url, file, request, param, arg, onload, onerror, onprogress) {
      Module['noExitRuntime'] = true;
  
      var _url = Pointer_stringify(url);
      var _file = Pointer_stringify(file);
      _file = PATH.resolve(FS.cwd(), _file);
      var _request = Pointer_stringify(request);
      var _param = Pointer_stringify(param);
      var index = _file.lastIndexOf('/');
  
      var http = new XMLHttpRequest();
      http.open(_request, _url, true);
      http.responseType = 'arraybuffer';
  
      var handle = Browser.getNextWgetRequestHandle();
  
      var destinationDirectory = PATH.dirname(_file);
  
      // LOAD
      http.onload = function http_onload(e) {
        if (http.status == 200) {
          // if a file exists there, we overwrite it
          try {
            FS.unlink(_file);
          } catch (e) {}
          // if the destination directory does not yet exist, create it
          FS.mkdirTree(destinationDirectory);
  
          FS.createDataFile( _file.substr(0, index), _file.substr(index + 1), new Uint8Array(http.response), true, true, false);
          if (onload) {
            var stack = stackSave();
            Module['dynCall_viii'](onload, handle, arg, allocate(intArrayFromString(_file), 'i8', ALLOC_STACK));
            stackRestore(stack);
          }
        } else {
          if (onerror) Module['dynCall_viii'](onerror, handle, arg, http.status);
        }
  
        delete Browser.wgetRequests[handle];
      };
  
      // ERROR
      http.onerror = function http_onerror(e) {
        if (onerror) Module['dynCall_viii'](onerror, handle, arg, http.status);
        delete Browser.wgetRequests[handle];
      };
  
      // PROGRESS
      http.onprogress = function http_onprogress(e) {
        if (e.lengthComputable || (e.lengthComputable === undefined && e.total != 0)) {
          var percentComplete = (e.loaded / e.total)*100;
          if (onprogress) Module['dynCall_viii'](onprogress, handle, arg, percentComplete);
        }
      };
  
      // ABORT
      http.onabort = function http_onabort(e) {
        delete Browser.wgetRequests[handle];
      };
  
      if (_request == "POST") {
        //Send the proper header information along with the request
        http.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
        http.send(_param);
      } else {
        http.send(null);
      }
  
      Browser.wgetRequests[handle] = http;
  
      return handle;
    }


  function _emscripten_async_wget2_data(url, request, param, arg, free, onload, onerror, onprogress) {
      var _url = Pointer_stringify(url);
      var _request = Pointer_stringify(request);
      var _param = Pointer_stringify(param);
  
      var http = new XMLHttpRequest();
      http.open(_request, _url, true);
      http.responseType = 'arraybuffer';
  
      var handle = Browser.getNextWgetRequestHandle();
  
      // LOAD
      http.onload = function http_onload(e) {
        if (http.status == 200 || _url.substr(0,4).toLowerCase() != "http") {
          var byteArray = new Uint8Array(http.response);
          var buffer = _malloc(byteArray.length);
          HEAPU8.set(byteArray, buffer);
          if (onload) Module['dynCall_viiii'](onload, handle, arg, buffer, byteArray.length);
          if (free) _free(buffer);
        } else {
          if (onerror) Module['dynCall_viiii'](onerror, handle, arg, http.status, http.statusText);
        }
        delete Browser.wgetRequests[handle];
      };
  
      // ERROR
      http.onerror = function http_onerror(e) {
        if (onerror) {
          Module['dynCall_viiii'](onerror, handle, arg, http.status, http.statusText);
        }
        delete Browser.wgetRequests[handle];
      };
  
      // PROGRESS
      http.onprogress = function http_onprogress(e) {
        if (onprogress) Module['dynCall_viiii'](onprogress, handle, arg, e.loaded, e.lengthComputable || e.lengthComputable === undefined ? e.total : 0);
      };
  
      // ABORT
      http.onabort = function http_onabort(e) {
        delete Browser.wgetRequests[handle];
      };
  
      if (_request == "POST") {
        //Send the proper header information along with the request
        http.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
        http.send(_param);
      } else {
        http.send(null);
      }
  
      Browser.wgetRequests[handle] = http;
  
      return handle;
    }


  function _emscripten_async_wget2_abort(handle) {
      var http = Browser.wgetRequests[handle];
      if (http) {
        http.abort();
      }
    }


  function _emscripten_run_preload_plugins(file, onload, onerror) {
      Module['noExitRuntime'] = true;
  
      var _file = Pointer_stringify(file);
      var data = FS.analyzePath(_file);
      if (!data.exists) return -1;
      FS.createPreloadedFile(
        PATH.dirname(_file),
        PATH.basename(_file),
        new Uint8Array(data.object.contents), true, true,
        function() {
          if (onload) Module['dynCall_vi'](onload, file);
        },
        function() {
          if (onerror) Module['dynCall_vi'](onerror, file);
        },
        true // don'tCreateFile - it's already there
      );
      return 0;
    }


  function _emscripten_run_preload_plugins_data(data, size, suffix, arg, onload, onerror) {
      Module['noExitRuntime'] = true;
  
      var _suffix = Pointer_stringify(suffix);
      if (!Browser.asyncPrepareDataCounter) Browser.asyncPrepareDataCounter = 0;
      var name = 'prepare_data_' + (Browser.asyncPrepareDataCounter++) + '.' + _suffix;
      var lengthAsUTF8 = lengthBytesUTF8(name);
      var cname = _malloc(lengthAsUTF8+1);
      stringToUTF8(name, cname, lengthAsUTF8+1);
      FS.createPreloadedFile(
        '/',
        name,
        HEAPU8.subarray((data),(data + size)),
        true, true,
        function() {
          if (onload) Module['dynCall_vii'](onload, arg, cname);
        },
        function() {
          if (onerror) Module['dynCall_vi'](onerror, arg);
        },
        true // don'tCreateFile - it's already there
      );
    }

  function _emscripten_async_run_script(script, millis) {
      Module['noExitRuntime'] = true;
  
      // TODO: cache these to avoid generating garbage
      Browser.safeSetTimeout(function() {
        _emscripten_run_script(script);
      }, millis);
    }

  function _emscripten_async_load_script(url, onload, onerror) {
      onload = getFuncWrapper(onload, 'v');
      onerror = getFuncWrapper(onerror, 'v');
  
      Module['noExitRuntime'] = true;
  
      assert(runDependencies === 0, 'async_load_script must be run when no other dependencies are active');
      var script = document.createElement('script');
      if (onload) {
        script.onload = function script_onload() {
          if (runDependencies > 0) {
            dependenciesFulfilled = onload;
          } else {
            onload();
          }
        };
      }
      if (onerror) script.onerror = onerror;
      script.src = Pointer_stringify(url);
      document.body.appendChild(script);
    }

  function _emscripten_get_main_loop_timing(mode, value) {
      if (mode) HEAP32[((mode)>>2)]=Browser.mainLoop.timingMode;
      if (value) HEAP32[((value)>>2)]=Browser.mainLoop.timingValue;
    }



  function _emscripten_set_main_loop_arg(func, arg, fps, simulateInfiniteLoop) {
      _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg);
    }

  function _emscripten_cancel_main_loop() {
      Browser.mainLoop.pause();
      Browser.mainLoop.func = null;
    }

  function _emscripten_pause_main_loop() {
      Browser.mainLoop.pause();
    }

  function _emscripten_resume_main_loop() {
      Browser.mainLoop.resume();
    }

  function __emscripten_push_main_loop_blocker(func, arg, name) {
      Browser.mainLoop.queue.push({ func: function() {
        Module['dynCall_vi'](func, arg);
      }, name: Pointer_stringify(name), counted: true });
      Browser.mainLoop.updateStatus();
    }

  function __emscripten_push_uncounted_main_loop_blocker(func, arg, name) {
      Browser.mainLoop.queue.push({ func: function() {
        Module['dynCall_vi'](func, arg);
      }, name: Pointer_stringify(name), counted: false });
      Browser.mainLoop.updateStatus();
    }

  function _emscripten_set_main_loop_expected_blockers(num) {
      Browser.mainLoop.expectedBlockers = num;
      Browser.mainLoop.remainingBlockers = num;
      Browser.mainLoop.updateStatus();
    }

  function _emscripten_async_call(func, arg, millis) {
      Module['noExitRuntime'] = true;
  
      function wrapper() {
        getFuncWrapper(func, 'vi')(arg);
      }
  
      if (millis >= 0) {
        Browser.safeSetTimeout(wrapper, millis);
      } else {
        Browser.safeRequestAnimationFrame(wrapper);
      }
    }

  function _emscripten_exit_with_live_runtime() {
      Module['noExitRuntime'] = true;
      throw 'SimulateInfiniteLoop';
    }


  function _emscripten_force_exit(status) {
      warnOnce('emscripten_force_exit cannot actually shut down the runtime, as the build does not have EXIT_RUNTIME set');
      Module['noExitRuntime'] = false;
      exit(status);
    }


  function _emscripten_get_device_pixel_ratio() {
      return window.devicePixelRatio || 1.0;
    }


  function _emscripten_hide_mouse() {
      var styleSheet = document.styleSheets[0];
      var rules = styleSheet.cssRules;
      for (var i = 0; i < rules.length; i++) {
        if (rules[i].cssText.substr(0, 6) == 'canvas') {
          styleSheet.deleteRule(i);
          i--;
        }
      }
      styleSheet.insertRule('canvas.emscripten { border: 1px solid black; cursor: none; }', 0);
    }


  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }


  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullscreen ? 1 : 0;
    }


  function _emscripten_create_worker(url) {
      url = Pointer_stringify(url);
      var id = Browser.workers.length;
      var info = {
        worker: new Worker(url),
        callbacks: [],
        awaited: 0,
        buffer: 0,
        bufferSize: 0
      };
      info.worker.onmessage = function info_worker_onmessage(msg) {
        if (ABORT) return;
        var info = Browser.workers[id];
        if (!info) return; // worker was destroyed meanwhile
        var callbackId = msg.data['callbackId'];
        var callbackInfo = info.callbacks[callbackId];
        if (!callbackInfo) return; // no callback or callback removed meanwhile
        // Don't trash our callback state if we expect additional calls.
        if (msg.data['finalResponse']) {
          info.awaited--;
          info.callbacks[callbackId] = null; // TODO: reuse callbackIds, compress this
        }
        var data = msg.data['data'];
        if (data) {
          if (!data.byteLength) data = new Uint8Array(data);
          if (!info.buffer || info.bufferSize < data.length) {
            if (info.buffer) _free(info.buffer);
            info.bufferSize = data.length;
            info.buffer = _malloc(data.length);
          }
          HEAPU8.set(data, info.buffer);
          callbackInfo.func(info.buffer, data.length, callbackInfo.arg);
        } else {
          callbackInfo.func(0, 0, callbackInfo.arg);
        }
      };
      Browser.workers.push(info);
      return id;
    }


  function _emscripten_destroy_worker(id) {
      var info = Browser.workers[id];
      info.worker.terminate();
      if (info.buffer) _free(info.buffer);
      Browser.workers[id] = null;
    }


  function _emscripten_call_worker(id, funcName, data, size, callback, arg) {
      Module['noExitRuntime'] = true; // should we only do this if there is a callback?
  
      funcName = Pointer_stringify(funcName);
      var info = Browser.workers[id];
      var callbackId = -1;
      if (callback) {
        callbackId = info.callbacks.length;
        info.callbacks.push({
          func: getFuncWrapper(callback, 'viii'),
          arg: arg
        });
        info.awaited++;
      }
      var transferObject = {
        'funcName': funcName,
        'callbackId': callbackId,
        'data': data ? new Uint8Array(HEAPU8.subarray((data),(data + size))) : 0
      };
      if (data) {
        info.worker.postMessage(transferObject, [transferObject.data.buffer]);
      } else {
        info.worker.postMessage(transferObject);
      }
    }


  function _emscripten_worker_respond_provisionally(data, size) {
      if (workerResponded) throw 'already responded with final response!';
      var transferObject = {
        'callbackId': workerCallbackId,
        'finalResponse': false,
        'data': data ? new Uint8Array(HEAPU8.subarray((data),(data + size))) : 0
      };
      if (data) {
        postMessage(transferObject, [transferObject.data.buffer]);
      } else {
        postMessage(transferObject);
      }
    }


  function _emscripten_worker_respond(data, size) {
      if (workerResponded) throw 'already responded with final response!';
      workerResponded = true;
      var transferObject = {
        'callbackId': workerCallbackId,
        'finalResponse': true,
        'data': data ? new Uint8Array(HEAPU8.subarray((data),(data + size))) : 0
      };
      if (data) {
        postMessage(transferObject, [transferObject.data.buffer]);
      } else {
        postMessage(transferObject);
      }
    }


  function _emscripten_get_worker_queue_size(id) {
      var info = Browser.workers[id];
      if (!info) return -1;
      return info.awaited;
    }


  function _emscripten_get_preloaded_image_data(path, w, h) {
      if (typeof path === "number") {
        path = Pointer_stringify(path);
      }
  
      path = PATH.resolve(path);
  
      var canvas = Module["preloadedImages"][path];
      if (canvas) {
        var ctx = canvas.getContext("2d");
        var image = ctx.getImageData(0, 0, canvas.width, canvas.height);
        var buf = _malloc(canvas.width * canvas.height * 4);
  
        HEAPU8.set(image.data, buf);
  
        HEAP32[((w)>>2)]=canvas.width;
        HEAP32[((h)>>2)]=canvas.height;
        return buf;
      }
  
      return 0;
    }


  function _emscripten_get_preloaded_image_data_from_FILE(file, w, h) {
      var fd = Module['_fileno'](file);
      var stream = FS.getStream(fd);
      if (stream) {
        return _emscripten_get_preloaded_image_data(stream.path, w, h);
      }
  
      return 0;
    }





  var __sigalrm_handler=0;

  function _signal(sig, func) {
      if (sig == 14 /*SIGALRM*/) {
        __sigalrm_handler = func;
      } else {
        err('Calling stub instead of signal()');
      }
      return 0;
    }

  function _sigemptyset(set) {
      HEAP32[((set)>>2)]=0;
      return 0;
    }


  function _sigaddset(set, signum) {
      HEAP32[((set)>>2)]=HEAP32[((set)>>2)]| (1 << (signum-1));
      return 0;
    }

  function _sigdelset(set, signum) {
      HEAP32[((set)>>2)]=HEAP32[((set)>>2)]& (~(1 << (signum-1)));
      return 0;
    }

  function _sigismember(set, signum) {
      return HEAP32[((set)>>2)] & (1 << (signum-1));
    }

  function _sigaction(signum, act, oldact) {
      //int sigaction(int signum, const struct sigaction *act, struct sigaction *oldact);
      err('Calling stub instead of sigaction()');
      return 0;
    }

  function _sigprocmask() {
      err('Calling stub instead of sigprocmask()');
      return 0;
    }

  function ___libc_current_sigrtmin() {
      err('Calling stub instead of __libc_current_sigrtmin');
      return 0;
    }

  function ___libc_current_sigrtmax() {
      err('Calling stub instead of __libc_current_sigrtmax');
      return 0;
    }

  function _kill(pid, sig) {
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/kill.html
      // Makes no sense in a single-process environment.
  	  // Should kill itself somtimes depending on `pid`
      err('Calling stub instead of kill()');
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }

  function _killpg() {
      err('Calling stub instead of killpg()');
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }

  function _siginterrupt() {
      err('Calling stub instead of siginterrupt()');
      return 0;
    }

  function _raise(sig) {
      err('Calling stub instead of raise()');
    ___setErrNo(ERRNO_CODES.ENOSYS);
      warnOnce('raise() returning an error as we do not support it');
      return -1;
    }

  function _alarm(seconds) {
      setTimeout(function() {
        if (__sigalrm_handler) Module['dynCall_vi'](__sigalrm_handler, 0);
      }, seconds*1000);
    }



  function _getitimer() {
      throw 'getitimer() is not implemented yet';
    }


  function _siglongjmp(env, value) {
      // We cannot wrap the sigsetjmp, but I hope that
      // in most cases siglongjmp will be called later.
  
      // siglongjmp can be called very many times, so don't flood the stderr.
      warnOnce("Calling longjmp() instead of siglongjmp()");
      _longjmp(env, value);
    }

  function _sigpending(set) {
      HEAP32[((set)>>2)]=0;
      return 0;
    }


  function ___syscall1(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // exit
      var status = SYSCALLS.get();
      exit(status);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


























  function ___syscall65(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // getpgrp
      return PROCINFO.pgid;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }











  function ___syscall104(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setitimer
      return -ERRNO_CODES.ENOSYS; // unsupported feature
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }





















  function ___syscall178(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // rt_sigqueueinfo
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


















  
  function ___syscall214(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setgid32
      var uid = SYSCALLS.get();
      if (uid !== 0) return -ERRNO_CODES.EPERM;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }function ___syscall203() {
  return ___syscall214.apply(null, arguments)
  }

  function ___syscall204() {
  return ___syscall214.apply(null, arguments)
  }

  function ___syscall213() {
  return ___syscall214.apply(null, arguments)
  }



  
  function ___syscall210(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // setresgid32
      var ruid = SYSCALLS.get(), euid = SYSCALLS.get(), suid = SYSCALLS.get();
      if (euid !== 0) return -ERRNO_CODES.EPERM;
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }function ___syscall208() {
  return ___syscall210.apply(null, arguments)
  }








  function ___syscall265(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // clock_nanosleep
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }








  function ___syscall299(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // futimesat
      abort('futimesat is obsolete');
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }








  function ___syscall307(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // faccessat
      var dirfd = SYSCALLS.get(), path = SYSCALLS.getStr(), amode = SYSCALLS.get(), flags = SYSCALLS.get();
      assert(flags === 0);
      path = SYSCALLS.calculateAt(dirfd, path);
      return SYSCALLS.doAccess(path, amode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }











  
  
  function _emscripten_get_canvas_element_size(target, width, height) {
      var canvas = JSEvents.findCanvasEventTarget(target);
      if (!canvas) return -4;
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
    }function __get_canvas_element_size(target) {
      var stackTop = stackSave();
      var w = stackAlloc(8);
      var h = w + 4;
  
      var targetInt = stackAlloc(target.id.length+1);
      stringToUTF8(target.id, targetInt, target.id.length+1);
      var ret = _emscripten_get_canvas_element_size(targetInt, w, h);
      var size = [HEAP32[((w)>>2)], HEAP32[((h)>>2)]];
      stackRestore(stackTop);
      return size;
    }
  
  
  function _emscripten_set_canvas_element_size(target, width, height) {
      var canvas = JSEvents.findCanvasEventTarget(target);
      if (!canvas) return -4;
      canvas.width = width;
      canvas.height = height;
      return 0;
    }function __set_canvas_element_size(target, width, height) {
      if (!target.controlTransferredOffscreen) {
        target.width = width;
        target.height = height;
      } else {
        // This function is being called from high-level JavaScript code instead of asm.js/Wasm,
        // and it needs to synchronously proxy over to another thread, so marshal the string onto the heap to do the call.
        var stackTop = stackSave();
        var targetInt = stackAlloc(target.id.length+1);
        stringToUTF8(target.id, targetInt, target.id.length+1);
        _emscripten_set_canvas_element_size(targetInt, width, height);
        stackRestore(stackTop);
      }
    }var JSEvents={keyEvent:0,mouseEvent:0,wheelEvent:0,uiEvent:0,focusEvent:0,deviceOrientationEvent:0,deviceMotionEvent:0,fullscreenChangeEvent:0,pointerlockChangeEvent:0,visibilityChangeEvent:0,touchEvent:0,lastGamepadState:null,lastGamepadStateFrame:null,numGamepadsConnected:0,previousFullscreenElement:null,previousScreenX:null,previousScreenY:null,removeEventListenersRegistered:false,_onGamepadConnected:function () { ++JSEvents.numGamepadsConnected; },_onGamepadDisconnected:function () { --JSEvents.numGamepadsConnected; },staticInit:function () {
        if (typeof window !== 'undefined') {
          window.addEventListener("gamepadconnected", JSEvents._onGamepadConnected);
          window.addEventListener("gamepaddisconnected", JSEvents._onGamepadDisconnected);
          
          // Chromium does not fire the gamepadconnected event on reload, so we need to get the number of gamepads here as a workaround.
          // See https://bugs.chromium.org/p/chromium/issues/detail?id=502824
          var firstState = navigator.getGamepads ? navigator.getGamepads() : (navigator.webkitGetGamepads ? navigator.webkitGetGamepads() : null);
          if (firstState) {
            JSEvents.numGamepadsConnected = firstState.length;
          }
        }
      },removeAllEventListeners:function () {
        for(var i = JSEvents.eventHandlers.length-1; i >= 0; --i) {
          JSEvents._removeHandler(i);
        }
        JSEvents.eventHandlers = [];
        JSEvents.deferredCalls = [];
        if (typeof window !== 'undefined') {
          window.removeEventListener("gamepadconnected", JSEvents._onGamepadConnected);
          window.removeEventListener("gamepaddisconnected", JSEvents._onGamepadDisconnected);
        }
      },registerRemoveEventListeners:function () {
        if (!JSEvents.removeEventListenersRegistered) {
          __ATEXIT__.push(JSEvents.removeAllEventListeners);
          JSEvents.removeEventListenersRegistered = true;
        }
      },findEventTarget:function (target) {
        try {
          // The sensible "default" target varies between events, but use window as the default
          // since DOM events mostly can default to that. Specific callback registrations
          // override their own defaults.
          if (!target) return window;
          if (typeof target === "number") target = Pointer_stringify(target);
          if (target === '#window') return window;
          else if (target === '#document') return document;
          else if (target === '#screen') return window.screen;
          else if (target === '#canvas') return Module['canvas'];
          return (typeof target === 'string') ? document.getElementById(target) : target;
        } catch(e) {
          // In Web Workers, some objects above, such as '#document' do not exist. Gracefully
          // return null for them.
          return null;
        }
      },findCanvasEventTarget:function (target) {
        if (typeof target === 'number') target = Pointer_stringify(target);
        if (!target || target === '#canvas') {
          if (typeof GL !== 'undefined' && GL.offscreenCanvases['canvas']) return GL.offscreenCanvases['canvas']; // TODO: Remove this line, target '#canvas' should refer only to Module['canvas'], not to GL.offscreenCanvases['canvas'] - but need stricter tests to be able to remove this line.
          return Module['canvas'];
        }
        if (typeof GL !== 'undefined' && GL.offscreenCanvases[target]) return GL.offscreenCanvases[target];
        return JSEvents.findEventTarget(target);
      },deferredCalls:[],deferCall:function (targetFunction, precedence, argsList) {
        function arraysHaveEqualContent(arrA, arrB) {
          if (arrA.length != arrB.length) return false;
  
          for(var i in arrA) {
            if (arrA[i] != arrB[i]) return false;
          }
          return true;
        }
        // Test if the given call was already queued, and if so, don't add it again.
        for(var i in JSEvents.deferredCalls) {
          var call = JSEvents.deferredCalls[i];
          if (call.targetFunction == targetFunction && arraysHaveEqualContent(call.argsList, argsList)) {
            return;
          }
        }
        JSEvents.deferredCalls.push({
          targetFunction: targetFunction,
          precedence: precedence,
          argsList: argsList
        });
  
        JSEvents.deferredCalls.sort(function(x,y) { return x.precedence < y.precedence; });
      },removeDeferredCalls:function (targetFunction) {
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          if (JSEvents.deferredCalls[i].targetFunction == targetFunction) {
            JSEvents.deferredCalls.splice(i, 1);
            --i;
          }
        }
      },canPerformEventHandlerRequests:function () {
        return JSEvents.inEventHandler && JSEvents.currentEventHandler.allowsDeferredCalls;
      },runDeferredCalls:function () {
        if (!JSEvents.canPerformEventHandlerRequests()) {
          return;
        }
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          var call = JSEvents.deferredCalls[i];
          JSEvents.deferredCalls.splice(i, 1);
          --i;
          call.targetFunction.apply(this, call.argsList);
        }
      },inEventHandler:0,currentEventHandler:null,eventHandlers:[],isInternetExplorer:function () { return navigator.userAgent.indexOf('MSIE') !== -1 || navigator.appVersion.indexOf('Trident/') > 0; },removeAllHandlersOnTarget:function (target, eventTypeString) {
        for(var i = 0; i < JSEvents.eventHandlers.length; ++i) {
          if (JSEvents.eventHandlers[i].target == target && 
            (!eventTypeString || eventTypeString == JSEvents.eventHandlers[i].eventTypeString)) {
             JSEvents._removeHandler(i--);
           }
        }
      },_removeHandler:function (i) {
        var h = JSEvents.eventHandlers[i];
        h.target.removeEventListener(h.eventTypeString, h.eventListenerFunc, h.useCapture);
        JSEvents.eventHandlers.splice(i, 1);
      },registerOrRemoveHandler:function (eventHandler) {
        var jsEventHandler = function jsEventHandler(event) {
          // Increment nesting count for the event handler.
          ++JSEvents.inEventHandler;
          JSEvents.currentEventHandler = eventHandler;
          // Process any old deferred calls the user has placed.
          JSEvents.runDeferredCalls();
          // Process the actual event, calls back to user C code handler.
          eventHandler.handlerFunc(event);
          // Process any new deferred calls that were placed right now from this event handler.
          JSEvents.runDeferredCalls();
          // Out of event handler - restore nesting count.
          --JSEvents.inEventHandler;
        }
        
        if (eventHandler.callbackfunc) {
          eventHandler.eventListenerFunc = jsEventHandler;
          eventHandler.target.addEventListener(eventHandler.eventTypeString, jsEventHandler, eventHandler.useCapture);
          JSEvents.eventHandlers.push(eventHandler);
          JSEvents.registerRemoveEventListeners();
        } else {
          for(var i = 0; i < JSEvents.eventHandlers.length; ++i) {
            if (JSEvents.eventHandlers[i].target == eventHandler.target
             && JSEvents.eventHandlers[i].eventTypeString == eventHandler.eventTypeString) {
               JSEvents._removeHandler(i--);
             }
          }
        }
      },registerKeyEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.keyEvent) JSEvents.keyEvent = _malloc( 164 );
  
        var keyEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var keyEventData = JSEvents.keyEvent;
          stringToUTF8(e.key ? e.key : "", keyEventData + 0, 32);
          stringToUTF8(e.code ? e.code : "", keyEventData + 32, 32);
          HEAP32[(((keyEventData)+(64))>>2)]=e.location;
          HEAP32[(((keyEventData)+(68))>>2)]=e.ctrlKey;
          HEAP32[(((keyEventData)+(72))>>2)]=e.shiftKey;
          HEAP32[(((keyEventData)+(76))>>2)]=e.altKey;
          HEAP32[(((keyEventData)+(80))>>2)]=e.metaKey;
          HEAP32[(((keyEventData)+(84))>>2)]=e.repeat;
          stringToUTF8(e.locale ? e.locale : "", keyEventData + 88, 32);
          stringToUTF8(e.char ? e.char : "", keyEventData + 120, 32);
          HEAP32[(((keyEventData)+(152))>>2)]=e.charCode;
          HEAP32[(((keyEventData)+(156))>>2)]=e.keyCode;
          HEAP32[(((keyEventData)+(160))>>2)]=e.which;
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, keyEventData, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: JSEvents.isInternetExplorer() ? false : true, // MSIE doesn't allow fullscreen and pointerlock requests from key handlers, others do.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: keyEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },getBoundingClientRectOrZeros:function (target) {
        return target.getBoundingClientRect ? target.getBoundingClientRect() : { left: 0, top: 0 };
      },fillMouseEventData:function (eventStruct, e, target) {
        HEAPF64[((eventStruct)>>3)]=JSEvents.tick();
        HEAP32[(((eventStruct)+(8))>>2)]=e.screenX;
        HEAP32[(((eventStruct)+(12))>>2)]=e.screenY;
        HEAP32[(((eventStruct)+(16))>>2)]=e.clientX;
        HEAP32[(((eventStruct)+(20))>>2)]=e.clientY;
        HEAP32[(((eventStruct)+(24))>>2)]=e.ctrlKey;
        HEAP32[(((eventStruct)+(28))>>2)]=e.shiftKey;
        HEAP32[(((eventStruct)+(32))>>2)]=e.altKey;
        HEAP32[(((eventStruct)+(36))>>2)]=e.metaKey;
        HEAP16[(((eventStruct)+(40))>>1)]=e.button;
        HEAP16[(((eventStruct)+(42))>>1)]=e.buttons;
        HEAP32[(((eventStruct)+(44))>>2)]=e["movementX"] || e["mozMovementX"] || e["webkitMovementX"] || (e.screenX-JSEvents.previousScreenX);
        HEAP32[(((eventStruct)+(48))>>2)]=e["movementY"] || e["mozMovementY"] || e["webkitMovementY"] || (e.screenY-JSEvents.previousScreenY);
  
        if (Module['canvas']) {
          var rect = Module['canvas'].getBoundingClientRect();
          HEAP32[(((eventStruct)+(60))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(64))>>2)]=e.clientY - rect.top;
        } else { // Canvas is not initialized, return 0.
          HEAP32[(((eventStruct)+(60))>>2)]=0;
          HEAP32[(((eventStruct)+(64))>>2)]=0;
        }
        if (target) {
          var rect = JSEvents.getBoundingClientRectOrZeros(target);
          HEAP32[(((eventStruct)+(52))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(56))>>2)]=e.clientY - rect.top;
        } else { // No specific target passed, return 0.
          HEAP32[(((eventStruct)+(52))>>2)]=0;
          HEAP32[(((eventStruct)+(56))>>2)]=0;
        }
        // wheel and mousewheel events contain wrong screenX/screenY on chrome/opera
        // https://github.com/kripken/emscripten/pull/4997
        // https://bugs.chromium.org/p/chromium/issues/detail?id=699956
        if (e.type !== 'wheel' && e.type !== 'mousewheel') {
          JSEvents.previousScreenX = e.screenX;
          JSEvents.previousScreenY = e.screenY;
        }
      },registerMouseEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.mouseEvent) JSEvents.mouseEvent = _malloc( 72 );
        target = JSEvents.findEventTarget(target);
  
        var mouseEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          // TODO: Make this access thread safe, or this could update live while app is reading it.
          JSEvents.fillMouseEventData(JSEvents.mouseEvent, e, target);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.mouseEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: eventTypeString != 'mousemove' && eventTypeString != 'mouseenter' && eventTypeString != 'mouseleave', // Mouse move events do not allow fullscreen/pointer lock requests to be handled in them!
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: mouseEventHandlerFunc,
          useCapture: useCapture
        };
        // In IE, mousedown events don't either allow deferred calls to be run!
        if (JSEvents.isInternetExplorer() && eventTypeString == 'mousedown') eventHandler.allowsDeferredCalls = false;
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWheelEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.wheelEvent) JSEvents.wheelEvent = _malloc( 104 );
        target = JSEvents.findEventTarget(target);
  
  
        // The DOM Level 3 events spec event 'wheel'
        var wheelHandlerFunc = function(event) {
          var e = event || window.event;
          var wheelEvent = JSEvents.wheelEvent;
          JSEvents.fillMouseEventData(wheelEvent, e, target);
          HEAPF64[(((wheelEvent)+(72))>>3)]=e["deltaX"];
          HEAPF64[(((wheelEvent)+(80))>>3)]=e["deltaY"];
          HEAPF64[(((wheelEvent)+(88))>>3)]=e["deltaZ"];
          HEAP32[(((wheelEvent)+(96))>>2)]=e["deltaMode"];
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, wheelEvent, userData)) e.preventDefault();
        };
        // The 'mousewheel' event as implemented in Safari 6.0.5
        var mouseWheelHandlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.wheelEvent, e, target);
          HEAPF64[(((JSEvents.wheelEvent)+(72))>>3)]=e["wheelDeltaX"] || 0;
          HEAPF64[(((JSEvents.wheelEvent)+(80))>>3)]=-(e["wheelDeltaY"] ? e["wheelDeltaY"] : e["wheelDelta"]) /* 1. Invert to unify direction with the DOM Level 3 wheel event. 2. MSIE does not provide wheelDeltaY, so wheelDelta is used as a fallback. */;
          HEAPF64[(((JSEvents.wheelEvent)+(88))>>3)]=0 /* Not available */;
          HEAP32[(((JSEvents.wheelEvent)+(96))>>2)]=0 /* DOM_DELTA_PIXEL */;
          var shouldCancel = Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.wheelEvent, userData);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: (eventTypeString == 'wheel') ? wheelHandlerFunc : mouseWheelHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },pageScrollPos:function () {
        if (window.pageXOffset > 0 || window.pageYOffset > 0) {
          return [window.pageXOffset, window.pageYOffset];
        }
        if (typeof document.documentElement.scrollLeft !== 'undefined' || typeof document.documentElement.scrollTop !== 'undefined') {
          return [document.documentElement.scrollLeft, document.documentElement.scrollTop];
        }
        return [document.body.scrollLeft|0, document.body.scrollTop|0];
      },registerUiEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.uiEvent) JSEvents.uiEvent = _malloc( 36 );
  
        if (eventTypeString == "scroll" && !target) {
          target = document; // By default read scroll events on document rather than window.
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var uiEventHandlerFunc = function(event) {
          var e = event || window.event;
          if (e.target != target) {
            // Never take ui events such as scroll via a 'bubbled' route, but always from the direct element that
            // was targeted. Otherwise e.g. if app logs a message in response to a page scroll, the Emscripten log
            // message box could cause to scroll, generating a new (bubbled) scroll message, causing a new log print,
            // causing a new scroll, etc..
            return;
          }
          var scrollPos = JSEvents.pageScrollPos();
  
          var uiEvent = JSEvents.uiEvent;
          HEAP32[((uiEvent)>>2)]=e.detail;
          HEAP32[(((uiEvent)+(4))>>2)]=document.body.clientWidth;
          HEAP32[(((uiEvent)+(8))>>2)]=document.body.clientHeight;
          HEAP32[(((uiEvent)+(12))>>2)]=window.innerWidth;
          HEAP32[(((uiEvent)+(16))>>2)]=window.innerHeight;
          HEAP32[(((uiEvent)+(20))>>2)]=window.outerWidth;
          HEAP32[(((uiEvent)+(24))>>2)]=window.outerHeight;
          HEAP32[(((uiEvent)+(28))>>2)]=scrollPos[0];
          HEAP32[(((uiEvent)+(32))>>2)]=scrollPos[1];
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, uiEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false, // Neither scroll or resize events allow running requests inside them.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: uiEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },getNodeNameForTarget:function (target) {
        if (!target) return '';
        if (target == window) return '#window';
        if (target == window.screen) return '#screen';
        return (target && target.nodeName) ? target.nodeName : '';
      },registerFocusEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.focusEvent) JSEvents.focusEvent = _malloc( 256 );
  
        var focusEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var nodeName = JSEvents.getNodeNameForTarget(e.target);
          var id = e.target.id ? e.target.id : '';
  
          var focusEvent = JSEvents.focusEvent;
          stringToUTF8(nodeName, focusEvent + 0, 128);
          stringToUTF8(id, focusEvent + 128, 128);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, focusEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: focusEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },tick:function () {
        if (window['performance'] && window['performance']['now']) return window['performance']['now']();
        else return Date.now();
      },fillDeviceOrientationEventData:function (eventStruct, e, target) {
        HEAPF64[((eventStruct)>>3)]=JSEvents.tick();
        HEAPF64[(((eventStruct)+(8))>>3)]=e.alpha;
        HEAPF64[(((eventStruct)+(16))>>3)]=e.beta;
        HEAPF64[(((eventStruct)+(24))>>3)]=e.gamma;
        HEAP32[(((eventStruct)+(32))>>2)]=e.absolute;
      },registerDeviceOrientationEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.deviceOrientationEvent) JSEvents.deviceOrientationEvent = _malloc( 40 );
  
        var deviceOrientationEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillDeviceOrientationEventData(JSEvents.deviceOrientationEvent, e, target); // TODO: Thread-safety with respect to emscripten_get_deviceorientation_status()
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.deviceOrientationEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: deviceOrientationEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fillDeviceMotionEventData:function (eventStruct, e, target) {
        HEAPF64[((eventStruct)>>3)]=JSEvents.tick();
        HEAPF64[(((eventStruct)+(8))>>3)]=e.acceleration.x;
        HEAPF64[(((eventStruct)+(16))>>3)]=e.acceleration.y;
        HEAPF64[(((eventStruct)+(24))>>3)]=e.acceleration.z;
        HEAPF64[(((eventStruct)+(32))>>3)]=e.accelerationIncludingGravity.x;
        HEAPF64[(((eventStruct)+(40))>>3)]=e.accelerationIncludingGravity.y;
        HEAPF64[(((eventStruct)+(48))>>3)]=e.accelerationIncludingGravity.z;
        HEAPF64[(((eventStruct)+(56))>>3)]=e.rotationRate.alpha;
        HEAPF64[(((eventStruct)+(64))>>3)]=e.rotationRate.beta;
        HEAPF64[(((eventStruct)+(72))>>3)]=e.rotationRate.gamma;
      },registerDeviceMotionEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.deviceMotionEvent) JSEvents.deviceMotionEvent = _malloc( 80 );
  
        var deviceMotionEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillDeviceMotionEventData(JSEvents.deviceMotionEvent, e, target); // TODO: Thread-safety with respect to emscripten_get_devicemotion_status()
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, JSEvents.deviceMotionEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: deviceMotionEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },screenOrientation:function () {
        if (!window.screen) return undefined;
        return window.screen.orientation || window.screen.mozOrientation || window.screen.webkitOrientation || window.screen.msOrientation;
      },fillOrientationChangeEventData:function (eventStruct, e) {
        var orientations  = ["portrait-primary", "portrait-secondary", "landscape-primary", "landscape-secondary"];
        var orientations2 = ["portrait",         "portrait",           "landscape",         "landscape"];
  
        var orientationString = JSEvents.screenOrientation();
        var orientation = orientations.indexOf(orientationString);
        if (orientation == -1) {
          orientation = orientations2.indexOf(orientationString);
        }
  
        HEAP32[((eventStruct)>>2)]=1 << orientation;
        HEAP32[(((eventStruct)+(4))>>2)]=window.orientation;
      },registerOrientationChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.orientationChangeEvent) JSEvents.orientationChangeEvent = _malloc( 8 );
  
        if (!target) {
          target = window.screen; // Orientation events need to be captured from 'window.screen' instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var orientationChangeEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var orientationChangeEvent = JSEvents.orientationChangeEvent;
  
          JSEvents.fillOrientationChangeEventData(orientationChangeEvent, e);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, orientationChangeEvent, userData)) e.preventDefault();
        };
  
        if (eventTypeString == "orientationchange" && window.screen.mozOrientation !== undefined) {
          eventTypeString = "mozorientationchange";
        }
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: orientationChangeEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fullscreenEnabled:function () {
        return document.fullscreenEnabled || document.mozFullScreenEnabled || document.webkitFullscreenEnabled || document.msFullscreenEnabled;
      },fillFullscreenChangeEventData:function (eventStruct, e) {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
        var isFullscreen = !!fullscreenElement;
        HEAP32[((eventStruct)>>2)]=isFullscreen;
        HEAP32[(((eventStruct)+(4))>>2)]=JSEvents.fullscreenEnabled();
        // If transitioning to fullscreen, report info about the element that is now fullscreen.
        // If transitioning to windowed mode, report info about the element that just was fullscreen.
        var reportedElement = isFullscreen ? fullscreenElement : JSEvents.previousFullscreenElement;
        var nodeName = JSEvents.getNodeNameForTarget(reportedElement);
        var id = (reportedElement && reportedElement.id) ? reportedElement.id : '';
        stringToUTF8(nodeName, eventStruct + 8, 128);
        stringToUTF8(id, eventStruct + 136, 128);
        HEAP32[(((eventStruct)+(264))>>2)]=reportedElement ? reportedElement.clientWidth : 0;
        HEAP32[(((eventStruct)+(268))>>2)]=reportedElement ? reportedElement.clientHeight : 0;
        HEAP32[(((eventStruct)+(272))>>2)]=screen.width;
        HEAP32[(((eventStruct)+(276))>>2)]=screen.height;
        if (isFullscreen) {
          JSEvents.previousFullscreenElement = fullscreenElement;
        }
      },registerFullscreenChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.fullscreenChangeEvent) JSEvents.fullscreenChangeEvent = _malloc( 280 );
  
        if (!target) target = document; // Fullscreen change events need to be captured from 'document' by default instead of 'window'
        else target = JSEvents.findEventTarget(target);
  
        var fullscreenChangeEventhandlerFunc = function(event) {
          var e = event || window.event;
  
          var fullscreenChangeEvent = JSEvents.fullscreenChangeEvent;
  
          JSEvents.fillFullscreenChangeEventData(fullscreenChangeEvent, e);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, fullscreenChangeEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: fullscreenChangeEventhandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },resizeCanvasForFullscreen:function (target, strategy) {
        var restoreOldStyle = __registerRestoreOldStyle(target);
        var cssWidth = strategy.softFullscreen ? window.innerWidth : screen.width;
        var cssHeight = strategy.softFullscreen ? window.innerHeight : screen.height;
        var rect = target.getBoundingClientRect();
        var windowedCssWidth = rect.right - rect.left;
        var windowedCssHeight = rect.bottom - rect.top;
        var canvasSize = __get_canvas_element_size(target);
        var windowedRttWidth = canvasSize[0];
        var windowedRttHeight = canvasSize[1];
  
        if (strategy.scaleMode == 3) {
          __setLetterbox(target, (cssHeight - windowedCssHeight) / 2, (cssWidth - windowedCssWidth) / 2);
          cssWidth = windowedCssWidth;
          cssHeight = windowedCssHeight;
        } else if (strategy.scaleMode == 2) {
          if (cssWidth*windowedRttHeight < windowedRttWidth*cssHeight) {
            var desiredCssHeight = windowedRttHeight * cssWidth / windowedRttWidth;
            __setLetterbox(target, (cssHeight - desiredCssHeight) / 2, 0);
            cssHeight = desiredCssHeight;
          } else {
            var desiredCssWidth = windowedRttWidth * cssHeight / windowedRttHeight;
            __setLetterbox(target, 0, (cssWidth - desiredCssWidth) / 2);
            cssWidth = desiredCssWidth;
          }
        }
  
        // If we are adding padding, must choose a background color or otherwise Chrome will give the
        // padding a default white color. Do it only if user has not customized their own background color.
        if (!target.style.backgroundColor) target.style.backgroundColor = 'black';
        // IE11 does the same, but requires the color to be set in the document body.
        if (!document.body.style.backgroundColor) document.body.style.backgroundColor = 'black'; // IE11
        // Firefox always shows black letterboxes independent of style color.
  
        target.style.width = cssWidth + 'px';
        target.style.height = cssHeight + 'px';
  
        if (strategy.filteringMode == 1) {
          target.style.imageRendering = 'optimizeSpeed';
          target.style.imageRendering = '-moz-crisp-edges';
          target.style.imageRendering = '-o-crisp-edges';
          target.style.imageRendering = '-webkit-optimize-contrast';
          target.style.imageRendering = 'optimize-contrast';
          target.style.imageRendering = 'crisp-edges';
          target.style.imageRendering = 'pixelated';
        }
  
        var dpiScale = (strategy.canvasResolutionScaleMode == 2) ? window.devicePixelRatio : 1;
        if (strategy.canvasResolutionScaleMode != 0) {
          var newWidth = (cssWidth * dpiScale)|0;
          var newHeight = (cssHeight * dpiScale)|0;
          __set_canvas_element_size(target, newWidth, newHeight);
          if (target.GLctxObject) target.GLctxObject.GLctx.viewport(0, 0, newWidth, newHeight);
        }
        return restoreOldStyle;
      },requestFullscreen:function (target, strategy) {
        // EMSCRIPTEN_FULLSCREEN_SCALE_DEFAULT + EMSCRIPTEN_FULLSCREEN_CANVAS_SCALE_NONE is a mode where no extra logic is performed to the DOM elements.
        if (strategy.scaleMode != 0 || strategy.canvasResolutionScaleMode != 0) {
          JSEvents.resizeCanvasForFullscreen(target, strategy);
        }
  
        if (target.requestFullscreen) {
          target.requestFullscreen();
        } else if (target.msRequestFullscreen) {
          target.msRequestFullscreen();
        } else if (target.mozRequestFullScreen) {
          target.mozRequestFullScreen();
        } else if (target.mozRequestFullscreen) {
          target.mozRequestFullscreen();
        } else if (target.webkitRequestFullscreen) {
          target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
        } else {
          if (typeof JSEvents.fullscreenEnabled() === 'undefined') {
            return -1;
          } else {
            return -3;
          }
        }
  
        if (strategy.canvasResizedCallback) {
          Module['dynCall_iiii'](strategy.canvasResizedCallback, 37, 0, strategy.canvasResizedCallbackUserData);
        }
  
        return 0;
      },fillPointerlockChangeEventData:function (eventStruct, e) {
        var pointerLockElement = document.pointerLockElement || document.mozPointerLockElement || document.webkitPointerLockElement || document.msPointerLockElement;
        var isPointerlocked = !!pointerLockElement;
        HEAP32[((eventStruct)>>2)]=isPointerlocked;
        var nodeName = JSEvents.getNodeNameForTarget(pointerLockElement);
        var id = (pointerLockElement && pointerLockElement.id) ? pointerLockElement.id : '';
        stringToUTF8(nodeName, eventStruct + 4, 128);
        stringToUTF8(id, eventStruct + 132, 128);
      },registerPointerlockChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.pointerlockChangeEvent) JSEvents.pointerlockChangeEvent = _malloc( 260 );
  
        if (!target) target = document; // Pointer lock change events need to be captured from 'document' by default instead of 'window'
        else target = JSEvents.findEventTarget(target);
  
        var pointerlockChangeEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var pointerlockChangeEvent = JSEvents.pointerlockChangeEvent;
          JSEvents.fillPointerlockChangeEventData(pointerlockChangeEvent, e);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, pointerlockChangeEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: pointerlockChangeEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerPointerlockErrorEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!target) target = document; // Pointer lock events need to be captured from 'document' by default instead of 'window'
        else target = JSEvents.findEventTarget(target);
  
        var pointerlockErrorEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: pointerlockErrorEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },requestPointerLock:function (target) {
        if (target.requestPointerLock) {
          target.requestPointerLock();
        } else if (target.mozRequestPointerLock) {
          target.mozRequestPointerLock();
        } else if (target.webkitRequestPointerLock) {
          target.webkitRequestPointerLock();
        } else if (target.msRequestPointerLock) {
          target.msRequestPointerLock();
        } else {
          // document.body is known to accept pointer lock, so use that to differentiate if the user passed a bad element,
          // or if the whole browser just doesn't support the feature.
          if (document.body.requestPointerLock || document.body.mozRequestPointerLock || document.body.webkitRequestPointerLock || document.body.msRequestPointerLock) {
            return -3;
          } else {
            return -1;
          }
        }
        return 0;
      },fillVisibilityChangeEventData:function (eventStruct, e) {
        var visibilityStates = [ "hidden", "visible", "prerender", "unloaded" ];
        var visibilityState = visibilityStates.indexOf(document.visibilityState);
  
        HEAP32[((eventStruct)>>2)]=document.hidden;
        HEAP32[(((eventStruct)+(4))>>2)]=visibilityState;
      },registerVisibilityChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.visibilityChangeEvent) JSEvents.visibilityChangeEvent = _malloc( 8 );
  
        if (!target) target = document; // Visibility change events need to be captured from 'document' by default instead of 'window'
        else target = JSEvents.findEventTarget(target);
  
        var visibilityChangeEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var visibilityChangeEvent = JSEvents.visibilityChangeEvent;
  
          JSEvents.fillVisibilityChangeEventData(visibilityChangeEvent, e);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, visibilityChangeEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: visibilityChangeEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerTouchEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.touchEvent) JSEvents.touchEvent = _malloc( 1684 );
  
        target = JSEvents.findEventTarget(target);
  
        var touchEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var touches = {};
          for(var i = 0; i < e.touches.length; ++i) {
            var touch = e.touches[i];
            touches[touch.identifier] = touch;
          }
          for(var i = 0; i < e.changedTouches.length; ++i) {
            var touch = e.changedTouches[i];
            touches[touch.identifier] = touch;
            touch.changed = true;
          }
          for(var i = 0; i < e.targetTouches.length; ++i) {
            var touch = e.targetTouches[i];
            touches[touch.identifier].onTarget = true;
          }
  
          var touchEvent = JSEvents.touchEvent;
          var ptr = touchEvent;
          HEAP32[(((ptr)+(4))>>2)]=e.ctrlKey;
          HEAP32[(((ptr)+(8))>>2)]=e.shiftKey;
          HEAP32[(((ptr)+(12))>>2)]=e.altKey;
          HEAP32[(((ptr)+(16))>>2)]=e.metaKey;
          ptr += 20; // Advance to the start of the touch array.
          var canvasRect = Module['canvas'] ? Module['canvas'].getBoundingClientRect() : undefined;
          var targetRect = JSEvents.getBoundingClientRectOrZeros(target);
          var numTouches = 0;
          for(var i in touches) {
            var t = touches[i];
            HEAP32[((ptr)>>2)]=t.identifier;
            HEAP32[(((ptr)+(4))>>2)]=t.screenX;
            HEAP32[(((ptr)+(8))>>2)]=t.screenY;
            HEAP32[(((ptr)+(12))>>2)]=t.clientX;
            HEAP32[(((ptr)+(16))>>2)]=t.clientY;
            HEAP32[(((ptr)+(20))>>2)]=t.pageX;
            HEAP32[(((ptr)+(24))>>2)]=t.pageY;
            HEAP32[(((ptr)+(28))>>2)]=t.changed;
            HEAP32[(((ptr)+(32))>>2)]=t.onTarget;
            if (canvasRect) {
              HEAP32[(((ptr)+(44))>>2)]=t.clientX - canvasRect.left;
              HEAP32[(((ptr)+(48))>>2)]=t.clientY - canvasRect.top;
            } else {
              HEAP32[(((ptr)+(44))>>2)]=0;
              HEAP32[(((ptr)+(48))>>2)]=0;            
            }
            HEAP32[(((ptr)+(36))>>2)]=t.clientX - targetRect.left;
            HEAP32[(((ptr)+(40))>>2)]=t.clientY - targetRect.top;
            
            ptr += 52;
  
            if (++numTouches >= 32) {
              break;
            }
          }
          HEAP32[((touchEvent)>>2)]=numTouches;
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, touchEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: eventTypeString == 'touchstart' || eventTypeString == 'touchend',
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: touchEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fillGamepadEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.timestamp;
        for(var i = 0; i < e.axes.length; ++i) {
          HEAPF64[(((eventStruct+i*8)+(16))>>3)]=e.axes[i];
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i].value;
          } else {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i];
          }
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i].pressed;
          } else {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i] == 1.0;
          }
        }
        HEAP32[(((eventStruct)+(1296))>>2)]=e.connected;
        HEAP32[(((eventStruct)+(1300))>>2)]=e.index;
        HEAP32[(((eventStruct)+(8))>>2)]=e.axes.length;
        HEAP32[(((eventStruct)+(12))>>2)]=e.buttons.length;
        stringToUTF8(e.id, eventStruct + 1304, 64);
        stringToUTF8(e.mapping, eventStruct + 1368, 64);
      },registerGamepadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.gamepadEvent) JSEvents.gamepadEvent = _malloc( 1432 );
  
        var gamepadEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var gamepadEvent = JSEvents.gamepadEvent;
          JSEvents.fillGamepadEventData(gamepadEvent, e.gamepad);
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, gamepadEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: gamepadEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerBeforeUnloadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        var beforeUnloadEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          // Note: This is always called on the main browser thread, since it needs synchronously return a value!
          var confirmationMessage = Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData);
          
          if (confirmationMessage) {
            confirmationMessage = Pointer_stringify(confirmationMessage);
          }
          if (confirmationMessage) {
            e.preventDefault();
            e.returnValue = confirmationMessage;
            return confirmationMessage;
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: beforeUnloadEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },battery:function () { return navigator.battery || navigator.mozBattery || navigator.webkitBattery; },fillBatteryEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.chargingTime;
        HEAPF64[(((eventStruct)+(8))>>3)]=e.dischargingTime;
        HEAPF64[(((eventStruct)+(16))>>3)]=e.level;
        HEAP32[(((eventStruct)+(24))>>2)]=e.charging;
      },registerBatteryEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!JSEvents.batteryEvent) JSEvents.batteryEvent = _malloc( 32 );
  
        var batteryEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          var batteryEvent = JSEvents.batteryEvent;
          JSEvents.fillBatteryEventData(batteryEvent, JSEvents.battery());
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, batteryEvent, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: batteryEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWebGlEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
        if (!target) target = Module['canvas'];
  
        var webGlEventHandlerFunc = function(event) {
          var e = event || window.event;
  
          if (Module['dynCall_iiii'](callbackfunc, eventTypeId, 0, userData)) e.preventDefault();
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: webGlEventHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      }};


  function _emscripten_set_keypress_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 1, "keypress", targetThread);
      return 0;
    }


  function _emscripten_set_keydown_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 2, "keydown", targetThread);
      return 0;
    }


  function _emscripten_set_keyup_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 3, "keyup", targetThread);
      return 0;
    }


  function _emscripten_set_click_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 4, "click", targetThread);
      return 0;
    }


  function _emscripten_set_mousedown_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 5, "mousedown", targetThread);
      return 0;
    }


  function _emscripten_set_mouseup_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 6, "mouseup", targetThread);
      return 0;
    }


  function _emscripten_set_dblclick_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 7, "dblclick", targetThread);
      return 0;
    }


  function _emscripten_set_mousemove_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 8, "mousemove", targetThread);
      return 0;
    }


  function _emscripten_set_mouseenter_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 33, "mouseenter", targetThread);
      return 0;
    }


  function _emscripten_set_mouseleave_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 34, "mouseleave", targetThread);
      return 0;
    }


  function _emscripten_set_mouseover_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 35, "mouseover", targetThread);
      return 0;
    }


  function _emscripten_set_mouseout_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 36, "mouseout", targetThread);
      return 0;
    }


  function _emscripten_get_mouse_status(mouseState) {
      if (!JSEvents.mouseEvent) return -7;
      // HTML5 does not really have a polling API for mouse events, so implement one manually by
      // returning the data from the most recently received event. This requires that user has registered
      // at least some no-op function as an event handler to any of the mouse function.
      HEAP8.set(HEAP8.subarray(JSEvents.mouseEvent, JSEvents.mouseEvent + 72), mouseState);
      return 0;
    }


  function _emscripten_set_wheel_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      target = JSEvents.findEventTarget(target);
      if (typeof target.onwheel !== 'undefined') {
        JSEvents.registerWheelEventCallback(target, userData, useCapture, callbackfunc, 9, "wheel", targetThread);
        return 0;
      } else if (typeof target.onmousewheel !== 'undefined') {
        JSEvents.registerWheelEventCallback(target, userData, useCapture, callbackfunc, 9, "mousewheel", targetThread);
        return 0;
      } else {
        return -1;
      }
    }


  function _emscripten_set_resize_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerUiEventCallback(target, userData, useCapture, callbackfunc, 10, "resize", targetThread);
      return 0;
    }


  function _emscripten_set_scroll_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerUiEventCallback(target, userData, useCapture, callbackfunc, 11, "scroll", targetThread);
      return 0;
    }


  function _emscripten_set_blur_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 12, "blur", targetThread);
      return 0;
    }


  function _emscripten_set_focus_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 13, "focus", targetThread);
      return 0;
    }


  function _emscripten_set_focusin_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 14, "focusin", targetThread);
      return 0;
    }


  function _emscripten_set_focusout_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 15, "focusout", targetThread);
      return 0;
    }


  function _emscripten_set_deviceorientation_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerDeviceOrientationEventCallback(window, userData, useCapture, callbackfunc, 16, "deviceorientation", targetThread);
      return 0;
    }


  function _emscripten_get_deviceorientation_status(orientationState) {
      if (!JSEvents.deviceOrientationEvent) return -7;
      // HTML5 does not really have a polling API for device orientation events, so implement one manually by
      // returning the data from the most recently received event. This requires that user has registered
      // at least some no-op function as an event handler.
      HEAP32.set(HEAP32.subarray(JSEvents.deviceOrientationEvent, 40), orientationState);
      return 0;
    }


  function _emscripten_set_devicemotion_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerDeviceMotionEventCallback(window, userData, useCapture, callbackfunc, 17, "devicemotion", targetThread);
      return 0;
    }


  function _emscripten_get_devicemotion_status(motionState) {
      if (!JSEvents.deviceMotionEvent) return -7;
      // HTML5 does not really have a polling API for device motion events, so implement one manually by
      // returning the data from the most recently received event. This requires that user has registered
      // at least some no-op function as an event handler.
      HEAP32.set(HEAP32.subarray(JSEvents.deviceMotionEvent, 80), motionState);
      return 0;
    }


  function _emscripten_set_orientationchange_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      if (!window.screen || !window.screen.addEventListener) return -1;
      JSEvents.registerOrientationChangeEventCallback(window.screen, userData, useCapture, callbackfunc, 18, "orientationchange", targetThread);
      return 0;
    }


  function _emscripten_get_orientation_status(orientationChangeEvent) {
      if (!JSEvents.screenOrientation() && typeof window.orientation === 'undefined') return -1;
      JSEvents.fillOrientationChangeEventData(orientationChangeEvent);
      return 0;
    }


  function _emscripten_lock_orientation(allowedOrientations) {
      var orientations = [];
      if (allowedOrientations & 1) orientations.push("portrait-primary");
      if (allowedOrientations & 2) orientations.push("portrait-secondary");
      if (allowedOrientations & 4) orientations.push("landscape-primary");
      if (allowedOrientations & 8) orientations.push("landscape-secondary");
      var succeeded;
      if (window.screen.lockOrientation) {
        succeeded = window.screen.lockOrientation(orientations);
      } else if (window.screen.mozLockOrientation) {
        succeeded = window.screen.mozLockOrientation(orientations);
      } else if (window.screen.webkitLockOrientation) {
        succeeded = window.screen.webkitLockOrientation(orientations);
      } else if (window.screen.msLockOrientation) {
        succeeded = window.screen.msLockOrientation(orientations);
      } else {
        return -1;
      }
      if (succeeded) {
        return 0;
      } else {
        return -6;
      }
    }


  function _emscripten_unlock_orientation() {
      if (window.screen.unlockOrientation) {
        window.screen.unlockOrientation();
      } else if (window.screen.mozUnlockOrientation) {
        window.screen.mozUnlockOrientation();
      } else if (window.screen.webkitUnlockOrientation) {
        window.screen.webkitUnlockOrientation();
      } else if (window.screen.msUnlockOrientation) {
        window.screen.msUnlockOrientation();
      } else {
        return -1;
      }
      return 0;
    }


  function _emscripten_set_fullscreenchange_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!target) target = document;
      else {
        target = JSEvents.findEventTarget(target);
        if (!target) return -4;
      }
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "fullscreenchange", targetThread);
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "mozfullscreenchange", targetThread);
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "webkitfullscreenchange", targetThread);
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "msfullscreenchange", targetThread);
      return 0;
    }


  function _emscripten_get_fullscreen_status(fullscreenStatus) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      JSEvents.fillFullscreenChangeEventData(fullscreenStatus);
      return 0;
    }

  function __registerRestoreOldStyle(canvas) {
      var canvasSize = __get_canvas_element_size(canvas);
      var oldWidth = canvasSize[0];
      var oldHeight = canvasSize[1];
      var oldCssWidth = canvas.style.width;
      var oldCssHeight = canvas.style.height;
      var oldBackgroundColor = canvas.style.backgroundColor; // Chrome reads color from here.
      var oldDocumentBackgroundColor = document.body.style.backgroundColor; // IE11 reads color from here.
      // Firefox always has black background color.
      var oldPaddingLeft = canvas.style.paddingLeft; // Chrome, FF, Safari
      var oldPaddingRight = canvas.style.paddingRight;
      var oldPaddingTop = canvas.style.paddingTop;
      var oldPaddingBottom = canvas.style.paddingBottom;
      var oldMarginLeft = canvas.style.marginLeft; // IE11
      var oldMarginRight = canvas.style.marginRight;
      var oldMarginTop = canvas.style.marginTop;
      var oldMarginBottom = canvas.style.marginBottom;
      var oldDocumentBodyMargin = document.body.style.margin;
      var oldDocumentOverflow = document.documentElement.style.overflow; // Chrome, Firefox
      var oldDocumentScroll = document.body.scroll; // IE
      var oldImageRendering = canvas.style.imageRendering;
  
      function restoreOldStyle() {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
        if (!fullscreenElement) {
          document.removeEventListener('fullscreenchange', restoreOldStyle);
          document.removeEventListener('mozfullscreenchange', restoreOldStyle);
          document.removeEventListener('webkitfullscreenchange', restoreOldStyle);
          document.removeEventListener('MSFullscreenChange', restoreOldStyle);
  
          __set_canvas_element_size(canvas, oldWidth, oldHeight);
  
          canvas.style.width = oldCssWidth;
          canvas.style.height = oldCssHeight;
          canvas.style.backgroundColor = oldBackgroundColor; // Chrome
          // IE11 hack: assigning 'undefined' or an empty string to document.body.style.backgroundColor has no effect, so first assign back the default color
          // before setting the undefined value. Setting undefined value is also important, or otherwise we would later treat that as something that the user
          // had explicitly set so subsequent fullscreen transitions would not set background color properly.
          if (!oldDocumentBackgroundColor) document.body.style.backgroundColor = 'white';
          document.body.style.backgroundColor = oldDocumentBackgroundColor; // IE11
          canvas.style.paddingLeft = oldPaddingLeft; // Chrome, FF, Safari
          canvas.style.paddingRight = oldPaddingRight;
          canvas.style.paddingTop = oldPaddingTop;
          canvas.style.paddingBottom = oldPaddingBottom;
          canvas.style.marginLeft = oldMarginLeft; // IE11
          canvas.style.marginRight = oldMarginRight;
          canvas.style.marginTop = oldMarginTop;
          canvas.style.marginBottom = oldMarginBottom;
          document.body.style.margin = oldDocumentBodyMargin;
          document.documentElement.style.overflow = oldDocumentOverflow; // Chrome, Firefox
          document.body.scroll = oldDocumentScroll; // IE
          canvas.style.imageRendering = oldImageRendering;
          if (canvas.GLctxObject) canvas.GLctxObject.GLctx.viewport(0, 0, oldWidth, oldHeight);
  
          if (__currentFullscreenStrategy.canvasResizedCallback) {
            Module['dynCall_iiii'](__currentFullscreenStrategy.canvasResizedCallback, 37, 0, __currentFullscreenStrategy.canvasResizedCallbackUserData);
          }
        }
      }
      document.addEventListener('fullscreenchange', restoreOldStyle);
      document.addEventListener('mozfullscreenchange', restoreOldStyle);
      document.addEventListener('webkitfullscreenchange', restoreOldStyle);
      document.addEventListener('MSFullscreenChange', restoreOldStyle);
      return restoreOldStyle;
    }

  function __hideEverythingExceptGivenElement(onlyVisibleElement) {
      var child = onlyVisibleElement;
      var parent = child.parentNode;
      var hiddenElements = [];
      while (child != document.body) {
        var children = parent.children;
        for (var i = 0; i < children.length; ++i) {
          if (children[i] != child) {
            hiddenElements.push({ node: children[i], displayState: children[i].style.display });
            children[i].style.display = 'none';
          }
        }
        child = parent;
        parent = parent.parentNode;
      }
      return hiddenElements;
    }

  function __restoreHiddenElements(hiddenElements) {
      for (var i = 0; i < hiddenElements.length; ++i) {
        hiddenElements[i].node.style.display = hiddenElements[i].displayState;
      }
    }

  function __setLetterbox(element, topBottom, leftRight) {
      if (JSEvents.isInternetExplorer()) {
        // Cannot use padding on IE11, because IE11 computes padding in addition to the size, unlike
        // other browsers, which treat padding to be part of the size.
        // e.g.
        // FF, Chrome: If CSS size = 1920x1080, padding-leftright = 460, padding-topbottomx40, then content size = (1920 - 2*460) x (1080-2*40) = 1000x1000px, and total element size = 1920x1080px.
        //       IE11: If CSS size = 1920x1080, padding-leftright = 460, padding-topbottomx40, then content size = 1920x1080px and total element size = (1920+2*460) x (1080+2*40)px.
        // IE11  treats margin like Chrome and FF treat padding.
        element.style.marginLeft = element.style.marginRight = leftRight + 'px';
        element.style.marginTop = element.style.marginBottom = topBottom + 'px';
      } else {
        // Cannot use margin to specify letterboxes in FF or Chrome, since those ignore margins in fullscreen mode.
        element.style.paddingLeft = element.style.paddingRight = leftRight + 'px';
        element.style.paddingTop = element.style.paddingBottom = topBottom + 'px';
      }
    }

  var __currentFullscreenStrategy={};

  var __restoreOldWindowedStyle=null;

  function __softFullscreenResizeWebGLRenderTarget() {
      var inHiDPIFullscreenMode = __currentFullscreenStrategy.canvasResolutionScaleMode == 2;
      var inAspectRatioFixedFullscreenMode = __currentFullscreenStrategy.scaleMode == 2;
      var inPixelPerfectFullscreenMode = __currentFullscreenStrategy.canvasResolutionScaleMode != 0;
      var inCenteredWithoutScalingFullscreenMode = __currentFullscreenStrategy.scaleMode == 3;
      var screenWidth = inHiDPIFullscreenMode ? Math.round(window.innerWidth*window.devicePixelRatio) : window.innerWidth;
      var screenHeight = inHiDPIFullscreenMode ? Math.round(window.innerHeight*window.devicePixelRatio) : window.innerHeight;
      var w = screenWidth;
      var h = screenHeight;
      var canvas = __currentFullscreenStrategy.target;
      var canvasSize = __get_canvas_element_size(canvas);
      var x = canvasSize[0];
      var y = canvasSize[1];
      var topMargin;
  
      if (inAspectRatioFixedFullscreenMode) {
        if (w*y < x*h) h = (w * y / x) | 0;
        else if (w*y > x*h) w = (h * x / y) | 0;
        topMargin = ((screenHeight - h) / 2) | 0;
      }
  
      if (inPixelPerfectFullscreenMode) {
        __set_canvas_element_size(canvas, w, h);
        if (canvas.GLctxObject) canvas.GLctxObject.GLctx.viewport(0, 0, w, h);
      }
  
      // Back to CSS pixels.
      if (inHiDPIFullscreenMode) {
        topMargin /= window.devicePixelRatio;
        w /= window.devicePixelRatio;
        h /= window.devicePixelRatio;
        // Round to nearest 4 digits of precision.
        w = Math.round(w*1e4)/1e4;
        h = Math.round(h*1e4)/1e4;
        topMargin = Math.round(topMargin*1e4)/1e4;
      }
  
      if (inCenteredWithoutScalingFullscreenMode) {
        var t = (window.innerHeight - parseInt(canvas.style.height)) / 2;
        var b = (window.innerWidth - parseInt(canvas.style.width)) / 2;
        __setLetterbox(canvas, t, b);
      } else {
        canvas.style.width = w + 'px';
        canvas.style.height = h + 'px';
        var b = (window.innerWidth - w) / 2;
        __setLetterbox(canvas, topMargin, b);
      }
  
      if (!inCenteredWithoutScalingFullscreenMode && __currentFullscreenStrategy.canvasResizedCallback) {
        Module['dynCall_iiii'](__currentFullscreenStrategy.canvasResizedCallback, 37, 0, __currentFullscreenStrategy.canvasResizedCallbackUserData);
      }
    }

  function __emscripten_do_request_fullscreen(target, strategy) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!JSEvents.fullscreenEnabled()) return -3;
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
  
      if (!target.requestFullscreen && !target.msRequestFullscreen && !target.mozRequestFullScreen && !target.mozRequestFullscreen && !target.webkitRequestFullscreen) {
        return -3;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (strategy.deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestFullscreen, 1 /* priority over pointer lock */, [target, strategy]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestFullscreen(target, strategy);
    }


  function _emscripten_request_fullscreen(target, deferUntilInEventHandler) {
      var strategy = {};
      // These options perform no added logic, but just bare request fullscreen.
      strategy.scaleMode = 0;
      strategy.canvasResolutionScaleMode = 0;
      strategy.filteringMode = 0;
      strategy.deferUntilInEventHandler = deferUntilInEventHandler;
      strategy.canvasResizedCallbackTargetThread = 2;
  
      return __emscripten_do_request_fullscreen(target, strategy);
    }


  function _emscripten_request_fullscreen_strategy(target, deferUntilInEventHandler, fullscreenStrategy) {
      var strategy = {};
      strategy.scaleMode = HEAP32[((fullscreenStrategy)>>2)];
      strategy.canvasResolutionScaleMode = HEAP32[(((fullscreenStrategy)+(4))>>2)];
      strategy.filteringMode = HEAP32[(((fullscreenStrategy)+(8))>>2)];
      strategy.deferUntilInEventHandler = deferUntilInEventHandler;
      strategy.canvasResizedCallback = HEAP32[(((fullscreenStrategy)+(12))>>2)];
      strategy.canvasResizedCallbackUserData = HEAP32[(((fullscreenStrategy)+(16))>>2)];
      __currentFullscreenStrategy = strategy;
  
      return __emscripten_do_request_fullscreen(target, strategy);
    }


  function _emscripten_enter_soft_fullscreen(target, fullscreenStrategy) {
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
  
      var strategy = {};
      strategy.scaleMode = HEAP32[((fullscreenStrategy)>>2)];
      strategy.canvasResolutionScaleMode = HEAP32[(((fullscreenStrategy)+(4))>>2)];
      strategy.filteringMode = HEAP32[(((fullscreenStrategy)+(8))>>2)];
      strategy.canvasResizedCallback = HEAP32[(((fullscreenStrategy)+(12))>>2)];
      strategy.canvasResizedCallbackUserData = HEAP32[(((fullscreenStrategy)+(16))>>2)];
      strategy.target = target;
      strategy.softFullscreen = true;
  
      var restoreOldStyle = JSEvents.resizeCanvasForFullscreen(target, strategy);
  
      document.documentElement.style.overflow = 'hidden';  // Firefox, Chrome
      document.body.scroll = "no"; // IE11
      document.body.style.margin = '0px'; // Override default document margin area on all browsers.
  
      var hiddenElements = __hideEverythingExceptGivenElement(target);
  
      function restoreWindowedState() {
        restoreOldStyle();
        __restoreHiddenElements(hiddenElements);
        window.removeEventListener('resize', __softFullscreenResizeWebGLRenderTarget);
        if (strategy.canvasResizedCallback) {
          Module['dynCall_iiii'](strategy.canvasResizedCallback, 37, 0, strategy.canvasResizedCallbackUserData);
        }
      }
      __restoreOldWindowedStyle = restoreWindowedState;
      __currentFullscreenStrategy = strategy;
      window.addEventListener('resize', __softFullscreenResizeWebGLRenderTarget);
  
      // Inform the caller that the canvas size has changed.
      if (strategy.canvasResizedCallback) {
        Module['dynCall_iiii'](strategy.canvasResizedCallback, 37, 0, strategy.canvasResizedCallbackUserData);
      }
  
      return 0;
    }


  function _emscripten_exit_soft_fullscreen() {
      if (__restoreOldWindowedStyle) __restoreOldWindowedStyle();
      __restoreOldWindowedStyle = null;
  
      return 0;
    }


  function _emscripten_exit_fullscreen() {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestFullscreen);
  
      if (document.exitFullscreen) {
        document.exitFullscreen();
      } else if (document.msExitFullscreen) {
        document.msExitFullscreen();
      } else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      } else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      } else {
        return -1;
      }
  
      if (__currentFullscreenStrategy.canvasResizedCallback) {
        Module['dynCall_iiii'](__currentFullscreenStrategy.canvasResizedCallback, 37, 0, __currentFullscreenStrategy.canvasResizedCallbackUserData);
      }
  
      return 0;
    }


  function _emscripten_set_pointerlockchange_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      // TODO: Currently not supported in pthreads or in --proxy-to-worker mode. (In pthreads mode, document object is not defined)
      if (!document || !document.body || (!document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock)) {
        return -1;
      }
      if (!target) target = document;
      else {
        target = JSEvents.findEventTarget(target);
        if (!target) return -4;
      }
      JSEvents.registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "pointerlockchange", targetThread);
      JSEvents.registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "mozpointerlockchange", targetThread);
      JSEvents.registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "webkitpointerlockchange", targetThread);
      JSEvents.registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "mspointerlockchange", targetThread);
      return 0;
    }


  function _emscripten_set_pointerlockerror_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      // TODO: Currently not supported in pthreads or in --proxy-to-worker mode. (In pthreads mode, document object is not defined)
      if (!document || !document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock) {
        return -1;
      }
      if (!target) target = document;
      else {
        target = JSEvents.findEventTarget(target);
        if (!target) return -4;
      }
      JSEvents.registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "pointerlockerror", targetThread);
      JSEvents.registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "mozpointerlockerror", targetThread);
      JSEvents.registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "webkitpointerlockerror", targetThread);
      JSEvents.registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "mspointerlockerror", targetThread);
      return 0;
    }


  function _emscripten_get_pointerlock_status(pointerlockStatus) {
      if (pointerlockStatus) JSEvents.fillPointerlockChangeEventData(pointerlockStatus);
      if (!document.body || (!document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock)) {
        return -1;
      }
      return 0;
    }


  function _emscripten_request_pointerlock(target, deferUntilInEventHandler) {
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
      if (!target.requestPointerLock && !target.mozRequestPointerLock && !target.webkitRequestPointerLock && !target.msRequestPointerLock) {
        return -1;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestPointerLock, 2 /* priority below fullscreen */, [target]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestPointerLock(target);
    }


  function _emscripten_exit_pointerlock() {
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestPointerLock);
  
      if (document.exitPointerLock) {
        document.exitPointerLock();
      } else if (document.msExitPointerLock) {
        document.msExitPointerLock();
      } else if (document.mozExitPointerLock) {
        document.mozExitPointerLock();
      } else if (document.webkitExitPointerLock) {
        document.webkitExitPointerLock();
      } else {
        return -1;
      }
      return 0;
    }


  function _emscripten_vibrate(msecs) {
      if (!navigator.vibrate) return -1;    
      navigator.vibrate(msecs);
      return 0;
    }


  function _emscripten_vibrate_pattern(msecsArray, numEntries) {
      if (!navigator.vibrate) return -1;
  
      var vibrateList = [];
      for(var i = 0; i < numEntries; ++i) {
        var msecs = HEAP32[(((msecsArray)+(i*4))>>2)];
        vibrateList.push(msecs);
      }
      navigator.vibrate(vibrateList);
      return 0;
    }


  function _emscripten_set_visibilitychange_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerVisibilityChangeEventCallback(document, userData, useCapture, callbackfunc, 21, "visibilitychange", targetThread);
      return 0;
    }


  function _emscripten_get_visibility_status(visibilityStatus) {
      if (typeof document.visibilityState === 'undefined' && typeof document.hidden === 'undefined') {
        return -1;
      }
      JSEvents.fillVisibilityChangeEventData(visibilityStatus);  
      return 0;
    }


  function _emscripten_set_touchstart_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 22, "touchstart", targetThread);
      return 0;
    }


  function _emscripten_set_touchend_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 23, "touchend", targetThread);
      return 0;
    }


  function _emscripten_set_touchmove_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 24, "touchmove", targetThread);
      return 0;
    }


  function _emscripten_set_touchcancel_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerTouchEventCallback(target, userData, useCapture, callbackfunc, 25, "touchcancel", targetThread);
      return 0;
    }


  function _emscripten_set_gamepadconnected_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
      JSEvents.registerGamepadEventCallback(window, userData, useCapture, callbackfunc, 26, "gamepadconnected", targetThread);
      return 0;
    }


  function _emscripten_set_gamepaddisconnected_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
      if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
      JSEvents.registerGamepadEventCallback(window, userData, useCapture, callbackfunc, 27, "gamepaddisconnected", targetThread);
      return 0;
   }

  function __emscripten_sample_gamepad_data() {
      // Polling gamepads generates garbage, so don't do it when we know there are no gamepads connected.
      if (!JSEvents.numGamepadsConnected) return;
  
      // Produce a new Gamepad API sample if we are ticking a new game frame, or if not using emscripten_set_main_loop() at all to drive animation.
      if (Browser.mainLoop.currentFrameNumber !== JSEvents.lastGamepadStateFrame || !Browser.mainLoop.currentFrameNumber) {
        JSEvents.lastGamepadState = navigator.getGamepads ? navigator.getGamepads() : (navigator.webkitGetGamepads ? navigator.webkitGetGamepads : null);
        JSEvents.lastGamepadStateFrame = Browser.mainLoop.currentFrameNumber;
      }
    }


  function _emscripten_get_num_gamepads() {
      // Polling gamepads generates garbage, so don't do it when we know there are no gamepads connected.
      if (!JSEvents.numGamepadsConnected) return 0;
  
      __emscripten_sample_gamepad_data();
      if (!JSEvents.lastGamepadState) return -1;
      return JSEvents.lastGamepadState.length;
    }


  function _emscripten_get_gamepad_status(index, gamepadState) {
      __emscripten_sample_gamepad_data();
      if (!JSEvents.lastGamepadState) return -1;
  
      // INVALID_PARAM is returned on a Gamepad index that never was there.
      if (index < 0 || index >= JSEvents.lastGamepadState.length) return -5;
  
      // NO_DATA is returned on a Gamepad index that was removed.
      // For previously disconnected gamepads there should be an empty slot (null/undefined/false) at the index.
      // This is because gamepads must keep their original position in the array.
      // For example, removing the first of two gamepads produces [null/undefined/false, gamepad].
      if (!JSEvents.lastGamepadState[index]) return -7;
  
      JSEvents.fillGamepadEventData(gamepadState, JSEvents.lastGamepadState[index]);
      return 0;
    }


  function _emscripten_set_beforeunload_callback_on_thread(userData, callbackfunc, targetThread) {
      if (typeof window.onbeforeunload === 'undefined') return -1;
      // beforeunload callback can only be registered on the main browser thread, because the page will go away immediately after returning from the handler,
      // and there is no time to start proxying it anywhere.
      if (targetThread !== 1) return -5;
      JSEvents.registerBeforeUnloadEventCallback(window, userData, true, callbackfunc, 28, "beforeunload"); 
      return 0;
    }


  function _emscripten_set_batterychargingchange_callback_on_thread(userData, callbackfunc, targetThread) {
      if (!JSEvents.battery()) return -1; 
      JSEvents.registerBatteryEventCallback(JSEvents.battery(), userData, true, callbackfunc, 29, "chargingchange", targetThread);
      return 0;
    }


  function _emscripten_set_batterylevelchange_callback_on_thread(userData, callbackfunc, targetThread) {
      if (!JSEvents.battery()) return -1; 
      JSEvents.registerBatteryEventCallback(JSEvents.battery(), userData, true, callbackfunc, 30, "levelchange", targetThread);
      return 0;
    }


  function _emscripten_get_battery_status(batteryState) {
      if (!JSEvents.battery()) return -1; 
      JSEvents.fillBatteryEventData(batteryState, JSEvents.battery());
      return 0;
    }

  function _emscripten_webgl_init_context_attributes(attributes) {
      HEAP32[((attributes)>>2)]=1;
      HEAP32[(((attributes)+(4))>>2)]=1;
      HEAP32[(((attributes)+(8))>>2)]=0;
      HEAP32[(((attributes)+(12))>>2)]=1;
      HEAP32[(((attributes)+(16))>>2)]=1;
      HEAP32[(((attributes)+(20))>>2)]=0;
      HEAP32[(((attributes)+(24))>>2)]=0;
      HEAP32[(((attributes)+(28))>>2)]=0;
      HEAP32[(((attributes)+(32))>>2)]=1;
      HEAP32[(((attributes)+(36))>>2)]=0;
      HEAP32[(((attributes)+(40))>>2)]=1;
      HEAP32[(((attributes)+(44))>>2)]=0;
      HEAP32[(((attributes)+(48))>>2)]=1;
      HEAP32[(((attributes)+(52))>>2)]=0;
    }

  
  
  var GL={counter:1,lastError:0,buffers:[],mappedBuffers:{},programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],vaos:[],contexts:{},currentContext:null,offscreenCanvases:{},timerQueriesEXT:[],byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],programInfos:{},stringCache:{},tempFixedLengthArray:[],packAlignment:4,unpackAlignment:4,init:function () {
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
  
        // For functions such as glDrawBuffers, glInvalidateFramebuffer and glInvalidateSubFramebuffer that need to pass a short array to the WebGL API,
        // create a set of short fixed-length arrays to avoid having to generate any garbage when calling those functions.
        for (var i = 0; i < 32; i++) {
          GL.tempFixedLengthArray.push(new Array(i));
        }
      },recordError:function recordError(errorCode) {
        if (!GL.lastError) {
          GL.lastError = errorCode;
        }
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:256,miniTempBuffer:null,miniTempBufferViews:[0],getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        return source;
      },createContext:function (canvas, webGLContextAttributes) {
        if (typeof webGLContextAttributes['majorVersion'] === 'undefined' && typeof webGLContextAttributes['minorVersion'] === 'undefined') {
          webGLContextAttributes['majorVersion'] = 1;
          webGLContextAttributes['minorVersion'] = 0;
        }
  
  
  
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
          try {
            if (webGLContextAttributes['majorVersion'] == 1 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl", webGLContextAttributes) || canvas.getContext("experimental-webgl", webGLContextAttributes);
            } else if (webGLContextAttributes['majorVersion'] == 2 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl2", webGLContextAttributes);
            } else {
              throw 'Unsupported WebGL context version ' + majorVersion + '.' + minorVersion + '!'
            }
          } finally {
            canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
          }
          if (!ctx) throw ':(';
        } catch (e) {
          return 0;
        }
  
        if (!ctx) return 0;
        var context = GL.registerContext(ctx, webGLContextAttributes);
        return context;
      },registerContext:function (ctx, webGLContextAttributes) {
        var handle = _malloc(8); // Make space on the heap to store GL context attributes that need to be accessible as shared between threads.
        HEAP32[((handle)>>2)]=webGLContextAttributes["explicitSwapControl"]; // explicitSwapControl
        var context = {
          handle: handle,
          attributes: webGLContextAttributes,
          version: webGLContextAttributes['majorVersion'],
          GLctx: ctx
        };
  
  
  
        // Store the created context object so that we can access the context given a canvas without having to pass the parameters again.
        if (ctx.canvas) ctx.canvas.GLctxObject = context;
        GL.contexts[handle] = context;
        if (typeof webGLContextAttributes['enableExtensionsByDefault'] === 'undefined' || webGLContextAttributes['enableExtensionsByDefault']) {
          GL.initExtensions(context);
        }
  
  
  
  
        return handle;
      },makeContextCurrent:function (contextHandle) {
        // Deactivating current context?
        if (!contextHandle) {
          GLctx = Module.ctx = GL.currentContext = null;
          return true;
        }
        var context = GL.contexts[contextHandle];
        if (!context) {
          return false;
        }
        GLctx = Module.ctx = context.GLctx; // Active WebGL context object.
        GL.currentContext = context; // Active Emscripten GL layer context object.
        return true;
      },getContext:function (contextHandle) {
        return GL.contexts[contextHandle];
      },deleteContext:function (contextHandle) {
        if (GL.currentContext === GL.contexts[contextHandle]) GL.currentContext = null;
        if (typeof JSEvents === 'object') JSEvents.removeAllHandlersOnTarget(GL.contexts[contextHandle].GLctx.canvas); // Release all JS event handlers on the DOM element that the GL context is associated with since the context is now deleted.
        if (GL.contexts[contextHandle] && GL.contexts[contextHandle].GLctx.canvas) GL.contexts[contextHandle].GLctx.canvas.GLctxObject = undefined; // Make sure the canvas object no longer refers to the context object so there are no GC surprises.
        _free(GL.contexts[contextHandle]);
        GL.contexts[contextHandle] = null;
      },initExtensions:function (context) {
        // If this function is called without a specific context object, init the extensions of the currently active context.
        if (!context) context = GL.currentContext;
  
        if (context.initExtensionsDone) return;
        context.initExtensionsDone = true;
  
        var GLctx = context.GLctx;
  
        // Detect the presence of a few extensions manually, this GL interop layer itself will need to know if they exist.
  
        if (context.version < 2) {
          // Extension available from Firefox 26 and Google Chrome 30
          var instancedArraysExt = GLctx.getExtension('ANGLE_instanced_arrays');
          if (instancedArraysExt) {
            GLctx['vertexAttribDivisor'] = function(index, divisor) { instancedArraysExt['vertexAttribDivisorANGLE'](index, divisor); };
            GLctx['drawArraysInstanced'] = function(mode, first, count, primcount) { instancedArraysExt['drawArraysInstancedANGLE'](mode, first, count, primcount); };
            GLctx['drawElementsInstanced'] = function(mode, count, type, indices, primcount) { instancedArraysExt['drawElementsInstancedANGLE'](mode, count, type, indices, primcount); };
          }
  
          // Extension available from Firefox 25 and WebKit
          var vaoExt = GLctx.getExtension('OES_vertex_array_object');
          if (vaoExt) {
            GLctx['createVertexArray'] = function() { return vaoExt['createVertexArrayOES'](); };
            GLctx['deleteVertexArray'] = function(vao) { vaoExt['deleteVertexArrayOES'](vao); };
            GLctx['bindVertexArray'] = function(vao) { vaoExt['bindVertexArrayOES'](vao); };
            GLctx['isVertexArray'] = function(vao) { return vaoExt['isVertexArrayOES'](vao); };
          }
  
          var drawBuffersExt = GLctx.getExtension('WEBGL_draw_buffers');
          if (drawBuffersExt) {
            GLctx['drawBuffers'] = function(n, bufs) { drawBuffersExt['drawBuffersWEBGL'](n, bufs); };
          }
        }
  
        GLctx.disjointTimerQueryExt = GLctx.getExtension("EXT_disjoint_timer_query");
  
        // These are the 'safe' feature-enabling extensions that don't add any performance impact related to e.g. debugging, and
        // should be enabled by default so that client GLES2/GL code will not need to go through extra hoops to get its stuff working.
        // As new extensions are ratified at http://www.khronos.org/registry/webgl/extensions/ , feel free to add your new extensions
        // here, as long as they don't produce a performance impact for users that might not be using those extensions.
        // E.g. debugging-related extensions should probably be off by default.
        var automaticallyEnabledExtensions = [ // Khronos ratified WebGL extensions ordered by number (no debug extensions):
                                               "OES_texture_float", "OES_texture_half_float", "OES_standard_derivatives",
                                               "OES_vertex_array_object", "WEBGL_compressed_texture_s3tc", "WEBGL_depth_texture",
                                               "OES_element_index_uint", "EXT_texture_filter_anisotropic", "EXT_frag_depth",
                                               "WEBGL_draw_buffers", "ANGLE_instanced_arrays", "OES_texture_float_linear",
                                               "OES_texture_half_float_linear", "EXT_blend_minmax", "EXT_shader_texture_lod",
                                               // Community approved WebGL extensions ordered by number:
                                               "WEBGL_compressed_texture_pvrtc", "EXT_color_buffer_half_float", "WEBGL_color_buffer_float",
                                               "EXT_sRGB", "WEBGL_compressed_texture_etc1", "EXT_disjoint_timer_query",
                                               "WEBGL_compressed_texture_etc", "WEBGL_compressed_texture_astc", "EXT_color_buffer_float",
                                               "WEBGL_compressed_texture_s3tc_srgb", "EXT_disjoint_timer_query_webgl2"];
  
        function shouldEnableAutomatically(extension) {
          var ret = false;
          automaticallyEnabledExtensions.forEach(function(include) {
            if (extension.indexOf(include) != -1) {
              ret = true;
            }
          });
          return ret;
        }
  
        var exts = GLctx.getSupportedExtensions();
        if (exts && exts.length > 0) {
          GLctx.getSupportedExtensions().forEach(function(ext) {
            if (automaticallyEnabledExtensions.indexOf(ext) != -1) {
              GLctx.getExtension(ext); // Calling .getExtension enables that extension permanently, no need to store the return value to be enabled.
            }
          });
        }
      },populateUniformTable:function (program) {
        var p = GL.programs[program];
        GL.programInfos[program] = {
          uniforms: {},
          maxUniformLength: 0, // This is eagerly computed below, since we already enumerate all uniforms anyway.
          maxAttributeLength: -1, // This is lazily computed and cached, computed when/if first asked, "-1" meaning not computed yet.
          maxUniformBlockNameLength: -1 // Lazily computed as well
        };
  
        var ptable = GL.programInfos[program];
        var utable = ptable.uniforms;
        // A program's uniform table maps the string name of an uniform to an integer location of that uniform.
        // The global GL.uniforms map maps integer locations to WebGLUniformLocations.
        var numUniforms = GLctx.getProgramParameter(p, GLctx.ACTIVE_UNIFORMS);
        for (var i = 0; i < numUniforms; ++i) {
          var u = GLctx.getActiveUniform(p, i);
  
          var name = u.name;
          ptable.maxUniformLength = Math.max(ptable.maxUniformLength, name.length+1);
  
          // Strip off any trailing array specifier we might have got, e.g. "[0]".
          if (name.indexOf(']', name.length-1) !== -1) {
            var ls = name.lastIndexOf('[');
            name = name.slice(0, ls);
          }
  
          // Optimize memory usage slightly: If we have an array of uniforms, e.g. 'vec3 colors[3];', then
          // only store the string 'colors' in utable, and 'colors[0]', 'colors[1]' and 'colors[2]' will be parsed as 'colors'+i.
          // Note that for the GL.uniforms table, we still need to fetch the all WebGLUniformLocations for all the indices.
          var loc = GLctx.getUniformLocation(p, name);
          if (loc != null)
          {
            var id = GL.getNewId(GL.uniforms);
            utable[name] = [u.size, id];
            GL.uniforms[id] = loc;
  
            for (var j = 1; j < u.size; ++j) {
              var n = name + '['+j+']';
              loc = GLctx.getUniformLocation(p, n);
              id = GL.getNewId(GL.uniforms);
  
              GL.uniforms[id] = loc;
            }
          }
        }
      }};function _emscripten_webgl_do_create_context(target, attributes) {
      var contextAttributes = {};
      contextAttributes['alpha'] = !!HEAP32[((attributes)>>2)];
      contextAttributes['depth'] = !!HEAP32[(((attributes)+(4))>>2)];
      contextAttributes['stencil'] = !!HEAP32[(((attributes)+(8))>>2)];
      contextAttributes['antialias'] = !!HEAP32[(((attributes)+(12))>>2)];
      contextAttributes['premultipliedAlpha'] = !!HEAP32[(((attributes)+(16))>>2)];
      contextAttributes['preserveDrawingBuffer'] = !!HEAP32[(((attributes)+(20))>>2)];
      contextAttributes['preferLowPowerToHighPerformance'] = !!HEAP32[(((attributes)+(24))>>2)];
      contextAttributes['failIfMajorPerformanceCaveat'] = !!HEAP32[(((attributes)+(28))>>2)];
      contextAttributes['majorVersion'] = HEAP32[(((attributes)+(32))>>2)];
      contextAttributes['minorVersion'] = HEAP32[(((attributes)+(36))>>2)];
      contextAttributes['enableExtensionsByDefault'] = HEAP32[(((attributes)+(40))>>2)];
      contextAttributes['explicitSwapControl'] = HEAP32[(((attributes)+(44))>>2)];
      contextAttributes['proxyContextToMainThread'] = HEAP32[(((attributes)+(48))>>2)];
      contextAttributes['renderViaOffscreenBackBuffer'] = HEAP32[(((attributes)+(52))>>2)];
  
      target = Pointer_stringify(target);
      var canvas;
      if ((!target || target === '#canvas') && Module['canvas']) {
        canvas = (Module['canvas'].id && GL.offscreenCanvases[Module['canvas'].id]) ? (GL.offscreenCanvases[Module['canvas'].id].offscreenCanvas || JSEvents.findEventTarget(Module['canvas'].id)) : Module['canvas'];
      } else {
        canvas = GL.offscreenCanvases[target] ? GL.offscreenCanvases[target].offscreenCanvas : JSEvents.findEventTarget(target);
      }
  
  
      if (!canvas) {
        return 0;
      }
  
      if (contextAttributes['explicitSwapControl']) {
        return 0;
      }
  
  
      var contextHandle = GL.createContext(canvas, contextAttributes);
      return contextHandle;
    }function _emscripten_webgl_create_context() {
  return _emscripten_webgl_do_create_context.apply(null, arguments)
  }

  
  function _emscripten_webgl_do_get_current_context() {
      return GL.currentContext ? GL.currentContext.handle : 0;
    }function _emscripten_webgl_get_current_context() {
  return _emscripten_webgl_do_get_current_context.apply(null, arguments)
  }

  
  function _emscripten_webgl_do_commit_frame() {
      if (!GL.currentContext || !GL.currentContext.GLctx) {
        return -3;
      }
  
      if (!GL.currentContext.GLctx.commit) {
        return -1;
      }
      if (!GL.currentContext.attributes.explicitSwapControl) {
        return -3;
      }
      GL.currentContext.GLctx.commit();
      return 0;
    }function _emscripten_webgl_commit_frame() {
  return _emscripten_webgl_do_commit_frame.apply(null, arguments)
  }


  function _emscripten_webgl_make_context_current(contextHandle) {
      var success = GL.makeContextCurrent(contextHandle);
      return success ? 0 : -5;
    }


  function _emscripten_webgl_get_drawing_buffer_size_calling_thread(contextHandle, width, height) {
      var GLContext = GL.getContext(contextHandle);
  
      if (!GLContext || !GLContext.GLctx || !width || !height) {
        return -5;
      }
      HEAP32[((width)>>2)]=GLContext.GLctx.drawingBufferWidth;
      HEAP32[((height)>>2)]=GLContext.GLctx.drawingBufferHeight;
      return 0;
    }

  function _emscripten_webgl_get_drawing_buffer_size() {
  return _emscripten_webgl_get_drawing_buffer_size_calling_thread.apply(null, arguments)
  }


  function _emscripten_webgl_destroy_context_calling_thread(contextHandle) {
      if (GL.currentContext == contextHandle) GL.currentContext = 0;
      GL.deleteContext(contextHandle);
    }

  function _emscripten_webgl_destroy_context() {
  return _emscripten_webgl_destroy_context_calling_thread.apply(null, arguments)
  }

  function _emscripten_webgl_enable_extension_calling_thread(contextHandle, extension) {
      var context = GL.getContext(contextHandle);
      var extString = Pointer_stringify(extension);
      if (extString.indexOf('GL_') == 0) extString = extString.substr(3); // Allow enabling extensions both with "GL_" prefix and without.
      var ext = context.GLctx.getExtension(extString);
      return !!ext;
    }

  function _emscripten_supports_offscreencanvas() {
      return 0;
    }

  function _emscripten_webgl_enable_extension() {
  return _emscripten_webgl_enable_extension_calling_thread.apply(null, arguments)
  }


  function _emscripten_set_webglcontextlost_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerWebGlEventCallback(target, userData, useCapture, callbackfunc, 31, "webglcontextlost", targetThread);
      return 0;
    }


  function _emscripten_set_webglcontextrestored_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
      JSEvents.registerWebGlEventCallback(target, userData, useCapture, callbackfunc, 32, "webglcontextrestored", targetThread);
      return 0;
    }


  function _emscripten_is_webgl_context_lost(target) {
      // TODO: In the future if multiple GL contexts are supported, use the 'target' parameter to find the canvas to query.
      return Module.ctx ? Module.ctx.isContextLost() : true; // No context ~> lost context.
    }






  function _emscripten_set_element_css_size(target, width, height) {
      if (target) target = JSEvents.findEventTarget(target);
      else target = Module['canvas'];
      if (!target) return -4;
  
      target.style.setProperty("width", width + "px");
      target.style.setProperty("height", height + "px");
  
      return 0;
    }


  function _emscripten_get_element_css_size(target, width, height) {
      if (target) target = JSEvents.findEventTarget(target);
      else target = Module['canvas'];
      if (!target) return -4;
  
      if (target.getBoundingClientRect) {
        var rect = target.getBoundingClientRect();
        HEAPF64[((width)>>3)]=rect.right - rect.left;
        HEAPF64[((height)>>3)]=rect.bottom - rect.top;
      } else {
        HEAPF64[((width)>>3)]=target.clientWidth;
        HEAPF64[((height)>>3)]=target.clientHeight;
      }
  
      return 0;
    }

  function _emscripten_html5_remove_all_event_listeners() {
      JSEvents.removeAllEventListeners();
    }







  var PROXYFS={mount:function (mount) {
        return PROXYFS.createNode(null, '/', mount.opts.fs.lstat(mount.opts.root).mode, 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = PROXYFS.node_ops;
        node.stream_ops = PROXYFS.stream_ops;
        return node;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },node_ops:{getattr:function (node) {
          var path = PROXYFS.realPath(node);
          var stat;
          try {
            stat = node.mount.opts.fs.lstat(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = PROXYFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              node.mount.opts.fs.chmod(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              node.mount.opts.fs.utime(path, date, date);
            }
            if (attr.size !== undefined) {
              node.mount.opts.fs.truncate(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          try {
            var path = PATH.join2(PROXYFS.realPath(parent), name);
            var mode = parent.mount.opts.fs.lstat(path).mode;
            var node = PROXYFS.createNode(parent, name, mode);
            return node;
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },mknod:function (parent, name, mode, dev) {
          var node = PROXYFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = PROXYFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              node.mount.opts.fs.mkdir(path, node.mode);
            } else {
              node.mount.opts.fs.writeFile(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = PROXYFS.realPath(oldNode);
          var newPath = PATH.join2(PROXYFS.realPath(newDir), newName);
          try {
            oldNode.mount.opts.fs.rename(oldPath, newPath);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(PROXYFS.realPath(parent), name);
          try {
            parent.mount.opts.fs.unlink(path);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(PROXYFS.realPath(parent), name);
          try {
            parent.mount.opts.fs.rmdir(path);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = PROXYFS.realPath(node);
          try {
            return node.mount.opts.fs.readdir(path);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(PROXYFS.realPath(parent), newName);
          try {
            parent.mount.opts.fs.symlink(oldPath, newPath);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = PROXYFS.realPath(node);
          try {
            return node.mount.opts.fs.readlink(path);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = PROXYFS.realPath(stream.node);
          try {
            stream.nfd = stream.node.mount.opts.fs.open(path,stream.flags);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            stream.node.mount.opts.fs.close(stream.nfd);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          try {
            return stream.node.mount.opts.fs.read(stream.nfd, buffer, offset, length, position);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },write:function (stream, buffer, offset, length, position) {
          try {
            return stream.node.mount.opts.fs.write(stream.nfd, buffer, offset, length, position);
          } catch(e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = stream.node.mount.opts.fs.fstat(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};


  function ___set_network_callback(event, userData, callback) {
      function _callback(data) {
        try {
          if (event === 'error') {
            var sp = stackSave();
            var msg = allocate(intArrayFromString(data[2]), 'i8', ALLOC_STACK);
            Module['dynCall_viiii'](callback, data[0], data[1], msg, userData);
            stackRestore(sp);
          } else {
            Module['dynCall_vii'](callback, data, userData);
          }
        } catch (e) {
          if (e instanceof ExitStatus) {
            return;
          } else {
            if (e && typeof e === 'object' && e.stack) err('exception thrown: ' + [e, e.stack]);
            throw e;
          }
        }
      };
  
      Module['noExitRuntime'] = true;
      Module['websocket']['on'](event, callback ? _callback : null);
    }

  function _emscripten_set_socket_error_callback(userData, callback) {
      ___set_network_callback('error', userData, callback);
    }

  function _emscripten_set_socket_open_callback(userData, callback) {
      ___set_network_callback('open', userData, callback);
    }

  function _emscripten_set_socket_listen_callback(userData, callback) {
      ___set_network_callback('listen', userData, callback);
    }

  function _emscripten_set_socket_connection_callback(userData, callback) {
      ___set_network_callback('connection', userData, callback);
    }

  function _emscripten_set_socket_message_callback(userData, callback) {
      ___set_network_callback('message', userData, callback);
    }

  function _emscripten_set_socket_close_callback(userData, callback) {
      ___set_network_callback('close', userData, callback);
    }


  
  function _SDL_GetTicks() {
      return (Date.now() - SDL.startTime)|0;
    }
  
  function _SDL_LockSurface(surf) {
      var surfData = SDL.surfaces[surf];
  
      surfData.locked++;
      if (surfData.locked > 1) return 0;
  
      if (!surfData.buffer) {
        surfData.buffer = _malloc(surfData.width * surfData.height * 4);
        HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
      }
  
      // Mark in C/C++-accessible SDL structure
      // SDL_Surface has the following fields: Uint32 flags, SDL_PixelFormat *format; int w, h; Uint16 pitch; void *pixels; ...
      // So we have fields all of the same size, and 5 of them before us.
      // TODO: Use macros like in library.js
      HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
  
      if (surf == SDL.screen && Module.screenIsReadOnly && surfData.image) return 0;
  
      if (SDL.defaults.discardOnLock) {
        if (!surfData.image) {
          surfData.image = surfData.ctx.createImageData(surfData.width, surfData.height);
        }
        if (!SDL.defaults.opaqueFrontBuffer) return;
      } else {
        surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
      }
  
      // Emulate desktop behavior and kill alpha values on the locked surface. (very costly!) Set SDL.defaults.opaqueFrontBuffer = false
      // if you don't want this.
      if (surf == SDL.screen && SDL.defaults.opaqueFrontBuffer) {
        var data = surfData.image.data;
        var num = data.length;
        for (var i = 0; i < num/4; i++) {
          data[i*4+3] = 255; // opacity, as canvases blend alpha
        }
      }
  
      if (SDL.defaults.copyOnLock && !SDL.defaults.discardOnLock) {
        // Copy pixel data to somewhere accessible to 'C/C++'
        if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
          // If this is neaded then
          // we should compact the data from 32bpp to 8bpp index.
          // I think best way to implement this is use
          // additional colorMap hash (color->index).
          // Something like this:
          //
          // var size = surfData.width * surfData.height;
          // var data = '';
          // for (var i = 0; i<size; i++) {
          //   var color = SDL.translateRGBAToColor(
          //     surfData.image.data[i*4   ],
          //     surfData.image.data[i*4 +1],
          //     surfData.image.data[i*4 +2],
          //     255);
          //   var index = surfData.colorMap[color];
          //   HEAP8[(((surfData.buffer)+(i))>>0)]=index;
          // }
          throw 'CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set' + new Error().stack;
        } else {
          HEAPU8.set(surfData.image.data, surfData.buffer);
        }
      }
  
      return 0;
    }var SDL={defaults:{width:320,height:200,copyOnLock:true,discardOnLock:false,opaqueFrontBuffer:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],rwops:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,glAttributes:{0:3,1:3,2:2,3:0,4:0,5:1,6:16,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:1,16:0,17:0,18:0},keyboardState:null,keyboardMap:{},canRequestFullscreen:false,isRequestingFullscreen:false,textInput:false,startTime:null,initFlags:0,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},TOUCH_DEFAULT_ID:0,eventHandler:null,eventHandlerContext:null,eventHandlerTemp:0,keyCodes:{16:1249,17:1248,18:1250,20:1081,33:1099,34:1102,35:1101,36:1098,37:1104,38:1106,39:1103,40:1105,44:316,45:1097,46:127,91:1251,93:1125,96:1122,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,106:1109,107:1111,109:1110,110:1123,111:1108,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,124:1128,125:1129,126:1130,127:1131,128:1132,129:1133,130:1134,131:1135,132:1136,133:1137,134:1138,135:1139,144:1107,160:94,161:33,162:34,163:35,164:36,165:37,166:38,167:95,168:40,169:41,170:42,171:43,172:124,173:45,174:123,175:125,176:126,181:127,182:129,183:128,188:44,190:46,191:47,192:96,219:91,220:92,221:93,222:39,224:1251},scanCodes:{8:42,9:43,13:40,27:41,32:44,35:204,39:53,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,58:203,59:51,61:46,91:47,92:49,93:48,96:52,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,127:76,305:224,308:226,316:70},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + 0)>>2)],
          y: HEAP32[((rect + 4)>>2)],
          w: HEAP32[((rect + 8)>>2)],
          h: HEAP32[((rect + 12)>>2)]
        };
      },updateRect:function (rect, r) {
        HEAP32[((rect)>>2)]=r.x;
        HEAP32[(((rect)+(4))>>2)]=r.y;
        HEAP32[(((rect)+(8))>>2)]=r.w;
        HEAP32[(((rect)+(12))>>2)]=r.h;
      },intersectionOfRects:function (first, second) {
        var leftX = Math.max(first.x, second.x);
        var leftY = Math.max(first.y, second.y);
        var rightX = Math.min(first.x + first.w, second.x + second.w);
        var rightY = Math.min(first.y + first.h, second.y + second.h);
  
        return {
          x: leftX,
          y: leftY,
          w: Math.max(leftX, rightX) - leftX,
          h: Math.max(leftY, rightY) - leftY
        }
      },checkPixelFormat:function (fmt) {
        // Canvas screens are always RGBA.
        var format = HEAP32[((fmt)>>2)];
        if (format != -2042224636) {
          warnOnce('Unsupported pixel format!');
        }
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var is_SDL_HWSURFACE = flags & 0x00000001;
        var is_SDL_HWPALETTE = flags & 0x00200000;
        var is_SDL_OPENGL = flags & 0x04000000;
  
        var surf = _malloc(60);
        var pixelFormat = _malloc(44);
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        var buffer = 0;
  
        // preemptively initialize this for software surfaces,
        // otherwise it will be lazily initialized inside of SDL_LockSurface
        if (!is_SDL_HWSURFACE && !is_SDL_OPENGL) {
          buffer = _malloc(width * height * 4);
        }
  
        HEAP32[((surf)>>2)]=flags;
        HEAP32[(((surf)+(4))>>2)]=pixelFormat;
        HEAP32[(((surf)+(8))>>2)]=width;
        HEAP32[(((surf)+(12))>>2)]=height;
        HEAP32[(((surf)+(16))>>2)]=width * bpp;  // assuming RGBA or indexed for now,
                                                                                          // since that is what ImageData gives us in browsers
        HEAP32[(((surf)+(20))>>2)]=buffer;
  
        HEAP32[(((surf)+(36))>>2)]=0;
        HEAP32[(((surf)+(40))>>2)]=0;
        HEAP32[(((surf)+(44))>>2)]=Module["canvas"].width;
        HEAP32[(((surf)+(48))>>2)]=Module["canvas"].height;
  
        HEAP32[(((surf)+(56))>>2)]=1;
  
        HEAP32[((pixelFormat)>>2)]=-2042224636;
        HEAP32[(((pixelFormat)+(4))>>2)]=0;// TODO
        HEAP8[(((pixelFormat)+(8))>>0)]=bpp * 8;
        HEAP8[(((pixelFormat)+(9))>>0)]=bpp;
  
        HEAP32[(((pixelFormat)+(12))>>2)]=rmask || 0x000000ff;
        HEAP32[(((pixelFormat)+(16))>>2)]=gmask || 0x0000ff00;
        HEAP32[(((pixelFormat)+(20))>>2)]=bmask || 0x00ff0000;
        HEAP32[(((pixelFormat)+(24))>>2)]=amask || 0xff000000;
  
        // Decide if we want to use WebGL or not
        SDL.GL = SDL.GL || is_SDL_OPENGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
  
        var webGLContextAttributes = {
          antialias: ((SDL.glAttributes[13 /*SDL_GL_MULTISAMPLEBUFFERS*/] != 0) && (SDL.glAttributes[14 /*SDL_GL_MULTISAMPLESAMPLES*/] > 1)),
          depth: (SDL.glAttributes[6 /*SDL_GL_DEPTH_SIZE*/] > 0),
          stencil: (SDL.glAttributes[7 /*SDL_GL_STENCIL_SIZE*/] > 0),
          alpha: (SDL.glAttributes[3 /*SDL_GL_ALPHA_SIZE*/] > 0)
        };
  
        var ctx = Browser.createContext(canvas, is_SDL_OPENGL, usePageCanvas, webGLContextAttributes);
  
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
  
          isFlagSet: function(flag) {
            return flags & flag;
          }
        };
  
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
  
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
  
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
  
        var buffer  = surfData.buffer;
  
        if (!surfData.image.data32) {
          surfData.image.data32 = new Uint32Array(surfData.image.data.buffer);
        }
        var data32   = surfData.image.data32;
  
        var colors32 = surfData.colors32;
  
        for (var y = startY; y < endY; ++y) {
          var base = y * fullWidth;
          for (var x = startX; x < endX; ++x) {
            data32[base + x] = colors32[HEAPU8[((buffer + base + x)>>0)]];
          }
        }
      },freeSurface:function (surf) {
        var refcountPointer = surf + 56;
        var refcount = HEAP32[((refcountPointer)>>2)];
        if (refcount > 1) {
          HEAP32[((refcountPointer)>>2)]=refcount - 1;
          return;
        }
  
        var info = SDL.surfaces[surf];
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        if (info.buffer) _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
  
        if (surf === SDL.screen) {
          SDL.screen = null;
        }
      },blitSurface:function (src, srcrect, dst, dstrect, scale) {
        var srcData = SDL.surfaces[src];
        var dstData = SDL.surfaces[dst];
        var sr, dr;
        if (srcrect) {
          sr = SDL.loadRect(srcrect);
        } else {
          sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
        }
        if (dstrect) {
          dr = SDL.loadRect(dstrect);
        } else {
          dr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
        }
        if (dstData.clipRect) {
          var widthScale = (!scale || sr.w === 0) ? 1 : sr.w / dr.w;
          var heightScale = (!scale || sr.h === 0) ? 1 : sr.h / dr.h;
  
          dr = SDL.intersectionOfRects(dstData.clipRect, dr);
  
          sr.w = dr.w * widthScale;
          sr.h = dr.h * heightScale;
  
          if (dstrect) {
            SDL.updateRect(dstrect, dr);
          }
        }
        var blitw, blith;
        if (scale) {
          blitw = dr.w; blith = dr.h;
        } else {
          blitw = sr.w; blith = sr.h;
        }
        if (sr.w === 0 || sr.h === 0 || blitw === 0 || blith === 0) {
          return 0;
        }
        var oldAlpha = dstData.ctx.globalAlpha;
        dstData.ctx.globalAlpha = srcData.alpha/255;
        dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, blitw, blith);
        dstData.ctx.globalAlpha = oldAlpha;
        if (dst != SDL.screen) {
          // XXX As in IMG_Load, for compatibility we write out |pixels|
          warnOnce('WARNING: copying canvas data to memory for compatibility');
          _SDL_LockSurface(dst);
          dstData.locked--; // The surface is not actually locked in this hack
        }
        return 0;
      },downFingers:{},savedKeydown:null,receiveEvent:function (event) {
        function unpressAllPressedKeys() {
          // Un-press all pressed keys: TODO
          for (var code in SDL.keyboardMap) {
            SDL.events.push({
              type: 'keyup',
              keyCode: SDL.keyboardMap[code]
            });
          }
        };
        switch(event.type) {
          case 'touchstart': case 'touchmove': {
            event.preventDefault();
  
            var touches = [];
  
            // Clear out any touchstart events that we've already processed
            if (event.type === 'touchstart') {
              for (var i = 0; i < event.touches.length; i++) {
                var touch = event.touches[i];
                if (SDL.downFingers[touch.identifier] != true) {
                  SDL.downFingers[touch.identifier] = true;
                  touches.push(touch);
                }
              }
            } else {
              touches = event.touches;
            }
  
            var firstTouch = touches[0];
            if (firstTouch) {
              if (event.type == 'touchstart') {
                SDL.DOMButtons[0] = 1;
              }
              var mouseEventType;
              switch(event.type) {
                case 'touchstart': mouseEventType = 'mousedown'; break;
                case 'touchmove': mouseEventType = 'mousemove'; break;
              }
              var mouseEvent = {
                type: mouseEventType,
                button: 0,
                pageX: firstTouch.clientX,
                pageY: firstTouch.clientY
              };
              SDL.events.push(mouseEvent);
            }
  
            for (var i = 0; i < touches.length; i++) {
              var touch = touches[i];
              SDL.events.push({
                type: event.type,
                touch: touch
              });
            };
            break;
          }
          case 'touchend': {
            event.preventDefault();
  
            // Remove the entry in the SDL.downFingers hash
            // because the finger is no longer down.
            for(var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              if (SDL.downFingers[touch.identifier] === true) {
                delete SDL.downFingers[touch.identifier];
              }
            }
  
            var mouseEvent = {
              type: 'mouseup',
              button: 0,
              pageX: event.changedTouches[0].clientX,
              pageY: event.changedTouches[0].clientY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(mouseEvent);
  
            for (var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              SDL.events.push({
                type: 'touchend',
                touch: touch
              });
            };
            break;
          }
          case 'DOMMouseScroll': case 'mousewheel': case 'wheel':
            var delta = -Browser.getMouseWheelDelta(event); // Flip the wheel direction to translate from browser wheel direction (+:down) to SDL direction (+:up)
            delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.
  
            // Simulate old-style SDL events representing mouse wheel input as buttons
            var button = delta > 0 ? 3 /*SDL_BUTTON_WHEELUP-1*/ : 4 /*SDL_BUTTON_WHEELDOWN-1*/; // Subtract one since JS->C marshalling is defined to add one back.
            SDL.events.push({ type: 'mousedown', button: button, pageX: event.pageX, pageY: event.pageY });
            SDL.events.push({ type: 'mouseup', button: button, pageX: event.pageX, pageY: event.pageY });
  
            // Pass a delta motion event.
            SDL.events.push({ type: 'wheel', deltaX: 0, deltaY: delta });
            event.preventDefault(); // If we don't prevent this, then 'wheel' event will be sent again by the browser as 'DOMMouseScroll' and we will receive this same event the second time.
            break;
          case 'mousemove':
            if (SDL.DOMButtons[0] === 1) {
              SDL.events.push({
                type: 'touchmove',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            }
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup':
            // If we preventDefault on keydown events, the subsequent keypress events
            // won't fire. However, it's fine (and in some cases necessary) to
            // preventDefault for keys that don't generate a character. Otherwise,
            // preventDefault is the right thing to do in general.
            if (event.type !== 'keydown' || (!SDL.unicode && !SDL.textInput) || (event.keyCode === 8 /* backspace */ || event.keyCode === 9 /* tab */)) {
              event.preventDefault();
            }
  
            if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
              SDL.events.push({
                type: 'touchstart',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                return;
              }
  
              SDL.events.push({
                type: 'touchend',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
              SDL.DOMButtons[event.button] = 0;
            }
  
            // We can only request fullscreen as the result of user input.
            // Due to this limitation, we toggle a boolean on keydown which
            // SDL_WM_ToggleFullScreen will check and subsequently set another
            // flag indicating for us to request fullscreen on the following
            // keyup. This isn't perfect, but it enables SDL_WM_ToggleFullScreen
            // to work as the result of a keypress (which is an extremely
            // common use case).
            if (event.type === 'keydown' || event.type === 'mousedown') {
              SDL.canRequestFullscreen = true;
            } else if (event.type === 'keyup' || event.type === 'mouseup') {
              if (SDL.isRequestingFullscreen) {
                Module['requestFullscreen'](/*lockPointer=*/true, /*resizeCanvas=*/true);
                SDL.isRequestingFullscreen = false;
              }
              SDL.canRequestFullscreen = false;
            }
  
            // SDL expects a unicode character to be passed to its keydown events.
            // Unfortunately, the browser APIs only provide a charCode property on
            // keypress events, so we must backfill in keydown events with their
            // subsequent keypress event's charCode.
            if (event.type === 'keypress' && SDL.savedKeydown) {
              // charCode is read-only
              SDL.savedKeydown.keypressCharCode = event.charCode;
              SDL.savedKeydown = null;
            } else if (event.type === 'keydown') {
              SDL.savedKeydown = event;
            }
  
            // Don't push keypress events unless SDL_StartTextInput has been called.
            if (event.type !== 'keypress' || SDL.textInput) {
              SDL.events.push(event);
            }
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            event.preventDefault();
            break;
          case 'focus':
            SDL.events.push(event);
            event.preventDefault();
            break;
          case 'blur':
            SDL.events.push(event);
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'visibilitychange':
            SDL.events.push({
              type: 'visibilitychange',
              visible: !document.hidden
            });
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            // manually triggered resize event doesn't have a preventDefault member
            if (event.preventDefault) {
              event.preventDefault();
            }
            break;
        }
        if (SDL.events.length >= 10000) {
          err('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // If we have a handler installed, this will push the events to the app
        // instead of the app polling for them.
        SDL.flushEventsToHandler();
        return;
      },lookupKeyCodeForEvent:function (event) {
          var code = event.keyCode;
          if (code >= 65 && code <= 90) {
            code += 32; // make lowercase for SDL
          } else {
            code = SDL.keyCodes[event.keyCode] || event.keyCode;
            // If this is one of the modifier keys (224 | 1<<10 - 227 | 1<<10), and the event specifies that it is
            // a right key, add 4 to get the right key SDL key code.
            if (event.location === KeyboardEvent.DOM_KEY_LOCATION_RIGHT && code >= (224 | 1<<10) && code <= (227 | 1<<10)) {
              code += 4;
            }
          }
          return code;
      },handleEvent:function (event) {
        if (event.handled) return;
        event.handled = true;
  
        switch (event.type) {
          case 'touchstart': case 'touchend': case 'touchmove': {
            Browser.calculateMouseEvent(event);
            break;
          }
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            var code = SDL.lookupKeyCodeForEvent(event);
            HEAP8[(((SDL.keyboardState)+(code))>>0)]=down;
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))>>0)] ? 0x0040 : 0) | // KMOD_LCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))>>0)] ? 0x0001 : 0) | // KMOD_LSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))>>0)] ? 0x0100 : 0) | // KMOD_LALT
              (HEAP8[(((SDL.keyboardState)+(1252))>>0)] ? 0x0080 : 0) | // KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1253))>>0)] ? 0x0002 : 0) | // KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1254))>>0)] ? 0x0200 : 0); //  KMOD_RALT
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
  
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            break;
          }
        }
      },flushEventsToHandler:function () {
        if (!SDL.eventHandler) return;
  
        while (SDL.pollEvent(SDL.eventHandlerTemp)) {
          Module['dynCall_iii'](SDL.eventHandler, SDL.eventHandlerContext, SDL.eventHandlerTemp);
        }
      },pollEvent:function (ptr) {
        if (SDL.initFlags & 0x200 && SDL.joystickEventState) {
          // If SDL_INIT_JOYSTICK was supplied AND the joystick system is configured
          // to automatically query for events, query for joystick events.
          SDL.queryJoysticks();
        }
        if (ptr) {
          while (SDL.events.length > 0) {
            if (SDL.makeCEvent(SDL.events.shift(), ptr) !== false) return 1;
          }
          return 0;
        } else {
          // XXX: somewhat risky in that we do not check if the event is real or not (makeCEvent returns false) if no pointer supplied
          return SDL.events.length > 0;
        }
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a copy of a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, 28);
          _free(event); // the copy is no longer needed
          return;
        }
  
        SDL.handleEvent(event);
  
        switch (event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //out('Received key event: ' + event.keyCode);
            var key = SDL.lookupKeyCodeForEvent(event);
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
  
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(8))>>0)]=down ? 1 : 0;
            HEAP8[(((ptr)+(9))>>0)]=0; // TODO
            HEAP32[(((ptr)+(12))>>2)]=scan;
            HEAP32[(((ptr)+(16))>>2)]=key;
            HEAP16[(((ptr)+(20))>>1)]=SDL.modState;
            // some non-character keys (e.g. backspace and tab) won't have keypressCharCode set, fill in with the keyCode.
            HEAP32[(((ptr)+(24))>>2)]=event.keypressCharCode || key;
  
            break;
          }
          case 'keypress': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(8 + i))>>0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup': case 'mousemove': {
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP8[(((ptr)+(16))>>0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(17))>>0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
            } else {
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP32[(((ptr)+(16))>>2)]=SDL.buttonState;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(28))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(32))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'wheel': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(16))>>2)]=event.deltaX;
            HEAP32[(((ptr)+(20))>>2)]=event.deltaY;
            break;
          }
          case 'touchstart': case 'touchend': case 'touchmove': {
            var touch = event.touch;
            if (!Browser.touches[touch.identifier]) break;
            var w = Module['canvas'].width;
            var h = Module['canvas'].height;
            var x = Browser.touches[touch.identifier].x / w;
            var y = Browser.touches[touch.identifier].y / h;
            var lx = Browser.lastTouches[touch.identifier].x / w;
            var ly = Browser.lastTouches[touch.identifier].y / h;
            var dx = x - lx;
            var dy = y - ly;
            if (touch['deviceID'] === undefined) touch.deviceID = SDL.TOUCH_DEFAULT_ID;
            if (dx === 0 && dy === 0 && event.type === 'touchmove') return false; // don't send these if nothing happened
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=_SDL_GetTicks();
            (tempI64 = [touch.deviceID>>>0,(tempDouble=touch.deviceID,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((ptr)+(8))>>2)]=tempI64[0],HEAP32[(((ptr)+(12))>>2)]=tempI64[1]);
            (tempI64 = [touch.identifier>>>0,(tempDouble=touch.identifier,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((ptr)+(16))>>2)]=tempI64[0],HEAP32[(((ptr)+(20))>>2)]=tempI64[1]);
            HEAPF32[(((ptr)+(24))>>2)]=x;
            HEAPF32[(((ptr)+(28))>>2)]=y;
            HEAPF32[(((ptr)+(32))>>2)]=dx;
            HEAPF32[(((ptr)+(36))>>2)]=dy;
            if (touch.force !== undefined) {
              HEAPF32[(((ptr)+(40))>>2)]=touch.force;
            } else { // No pressure data, send a digital 0/1 pressure.
              HEAPF32[(((ptr)+(40))>>2)]=event.type == "touchend" ? 0 : 1;
            }
            break;
          }
          case 'unload': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=event.w;
            HEAP32[(((ptr)+(8))>>2)]=event.h;
            break;
          }
          case 'joystick_button_up': case 'joystick_button_down': {
            var state = event.type === 'joystick_button_up' ? 0 : 1;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.button;
            HEAP8[(((ptr)+(6))>>0)]=state;
            break;
          }
          case 'joystick_axis_motion': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.axis;
            HEAP32[(((ptr)+(8))>>2)]=SDL.joystickAxisValueConversion(event.value);
            break;
          }
          case 'focus': {
            var SDL_WINDOWEVENT_FOCUS_GAINED = 12 /* SDL_WINDOWEVENT_FOCUS_GAINED */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_GAINED;
            break;
          }
          case 'blur': {
            var SDL_WINDOWEVENT_FOCUS_LOST = 13 /* SDL_WINDOWEVENT_FOCUS_LOST */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_LOST;
            break;
          }
          case 'visibilitychange': {
            var SDL_WINDOWEVENT_SHOWN  = 1 /* SDL_WINDOWEVENT_SHOWN */;
            var SDL_WINDOWEVENT_HIDDEN = 2 /* SDL_WINDOWEVENT_HIDDEN */;
            var visibilityEventID = event.visible ? SDL_WINDOWEVENT_SHOWN : SDL_WINDOWEVENT_HIDDEN;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=visibilityEventID;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },makeFontString:function (height, fontName) {
        if (fontName.charAt(0) != "'" && fontName.charAt(0) != '"') {
          // https://developer.mozilla.org/ru/docs/Web/CSS/font-family
          // Font family names containing whitespace should be quoted.
          // BTW, quote all font names is easier than searching spaces
          fontName = '"' + fontName + '"';
        }
        return height + 'px ' + fontName + ', serif';
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = SDL.makeFontString(h, fontData.name);
        var tempCtx = SDL.ttfContext;
        assert(tempCtx, 'TTF_Init must have been called');
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num && num != 0) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = Math.min(Math.max(volume, 0), 128) / 128;
          if (info.audio) {
            try {
              info.audio.volume = info.volume; // For <audio> element
              if (info.audio.webAudioGainNode) info.audio.webAudioGainNode['gain']['value'] = info.volume; // For WebAudio playback
            } catch(e) {
              err('setGetVolume failed to set audio volume: ' + e);
            }
          }
        }
        return ret;
      },setPannerPosition:function (info, x, y, z) {
        if (!info) return;
        if (info.audio) {
          if (info.audio.webAudioPannerNode) {
            info.audio.webAudioPannerNode['setPosition'](x, y, z);
          }
        }
      },playWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) return; // This instance is already playing, don't start again.
        if (!SDL.webAudioAvailable()) return;
        try {
          var webAudio = audio.resource.webAudio;
          audio.paused = false;
          if (!webAudio.decodedBuffer) {
            if (webAudio.onDecodeComplete === undefined) abort("Cannot play back audio object that was not loaded");
            webAudio.onDecodeComplete.push(function() { if (!audio.paused) SDL.playWebAudio(audio); });
            return;
          }
          audio.webAudioNode = SDL.audioContext['createBufferSource']();
          audio.webAudioNode['buffer'] = webAudio.decodedBuffer;
          audio.webAudioNode['loop'] = audio.loop;
          audio.webAudioNode['onended'] = function() { audio['onended'](); } // For <media> element compatibility, route the onended signal to the instance.
  
          audio.webAudioPannerNode = SDL.audioContext['createPanner']();
          // avoid Chrome bug
          // If posz = 0, the sound will come from only the right.
          // By posz = -0.5 (slightly ahead), the sound will come from right and left correctly.
          audio.webAudioPannerNode["setPosition"](0, 0, -.5);
          audio.webAudioPannerNode['panningModel'] = 'equalpower';
  
          // Add an intermediate gain node to control volume.
          audio.webAudioGainNode = SDL.audioContext['createGain']();
          audio.webAudioGainNode['gain']['value'] = audio.volume;
  
          audio.webAudioNode['connect'](audio.webAudioPannerNode);
          audio.webAudioPannerNode['connect'](audio.webAudioGainNode);
          audio.webAudioGainNode['connect'](SDL.audioContext['destination']);
  
          audio.webAudioNode['start'](0, audio.currentPosition);
          audio.startTime = SDL.audioContext['currentTime'] - audio.currentPosition;
        } catch(e) {
          err('playWebAudio failed: ' + e);
        }
      },pauseWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) {
          try {
            // Remember where we left off, so that if/when we resume, we can restart the playback at a proper place.
            audio.currentPosition = (SDL.audioContext['currentTime'] - audio.startTime) % audio.resource.webAudio.decodedBuffer.duration;
            // Important: When we reach here, the audio playback is stopped by the user. But when calling .stop() below, the Web Audio
            // graph will send the onended signal, but we don't want to process that, since pausing should not clear/destroy the audio
            // channel.
            audio.webAudioNode['onended'] = undefined;
            audio.webAudioNode.stop(0); // 0 is a default parameter, but WebKit is confused by it #3861
            audio.webAudioNode = undefined;
          } catch(e) {
            err('pauseWebAudio failed: ' + e);
          }
        }
        audio.paused = true;
      },openAudioContext:function () {
        // Initialize Web Audio API if we haven't done so yet. Note: Only initialize Web Audio context ever once on the web page,
        // since initializing multiple times fails on Chrome saying 'audio resources have been exhausted'.
        if (!SDL.audioContext) {
          if (typeof(AudioContext) !== 'undefined') SDL.audioContext = new AudioContext();
          else if (typeof(webkitAudioContext) !== 'undefined') SDL.audioContext = new webkitAudioContext();
        }
      },webAudioAvailable:function () { return !!SDL.audioContext; },fillWebAudioBufferFromHeap:function (heapPtr, sizeSamplesPerChannel, dstAudioBuffer) {
        // The input audio data is interleaved across the channels, i.e. [L, R, L, R, L, R, ...] and is either 8-bit, 16-bit or float as
        // supported by the SDL API. The output audio wave data for Web Audio API must be in planar buffers of [-1,1]-normalized Float32 data,
        // so perform a buffer conversion for the data.
        var numChannels = SDL.audio.channels;
        for(var c = 0; c < numChannels; ++c) {
          var channelData = dstAudioBuffer['getChannelData'](c);
          if (channelData.length != sizeSamplesPerChannel) {
            throw 'Web Audio output buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + sizeSamplesPerChannel + ' samples!';
          }
          if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              channelData[j] = (HEAP16[(((heapPtr)+((j*numChannels + c)*2))>>1)]) / 0x8000;
            }
          } else if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              var v = (HEAP8[(((heapPtr)+(j*numChannels + c))>>0)]);
              channelData[j] = ((v >= 0) ? v-128 : v+128) /128;
            }
          } else if (SDL.audio.format == 0x8120 /*AUDIO_F32*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              channelData[j] = (HEAPF32[(((heapPtr)+((j*numChannels + c)*4))>>2)]);
            }
          } else {
            throw 'Invalid SDL audio format ' + SDL.audio.format + '!';
          }
        }
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      },joystickEventState:1,lastJoystickState:{},joystickNamePool:{},recordJoystickState:function (joystick, state) {
        // Standardize button state.
        var buttons = new Array(state.buttons.length);
        for (var i = 0; i < state.buttons.length; i++) {
          buttons[i] = SDL.getJoystickButtonState(state.buttons[i]);
        }
  
        SDL.lastJoystickState[joystick] = {
          buttons: buttons,
          axes: state.axes.slice(0),
          timestamp: state.timestamp,
          index: state.index,
          id: state.id
        };
      },getJoystickButtonState:function (button) {
        if (typeof button === 'object') {
          // Current gamepad API editor's draft (Firefox Nightly)
          // https://dvcs.w3.org/hg/gamepad/raw-file/default/gamepad.html#idl-def-GamepadButton
          return button['pressed'];
        } else {
          // Current gamepad API working draft (Firefox / Chrome Stable)
          // http://www.w3.org/TR/2012/WD-gamepad-20120529/#gamepad-interface
          return button > 0;
        }
      },queryJoysticks:function () {
        for (var joystick in SDL.lastJoystickState) {
          var state = SDL.getGamepad(joystick - 1);
          var prevState = SDL.lastJoystickState[joystick];
          // If joystick was removed, state returns null.
          if (typeof state === 'undefined') return;
          if (state === null) return;
          // Check only if the timestamp has differed.
          // NOTE: Timestamp is not available in Firefox.
          // NOTE: Timestamp is currently not properly set for the GearVR controller
          //       on Samsung Internet: it is always zero.
          if (typeof state.timestamp !== 'number' || state.timestamp !== prevState.timestamp || !state.timestamp) {
            var i;
            for (i = 0; i < state.buttons.length; i++) {
              var buttonState = SDL.getJoystickButtonState(state.buttons[i]);
              // NOTE: The previous state already has a boolean representation of
              //       its button, so no need to standardize its button state here.
              if (buttonState !== prevState.buttons[i]) {
                // Insert button-press event.
                SDL.events.push({
                  type: buttonState ? 'joystick_button_down' : 'joystick_button_up',
                  joystick: joystick,
                  index: joystick - 1,
                  button: i
                });
              }
            }
            for (i = 0; i < state.axes.length; i++) {
              if (state.axes[i] !== prevState.axes[i]) {
                // Insert axes-change event.
                SDL.events.push({
                  type: 'joystick_axis_motion',
                  joystick: joystick,
                  index: joystick - 1,
                  axis: i,
                  value: state.axes[i]
                });
              }
            }
  
            SDL.recordJoystickState(joystick, state);
          }
        }
      },joystickAxisValueConversion:function (value) {
        // Make sure value is properly clamped
        value = Math.min(1, Math.max(value, -1));
        // Ensures that 0 is 0, 1 is 32767, and -1 is 32768.
        return Math.ceil(((value+1) * 32767.5) - 32768);
      },getGamepads:function () {
        var fcn = navigator.getGamepads || navigator.webkitGamepads || navigator.mozGamepads || navigator.gamepads || navigator.webkitGetGamepads;
        if (fcn !== undefined) {
          // The function must be applied on the navigator object.
          return fcn.apply(navigator);
        } else {
          return [];
        }
      },getGamepad:function (deviceIndex) {
        var gamepads = SDL.getGamepads();
        if (gamepads.length > deviceIndex && deviceIndex >= 0) {
          return gamepads[deviceIndex];
        }
        return null;
      }};


  function _SDL_Linked_Version() {
      if (SDL.version === null) {
        SDL.version = _malloc(3);
        HEAP8[((SDL.version + 0)>>0)]=1;
        HEAP8[((SDL.version + 1)>>0)]=3;
        HEAP8[((SDL.version + 2)>>0)]=0;
      }
      return SDL.version;
    }


  function _SDL_Init(initFlags) {
      SDL.startTime = Date.now();
      SDL.initFlags = initFlags;
  
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        var keyboardListeningElement = Module['keyboardListeningElement'] || document;
        keyboardListeningElement.addEventListener("keydown", SDL.receiveEvent);
        keyboardListeningElement.addEventListener("keyup", SDL.receiveEvent);
        keyboardListeningElement.addEventListener("keypress", SDL.receiveEvent);
        window.addEventListener("focus", SDL.receiveEvent);
        window.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
  
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown']    = 0x300  /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup']      = 0x301  /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress']   = 0x303  /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown']  = 0x401  /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup']    = 0x402  /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove']  = 0x400  /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['wheel']      = 0x403  /* SDL_MOUSEWHEEL */;
      SDL.DOMEventToSDLEvent['touchstart'] = 0x700  /* SDL_FINGERDOWN */;
      SDL.DOMEventToSDLEvent['touchend']   = 0x701  /* SDL_FINGERUP */;
      SDL.DOMEventToSDLEvent['touchmove']  = 0x702  /* SDL_FINGERMOTION */;
      SDL.DOMEventToSDLEvent['unload']     = 0x100  /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize']     = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      SDL.DOMEventToSDLEvent['visibilitychange'] = 0x200 /* SDL_WINDOWEVENT */;
      SDL.DOMEventToSDLEvent['focus']      = 0x200 /* SDL_WINDOWEVENT */;
      SDL.DOMEventToSDLEvent['blur']       = 0x200 /* SDL_WINDOWEVENT */;
  
      // These are not technically DOM events; the HTML gamepad API is poll-based.
      // However, we define them here, as the rest of the SDL code assumes that
      // all SDL events originate as DOM events.
      SDL.DOMEventToSDLEvent['joystick_axis_motion'] = 0x600 /* SDL_JOYAXISMOTION */;
      SDL.DOMEventToSDLEvent['joystick_button_down'] = 0x603 /* SDL_JOYBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['joystick_button_up'] = 0x604 /* SDL_JOYBUTTONUP */;
      return 0; // success
    }


  function _SDL_WasInit() {
      if (SDL.startTime === null) {
        _SDL_Init();
      }
      return 1;
    }


  function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5 * 4);
      HEAP32[((ret+0)>>2)]=0; // TODO
      HEAP32[((ret+4)>>2)]=0; // TODO
      HEAP32[((ret+8)>>2)]=0;
      HEAP32[((ret+12)>>2)]=Module["canvas"].width;
      HEAP32[((ret+16)>>2)]=Module["canvas"].height;
      return ret;
    }

  function _SDL_ListModes(format, flags) {
      return -1; // -1 == all modes are ok. TODO
    }

  function _SDL_VideoModeOK(width, height, depth, flags) {
      // SDL_VideoModeOK returns 0 if the requested mode is not supported under any bit depth, or returns the
      // bits-per-pixel of the closest available mode with the given width, height and requested surface flags
      return depth; // all modes are ok.
    }

  
  function _SDL_VideoDriverName(buf, max_size) {
      if (SDL.startTime === null) {
        return 0; //return NULL
      }
      //driverName - emscripten_sdl_driver
      var driverName = [101, 109, 115, 99, 114, 105, 112, 116, 101,
        110, 95, 115, 100, 108, 95, 100, 114, 105, 118, 101, 114];
  
      var index = 0;
      var size  = driverName.length;
  
      if (max_size <= size) {
        size = max_size - 1; //-1 cause null-terminator
      }
  
      while (index < size) {
          var value = driverName[index];
          HEAP8[(((buf)+(index))>>0)]=value;
          index++;
      }
  
      HEAP8[(((buf)+(index))>>0)]=0;
      return buf;
    }function _SDL_AudioDriverName(buf, max_size) {
      return _SDL_VideoDriverName(buf, max_size);
    }




  function _SDL_SetVideoMode(width, height, depth, flags) {
      ['touchstart', 'touchend', 'touchmove', 'mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'wheel', 'mouseout'].forEach(function(event) {
        Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
      });
  
      var canvas = Module['canvas'];
  
      // (0,0) means 'use fullscreen' in native; in Emscripten, use the current canvas size.
      if (width == 0 && height == 0) {
        width = canvas.width;
        height = canvas.height;
      }
  
      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          if (!SDL.settingVideoMode) {
            SDL.receiveEvent({
              type: 'resize',
              w: w,
              h: h
            });
          }
        });
      }
  
      SDL.settingVideoMode = true; // SetVideoMode itself should not trigger resize events
      Browser.setCanvasSize(width, height);
      SDL.settingVideoMode = false;
  
      // Free the old surface first if there is one
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        assert(!SDL.screen);
      }
  
      if (SDL.GL) flags = flags | 0x04000000; // SDL_OPENGL - if we are using GL, then later calls to SetVideoMode may not mention GL, but we do need it. Once in GL mode, we never leave it.
  
      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');
  
      return SDL.screen;
    }


  function _SDL_GetVideoSurface() {
      return SDL.screen;
    }


  function _SDL_AudioQuit() {
      for (var i = 0; i < SDL.numChannels; ++i) {
        if (SDL.channels[i].audio) {
          SDL.channels[i].audio.pause();
          SDL.channels[i].audio = undefined;
        }
      }
      if (SDL.music.audio) SDL.music.audio.pause();
      SDL.music.audio = undefined;
    }

  function _SDL_VideoQuit() {
      out('SDL_VideoQuit called (and ignored)');
    }

  function _SDL_QuitSubSystem(flags) {
      out('SDL_QuitSubSystem called (and ignored)');
    }

  function _SDL_Quit() {
      _SDL_AudioQuit();
      out('SDL_Quit called (and ignored)');
    }




  function _SDL_UnlockSurface(surf) {
      assert(!SDL.GL); // in GL mode we do not keep around 2D canvases and contexts
  
      var surfData = SDL.surfaces[surf];
  
      if (!surfData.locked || --surfData.locked > 0) {
        return;
      }
  
      // Copy pixel data to image
      if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
        SDL.copyIndexedColorData(surfData);
      } else if (!surfData.colors) {
        var data = surfData.image.data;
        var buffer = surfData.buffer;
        assert(buffer % 4 == 0, 'Invalid buffer offset: ' + buffer);
        var src = buffer >> 2;
        var dst = 0;
        var isScreen = surf == SDL.screen;
        var num;
        if (typeof CanvasPixelArray !== 'undefined' && data instanceof CanvasPixelArray) {
          // IE10/IE11: ImageData objects are backed by the deprecated CanvasPixelArray,
          // not UInt8ClampedArray. These don't have buffers, so we need to revert
          // to copying a byte at a time. We do the undefined check because modern
          // browsers do not define CanvasPixelArray anymore.
          num = data.length;
          while (dst < num) {
            var val = HEAP32[src]; // This is optimized. Instead, we could do HEAP32[(((buffer)+(dst))>>2)];
            data[dst  ] = val & 0xff;
            data[dst+1] = (val >> 8) & 0xff;
            data[dst+2] = (val >> 16) & 0xff;
            data[dst+3] = isScreen ? 0xff : ((val >> 24) & 0xff);
            src++;
            dst += 4;
          }
        } else {
          var data32 = new Uint32Array(data.buffer);
          if (isScreen && SDL.defaults.opaqueFrontBuffer) {
            num = data32.length;
            // logically we need to do
            //      while (dst < num) {
            //          data32[dst++] = HEAP32[src++] | 0xff000000
            //      }
            // the following code is faster though, because
            // .set() is almost free - easily 10x faster due to
            // native memcpy efficiencies, and the remaining loop
            // just stores, not load + store, so it is faster
            data32.set(HEAP32.subarray(src, src + num));
            var data8 = new Uint8Array(data.buffer);
            var i = 3;
            var j = i + 4*num;
            if (num % 8 == 0) {
              // unrolling gives big speedups
              while (i < j) {
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
              }
             } else {
              while (i < j) {
                data8[i] = 0xff;
                i = i + 4 | 0;
              }
            }
          } else {
            data32.set(HEAP32.subarray(src, src + data32.length));
          }
        }
      } else {
        var width = Module['canvas'].width;
        var height = Module['canvas'].height;
        var s = surfData.buffer;
        var data = surfData.image.data;
        var colors = surfData.colors; // TODO: optimize using colors32
        for (var y = 0; y < height; y++) {
          var base = y*width*4;
          for (var x = 0; x < width; x++) {
            // See comment above about signs
            var val = HEAPU8[((s++)>>0)] * 4;
            var start = base + x*4;
            data[start]   = colors[val];
            data[start+1] = colors[val+1];
            data[start+2] = colors[val+2];
          }
          s += width*3;
        }
      }
      // Copy to canvas
      surfData.ctx.putImageData(surfData.image, 0, 0);
      // Note that we save the image, so future writes are fast. But, memory is not yet released
    }

  function _SDL_Flip(surf) {
      // We actually do this in Unlock, since the screen surface has as its canvas
      // backing the page canvas element
    }

  function _SDL_UpdateRect(surf, x, y, w, h) {
      // We actually do the whole screen in Unlock...
    }

  function _SDL_UpdateRects(surf, numrects, rects) {
      // We actually do the whole screen in Unlock...
    }

  function _SDL_Delay(delay) {
      if (!ENVIRONMENT_IS_WORKER) abort('SDL_Delay called on the main thread! Potential infinite loop, quitting.');
      // horrible busy-wait, but in a worker it at least does not block rendering
      var now = Date.now();
      while (Date.now() - now < delay) {}
    }


  function _SDL_WM_SetCaption(title, icon) {
      if (title && typeof Module['setWindowTitle'] !== 'undefined') {
        Module['setWindowTitle'](Pointer_stringify(title));
      }
      icon = icon && Pointer_stringify(icon);
    }

  function _SDL_EnableKeyRepeat(delay, interval) {
      // TODO
    }


  function _SDL_GetKeyboardState(numKeys) {
      if (numKeys) {
        HEAP32[((numKeys)>>2)]=65536;
      }
      return SDL.keyboardState;
    }

  function _SDL_GetKeyState() {
      return _SDL_GetKeyboardState();
    }


  function _SDL_GetKeyName(key) {
      if (!SDL.keyName) {
        SDL.keyName = allocate(intArrayFromString('unknown key'), 'i8', ALLOC_NORMAL);
      }
      return SDL.keyName;
    }


  function _SDL_GetModState() {
      return SDL.modState;
    }


  function _SDL_GetMouseState(x, y) {
      if (x) HEAP32[((x)>>2)]=Browser.mouseX;
      if (y) HEAP32[((y)>>2)]=Browser.mouseY;
      return SDL.buttonState;
    }


  function _SDL_WarpMouse(x, y) {
      return; // TODO: implement this in a non-buggy way. Need to keep relative mouse movements correct after calling this
      /*
      var rect = Module["canvas"].getBoundingClientRect();
      SDL.events.push({
        type: 'mousemove',
        pageX: x + (window.scrollX + rect.left),
        pageY: y + (window.scrollY + rect.top)
      });
      */
    }


  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullscreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }


  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }

  function _SDL_SetError() {}

  function _SDL_malloc() {
  return _malloc.apply(null, arguments)
  }

  function _SDL_free() {
  return _free.apply(null, arguments)
  }


  function _SDL_CreateRGBSurface(flags, width, height, depth, rmask, gmask, bmask, amask) {
      return SDL.makeSurface(width, height, flags, false, 'CreateRGBSurface', rmask, gmask, bmask, amask);
    }


  function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
      var surf = SDL.makeSurface(width, height, 0, false, 'CreateRGBSurfaceFrom', rmask, gmask, bmask, amask);
  
      if (depth !== 32) {
        // TODO: Actually fill pixel data to created surface.
        // TODO: Take into account depth and pitch parameters.
        console.log('TODO: Partially unimplemented SDL_CreateRGBSurfaceFrom called!');
        return surf;
      }
  
      var data = SDL.surfaces[surf];
      var image = data.ctx.createImageData(width, height);
      var pitchOfDst = width * 4;
  
      for (var row = 0; row < height; ++row) {
        var baseOfSrc = row * pitch;
        var baseOfDst = row * pitchOfDst;
  
        for (var col = 0; col < width * 4; ++col) {
          image.data[baseOfDst + col] = HEAPU8[(((pixels)+(baseOfDst + col))>>0)];
        }
      }
  
      data.ctx.putImageData(image, 0, 0);
  
      return surf;
    }


  function _SDL_ConvertSurface(surf, format, flags) {
      if  (format) {
        SDL.checkPixelFormat(format);
      }
  
      var oldData = SDL.surfaces[surf];
      var ret = SDL.makeSurface(oldData.width, oldData.height, oldData.flags, false, 'copy:' + oldData.source);
      var newData = SDL.surfaces[ret];
  
      newData.ctx.globalCompositeOperation = "copy";
      newData.ctx.drawImage(oldData.canvas, 0, 0);
      newData.ctx.globalCompositeOperation = oldData.ctx.globalCompositeOperation;
      return ret;
    }

  function _SDL_DisplayFormatAlpha(surf) {
      return _SDL_ConvertSurface(surf);
    }


  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }


  function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, false);
    }


  function _SDL_UpperBlitScaled(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, true);
    }

  function _SDL_LowerBlit() {
  return _SDL_UpperBlit.apply(null, arguments)
  }

  function _SDL_LowerBlitScaled() {
  return _SDL_UpperBlitScaled.apply(null, arguments)
  }


  function _SDL_GetClipRect(surf, rect) {
      assert(rect);
  
      var surfData = SDL.surfaces[surf];
      var r = surfData.clipRect || { x: 0, y: 0, w: surfData.width, h: surfData.height };
      SDL.updateRect(rect, r);
    }


  function _SDL_SetClipRect(surf, rect) {
      var surfData = SDL.surfaces[surf];
  
      if (rect) {
        surfData.clipRect = SDL.intersectionOfRects({ x: 0, y: 0, w: surfData.width, h: surfData.height }, SDL.loadRect(rect));
      } else {
        delete surfData.clipRect;
      }
    }


  function _SDL_FillRect(surf, rect, color) {
      var surfData = SDL.surfaces[surf];
      assert(!surfData.locked); // but we could unlock and re-lock if we must..
  
      if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
        //in SDL_HWPALETTE color is index (0..255)
        //so we should translate 1 byte value to
        //32 bit canvas
        color = surfData.colors32[color];
      }
  
      var r = rect ? SDL.loadRect(rect) : { x: 0, y: 0, w: surfData.width, h: surfData.height };
  
      if (surfData.clipRect) {
        r = SDL.intersectionOfRects(surfData.clipRect, r);
  
        if (rect) {
          SDL.updateRect(rect, r);
        }
      }
  
      surfData.ctx.save();
      surfData.ctx.fillStyle = SDL.translateColorToCSSRGBA(color);
      surfData.ctx.fillRect(r.x, r.y, r.w, r.h);
      surfData.ctx.restore();
      return 0;
    }


  function _SDL_BlitSurface(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, false);
    }


  function _SDL_BlitScaled(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, true);
    }

  function _zoomSurface(src, x, y, smooth) {
      var srcData = SDL.surfaces[src];
      var w = srcData.width * x;
      var h = srcData.height * y;
      var ret = SDL.makeSurface(Math.abs(w), Math.abs(h), srcData.flags, false, 'zoomSurface');
      var dstData = SDL.surfaces[ret];
      if (x >= 0 && y >= 0) dstData.ctx.drawImage(srcData.canvas, 0, 0, w, h);
      else {
        dstData.ctx.save();
        dstData.ctx.scale(x < 0 ? -1 : 1, y < 0 ? -1 : 1);
        dstData.ctx.drawImage(srcData.canvas, w < 0 ? w : 0, h < 0 ? h : 0, Math.abs(w), Math.abs(h));
        // XXX I think this should work according to the spec, but currently
        // fails on FF: dstData.ctx.drawImage(srcData.canvas, 0, 0, w, h);
        dstData.ctx.restore();
      }
      return ret;
    }

  function _rotozoomSurface(src, angle, zoom, smooth) {
      if (angle % 360 === 0) {
        return _zoomSurface(src, zoom, zoom, smooth);
      }
      var srcData = SDL.surfaces[src];
      var w = srcData.width * zoom;
      var h = srcData.height * zoom;
      var diagonal = Math.ceil(Math.sqrt(Math.pow(w, 2) + Math.pow(h, 2)));
      var ret = SDL.makeSurface(diagonal, diagonal, srcData.flags, false, 'rotozoomSurface');
      var dstData = SDL.surfaces[ret];
      dstData.ctx.translate(diagonal / 2, diagonal / 2);
      dstData.ctx.rotate(-angle * Math.PI / 180);
      dstData.ctx.drawImage(srcData.canvas, -w / 2, -h / 2, w, h);
      return ret;
    }


  function _SDL_SetAlpha(surf, flag, alpha) {
      var surfData = SDL.surfaces[surf];
      surfData.alpha = alpha;
  
      if (!(flag & 0x00010000)) { // !SDL_SRCALPHA
        surfData.alpha = 255;
      }
    }

  function _SDL_SetColorKey(surf, flag, key) {
      // SetColorKey assigns one color to be rendered as transparent. I don't
      // think the canvas API allows for anything like this, and iterating through
      // each pixel to replace that color seems prohibitively expensive.
      warnOnce('SDL_SetColorKey is a no-op for performance reasons');
      return 0;
    }




  function _SDL_PollEvent(ptr) {
      return SDL.pollEvent(ptr);
    }


  function _SDL_PushEvent(ptr) {
      var copy = _malloc(28);
      _memcpy(copy, ptr, 28);
      SDL.events.push(copy);
      return 0;
    }


  function _SDL_PeepEvents(events, requestedEventCount, action, from, to) {
      switch(action) {
        case 2: { // SDL_GETEVENT
          // We only handle 1 event right now
          assert(requestedEventCount == 1);
  
          var index = 0;
          var retrievedEventCount = 0;
          // this should look through the entire queue until it has filled up the events
          // array
          while (index < SDL.events.length && retrievedEventCount < requestedEventCount) {
            var event = SDL.events[index];
            var type = SDL.DOMEventToSDLEvent[event.type];
            if (from <= type && type <= to) {
              if (SDL.makeCEvent(event, events) === false) {
                index++;
              } else {
                SDL.events.splice(index, 1);
                retrievedEventCount++;
              }
            } else {
              index++;
            }
          }
          return retrievedEventCount;
        }
        default: throw 'SDL_PeepEvents does not yet support that action: ' + action;
      }
    }


  function _SDL_PumpEvents(){
      SDL.events.forEach(function(event) {
        SDL.handleEvent(event);
      });
    }


  function _emscripten_SDL_SetEventHandler(handler, userdata) {
      SDL.eventHandler = handler;
      SDL.eventHandlerContext = userdata;
  
      // All SDLEvents take the same amount of memory
      if (!SDL.eventHandlerTemp) SDL.eventHandlerTemp = _malloc(28);
    }


  function _SDL_SetColors(surf, colors, firstColor, nColors) {
      var surfData = SDL.surfaces[surf];
  
      // we should create colors array
      // only once cause client code
      // often wants to change portion
      // of palette not all palette.
      if (!surfData.colors) {
        var buffer = new ArrayBuffer(256 * 4); // RGBA, A is unused, but faster this way
        surfData.colors = new Uint8Array(buffer);
        surfData.colors32 = new Uint32Array(buffer);
      }
  
      for (var i = 0; i < nColors; ++i) {
        var index = (firstColor + i) * 4;
        surfData.colors[index] = HEAPU8[(((colors)+(i*4))>>0)];
        surfData.colors[index + 1] = HEAPU8[(((colors)+(i*4 + 1))>>0)];
        surfData.colors[index + 2] = HEAPU8[(((colors)+(i*4 + 2))>>0)];
        surfData.colors[index + 3] = 255; // opaque
      }
  
      return 1;
    }

  function _SDL_SetPalette(surf, flags, colors, firstColor, nColors) {
      return _SDL_SetColors(surf, colors, firstColor, nColors);
    }


  function _SDL_MapRGB(fmt, r, g, b) {
      SDL.checkPixelFormat(fmt);
      // We assume the machine is little-endian.
      return r&0xff|(g&0xff)<<8|(b&0xff)<<16|0xff000000;
    }


  function _SDL_MapRGBA(fmt, r, g, b, a) {
      SDL.checkPixelFormat(fmt);
      // We assume the machine is little-endian.
      return r&0xff|(g&0xff)<<8|(b&0xff)<<16|(a&0xff)<<24;
    }


  function _SDL_GetRGB(pixel, fmt, r, g, b) {
      SDL.checkPixelFormat(fmt);
      // We assume the machine is little-endian.
      if (r) {
        HEAP8[((r)>>0)]=pixel&0xff;
      }
      if (g) {
        HEAP8[((g)>>0)]=(pixel>>8)&0xff;
      }
      if (b) {
        HEAP8[((b)>>0)]=(pixel>>16)&0xff;
      }
    }


  function _SDL_GetRGBA(pixel, fmt, r, g, b, a) {
      SDL.checkPixelFormat(fmt);
      // We assume the machine is little-endian.
      if (r) {
        HEAP8[((r)>>0)]=pixel&0xff;
      }
      if (g) {
        HEAP8[((g)>>0)]=(pixel>>8)&0xff;
      }
      if (b) {
        HEAP8[((b)>>0)]=(pixel>>16)&0xff;
      }
      if (a) {
        HEAP8[((a)>>0)]=(pixel>>24)&0xff;
      }
    }


  function _SDL_GetAppState() {
      var state = 0;
  
      if (Browser.pointerLock) {
        state |= 0x01;  // SDL_APPMOUSEFOCUS
      }
      if (document.hasFocus()) {
        state |= 0x02;  // SDL_APPINPUTFOCUS
      }
      state |= 0x04;  // SDL_APPACTIVE
  
      return state;
    }

  function _SDL_WM_GrabInput() {}


  function _SDL_WM_ToggleFullScreen(surf) {
      if (Browser.isFullscreen) {
        Module['canvas'].exitFullscreen();
        return 1;
      } else {
        if (!SDL.canRequestFullscreen) {
          return 0;
        }
        SDL.isRequestingFullscreen = true;
        return 1;
      }
    }

  function _IMG_Init(flags) {
      return flags; // We support JPG, PNG, TIF because browsers do
    }


  
  function _SDL_FreeRW(rwopsID) {
      SDL.rwops[rwopsID] = null;
      while (SDL.rwops.length > 0 && SDL.rwops[SDL.rwops.length-1] === null) {
        SDL.rwops.pop();
      }
    }function _IMG_Load_RW(rwopsID, freeSrc) {
      try {
        // stb_image integration support
        var cleanup = function() {
          if (rwops && freeSrc) _SDL_FreeRW(rwopsID);
        }
        var addCleanup = function(func) {
          var old = cleanup;
          cleanup = function added_cleanup() {
            old();
            func();
          }
        }
        var callStbImage = function(func, params) {
          var x = Module['_malloc'](4);
          var y = Module['_malloc'](4);
          var comp = Module['_malloc'](4);
          addCleanup(function() {
            Module['_free'](x);
            Module['_free'](y);
            Module['_free'](comp);
            if (data) Module['_stbi_image_free'](data);
          });
          var data = Module['_' + func].apply(null, params.concat([x, y, comp, 0]));
          if (!data) return null;
          return {
            rawData: true,
            data: data,
            width: HEAP32[((x)>>2)],
            height: HEAP32[((y)>>2)],
            size: HEAP32[((x)>>2)] * HEAP32[((y)>>2)] * HEAP32[((comp)>>2)],
            bpp: HEAP32[((comp)>>2)]
          };
        }
  
        var rwops = SDL.rwops[rwopsID];
        if (rwops === undefined) {
          return 0;
        }
  
        var filename = rwops.filename;
        if (filename === undefined) {
          warnOnce('Only file names that have been preloaded are supported for IMG_Load_RW. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins');
          return 0;
        }
  
        if (!raw) {
          filename = PATH.resolve(filename);
          var raw = Module["preloadedImages"][filename];
          if (!raw) {
            if (raw === null) err('Trying to reuse preloaded image, but freePreloadedMediaOnUse is set!');
            warnOnce('Cannot find preloaded image ' + filename);
            warnOnce('Cannot find preloaded image ' + filename + '. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins');
            return 0;
          } else if (Module['freePreloadedMediaOnUse']) {
            Module["preloadedImages"][filename] = null;
          }
        }
  
        var surf = SDL.makeSurface(raw.width, raw.height, 0, false, 'load:' + filename);
        var surfData = SDL.surfaces[surf];
        surfData.ctx.globalCompositeOperation = "copy";
        if (!raw.rawData) {
          surfData.ctx.drawImage(raw, 0, 0, raw.width, raw.height, 0, 0, raw.width, raw.height);
        } else {
          var imageData = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
          if (raw.bpp == 4) {
            // rgba
            imageData.data.set(HEAPU8.subarray((raw.data),(raw.data+raw.size)));
          } else if (raw.bpp == 3) {
            // rgb
            var pixels = raw.size/3;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = 255;
            }
          } else if (raw.bpp == 2) {
            // grayscale + alpha
            var pixels = raw.size;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              var gray = HEAPU8[((sourcePtr++)>>0)];
              var alpha = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = gray;
              data[destPtr++] = gray;
              data[destPtr++] = gray;
              data[destPtr++] = alpha;
            }
          } else if (raw.bpp == 1) {
            // grayscale
            var pixels = raw.size;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              var value = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = 255;
            }
          } else {
            err('cannot handle bpp ' + raw.bpp);
            return 0;
          }
          surfData.ctx.putImageData(imageData, 0, 0);
        }
        surfData.ctx.globalCompositeOperation = "source-over";
        // XXX SDL does not specify that loaded images must have available pixel data, in fact
        //     there are cases where you just want to blit them, so you just need the hardware
        //     accelerated version. However, code everywhere seems to assume that the pixels
        //     are in fact available, so we retrieve it here. This does add overhead though.
        _SDL_LockSurface(surf);
        surfData.locked--; // The surface is not actually locked in this hack
        if (SDL.GL) {
          // After getting the pixel data, we can free the canvas and context if we do not need to do 2D canvas blitting
          surfData.canvas = surfData.ctx = null;
        }
        return surf;
      } finally {
        cleanup();
      }
    }

  
  
  function _SDL_RWFromFile(_name, mode) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      var name = Pointer_stringify(_name)
      SDL.rwops.push({ filename: name, mimetype: Browser.getMimetype(name) });
      return id;
    }function _IMG_Load(filename){
      var rwops = _SDL_RWFromFile(filename);
      var result = _IMG_Load_RW(rwops, 1);
      return result;
    }function _SDL_LoadBMP() {
  return _IMG_Load.apply(null, arguments)
  }

  function _SDL_LoadBMP_RW() {
  return _IMG_Load_RW.apply(null, arguments)
  }



  function _IMG_Quit() {
      out('IMG_Quit called (and ignored)');
    }


  function _SDL_OpenAudio(desired, obtained) {
      try {
        SDL.audio = {
          freq: HEAPU32[((desired)>>2)],
          format: HEAPU16[(((desired)+(4))>>1)],
          channels: HEAPU8[(((desired)+(6))>>0)],
          samples: HEAPU16[(((desired)+(8))>>1)], // Samples in the CB buffer per single sound channel.
          callback: HEAPU32[(((desired)+(16))>>2)],
          userdata: HEAPU32[(((desired)+(20))>>2)],
          paused: true,
          timer: null
        };
        // The .silence field tells the constant sample value that corresponds to the safe un-skewed silence value for the wave data.
        if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
          SDL.audio.silence = 128; // Audio ranges in [0, 255], so silence is half-way in between.
        } else if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
          SDL.audio.silence = 0; // Signed data in range [-32768, 32767], silence is 0.
        } else if (SDL.audio.format == 0x8120 /*AUDIO_F32*/) {
          SDL.audio.silence = 0.0; // Float data in range [-1.0, 1.0], silence is 0.0
        } else {
          throw 'Invalid SDL audio format ' + SDL.audio.format + '!';
        }
        // Round the desired audio frequency up to the next 'common' frequency value.
        // Web Audio API spec states 'An implementation must support sample-rates in at least the range 22050 to 96000.'
        if (SDL.audio.freq <= 0) {
          throw 'Unsupported sound frequency ' + SDL.audio.freq + '!';
        } else if (SDL.audio.freq <= 22050) {
          SDL.audio.freq = 22050; // Take it safe and clamp everything lower than 22kHz to that.
        } else if (SDL.audio.freq <= 32000) {
          SDL.audio.freq = 32000;
        } else if (SDL.audio.freq <= 44100) {
          SDL.audio.freq = 44100;
        } else if (SDL.audio.freq <= 48000) {
          SDL.audio.freq = 48000;
        } else if (SDL.audio.freq <= 96000) {
          SDL.audio.freq = 96000;
        } else {
          throw 'Unsupported sound frequency ' + SDL.audio.freq + '!';
        }
        if (SDL.audio.channels == 0) {
          SDL.audio.channels = 1; // In SDL both 0 and 1 mean mono.
        } else if (SDL.audio.channels < 0 || SDL.audio.channels > 32) {
          throw 'Unsupported number of audio channels for SDL audio: ' + SDL.audio.channels + '!';
        } else if (SDL.audio.channels != 1 && SDL.audio.channels != 2) { // Unsure what SDL audio spec supports. Web Audio spec supports up to 32 channels.
          console.log('Warning: Using untested number of audio channels ' + SDL.audio.channels);
        }
        if (SDL.audio.samples < 128 || SDL.audio.samples > 524288 /* arbitrary cap */) {
          throw 'Unsupported audio callback buffer size ' + SDL.audio.samples + '!';
        } else if ((SDL.audio.samples & (SDL.audio.samples-1)) != 0) {
          throw 'Audio callback buffer size ' + SDL.audio.samples + ' must be a power-of-two!';
        }
  
        var totalSamples = SDL.audio.samples*SDL.audio.channels;
        if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
          SDL.audio.bytesPerSample = 1;
        } else if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
          SDL.audio.bytesPerSample = 2;
        } else if (SDL.audio.format == 0x8120 /*AUDIO_F32*/) {
          SDL.audio.bytesPerSample = 4;
        } else {
          throw 'Invalid SDL audio format ' + SDL.audio.format + '!';
        }
        SDL.audio.bufferSize = totalSamples*SDL.audio.bytesPerSample;
        SDL.audio.bufferDurationSecs = SDL.audio.bufferSize / SDL.audio.bytesPerSample / SDL.audio.channels / SDL.audio.freq; // Duration of a single queued buffer in seconds.
        SDL.audio.bufferingDelay = 50 / 1000; // Audio samples are played with a constant delay of this many seconds to account for browser and jitter.
        SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
  
        // To account for jittering in frametimes, always have multiple audio buffers queued up for the audio output device.
        // This helps that we won't starve that easily if a frame takes long to complete.
        SDL.audio.numSimultaneouslyQueuedBuffers = Module['SDL_numSimultaneouslyQueuedBuffers'] || 5;
  
        // Pulls and queues new audio data if appropriate. This function gets "over-called" in both requestAnimationFrames and
        // setTimeouts to ensure that we get the finest granularity possible and as many chances from the browser to fill
        // new audio data. This is because setTimeouts alone have very poor granularity for audio streaming purposes, but also
        // the application might not be using emscripten_set_main_loop to drive the main loop, so we cannot rely on that alone.
        SDL.audio.queueNewAudioData = function SDL_queueNewAudioData() {
          if (!SDL.audio) return;
  
          for(var i = 0; i < SDL.audio.numSimultaneouslyQueuedBuffers; ++i) {
            // Only queue new data if we don't have enough audio data already in queue. Otherwise skip this time slot
            // and wait to queue more in the next time the callback is run.
            var secsUntilNextPlayStart = SDL.audio.nextPlayTime - SDL.audioContext['currentTime'];
            if (secsUntilNextPlayStart >= SDL.audio.bufferingDelay + SDL.audio.bufferDurationSecs*SDL.audio.numSimultaneouslyQueuedBuffers) return;
  
            // Ask SDL audio data from the user code.
            Module['dynCall_viii'](SDL.audio.callback, SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize);
            // And queue it to be played after the currently playing audio stream.
            SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
          }
        }
  
  
        // Create a callback function that will be routinely called to ask more audio data from the user application.
        SDL.audio.caller = function SDL_audioCaller() {
          if (!SDL.audio) return;
  
          --SDL.audio.numAudioTimersPending;
  
          SDL.audio.queueNewAudioData();
  
          // Queue this callback function to be called again later to pull more audio data.
          var secsUntilNextPlayStart = SDL.audio.nextPlayTime - SDL.audioContext['currentTime'];
  
          // Queue the next audio frame push to be performed half-way when the previously queued buffer has finished playing.
          var preemptBufferFeedSecs = SDL.audio.bufferDurationSecs/2.0;
  
          if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
            ++SDL.audio.numAudioTimersPending;
            SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, Math.max(0.0, 1000.0*(secsUntilNextPlayStart-preemptBufferFeedSecs)));
  
            // If we are risking starving, immediately queue an extra buffer.
            if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
              ++SDL.audio.numAudioTimersPending;
              Browser.safeSetTimeout(SDL.audio.caller, 1.0);
            }
          }
        };
  
        SDL.audio.audioOutput = new Audio();
  
        // Initialize Web Audio API if we haven't done so yet. Note: Only initialize Web Audio context ever once on the web page,
        // since initializing multiple times fails on Chrome saying 'audio resources have been exhausted'.
        SDL.openAudioContext();
        if (!SDL.audioContext) throw 'Web Audio API is not available!';
        SDL.audio.nextPlayTime = 0; // Time in seconds when the next audio block is due to start.
  
        // The pushAudio function with a new audio buffer whenever there is new audio data to schedule to be played back on the device.
        SDL.audio.pushAudio=function(ptr,sizeBytes) {
          try {
            if (SDL.audio.paused) return;
  
            var sizeSamples = sizeBytes / SDL.audio.bytesPerSample; // How many samples fit in the callback buffer?
            var sizeSamplesPerChannel = sizeSamples / SDL.audio.channels; // How many samples per a single channel fit in the cb buffer?
            if (sizeSamplesPerChannel != SDL.audio.samples) {
              throw 'Received mismatching audio buffer size!';
            }
            // Allocate new sound buffer to be played.
            var source = SDL.audioContext['createBufferSource']();
            var soundBuffer = SDL.audioContext['createBuffer'](SDL.audio.channels,sizeSamplesPerChannel,SDL.audio.freq);
            source['connect'](SDL.audioContext['destination']);
  
            SDL.fillWebAudioBufferFromHeap(ptr, sizeSamplesPerChannel, soundBuffer);
            // Workaround https://bugzilla.mozilla.org/show_bug.cgi?id=883675 by setting the buffer only after filling. The order is important here!
            source['buffer'] = soundBuffer;
  
            // Schedule the generated sample buffer to be played out at the correct time right after the previously scheduled
            // sample buffer has finished.
            var curtime = SDL.audioContext['currentTime'];
            if (curtime > SDL.audio.nextPlayTime && SDL.audio.nextPlayTime != 0) {
              console.log('warning: Audio callback had starved sending audio by ' + (curtime - SDL.audio.nextPlayTime) + ' seconds.');
            }
            // Don't ever start buffer playbacks earlier from current time than a given constant 'SDL.audio.bufferingDelay', since a browser
            // may not be able to mix that audio clip in immediately, and there may be subsequent jitter that might cause the stream to starve.
            var playtime = Math.max(curtime + SDL.audio.bufferingDelay, SDL.audio.nextPlayTime);
            if (typeof source['start'] !== 'undefined') {
              source['start'](playtime); // New Web Audio API: sound sources are started with a .start() call.
            } else if (typeof source['noteOn'] !== 'undefined') {
              source['noteOn'](playtime); // Support old Web Audio API specification which had the .noteOn() API.
            }
            /*
            // Uncomment to debug SDL buffer feed starves.
            if (SDL.audio.curBufferEnd) {
              var thisBufferStart = Math.round(playtime * SDL.audio.freq);
              if (thisBufferStart != SDL.audio.curBufferEnd) console.log('SDL starved ' + (thisBufferStart - SDL.audio.curBufferEnd) + ' samples!');
            }
            SDL.audio.curBufferEnd = Math.round(playtime * SDL.audio.freq + sizeSamplesPerChannel);
            */
  
            SDL.audio.nextPlayTime = playtime + SDL.audio.bufferDurationSecs;
          } catch(e) {
            console.log('Web Audio API error playing back audio: ' + e.toString());
          }
        }
  
        if (obtained) {
          // Report back the initialized audio parameters.
          HEAP32[((obtained)>>2)]=SDL.audio.freq;
          HEAP16[(((obtained)+(4))>>1)]=SDL.audio.format;
          HEAP8[(((obtained)+(6))>>0)]=SDL.audio.channels;
          HEAP8[(((obtained)+(7))>>0)]=SDL.audio.silence;
          HEAP16[(((obtained)+(8))>>1)]=SDL.audio.samples;
          HEAP32[(((obtained)+(16))>>2)]=SDL.audio.callback;
          HEAP32[(((obtained)+(20))>>2)]=SDL.audio.userdata;
        }
        SDL.allocateChannels(32);
  
      } catch(e) {
        console.log('Initializing SDL audio threw an exception: "' + e.toString() + '"! Continuing without audio.');
        SDL.audio = null;
        SDL.allocateChannels(0);
        if (obtained) {
          HEAP32[((obtained)>>2)]=0;
          HEAP16[(((obtained)+(4))>>1)]=0;
          HEAP8[(((obtained)+(6))>>0)]=0;
          HEAP8[(((obtained)+(7))>>0)]=0;
          HEAP16[(((obtained)+(8))>>1)]=0;
          HEAP32[(((obtained)+(16))>>2)]=0;
          HEAP32[(((obtained)+(20))>>2)]=0;
        }
      }
      if (!SDL.audio) {
        return -1;
      }
      return 0;
    }


  function _SDL_PauseAudio(pauseOn) {
      if (!SDL.audio) {
        return;
      }
      if (pauseOn) {
        if (SDL.audio.timer !== undefined) {
          clearTimeout(SDL.audio.timer);
          SDL.audio.numAudioTimersPending = 0;
          SDL.audio.timer = undefined;
        }
      } else if (!SDL.audio.timer) {
        // Start the audio playback timer callback loop.
        SDL.audio.numAudioTimersPending = 1;
        SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1);
      }
      SDL.audio.paused = pauseOn;
    }


  function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
        SDL.allocateChannels(0);
      }
    }

  function _SDL_LockAudio() {}

  function _SDL_UnlockAudio() {}

  function _SDL_CreateMutex() { return 0 }

  function _SDL_LockMutex() {}

  function _SDL_UnlockMutex() {}

  function _SDL_mutexP() { return 0 }

  function _SDL_mutexV() { return 0 }

  function _SDL_DestroyMutex() {}

  function _SDL_CreateCond() { return 0 }

  function _SDL_CondSignal() {}

  function _SDL_CondWait() {}

  function _SDL_DestroyCond() {}


  function _SDL_StartTextInput() {
      SDL.textInput = true;
    }


  function _SDL_StopTextInput() {
      SDL.textInput = false;
    }

  function _Mix_Init(flags) {
      if (!flags) return 0;
      return 8; /* MIX_INIT_OGG */
    }

  function _Mix_Quit(){}


  function _Mix_OpenAudio(frequency, format, channels, chunksize) {
      SDL.openAudioContext();
      SDL.allocateChannels(32);
      // Just record the values for a later call to Mix_QuickLoad_RAW
      SDL.mixerFrequency = frequency;
      SDL.mixerFormat = format;
      SDL.mixerNumChannels = channels;
      SDL.mixerChunkSize = chunksize;
      return 0;
    }

  function _Mix_CloseAudio() {
  return _SDL_CloseAudio.apply(null, arguments)
  }


  function _Mix_AllocateChannels(num) {
      SDL.allocateChannels(num);
      return num;
    }


  function _Mix_ChannelFinished(func) {
      SDL.channelFinished = func;
    }


  function _Mix_Volume(channel, volume) {
      if (channel == -1) {
        for (var i = 0; i < SDL.numChannels-1; i++) {
          _Mix_Volume(i, volume);
        }
        return _Mix_Volume(SDL.numChannels-1, volume);
      }
      return SDL.setGetVolume(SDL.channels[channel], volume);
    }


  function _Mix_SetPanning(channel, left, right) {
      // SDL API uses [0-255], while PannerNode has an (x, y, z) position.
  
      // Normalizing.
      left /= 255;
      right /= 255;
  
      // Set the z coordinate a little forward, otherwise there won't be any
      // smooth transition between left and right.
      SDL.setPannerPosition(SDL.channels[channel], right - left, 0, 0.1);
      return 1;
    }


  function _Mix_LoadWAV_RW(rwopsID, freesrc) {
      var rwops = SDL.rwops[rwopsID];
  
  
      if (rwops === undefined)
        return 0;
  
      var filename = '';
      var audio;
      var webAudio;
      var bytes;
  
      if (rwops.filename !== undefined) {
        filename = PATH.resolve(rwops.filename);
        var raw = Module["preloadedAudios"][filename];
        if (!raw) {
          if (raw === null) err('Trying to reuse preloaded audio, but freePreloadedMediaOnUse is set!');
          if (!Module.noAudioDecoding) warnOnce('Cannot find preloaded audio ' + filename);
  
          // see if we can read the file-contents from the in-memory FS
          try {
            bytes = FS.readFile(filename);
          } catch (e) {
            err('Couldn\'t find file for: ' + filename);
            return 0;
          }
        }
        if (Module['freePreloadedMediaOnUse']) {
          Module["preloadedAudios"][filename] = null;
        }
        audio = raw;
      }
      else if (rwops.bytes !== undefined) {
        // For Web Audio context buffer decoding, we must make a clone of the audio data, but for <media> element,
        // a view to existing data is sufficient.
        if (SDL.webAudioAvailable()) bytes = HEAPU8.buffer.slice(rwops.bytes, rwops.bytes + rwops.count);
        else bytes = HEAPU8.subarray(rwops.bytes, rwops.bytes + rwops.count);
      }
      else {
        return 0;
      }
  
      var arrayBuffer = bytes ? bytes.buffer || bytes : bytes;
  
      // To allow user code to work around browser bugs with audio playback on <audio> elements an Web Audio, enable
      // the user code to hook in a callback to decide on a file basis whether each file should use Web Audio or <audio> for decoding and playback.
      // In particular, see https://bugzilla.mozilla.org/show_bug.cgi?id=654787 and ?id=1012801 for tradeoffs.
      var canPlayWithWebAudio = Module['SDL_canPlayWithWebAudio'] === undefined || Module['SDL_canPlayWithWebAudio'](filename, arrayBuffer);
  
      if (bytes !== undefined && SDL.webAudioAvailable() && canPlayWithWebAudio) {
        audio = undefined;
        webAudio = {};
        // The audio decoding process is asynchronous, which gives trouble if user code plays the audio data back immediately
        // after loading. Therefore prepare an array of callback handlers to run when this audio decoding is complete, which
        // will then start the playback (with some delay).
        webAudio.onDecodeComplete = []; // While this member array exists, decoding hasn't finished yet.
        function onDecodeComplete(data) {
          webAudio.decodedBuffer = data;
          // Call all handlers that were waiting for this decode to finish, and clear the handler list.
          webAudio.onDecodeComplete.forEach(function(e) { e(); });
          webAudio.onDecodeComplete = undefined; // Don't allow more callback handlers since audio has finished decoding.
        }
  
        SDL.audioContext['decodeAudioData'](arrayBuffer, onDecodeComplete);
      } else if (audio === undefined && bytes) {
        // Here, we didn't find a preloaded audio but we either were passed a filepath for
        // which we loaded bytes, or we were passed some bytes
        var blob = new Blob([bytes], {type: rwops.mimetype});
        var url = URL.createObjectURL(blob);
        audio = new Audio();
        audio.src = url;
        audio.mozAudioChannelType = 'content'; // bugzilla 910340
      }
  
      var id = SDL.audios.length;
      // Keep the loaded audio in the audio arrays, ready for playback
      SDL.audios.push({
        source: filename,
        audio: audio, // Points to the <audio> element, if loaded
        webAudio: webAudio // Points to a Web Audio -specific resource object, if loaded
      });
      return id;
    }


  function _Mix_LoadWAV(filename) {
      var rwops = _SDL_RWFromFile(filename);
      var result = _Mix_LoadWAV_RW(rwops);
      _SDL_FreeRW(rwops);
      return result;
    }


  function _Mix_QuickLoad_RAW(mem, len) {
      var audio;
      var webAudio;
  
      var numSamples = len >> 1; // len is the length in bytes, and the array contains 16-bit PCM values
      var buffer = new Float32Array(numSamples);
      for (var i = 0; i < numSamples; ++i) {
        buffer[i] = (HEAP16[(((mem)+(i*2))>>1)]) / 0x8000; // hardcoded 16-bit audio, signed (TODO: reSign if not ta2?)
      }
  
      if (SDL.webAudioAvailable()) {
        webAudio = {};
        webAudio.decodedBuffer = buffer;
      } else {
        var audio = new Audio();
        audio.mozAudioChannelType = 'content'; // bugzilla 910340
        // Record the number of channels and frequency for later usage
        audio.numChannels = SDL.mixerNumChannels;
        audio.frequency = SDL.mixerFrequency;
        // FIXME: doesn't make sense to keep the audio element in the buffer
      }
  
      var id = SDL.audios.length;
      SDL.audios.push({
        source: '',
        audio: audio,
        webAudio: webAudio,
        buffer: buffer
      });
      return id;
    }


  function _Mix_FreeChunk(id) {
      SDL.audios[id] = null;
    }


  function _Mix_ReserveChannels(num) {
      SDL.channelMinimumNumber = num;
    }


  function _Mix_PlayChannel(channel, id, loops) {
      // TODO: handle fixed amount of N loops. Currently loops either 0 or infinite times.
  
      // Get the audio element associated with the ID
      var info = SDL.audios[id];
      if (!info) return -1;
      if (!info.audio && !info.webAudio) return -1;
  
      // If the user asks us to allocate a channel automatically, get the first
      // free one.
      if (channel == -1) {
        for (var i = SDL.channelMinimumNumber; i < SDL.numChannels; i++) {
          if (!SDL.channels[i].audio) {
            channel = i;
            break;
          }
        }
        if (channel == -1) {
          err('All ' + SDL.numChannels + ' channels in use!');
          return -1;
        }
      }
      var channelInfo = SDL.channels[channel];
      var audio;
      if (info.webAudio) {
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        // Make our instance look similar to the instance of a <media> to make api simple.
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else {
        // We clone the audio node to utilize the preloaded audio buffer, since
        // the browser has already preloaded the audio file.
        audio = info.audio.cloneNode(true);
        audio.numChannels = info.audio.numChannels;
        audio.frequency = info.audio.frequency;
      }
      audio['onended'] = function SDL_audio_onended() { // TODO: cache these
        if (channelInfo.audio == this) { channelInfo.audio.paused = true; channelInfo.audio = null; }
        if (SDL.channelFinished) getFuncWrapper(SDL.channelFinished, 'vi')(channel);
      }
      channelInfo.audio = audio;
      // TODO: handle N loops. Behavior matches Mix_PlayMusic
      audio.loop = loops != 0;
      audio.volume = channelInfo.volume;
      audio.play();
      return channel;
    }

  function _Mix_PlayChannelTimed() {
  return _Mix_PlayChannel.apply(null, arguments)
  }

  function _Mix_FadingChannel(channel) {
      return 0; // MIX_NO_FADING, TODO
    }


  function _Mix_HaltChannel(channel) {
      function halt(channel) {
        var info = SDL.channels[channel];
        if (info.audio) {
          info.audio.pause();
          info.audio = null;
        }
        if (SDL.channelFinished) {
          getFuncWrapper(SDL.channelFinished, 'vi')(channel);
        }
      }
      if (channel != -1) {
        halt(channel);
      } else {
        for (var i = 0; i < SDL.channels.length; ++i) halt(i);
      }
      return 0;
    }


  
  function _Mix_HaltMusic() {
      var audio = SDL.music.audio;
      if (audio) {
        audio.src = audio.src; // rewind <media> element
        audio.currentPosition = 0; // rewind Web Audio graph playback.
        audio.pause();
      }
      SDL.music.audio = null;
      if (SDL.hookMusicFinished) {
        Module['dynCall_v'](SDL.hookMusicFinished);
      }
      return 0;
    }function _Mix_HookMusicFinished(func) {
      SDL.hookMusicFinished = func;
      if (SDL.music.audio) { // ensure the callback will be called, if a music is already playing
        SDL.music.audio['onended'] = _Mix_HaltMusic;
      }
    }


  function _Mix_VolumeMusic(volume) {
      return SDL.setGetVolume(SDL.music, volume);
    }

  function _Mix_LoadMUS_RW() {
  return _Mix_LoadWAV_RW.apply(null, arguments)
  }


  function _Mix_LoadMUS(filename) {
      var rwops = _SDL_RWFromFile(filename);
      var result = _Mix_LoadMUS_RW(rwops);
      _SDL_FreeRW(rwops);
      return result;
    }

  function _Mix_FreeMusic() {
  return _Mix_FreeChunk.apply(null, arguments)
  }


  function _Mix_PlayMusic(id, loops) {
      // Pause old music if it exists.
      if (SDL.music.audio) {
        if (!SDL.music.audio.paused) err('Music is already playing. ' + SDL.music.source);
        SDL.music.audio.pause();
      }
      var info = SDL.audios[id];
      var audio;
      if (info.webAudio) { // Play via Web Audio API
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new webAudio object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else if (info.audio) { // Play via the <audio> element
        audio = info.audio;
      }
      audio['onended'] = function() { if (SDL.music.audio == this) _Mix_HaltMusic(); } // will send callback
      audio.loop = loops != 0; // TODO: handle N loops for finite N
      audio.volume = SDL.music.volume;
      SDL.music.audio = audio;
      audio.play();
      return 0;
    }


  function _Mix_PauseMusic() {
      var audio = SDL.music.audio;
      if (audio) audio.pause();
    }


  function _Mix_ResumeMusic() {
      var audio = SDL.music.audio;
      if (audio) audio.play();
    }



  function _Mix_FadeInMusicPos() {
  return _Mix_PlayMusic.apply(null, arguments)
  }

  function _Mix_FadeOutMusic() {
  return _Mix_HaltMusic.apply(null, arguments)
  }


  function _Mix_PlayingMusic() {
      return (SDL.music.audio && !SDL.music.audio.paused) ? 1 : 0;
    }


  function _Mix_Playing(channel) {
      if (channel === -1) {
        var count = 0;
        for (var i = 0; i < SDL.channels.length; i++) {
          count += _Mix_Playing(i);
        }
        return count;
      }
      var info = SDL.channels[channel];
      if (info && info.audio && !info.audio.paused) {
        return 1;
      }
      return 0;
    }


  function _Mix_Pause(channel) {
      if (channel === -1) {
        for (var i = 0; i<SDL.channels.length;i++) {
          _Mix_Pause(i);
        }
        return;
      }
      var info = SDL.channels[channel];
      if (info && info.audio) {
        info.audio.pause();
      } else {
        //err('Mix_Pause: no sound found for channel: ' + channel);
      }
    }


  function _Mix_Paused(channel) {
      if (channel === -1) {
        var pausedCount = 0;
        for (var i = 0; i<SDL.channels.length;i++) {
          pausedCount += _Mix_Paused(i);
        }
        return pausedCount;
      }
      var info = SDL.channels[channel];
      if (info && info.audio && info.audio.paused) {
        return 1;
      }
      return 0;
    }


  function _Mix_PausedMusic() {
      return (SDL.music.audio && SDL.music.audio.paused) ? 1 : 0;
    }


  function _Mix_Resume(channel) {
      if (channel === -1) {
        for (var i = 0; i<SDL.channels.length;i++) {
          _Mix_Resume(i);
        }
        return;
      }
      var info = SDL.channels[channel];
      if (info && info.audio) info.audio.play();
    }


  function _TTF_Init() {
      var canvas = document.createElement('canvas');
      SDL.ttfContext = canvas.getContext('2d');
      return 0;
    }


  function _TTF_OpenFont(filename, size) {
      filename = PATH.normalize(Pointer_stringify(filename));
      var id = SDL.fonts.length;
      SDL.fonts.push({
        name: filename, // but we don't actually do anything with it..
        size: size
      });
      return id;
    }


  function _TTF_CloseFont(font) {
      SDL.fonts[font] = null;
    }


  function _TTF_RenderText_Solid(font, text, color) {
      // XXX the font and color are ignored
      text = Pointer_stringify(text) || ' '; // if given an empty string, still return a valid surface
      var fontData = SDL.fonts[font];
      var w = SDL.estimateTextWidth(fontData, text);
      var h = fontData.size;
      color = SDL.loadColorToCSSRGB(color); // XXX alpha breaks fonts?
      var fontString = SDL.makeFontString(h, fontData.name);
      var surf = SDL.makeSurface(w, h, 0, false, 'text:' + text); // bogus numbers..
      var surfData = SDL.surfaces[surf];
      surfData.ctx.save();
      surfData.ctx.fillStyle = color;
      surfData.ctx.font = fontString;
      // use bottom alligment, because it works
      // same in all browsers, more info here:
      // https://bugzilla.mozilla.org/show_bug.cgi?id=737852
      surfData.ctx.textBaseline = 'bottom';
      surfData.ctx.fillText(text, 0, h|0);
      surfData.ctx.restore();
      return surf;
    }

  function _TTF_RenderText_Blended() {
  return _TTF_RenderText_Solid.apply(null, arguments)
  }

  function _TTF_RenderText_Shaded() {
  return _TTF_RenderText_Solid.apply(null, arguments)
  }

  function _TTF_RenderUTF8_Solid() {
  return _TTF_RenderText_Solid.apply(null, arguments)
  }

  
  function _TTF_SizeText(font, text, w, h) {
      var fontData = SDL.fonts[font];
      if (w) {
        HEAP32[((w)>>2)]=SDL.estimateTextWidth(fontData, Pointer_stringify(text));
      }
      if (h) {
        HEAP32[((h)>>2)]=fontData.size;
      }
      return 0;
    }function _TTF_SizeUTF8() {
  return _TTF_SizeText.apply(null, arguments)
  }




  function _TTF_GlyphMetrics(font, ch, minx, maxx, miny, maxy, advance) {
      var fontData = SDL.fonts[font];
      var width = SDL.estimateTextWidth(fontData,  String.fromCharCode(ch));
  
      if (advance) {
        HEAP32[((advance)>>2)]=width;
      }
      if (minx) {
        HEAP32[((minx)>>2)]=0;
      }
      if (maxx) {
        HEAP32[((maxx)>>2)]=width;
      }
      if (miny) {
        HEAP32[((miny)>>2)]=0;
      }
      if (maxy) {
        HEAP32[((maxy)>>2)]=fontData.size;
      }
    }


  function _TTF_FontAscent(font) {
      var fontData = SDL.fonts[font];
      return (fontData.size*0.98)|0; // XXX
    }


  function _TTF_FontDescent(font) {
      var fontData = SDL.fonts[font];
      return (fontData.size*0.02)|0; // XXX
    }


  function _TTF_FontHeight(font) {
      var fontData = SDL.fonts[font];
      return fontData.size;
    }

  function _TTF_FontLineSkip() {
  return _TTF_FontHeight.apply(null, arguments)
  }

  function _TTF_Quit() {
      out('TTF_Quit called (and ignored)');
    }

  var SDL_gfx={drawRectangle:function (surf, x1, y1, x2, y2, action, cssColor) {
        x1 = x1 << 16 >> 16;
        y1 = y1 << 16 >> 16;
        x2 = x2 << 16 >> 16;
        y2 = y2 << 16 >> 16;
        var surfData = SDL.surfaces[surf];
        assert(!surfData.locked); // but we could unlock and re-lock if we must..
        // TODO: if ctx does not change, leave as is, and also do not re-set xStyle etc.
        var x = x1 < x2 ? x1 : x2;
        var y = y1 < y2 ? y1 : y2;
        var w = Math.abs(x2 - x1);
        var h = Math.abs(y2 - y1);
        surfData.ctx.save();
        surfData.ctx[action + 'Style'] = cssColor;
        surfData.ctx[action + 'Rect'](x, y, w, h);
        surfData.ctx.restore();
      },drawLine:function (surf, x1, y1, x2, y2, cssColor) {
        x1 = x1 << 16 >> 16;
        y1 = y1 << 16 >> 16;
        x2 = x2 << 16 >> 16;
        y2 = y2 << 16 >> 16;
        var surfData = SDL.surfaces[surf];
        assert(!surfData.locked); // but we could unlock and re-lock if we must..
        surfData.ctx.save();
        surfData.ctx.strokeStyle = cssColor;
        surfData.ctx.beginPath();
        surfData.ctx.moveTo(x1, y1);
        surfData.ctx.lineTo(x2, y2);
        surfData.ctx.stroke();
        surfData.ctx.restore();
      },drawEllipse:function (surf, x, y, rx, ry, action, cssColor) {
        x = x << 16 >> 16;
        y = y << 16 >> 16;
        rx = rx << 16 >> 16;
        ry = ry << 16 >> 16;
        var surfData = SDL.surfaces[surf];
        assert(!surfData.locked); // but we could unlock and re-lock if we must..
  
        surfData.ctx.save();
        surfData.ctx.beginPath();
        surfData.ctx.translate(x, y);
        surfData.ctx.scale(rx, ry);
        surfData.ctx.arc(0, 0, 1, 0, 2 * Math.PI);
        surfData.ctx.restore();
  
        surfData.ctx.save();
        surfData.ctx[action + 'Style'] = cssColor;
        surfData.ctx[action]();
        surfData.ctx.restore();
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba>>>24) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba&0xff) + ')';
      }};

  function _boxColor(surf, x1, y1, x2, y2, color) {
      return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, 'fill', SDL_gfx.translateColorToCSSRGBA(color));
    }

  function _boxRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
      return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, 'fill', SDL.translateRGBAToCSSRGBA(r, g, b, a));
    }

  function _rectangleColor(surf, x1, y1, x2, y2, color) {
      return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, 'stroke', SDL_gfx.translateColorToCSSRGBA(color));
    }

  function _rectangleRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
      return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, 'stroke', SDL.translateRGBAToCSSRGBA(r, g, b, a));
    }

  function _ellipseColor(surf, x, y, rx, ry, color) {
      return SDL_gfx.drawEllipse(surf, x, y, rx, ry, 'stroke', SDL_gfx.translateColorToCSSRGBA(color));
    }

  function _ellipseRGBA(surf, x, y, rx, ry, r, g, b, a) {
      return SDL_gfx.drawEllipse(surf, x, y, rx, ry, 'stroke', SDL.translateRGBAToCSSRGBA(r, g, b, a));
    }

  function _filledEllipseColor(surf, x, y, rx, ry, color) {
      return SDL_gfx.drawEllipse(surf, x, y, rx, ry, 'fill', SDL_gfx.translateColorToCSSRGBA(color));
    }

  function _filledEllipseRGBA(surf, x, y, rx, ry, r, g, b, a) {
      return SDL_gfx.drawEllipse(surf, x, y, rx, ry, 'fill', SDL.translateRGBAToCSSRGBA(r, g, b, a));
    }

  function _lineColor(surf, x1, y1, x2, y2, color) {
      return SDL_gfx.drawLine(surf, x1, y1, x2, y2, SDL_gfx.translateColorToCSSRGBA(color));
    }

  function _lineRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
      return SDL_gfx.drawLine(surf, x1, y1, x2, y2, SDL.translateRGBAToCSSRGBA(r, g, b, a));
    }

  function _pixelRGBA(surf, x1, y1, r, g, b, a) {
      // This cannot be fast, to render many pixels this way!
      _boxRGBA(surf, x1, y1, x1, y1, r, g, b, a);
    }


  function _SDL_GL_SetAttribute(attr, value) {
      if (!(attr in SDL.glAttributes)) {
        abort('Unknown SDL GL attribute (' + attr + '). Please check if your SDL version is supported.');
      }
  
      SDL.glAttributes[attr] = value;
    }


  function _SDL_GL_GetAttribute(attr, value) {
      if (!(attr in SDL.glAttributes)) {
        abort('Unknown SDL GL attribute (' + attr + '). Please check if your SDL version is supported.');
      }
  
      if (value) HEAP32[((value)>>2)]=SDL.glAttributes[attr];
  
      return 0;
    }

  
  var _emscripten_GetProcAddress=undefined;function _SDL_GL_GetProcAddress(name_) {
      return _emscripten_GetProcAddress(name_);
    }


  function _SDL_GL_SwapBuffers() {
      if (Browser.doSwapBuffers) Browser.doSwapBuffers(); // in workers, this is used to send out a buffered frame
    }


  function _SDL_GL_ExtensionSupported(extension) {
      return Module.ctx.getExtension(extension) | 0;
    }

  function _SDL_DestroyWindow(window) {}

  function _SDL_DestroyRenderer(renderer) {}


  function _SDL_GetWindowFlags() {}

  function _SDL_GL_SwapWindow(window) {}

  function _SDL_GL_MakeCurrent(window, context) {}

  function _SDL_GL_DeleteContext(context) {}


  function _SDL_GL_GetSwapInterval(state) {
      if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/) return Browser.mainLoop.timingValue;
      else return 0;
    }

  function _SDL_GL_SetSwapInterval(state) {
      _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, state);
    }


  function _SDL_SetWindowTitle(window, title) {
      if (title) document.title = Pointer_stringify(title);
    }


  function _SDL_GetWindowSize(window, width, height){
      var w = Module['canvas'].width;
      var h = Module['canvas'].height;
      if (width) HEAP32[((width)>>2)]=w;
      if (height) HEAP32[((height)>>2)]=h;
    }

  function _SDL_LogSetOutputFunction(callback, userdata) {}


  function _SDL_SetWindowFullscreen(window, fullscreen) {
      if (Browser.isFullscreen) {
        Module['canvas'].exitFullscreen();
        return 1;
      } else {
        return 0;
      }
    }

  function _SDL_ClearError() {}

  function _SDL_getenv() {
  return _getenv.apply(null, arguments)
  }

  function _SDL_putenv() {
  return _putenv.apply(null, arguments)
  }

  function _SDL_SetGamma(r, g, b) {
      return -1;
    }

  function _SDL_SetGammaRamp(redTable, greenTable, blueTable) {
      return -1;
    }


  function _SDL_NumJoysticks() {
      var count = 0;
      var gamepads = SDL.getGamepads();
      // The length is not the number of gamepads; check which ones are defined.
      for (var i = 0; i < gamepads.length; i++) {
        if (gamepads[i] !== undefined) count++;
      }
      return count;
    }


  function _SDL_JoystickName(deviceIndex) {
      var gamepad = SDL.getGamepad(deviceIndex);
      if (gamepad) {
        var name = gamepad.id;
        if (SDL.joystickNamePool.hasOwnProperty(name)) {
          return SDL.joystickNamePool[name];
        }
        return SDL.joystickNamePool[name] = allocate(intArrayFromString(name), 'i8', ALLOC_NORMAL);
      }
      return 0;
    }


  function _SDL_JoystickOpen(deviceIndex) {
      var gamepad = SDL.getGamepad(deviceIndex);
      if (gamepad) {
        // Use this as a unique 'pointer' for this joystick.
        var joystick = deviceIndex+1;
        SDL.recordJoystickState(joystick, gamepad);
        return joystick;
      }
      return 0;
    }


  function _SDL_JoystickOpened(deviceIndex) {
      return SDL.lastJoystickState.hasOwnProperty(deviceIndex+1) ? 1 : 0;
    }

  function _SDL_JoystickIndex(joystick) {
      // joystick pointers are simply the deviceIndex+1.
      return joystick - 1;
    }


  function _SDL_JoystickNumAxes(joystick) {
      var gamepad = SDL.getGamepad(joystick - 1);
      if (gamepad) {
        return gamepad.axes.length;
      }
      return 0;
    }

  function _SDL_JoystickNumBalls(joystick) { return 0; }

  function _SDL_JoystickNumHats(joystick) { return 0; }


  function _SDL_JoystickNumButtons(joystick) {
      var gamepad = SDL.getGamepad(joystick - 1);
      if (gamepad) {
        return gamepad.buttons.length;
      }
      return 0;
    }


  function _SDL_JoystickUpdate() {
      SDL.queryJoysticks();
    }


  function _SDL_JoystickEventState(state) {
      if (state < 0) {
        // SDL_QUERY: Return current state.
        return SDL.joystickEventState;
      }
      return SDL.joystickEventState = state;
    }


  function _SDL_JoystickGetAxis(joystick, axis) {
      var gamepad = SDL.getGamepad(joystick - 1);
      if (gamepad && gamepad.axes.length > axis) {
        return SDL.joystickAxisValueConversion(gamepad.axes[axis]);
      }
      return 0;
    }

  function _SDL_JoystickGetHat(joystick, hat) { return 0; }

  function _SDL_JoystickGetBall(joystick, ball, dxptr, dyptr) { return -1; }


  function _SDL_JoystickGetButton(joystick, button) {
      var gamepad = SDL.getGamepad(joystick - 1);
      if (gamepad && gamepad.buttons.length > button) {
        return SDL.getJoystickButtonState(gamepad.buttons[button]) ? 1 : 0;
      }
      return 0;
    }


  function _SDL_JoystickClose(joystick) {
      delete SDL.lastJoystickState[joystick];
    }

  function _SDL_InitSubSystem(flags) { return 0 }


  function _SDL_RWFromConstMem(mem, size) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      SDL.rwops.push({ bytes: mem, count: size });
      return id;
    }

  function _SDL_RWFromMem() {
  return _SDL_RWFromConstMem.apply(null, arguments)
  }





  function _SDL_GetNumAudioDrivers() { return 1 }

  function _SDL_GetCurrentAudioDriver() {
      return allocate(intArrayFromString('Emscripten Audio'), 'i8', ALLOC_NORMAL);
    }

  function _SDL_GetAudioDriver(index) { return _SDL_GetCurrentAudioDriver() }


  function _SDL_EnableUNICODE(on) {
      var ret = SDL.unicode || 0;
      SDL.unicode = on;
      return ret;
    }


  function _SDL_AddTimer(interval, callback, param) {
      return window.setTimeout(function() {
        Module['dynCall_iii'](callback, interval, param);
      }, interval);
    }


  function _SDL_RemoveTimer(id) {
      window.clearTimeout(id);
      return true;
    }

  function _SDL_CreateThread() {
      throw 'SDL threads cannot be supported in the web platform because they assume shared state. See emscripten_create_worker etc. for a message-passing concurrency model that does let you run code in another thread.'
    }

  function _SDL_WaitThread() { throw 'SDL_WaitThread' }

  function _SDL_GetThreadID() { throw 'SDL_GetThreadID' }

  function _SDL_ThreadID() { return 0; }

  function _SDL_AllocRW() { throw 'SDL_AllocRW: TODO' }

  function _SDL_CondBroadcast() { throw 'SDL_CondBroadcast: TODO' }

  function _SDL_CondWaitTimeout() { throw 'SDL_CondWaitTimeout: TODO' }

  function _SDL_WM_IconifyWindow() { throw 'SDL_WM_IconifyWindow TODO' }

  function _Mix_SetPostMix() { warnOnce('Mix_SetPostMix: TODO') }

  function _Mix_VolumeChunk(chunk, volume) { throw 'Mix_VolumeChunk: TODO' }

  function _Mix_SetPosition(channel, angle, distance) { throw 'Mix_SetPosition: TODO' }

  function _Mix_QuerySpec() { throw 'Mix_QuerySpec: TODO' }

  function _Mix_FadeInChannelTimed() { throw 'Mix_FadeInChannelTimed' }

  function _Mix_FadeOutChannel() { throw 'Mix_FadeOutChannel' }

  function _Mix_Linked_Version() { throw 'Mix_Linked_Version: TODO' }

  function _SDL_SaveBMP_RW() { throw 'SDL_SaveBMP_RW: TODO' }

  function _SDL_WM_SetIcon() { /* This function would set the application window icon surface, which doesn't apply for web canvases, so a no-op. */ }

  function _SDL_HasRDTSC() { return 0; }

  function _SDL_HasMMX() { return 0; }

  function _SDL_HasMMXExt() { return 0; }

  function _SDL_Has3DNow() { return 0; }

  function _SDL_Has3DNowExt() { return 0; }

  function _SDL_HasSSE() { return 0; }

  function _SDL_HasSSE2() { return 0; }

  function _SDL_HasAltiVec() { return 0; }


  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }

  function _glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret;
      switch(name_) {
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (var i = 0; i < exts.length; ++i) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x9245 /* UNMASKED_VENDOR_WEBGL */:
        case 0x9246 /* UNMASKED_RENDERER_WEBGL */:
          var s = GLctx.getParameter(name_);
          if (!s) {
            GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          }
          ret = allocate(intArrayFromString(s), 'i8', ALLOC_NORMAL);
          break;
  
        case 0x1F02 /* GL_VERSION */:
          var glVersion = GLctx.getParameter(GLctx.VERSION);
          // return GLES version string corresponding to the version of the WebGL context
          {
            glVersion = 'OpenGL ES 2.0 (' + glVersion + ')';
          }
          ret = allocate(intArrayFromString(glVersion), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          var glslVersion = GLctx.getParameter(GLctx.SHADING_LANGUAGE_VERSION);
          // extract the version number 'N.M' from the string 'WebGL GLSL ES N.M ...'
          var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
          var ver_num = glslVersion.match(ver_re);
          if (ver_num !== null) {
            if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + '0'; // ensure minor version has 2 digits
            glslVersion = 'OpenGL ES GLSL ES ' + ver_num[1] + ' (' + glslVersion + ')';
          }
          ret = allocate(intArrayFromString(glslVersion), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }

  function emscriptenWebGLGet(name_, p, type) {
      // Guard against user passing a null pointer.
      // Note that GLES2 spec does not say anything about how passing a null pointer should be treated.
      // Testing on desktop core GL 3, the application crashes on glGetIntegerv to a null pointer, but
      // better to report an error instead of doing anything random.
      if (!p) {
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var ret = undefined;
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          ret = 1;
          break;
        case 0x8DF8: // GL_SHADER_BINARY_FORMATS
          if (type !== 'Integer' && type !== 'Integer64') {
            GL.recordError(0x0500); // GL_INVALID_ENUM
          }
          return; // Do not write anything to the out pointer, since no binary formats are supported.
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          ret = 0;
          break;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = GLctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          ret = formats ? formats.length : 0;
          break;
      }
  
      if (ret === undefined) {
        var result = GLctx.getParameter(name_);
        switch (typeof(result)) {
          case "number":
            ret = result;
            break;
          case "boolean":
            ret = result ? 1 : 0;
            break;
          case "string":
            GL.recordError(0x0500); // GL_INVALID_ENUM
            return;
          case "object":
            if (result === null) {
              // null is a valid result for some (e.g., which buffer is bound - perhaps nothing is bound), but otherwise
              // can mean an invalid name_, which we need to report as an error
              switch(name_) {
                case 0x8894: // ARRAY_BUFFER_BINDING
                case 0x8B8D: // CURRENT_PROGRAM
                case 0x8895: // ELEMENT_ARRAY_BUFFER_BINDING
                case 0x8CA6: // FRAMEBUFFER_BINDING
                case 0x8CA7: // RENDERBUFFER_BINDING
                case 0x8069: // TEXTURE_BINDING_2D
                case 0x8514: { // TEXTURE_BINDING_CUBE_MAP
                  ret = 0;
                  break;
                }
                default: {
                  GL.recordError(0x0500); // GL_INVALID_ENUM
                  return;
                }
              }
            } else if (result instanceof Float32Array ||
                       result instanceof Uint32Array ||
                       result instanceof Int32Array ||
                       result instanceof Array) {
              for (var i = 0; i < result.length; ++i) {
                switch (type) {
                  case 'Integer': HEAP32[(((p)+(i*4))>>2)]=result[i];   break;
                  case 'Float':   HEAPF32[(((p)+(i*4))>>2)]=result[i]; break;
                  case 'Boolean': HEAP8[(((p)+(i))>>0)]=result[i] ? 1 : 0;    break;
                  default: throw 'internal glGet error, bad type: ' + type;
                }
              }
              return;
            } else {
              try {
                ret = result.name | 0;
              } catch(e) {
                GL.recordError(0x0500); // GL_INVALID_ENUM
                err('GL_INVALID_ENUM in glGet' + type + 'v: Unknown object returned from WebGL getParameter(' + name_ + ')! (error: ' + e + ')');
                return;
              }
            }
            break;
          default:
            GL.recordError(0x0500); // GL_INVALID_ENUM
            return;
        }
      }
  
      switch (type) {
        case 'Integer64': (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((p)>>2)]=tempI64[0],HEAP32[(((p)+(4))>>2)]=tempI64[1]);    break;
        case 'Integer': HEAP32[((p)>>2)]=ret;    break;
        case 'Float':   HEAPF32[((p)>>2)]=ret;  break;
        case 'Boolean': HEAP8[((p)>>0)]=ret ? 1 : 0; break;
        default: throw 'internal glGet error, bad type: ' + type;
      }
    }

  function _glGetIntegerv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Integer');
    }

  function _glGetFloatv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Float');
    }

  function _glGetBooleanv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Boolean');
    }

  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var texture = GLctx.createTexture();
        if (!texture) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */); // GLES + EGL specs don't specify what should happen here, so best to issue an error and create IDs with 0.
          while(i < n) HEAP32[(((textures)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.textures);
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue; // GL spec: "glDeleteTextures silently ignores 0s and names that do not correspond to existing textures".
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }

  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      GLctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }

  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      GLctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, format, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }

  function emscriptenWebGLComputeImageSize(width, height, sizePerPixel, alignment) {
      function roundedToNextMultipleOf(x, y) {
        return Math.floor((x + y - 1) / y) * y
      }
      var plainRowSize = width * sizePerPixel;
      var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
      return (height <= 0) ? 0 :
               ((height - 1) * alignedRowSize + plainRowSize);
    }

  function emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat) {
      var sizePerPixel;
      var numChannels;
      switch(format) {
        case 0x1906 /* GL_ALPHA */:
        case 0x1909 /* GL_LUMINANCE */:
        case 0x1902 /* GL_DEPTH_COMPONENT */:
          numChannels = 1;
          break;
        case 0x190A /* GL_LUMINANCE_ALPHA */:
          numChannels = 2;
          break;
        case 0x1907 /* GL_RGB */:
        case 0x8C40 /* GL_SRGB_EXT */:
          numChannels = 3;
          break;
        case 0x1908 /* GL_RGBA */:
        case 0x8C42 /* GL_SRGB_ALPHA_EXT */:
          numChannels = 4;
          break;
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
      switch (type) {
        case 0x1401 /* GL_UNSIGNED_BYTE */:
          sizePerPixel = numChannels*1;
          break;
        case 0x1403 /* GL_UNSIGNED_SHORT */:
        case 0x8D61 /* GL_HALF_FLOAT_OES */:
          sizePerPixel = numChannels*2;
          break;
        case 0x1405 /* GL_UNSIGNED_INT */:
        case 0x1406 /* GL_FLOAT */:
          sizePerPixel = numChannels*4;
          break;
        case 0x84FA /* GL_UNSIGNED_INT_24_8_WEBGL/GL_UNSIGNED_INT_24_8 */:
          sizePerPixel = 4;
          break;
        case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
        case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
        case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
          sizePerPixel = 2;
          break;
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
      var bytes = emscriptenWebGLComputeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
      switch(type) {
        case 0x1401 /* GL_UNSIGNED_BYTE */:
          return HEAPU8.subarray((pixels),(pixels+bytes));
        case 0x1406 /* GL_FLOAT */:
          return HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        case 0x1405 /* GL_UNSIGNED_INT */:
        case 0x84FA /* GL_UNSIGNED_INT_24_8_WEBGL/GL_UNSIGNED_INT_24_8 */:
          return HEAPU32.subarray((pixels)>>2,(pixels+bytes)>>2);
        case 0x1403 /* GL_UNSIGNED_SHORT */:
        case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
        case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
        case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
        case 0x8D61 /* GL_HALF_FLOAT_OES */:
          return HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        default:
          GL.recordError(0x0500); // GL_INVALID_ENUM
          return null;
      }
    }

  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
  
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat);
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixelData);
    }

  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData);
    }

  function _glReadPixels(x, y, width, height, format, type, pixels) {
      var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
      if (!pixelData) {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
      GLctx.readPixels(x, y, width, height, format, type, pixelData);
    }

  function _glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }

  function _glGetTexParameterfv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAPF32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _glGetTexParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      GLctx.texParameterf(target, pname, param);
    }

  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      GLctx.texParameteri(target, pname, param);
    }

  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return GLctx.isTexture(texture);
    }

  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var buffer = GLctx.createBuffer();
        if (!buffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((buffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.buffers);
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
  
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
  
        GLctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
  
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }

  function _glGetBufferParameteriv(target, value, data) {
      if (!data) {
        // GLES2 specification does not specify how to behave if data is a null pointer. Since calling this function does not make sense
        // if data == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((data)>>2)]=GLctx.getBufferParameter(target, value);
    }

  function _glBufferData(target, size, data, usage) {
      if (!data) {
        GLctx.bufferData(target, size, usage);
      } else {
        GLctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
      }
    }

  function _glBufferSubData(target, offset, size, data) {
      GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }

  function _glGenQueriesEXT(n, ids) {
      for (var i = 0; i < n; i++) {
        var query = GLctx.disjointTimerQueryExt['createQueryEXT']();
        if (!query) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((ids)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.timerQueriesEXT);
        query.name = id;
        GL.timerQueriesEXT[id] = query;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteQueriesEXT(n, ids) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((ids)+(i*4))>>2)];
        var query = GL.timerQueriesEXT[id];
        if (!query) continue; // GL spec: "unused names in ids are ignored, as is the name zero."
        GLctx.disjointTimerQueryExt['deleteQueryEXT'](query);
        GL.timerQueriesEXT[id] = null;
      }
    }

  function _glIsQueryEXT(id) {
      var query = GL.timerQueriesEXT[query];
      if (!query) return 0;
      return GLctx.disjointTimerQueryExt['isQueryEXT'](query);
    }

  function _glBeginQueryEXT(target, id) {
      GLctx.disjointTimerQueryExt['beginQueryEXT'](target, id ? GL.timerQueriesEXT[id] : null);
    }

  function _glEndQueryEXT(target) {
      GLctx.disjointTimerQueryExt['endQueryEXT'](target);
    }

  function _glQueryCounterEXT(id, target) {
      GLctx.disjointTimerQueryExt['queryCounterEXT'](id ? GL.timerQueriesEXT[id] : null, target);
    }

  function _glGetQueryivEXT(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.disjointTimerQueryExt['getQueryEXT'](target, pname);
    }

  function _glGetQueryObjectivEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      HEAP32[((params)>>2)]=ret;
    }

  function _glGetQueryObjectuivEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      HEAP32[((params)>>2)]=ret;
    }

  function _glGetQueryObjecti64vEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((params)>>2)]=tempI64[0],HEAP32[(((params)+(4))>>2)]=tempI64[1]);
    }

  function _glGetQueryObjectui64vEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((params)>>2)]=tempI64[0],HEAP32[(((params)+(4))>>2)]=tempI64[1]);
    }

  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return GLctx.isBuffer(b);
    }

  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var renderbuffer = GLctx.createRenderbuffer();
        if (!renderbuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((renderbuffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.renderbuffers);
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        if (!renderbuffer) continue; // GL spec: "glDeleteRenderbuffers silently ignores 0s and names that do not correspond to existing renderbuffer objects".
        GLctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }

  function _glBindRenderbuffer(target, renderbuffer) {
      GLctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }

  function _glGetRenderbufferParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getRenderbufferParameter(target, pname);
    }

  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return GLctx.isRenderbuffer(rb);
    }

  function emscriptenWebGLGetUniform(program, location, params, type) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var data = GLctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        switch (type) {
          case 'Integer': HEAP32[((params)>>2)]=data; break;
          case 'Float': HEAPF32[((params)>>2)]=data; break;
          default: throw 'internal emscriptenWebGLGetUniform() error, bad type: ' + type;
        }
      } else {
        for (var i = 0; i < data.length; i++) {
          switch (type) {
            case 'Integer': HEAP32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'Float': HEAPF32[(((params)+(i*4))>>2)]=data[i]; break;
            default: throw 'internal emscriptenWebGLGetUniform() error, bad type: ' + type;
          }
        }
      }
    }

  function _glGetUniformfv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Float');
    }

  function _glGetUniformiv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Integer');
    }

  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
  
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        return -1;
      }
      var utable = ptable.uniforms;
      var uniformInfo = utable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }

  function emscriptenWebGLGetVertexAttrib(index, pname, params, type) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var data = GLctx.getVertexAttrib(index, pname);
      if (pname == 0x889F/*VERTEX_ATTRIB_ARRAY_BUFFER_BINDING*/) {
        HEAP32[((params)>>2)]=data["name"];
      } else if (typeof data == 'number' || typeof data == 'boolean') {
        switch (type) {
          case 'Integer': HEAP32[((params)>>2)]=data; break;
          case 'Float': HEAPF32[((params)>>2)]=data; break;
          case 'FloatToInteger': HEAP32[((params)>>2)]=Math.fround(data); break;
          default: throw 'internal emscriptenWebGLGetVertexAttrib() error, bad type: ' + type;
        }
      } else {
        for (var i = 0; i < data.length; i++) {
          switch (type) {
            case 'Integer': HEAP32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'Float': HEAPF32[(((params)+(i*4))>>2)]=data[i]; break;
            case 'FloatToInteger': HEAP32[(((params)+(i*4))>>2)]=Math.fround(data[i]); break;
            default: throw 'internal emscriptenWebGLGetVertexAttrib() error, bad type: ' + type;
          }
        }
      }
    }

  function _glGetVertexAttribfv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'Float');
    }

  function _glGetVertexAttribiv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'FloatToInteger');
    }

  function _glGetVertexAttribPointerv(index, pname, pointer) {
      if (!pointer) {
        // GLES2 specification does not specify how to behave if pointer is a null pointer. Since calling this function does not make sense
        // if pointer == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((pointer)>>2)]=GLctx.getVertexAttribOffset(index, pname);
    }

  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveUniform(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size, type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }

  function _glUniform1f(location, v0) {
      GLctx.uniform1f(GL.uniforms[location], v0);
    }

  function _glUniform2f(location, v0, v1) {
      GLctx.uniform2f(GL.uniforms[location], v0, v1);
    }

  function _glUniform3f(location, v0, v1, v2) {
      GLctx.uniform3f(GL.uniforms[location], v0, v1, v2);
    }

  function _glUniform4f(location, v0, v1, v2, v3) {
      GLctx.uniform4f(GL.uniforms[location], v0, v1, v2, v3);
    }

  function _glUniform1i(location, v0) {
      GLctx.uniform1i(GL.uniforms[location], v0);
    }

  function _glUniform2i(location, v0, v1) {
      GLctx.uniform2i(GL.uniforms[location], v0, v1);
    }

  function _glUniform3i(location, v0, v1, v2) {
      GLctx.uniform3i(GL.uniforms[location], v0, v1, v2);
    }

  function _glUniform4i(location, v0, v1, v2, v3) {
      GLctx.uniform4i(GL.uniforms[location], v0, v1, v2, v3);
    }

  function _glUniform1iv(location, count, value) {
  
  
      GLctx.uniform1iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*4)>>2));
    }

  function _glUniform2iv(location, count, value) {
  
  
      GLctx.uniform2iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*8)>>2));
    }

  function _glUniform3iv(location, count, value) {
  
  
      GLctx.uniform3iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*12)>>2));
    }

  function _glUniform4iv(location, count, value) {
  
  
      GLctx.uniform4iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*16)>>2));
    }

  function _glUniform1fv(location, count, value) {
  
  
      var view;
      if (count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[count-1];
        for (var i = 0; i < count; ++i) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      GLctx.uniform1fv(GL.uniforms[location], view);
    }

  function _glUniform2fv(location, count, value) {
  
  
      var view;
      if (2*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[2*count-1];
        for (var i = 0; i < 2*count; i += 2) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      GLctx.uniform2fv(GL.uniforms[location], view);
    }

  function _glUniform3fv(location, count, value) {
  
  
      var view;
      if (3*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[3*count-1];
        for (var i = 0; i < 3*count; i += 3) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      GLctx.uniform3fv(GL.uniforms[location], view);
    }

  function _glUniform4fv(location, count, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniform4fv(GL.uniforms[location], view);
    }

  function _glUniformMatrix2fv(location, count, transpose, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniformMatrix2fv(GL.uniforms[location], !!transpose, view);
    }

  function _glUniformMatrix3fv(location, count, transpose, value) {
  
  
      var view;
      if (9*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[9*count-1];
        for (var i = 0; i < 9*count; i += 9) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      GLctx.uniformMatrix3fv(GL.uniforms[location], !!transpose, view);
    }

  function _glUniformMatrix4fv(location, count, transpose, value) {
  
  
      var view;
      if (16*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[16*count-1];
        for (var i = 0; i < 16*count; i += 16) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
          view[i+9] = HEAPF32[(((value)+(4*i+36))>>2)];
          view[i+10] = HEAPF32[(((value)+(4*i+40))>>2)];
          view[i+11] = HEAPF32[(((value)+(4*i+44))>>2)];
          view[i+12] = HEAPF32[(((value)+(4*i+48))>>2)];
          view[i+13] = HEAPF32[(((value)+(4*i+52))>>2)];
          view[i+14] = HEAPF32[(((value)+(4*i+56))>>2)];
          view[i+15] = HEAPF32[(((value)+(4*i+60))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      GLctx.uniformMatrix4fv(GL.uniforms[location], !!transpose, view);
    }

  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
  
  
      GLctx.bindBuffer(target, bufferObj);
    }

  function _glVertexAttrib1fv(index, v) {
  
      GLctx.vertexAttrib1f(index, HEAPF32[v>>2]);
    }

  function _glVertexAttrib2fv(index, v) {
  
      GLctx.vertexAttrib2f(index, HEAPF32[v>>2], HEAPF32[v+4>>2]);
    }

  function _glVertexAttrib3fv(index, v) {
  
      GLctx.vertexAttrib3f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2]);
    }

  function _glVertexAttrib4fv(index, v) {
  
      GLctx.vertexAttrib4f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2], HEAPF32[v+12>>2]);
    }

  function _glGetAttribLocation(program, name) {
      return GLctx.getAttribLocation(GL.programs[program], Pointer_stringify(name));
    }

  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveAttrib(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size and type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }

  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = GLctx.createShader(shaderType);
      return id;
    }

  function _glDeleteShader(id) {
      if (!id) return;
      var shader = GL.shaders[id];
      if (!shader) { // glDeleteShader actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteShader(shader);
      GL.shaders[id] = null;
    }

  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = GLctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }

  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
  
  
      GLctx.shaderSource(GL.shaders[shader], source);
    }

  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = GLctx.getShaderSource(GL.shaders[shader]);
      if (!result) return; // If an error occurs, nothing will be written to length or source.
      if (bufSize > 0 && source) {
        var numBytesWrittenExclNull = stringToUTF8(result, source, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _glCompileShader(shader) {
      GLctx.compileShader(GL.shaders[shader]);
    }

  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
      if (log === null) log = '(unknown error)';
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _glGetShaderiv(shader, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B88) { // GL_SHADER_SOURCE_LENGTH
        var source = GLctx.getShaderSource(GL.shaders[shader]);
        var sourceLength = (source === null || source.length == 0) ? 0 : source.length + 1;
        HEAP32[((p)>>2)]=sourceLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }

  function _glGetProgramiv(program, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      if (program >= GL.counter) {
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        return;
      }
  
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getProgramInfoLog(GL.programs[program]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B87 /* GL_ACTIVE_UNIFORM_MAX_LENGTH */) {
        HEAP32[((p)>>2)]=ptable.maxUniformLength;
      } else if (pname == 0x8B8A /* GL_ACTIVE_ATTRIBUTE_MAX_LENGTH */) {
        if (ptable.maxAttributeLength == -1) {
          program = GL.programs[program];
          var numAttribs = GLctx.getProgramParameter(program, GLctx.ACTIVE_ATTRIBUTES);
          ptable.maxAttributeLength = 0; // Spec says if there are no active attribs, 0 must be returned.
          for (var i = 0; i < numAttribs; ++i) {
            var activeAttrib = GLctx.getActiveAttrib(program, i);
            ptable.maxAttributeLength = Math.max(ptable.maxAttributeLength, activeAttrib.name.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxAttributeLength;
      } else if (pname == 0x8A35 /* GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH */) {
        if (ptable.maxUniformBlockNameLength == -1) {
          program = GL.programs[program];
          var numBlocks = GLctx.getProgramParameter(program, GLctx.ACTIVE_UNIFORM_BLOCKS);
          ptable.maxUniformBlockNameLength = 0;
          for (var i = 0; i < numBlocks; ++i) {
            var activeBlockName = GLctx.getActiveUniformBlockName(program, i);
            ptable.maxUniformBlockNameLength = Math.max(ptable.maxUniformBlockNameLength, activeBlockName.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxUniformBlockNameLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getProgramParameter(GL.programs[program], pname);
      }
    }

  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return GLctx.isShader(s);
    }

  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = GLctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }

  function _glDeleteProgram(id) {
      if (!id) return;
      var program = GL.programs[id];
      if (!program) { // glDeleteProgram actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteProgram(program);
      program.name = 0;
      GL.programs[id] = null;
      GL.programInfos[id] = null;
    }

  function _glAttachShader(program, shader) {
      GLctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _glDetachShader(program, shader) {
      GLctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }

  function _glLinkProgram(program) {
      GLctx.linkProgram(GL.programs[program]);
      GL.programInfos[program] = null; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }

  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = GLctx.getProgramInfoLog(GL.programs[program]);
      if (log === null) log = '(unknown error)';
  
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }

  function _glUseProgram(program) {
      GLctx.useProgram(program ? GL.programs[program] : null);
    }

  function _glValidateProgram(program) {
      GLctx.validateProgram(GL.programs[program]);
    }

  function _glIsProgram(program) {
      program = GL.programs[program];
      if (!program) return 0;
      return GLctx.isProgram(program);
    }

  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      GLctx.bindAttribLocation(GL.programs[program], index, name);
    }

  function _glBindFramebuffer(target, framebuffer) {
  
      GLctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
  
    }

  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var framebuffer = GLctx.createFramebuffer();
        if (!framebuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((ids)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.framebuffers);
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        if (!framebuffer) continue; // GL spec: "glDeleteFramebuffers silently ignores 0s and names that do not correspond to existing framebuffer objects".
        GLctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }

  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }

  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      GLctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }

  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
      if (result instanceof WebGLRenderbuffer ||
          result instanceof WebGLTexture) {
        result = result.name | 0;
      }
      HEAP32[((params)>>2)]=result;
    }

  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return GLctx.isFramebuffer(fb);
    }

  function _glGenVertexArrays(n, arrays) {
  
      for (var i = 0; i < n; i++) {
        var vao = GLctx['createVertexArray']();
        if (!vao) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((arrays)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.vaos);
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteVertexArrays(n, vaos) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GLctx['deleteVertexArray'](GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }

  function _glBindVertexArray(vao) {
      GLctx['bindVertexArray'](GL.vaos[vao]);
    }

  function _glIsVertexArray(array) {
  
      var vao = GL.vaos[array];
      if (!vao) return 0;
      return GLctx['isVertexArray'](vao);
    }

  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _glBegin(){ throw 'Legacy GL function (glBegin) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _glGenVertexArraysOES(n, arrays) {
  
      for (var i = 0; i < n; i++) {
        var vao = GLctx['createVertexArray']();
        if (!vao) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((arrays)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.vaos);
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }

  function _glDeleteVertexArraysOES(n, vaos) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GLctx['deleteVertexArray'](GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }

  function _glBindVertexArrayOES(vao) {
      GLctx['bindVertexArray'](GL.vaos[vao]);
    }

  function _glIsVertexArrayOES(array) {
  
      var vao = GL.vaos[array];
      if (!vao) return 0;
      return GLctx['isVertexArray'](vao);
    }

  function _gluPerspective(fov, aspect, near, far) {
      GLImmediate.matricesModified = true;
      GLImmediate.matrixVersion[GLImmediate.currentMatrix] = (GLImmediate.matrixVersion[GLImmediate.currentMatrix] + 1)|0;
      GLImmediate.matrix[GLImmediate.currentMatrix] =
        GLImmediate.matrixLib.mat4.perspective(fov, aspect, near, far,
                                                 GLImmediate.matrix[GLImmediate.currentMatrix]);
    }

  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GLImmediate.matricesModified = true;
      GLImmediate.matrixVersion[GLImmediate.currentMatrix] = (GLImmediate.matrixVersion[GLImmediate.currentMatrix] + 1)|0;
      GLImmediate.matrixLib.mat4.lookAt(GLImmediate.matrix[GLImmediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }

  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
  
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GLImmediate.matrixLib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GLImmediate.matrixLib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
  
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
  
      return 1 /* GL_TRUE */;
    }

  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GLImmediate.matrixLib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
  
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
  
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
  
      return 1 /* GL_TRUE */;
    }

  
  var _glOrtho=undefined;function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }

  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      GLctx.vertexAttribPointer(index, size, type, !!normalized, stride, ptr);
    }

  function _glEnableVertexAttribArray(index) {
      GLctx.enableVertexAttribArray(index);
    }

  function _glDisableVertexAttribArray(index) {
      GLctx.disableVertexAttribArray(index);
    }

  function _glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }

  function _glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }

  function _glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }

  function _glReleaseShaderCompiler() {
      // NOP (as allowed by GLES 2.0 spec)
    }

  function _glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }

  function _glVertexAttribDivisor(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _glDrawArraysInstanced(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _glDrawElementsInstanced(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _glVertexAttribDivisorNV(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _glDrawArraysInstancedNV(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _glDrawElementsInstancedNV(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _glVertexAttribDivisorEXT(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _glDrawArraysInstancedEXT(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _glDrawElementsInstancedEXT(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _glVertexAttribDivisorARB(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _glDrawArraysInstancedARB(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _glDrawElementsInstancedARB(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _glVertexAttribDivisorANGLE(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }

  function _glDrawArraysInstancedANGLE(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }

  function _glDrawElementsInstancedANGLE(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }

  function _glDrawBuffers(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }

  function _glDrawBuffersEXT(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }

  function _glDrawBuffersWEBGL(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }

  function _glColorMask(red, green, blue, alpha) {
      GLctx.colorMask(!!red, !!green, !!blue, !!alpha);
    }

  function _glDepthMask(flag) {
      GLctx.depthMask(!!flag);
    }

  function _glSampleCoverage(value, invert) {
      GLctx.sampleCoverage(value, !!invert);
    }

  function _glFinish() { GLctx['finish']() }

  function _glFlush() { GLctx['flush']() }

  function _glClearDepth(x0) { GLctx['clearDepth'](x0) }

  function _glClearDepthf(x0) { GLctx['clearDepth'](x0) }

  function _glDepthFunc(x0) { GLctx['depthFunc'](x0) }

  function _glEnable(x0) { GLctx['enable'](x0) }

  function _glDisable(x0) { GLctx['disable'](x0) }

  function _glFrontFace(x0) { GLctx['frontFace'](x0) }

  function _glCullFace(x0) { GLctx['cullFace'](x0) }

  function _glClear(x0) { GLctx['clear'](x0) }

  function _glLineWidth(x0) { GLctx['lineWidth'](x0) }

  function _glClearStencil(x0) { GLctx['clearStencil'](x0) }

  function _glStencilMask(x0) { GLctx['stencilMask'](x0) }

  function _glCheckFramebufferStatus(x0) { return GLctx['checkFramebufferStatus'](x0) }

  function _glGenerateMipmap(x0) { GLctx['generateMipmap'](x0) }

  function _glActiveTexture(x0) { GLctx['activeTexture'](x0) }

  function _glBlendEquation(x0) { GLctx['blendEquation'](x0) }

  function _glIsEnabled(x0) { return GLctx['isEnabled'](x0) }

  function _glBlendFunc(x0, x1) { GLctx['blendFunc'](x0, x1) }

  function _glBlendEquationSeparate(x0, x1) { GLctx['blendEquationSeparate'](x0, x1) }

  function _glDepthRange(x0, x1) { GLctx['depthRange'](x0, x1) }

  function _glDepthRangef(x0, x1) { GLctx['depthRange'](x0, x1) }

  function _glStencilMaskSeparate(x0, x1) { GLctx['stencilMaskSeparate'](x0, x1) }

  function _glHint(x0, x1) { GLctx['hint'](x0, x1) }

  function _glPolygonOffset(x0, x1) { GLctx['polygonOffset'](x0, x1) }

  function _glVertexAttrib1f(x0, x1) { GLctx['vertexAttrib1f'](x0, x1) }

  function _glTexParameteri(x0, x1, x2) { GLctx['texParameteri'](x0, x1, x2) }

  function _glTexParameterf(x0, x1, x2) { GLctx['texParameterf'](x0, x1, x2) }

  function _glVertexAttrib2f(x0, x1, x2) { GLctx['vertexAttrib2f'](x0, x1, x2) }

  function _glStencilFunc(x0, x1, x2) { GLctx['stencilFunc'](x0, x1, x2) }

  function _glStencilOp(x0, x1, x2) { GLctx['stencilOp'](x0, x1, x2) }

  function _glViewport(x0, x1, x2, x3) { GLctx['viewport'](x0, x1, x2, x3) }

  function _glClearColor(x0, x1, x2, x3) { GLctx['clearColor'](x0, x1, x2, x3) }

  function _glScissor(x0, x1, x2, x3) { GLctx['scissor'](x0, x1, x2, x3) }

  function _glVertexAttrib3f(x0, x1, x2, x3) { GLctx['vertexAttrib3f'](x0, x1, x2, x3) }

  function _glRenderbufferStorage(x0, x1, x2, x3) { GLctx['renderbufferStorage'](x0, x1, x2, x3) }

  function _glBlendFuncSeparate(x0, x1, x2, x3) { GLctx['blendFuncSeparate'](x0, x1, x2, x3) }

  function _glBlendColor(x0, x1, x2, x3) { GLctx['blendColor'](x0, x1, x2, x3) }

  function _glStencilFuncSeparate(x0, x1, x2, x3) { GLctx['stencilFuncSeparate'](x0, x1, x2, x3) }

  function _glStencilOpSeparate(x0, x1, x2, x3) { GLctx['stencilOpSeparate'](x0, x1, x2, x3) }

  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { GLctx['vertexAttrib4f'](x0, x1, x2, x3, x4) }

  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexSubImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }

  function _emscripten_glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }


  function _emscripten_glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret;
      switch(name_) {
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (var i = 0; i < exts.length; ++i) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x9245 /* UNMASKED_VENDOR_WEBGL */:
        case 0x9246 /* UNMASKED_RENDERER_WEBGL */:
          var s = GLctx.getParameter(name_);
          if (!s) {
            GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          }
          ret = allocate(intArrayFromString(s), 'i8', ALLOC_NORMAL);
          break;
  
        case 0x1F02 /* GL_VERSION */:
          var glVersion = GLctx.getParameter(GLctx.VERSION);
          // return GLES version string corresponding to the version of the WebGL context
          {
            glVersion = 'OpenGL ES 2.0 (' + glVersion + ')';
          }
          ret = allocate(intArrayFromString(glVersion), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          var glslVersion = GLctx.getParameter(GLctx.SHADING_LANGUAGE_VERSION);
          // extract the version number 'N.M' from the string 'WebGL GLSL ES N.M ...'
          var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
          var ver_num = glslVersion.match(ver_re);
          if (ver_num !== null) {
            if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + '0'; // ensure minor version has 2 digits
            glslVersion = 'OpenGL ES GLSL ES ' + ver_num[1] + ' (' + glslVersion + ')';
          }
          ret = allocate(intArrayFromString(glslVersion), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }


  function _emscripten_glGetIntegerv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Integer');
    }


  function _emscripten_glGetFloatv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Float');
    }


  function _emscripten_glGetBooleanv(name_, p) {
      emscriptenWebGLGet(name_, p, 'Boolean');
    }


  function _emscripten_glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var texture = GLctx.createTexture();
        if (!texture) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */); // GLES + EGL specs don't specify what should happen here, so best to issue an error and create IDs with 0.
          while(i < n) HEAP32[(((textures)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.textures);
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue; // GL spec: "glDeleteTextures silently ignores 0s and names that do not correspond to existing textures".
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }


  function _emscripten_glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      GLctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }


  function _emscripten_glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      GLctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, format, data ? HEAPU8.subarray((data),(data+imageSize)) : null);
    }


  function _emscripten_glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
  
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat);
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixelData);
    }


  function _emscripten_glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      var pixelData = null;
      if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData);
    }


  function _emscripten_glReadPixels(x, y, width, height, format, type, pixels) {
      var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
      if (!pixelData) {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
      GLctx.readPixels(x, y, width, height, format, type, pixelData);
    }


  function _emscripten_glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }


  function _emscripten_glGetTexParameterfv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAPF32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }


  function _emscripten_glGetTexParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }


  function _emscripten_glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      GLctx.texParameterf(target, pname, param);
    }


  function _emscripten_glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      GLctx.texParameteri(target, pname, param);
    }


  function _emscripten_glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return GLctx.isTexture(texture);
    }


  function _emscripten_glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var buffer = GLctx.createBuffer();
        if (!buffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((buffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.buffers);
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
  
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
  
        GLctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
  
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }


  function _emscripten_glGetBufferParameteriv(target, value, data) {
      if (!data) {
        // GLES2 specification does not specify how to behave if data is a null pointer. Since calling this function does not make sense
        // if data == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((data)>>2)]=GLctx.getBufferParameter(target, value);
    }


  function _emscripten_glBufferData(target, size, data, usage) {
      if (!data) {
        GLctx.bufferData(target, size, usage);
      } else {
        GLctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
      }
    }


  function _emscripten_glBufferSubData(target, offset, size, data) {
      GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }


  function _emscripten_glGenQueriesEXT(n, ids) {
      for (var i = 0; i < n; i++) {
        var query = GLctx.disjointTimerQueryExt['createQueryEXT']();
        if (!query) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((ids)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.timerQueriesEXT);
        query.name = id;
        GL.timerQueriesEXT[id] = query;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteQueriesEXT(n, ids) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((ids)+(i*4))>>2)];
        var query = GL.timerQueriesEXT[id];
        if (!query) continue; // GL spec: "unused names in ids are ignored, as is the name zero."
        GLctx.disjointTimerQueryExt['deleteQueryEXT'](query);
        GL.timerQueriesEXT[id] = null;
      }
    }


  function _emscripten_glIsQueryEXT(id) {
      var query = GL.timerQueriesEXT[query];
      if (!query) return 0;
      return GLctx.disjointTimerQueryExt['isQueryEXT'](query);
    }


  function _emscripten_glBeginQueryEXT(target, id) {
      GLctx.disjointTimerQueryExt['beginQueryEXT'](target, id ? GL.timerQueriesEXT[id] : null);
    }


  function _emscripten_glEndQueryEXT(target) {
      GLctx.disjointTimerQueryExt['endQueryEXT'](target);
    }


  function _emscripten_glQueryCounterEXT(id, target) {
      GLctx.disjointTimerQueryExt['queryCounterEXT'](id ? GL.timerQueriesEXT[id] : null, target);
    }


  function _emscripten_glGetQueryivEXT(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.disjointTimerQueryExt['getQueryEXT'](target, pname);
    }


  function _emscripten_glGetQueryObjectivEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      HEAP32[((params)>>2)]=ret;
    }



  function _emscripten_glGetQueryObjectuivEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      HEAP32[((params)>>2)]=ret;
    }


  function _emscripten_glGetQueryObjecti64vEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((params)>>2)]=tempI64[0],HEAP32[(((params)+(4))>>2)]=tempI64[1]);
    }



  function _emscripten_glGetQueryObjectui64vEXT(id, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      var query = GL.timerQueriesEXT[id];
      var param = GLctx.disjointTimerQueryExt['getQueryObjectEXT'](query, pname);
      var ret;
      if (typeof param == 'boolean') {
        ret = param ? 1 : 0;
      } else {
        ret = param;
      }
      (tempI64 = [ret>>>0,(tempDouble=ret,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((params)>>2)]=tempI64[0],HEAP32[(((params)+(4))>>2)]=tempI64[1]);
    }


  function _emscripten_glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return GLctx.isBuffer(b);
    }


  function _emscripten_glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var renderbuffer = GLctx.createRenderbuffer();
        if (!renderbuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((renderbuffers)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.renderbuffers);
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        if (!renderbuffer) continue; // GL spec: "glDeleteRenderbuffers silently ignores 0s and names that do not correspond to existing renderbuffer objects".
        GLctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }


  function _emscripten_glBindRenderbuffer(target, renderbuffer) {
      GLctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }


  function _emscripten_glGetRenderbufferParameteriv(target, pname, params) {
      if (!params) {
        // GLES2 specification does not specify how to behave if params is a null pointer. Since calling this function does not make sense
        // if params == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((params)>>2)]=GLctx.getRenderbufferParameter(target, pname);
    }


  function _emscripten_glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return GLctx.isRenderbuffer(rb);
    }


  function _emscripten_glGetUniformfv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Float');
    }


  function _emscripten_glGetUniformiv(program, location, params) {
      emscriptenWebGLGetUniform(program, location, params, 'Integer');
    }


  function _emscripten_glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
  
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        return -1;
      }
      var utable = ptable.uniforms;
      var uniformInfo = utable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }


  function _emscripten_glGetVertexAttribfv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'Float');
    }


  function _emscripten_glGetVertexAttribiv(index, pname, params) {
      // N.B. This function may only be called if the vertex attribute was specified using the function glVertexAttrib*f(),
      // otherwise the results are undefined. (GLES3 spec 6.1.12)
      emscriptenWebGLGetVertexAttrib(index, pname, params, 'FloatToInteger');
    }


  function _emscripten_glGetVertexAttribPointerv(index, pname, pointer) {
      if (!pointer) {
        // GLES2 specification does not specify how to behave if pointer is a null pointer. Since calling this function does not make sense
        // if pointer == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      HEAP32[((pointer)>>2)]=GLctx.getVertexAttribOffset(index, pname);
    }


  function _emscripten_glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveUniform(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size, type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }


  function _emscripten_glUniform1f(location, v0) {
      GLctx.uniform1f(GL.uniforms[location], v0);
    }


  function _emscripten_glUniform2f(location, v0, v1) {
      GLctx.uniform2f(GL.uniforms[location], v0, v1);
    }


  function _emscripten_glUniform3f(location, v0, v1, v2) {
      GLctx.uniform3f(GL.uniforms[location], v0, v1, v2);
    }


  function _emscripten_glUniform4f(location, v0, v1, v2, v3) {
      GLctx.uniform4f(GL.uniforms[location], v0, v1, v2, v3);
    }


  function _emscripten_glUniform1i(location, v0) {
      GLctx.uniform1i(GL.uniforms[location], v0);
    }


  function _emscripten_glUniform2i(location, v0, v1) {
      GLctx.uniform2i(GL.uniforms[location], v0, v1);
    }


  function _emscripten_glUniform3i(location, v0, v1, v2) {
      GLctx.uniform3i(GL.uniforms[location], v0, v1, v2);
    }


  function _emscripten_glUniform4i(location, v0, v1, v2, v3) {
      GLctx.uniform4i(GL.uniforms[location], v0, v1, v2, v3);
    }


  function _emscripten_glUniform1iv(location, count, value) {
  
  
      GLctx.uniform1iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*4)>>2));
    }


  function _emscripten_glUniform2iv(location, count, value) {
  
  
      GLctx.uniform2iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*8)>>2));
    }


  function _emscripten_glUniform3iv(location, count, value) {
  
  
      GLctx.uniform3iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*12)>>2));
    }


  function _emscripten_glUniform4iv(location, count, value) {
  
  
      GLctx.uniform4iv(GL.uniforms[location], HEAP32.subarray((value)>>2,(value+count*16)>>2));
    }


  function _emscripten_glUniform1fv(location, count, value) {
  
  
      var view;
      if (count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[count-1];
        for (var i = 0; i < count; ++i) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      GLctx.uniform1fv(GL.uniforms[location], view);
    }


  function _emscripten_glUniform2fv(location, count, value) {
  
  
      var view;
      if (2*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[2*count-1];
        for (var i = 0; i < 2*count; i += 2) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      GLctx.uniform2fv(GL.uniforms[location], view);
    }


  function _emscripten_glUniform3fv(location, count, value) {
  
  
      var view;
      if (3*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[3*count-1];
        for (var i = 0; i < 3*count; i += 3) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      GLctx.uniform3fv(GL.uniforms[location], view);
    }


  function _emscripten_glUniform4fv(location, count, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniform4fv(GL.uniforms[location], view);
    }


  function _emscripten_glUniformMatrix2fv(location, count, transpose, value) {
  
  
      var view;
      if (4*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[4*count-1];
        for (var i = 0; i < 4*count; i += 4) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniformMatrix2fv(GL.uniforms[location], !!transpose, view);
    }


  function _emscripten_glUniformMatrix3fv(location, count, transpose, value) {
  
  
      var view;
      if (9*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[9*count-1];
        for (var i = 0; i < 9*count; i += 9) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      GLctx.uniformMatrix3fv(GL.uniforms[location], !!transpose, view);
    }


  function _emscripten_glUniformMatrix4fv(location, count, transpose, value) {
  
  
      var view;
      if (16*count <= GL.MINI_TEMP_BUFFER_SIZE) {
        // avoid allocation when uploading few enough uniforms
        view = GL.miniTempBufferViews[16*count-1];
        for (var i = 0; i < 16*count; i += 16) {
          view[i] = HEAPF32[(((value)+(4*i))>>2)];
          view[i+1] = HEAPF32[(((value)+(4*i+4))>>2)];
          view[i+2] = HEAPF32[(((value)+(4*i+8))>>2)];
          view[i+3] = HEAPF32[(((value)+(4*i+12))>>2)];
          view[i+4] = HEAPF32[(((value)+(4*i+16))>>2)];
          view[i+5] = HEAPF32[(((value)+(4*i+20))>>2)];
          view[i+6] = HEAPF32[(((value)+(4*i+24))>>2)];
          view[i+7] = HEAPF32[(((value)+(4*i+28))>>2)];
          view[i+8] = HEAPF32[(((value)+(4*i+32))>>2)];
          view[i+9] = HEAPF32[(((value)+(4*i+36))>>2)];
          view[i+10] = HEAPF32[(((value)+(4*i+40))>>2)];
          view[i+11] = HEAPF32[(((value)+(4*i+44))>>2)];
          view[i+12] = HEAPF32[(((value)+(4*i+48))>>2)];
          view[i+13] = HEAPF32[(((value)+(4*i+52))>>2)];
          view[i+14] = HEAPF32[(((value)+(4*i+56))>>2)];
          view[i+15] = HEAPF32[(((value)+(4*i+60))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      GLctx.uniformMatrix4fv(GL.uniforms[location], !!transpose, view);
    }


  function _emscripten_glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
  
  
      GLctx.bindBuffer(target, bufferObj);
    }


  function _emscripten_glVertexAttrib1fv(index, v) {
  
      GLctx.vertexAttrib1f(index, HEAPF32[v>>2]);
    }


  function _emscripten_glVertexAttrib2fv(index, v) {
  
      GLctx.vertexAttrib2f(index, HEAPF32[v>>2], HEAPF32[v+4>>2]);
    }


  function _emscripten_glVertexAttrib3fv(index, v) {
  
      GLctx.vertexAttrib3f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2]);
    }


  function _emscripten_glVertexAttrib4fv(index, v) {
  
      GLctx.vertexAttrib4f(index, HEAPF32[v>>2], HEAPF32[v+4>>2], HEAPF32[v+8>>2], HEAPF32[v+12>>2]);
    }


  function _emscripten_glGetAttribLocation(program, name) {
      return GLctx.getAttribLocation(GL.programs[program], Pointer_stringify(name));
    }


  function _emscripten_glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveAttrib(program, index);
      if (!info) return; // If an error occurs, nothing will be written to length, size and type and name.
  
      if (bufSize > 0 && name) {
        var numBytesWrittenExclNull = stringToUTF8(info.name, name, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
  
      if (size) HEAP32[((size)>>2)]=info.size;
      if (type) HEAP32[((type)>>2)]=info.type;
    }


  function _emscripten_glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = GLctx.createShader(shaderType);
      return id;
    }


  function _emscripten_glDeleteShader(id) {
      if (!id) return;
      var shader = GL.shaders[id];
      if (!shader) { // glDeleteShader actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteShader(shader);
      GL.shaders[id] = null;
    }


  function _emscripten_glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = GLctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
  
  
      GLctx.shaderSource(GL.shaders[shader], source);
    }


  function _emscripten_glGetShaderSource(shader, bufSize, length, source) {
      var result = GLctx.getShaderSource(GL.shaders[shader]);
      if (!result) return; // If an error occurs, nothing will be written to length or source.
      if (bufSize > 0 && source) {
        var numBytesWrittenExclNull = stringToUTF8(result, source, bufSize);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }


  function _emscripten_glCompileShader(shader) {
      GLctx.compileShader(GL.shaders[shader]);
    }


  function _emscripten_glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
      if (log === null) log = '(unknown error)';
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }


  function _emscripten_glGetShaderiv(shader, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B88) { // GL_SHADER_SOURCE_LENGTH
        var source = GLctx.getShaderSource(GL.shaders[shader]);
        var sourceLength = (source === null || source.length == 0) ? 0 : source.length + 1;
        HEAP32[((p)>>2)]=sourceLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }


  function _emscripten_glGetProgramiv(program, pname, p) {
      if (!p) {
        // GLES2 specification does not specify how to behave if p is a null pointer. Since calling this function does not make sense
        // if p == null, issue a GL error to notify user about it.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      if (program >= GL.counter) {
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        return;
      }
  
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getProgramInfoLog(GL.programs[program]);
        if (log === null) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else if (pname == 0x8B87 /* GL_ACTIVE_UNIFORM_MAX_LENGTH */) {
        HEAP32[((p)>>2)]=ptable.maxUniformLength;
      } else if (pname == 0x8B8A /* GL_ACTIVE_ATTRIBUTE_MAX_LENGTH */) {
        if (ptable.maxAttributeLength == -1) {
          program = GL.programs[program];
          var numAttribs = GLctx.getProgramParameter(program, GLctx.ACTIVE_ATTRIBUTES);
          ptable.maxAttributeLength = 0; // Spec says if there are no active attribs, 0 must be returned.
          for (var i = 0; i < numAttribs; ++i) {
            var activeAttrib = GLctx.getActiveAttrib(program, i);
            ptable.maxAttributeLength = Math.max(ptable.maxAttributeLength, activeAttrib.name.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxAttributeLength;
      } else if (pname == 0x8A35 /* GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH */) {
        if (ptable.maxUniformBlockNameLength == -1) {
          program = GL.programs[program];
          var numBlocks = GLctx.getProgramParameter(program, GLctx.ACTIVE_UNIFORM_BLOCKS);
          ptable.maxUniformBlockNameLength = 0;
          for (var i = 0; i < numBlocks; ++i) {
            var activeBlockName = GLctx.getActiveUniformBlockName(program, i);
            ptable.maxUniformBlockNameLength = Math.max(ptable.maxUniformBlockNameLength, activeBlockName.length+1);
          }
        }
        HEAP32[((p)>>2)]=ptable.maxUniformBlockNameLength;
      } else {
        HEAP32[((p)>>2)]=GLctx.getProgramParameter(GL.programs[program], pname);
      }
    }


  function _emscripten_glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return GLctx.isShader(s);
    }


  function _emscripten_glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = GLctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }


  function _emscripten_glDeleteProgram(id) {
      if (!id) return;
      var program = GL.programs[id];
      if (!program) { // glDeleteProgram actually signals an error when deleting a nonexisting object, unlike some other GL delete functions.
        GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        return;
      }
      GLctx.deleteProgram(program);
      program.name = 0;
      GL.programs[id] = null;
      GL.programInfos[id] = null;
    }


  function _emscripten_glAttachShader(program, shader) {
      GLctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }


  function _emscripten_glDetachShader(program, shader) {
      GLctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }


  function _emscripten_glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }


  function _emscripten_glLinkProgram(program) {
      GLctx.linkProgram(GL.programs[program]);
      GL.programInfos[program] = null; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }


  function _emscripten_glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = GLctx.getProgramInfoLog(GL.programs[program]);
      if (log === null) log = '(unknown error)';
  
      if (maxLength > 0 && infoLog) {
        var numBytesWrittenExclNull = stringToUTF8(log, infoLog, maxLength);
        if (length) HEAP32[((length)>>2)]=numBytesWrittenExclNull;
      } else {
        if (length) HEAP32[((length)>>2)]=0;
      }
    }


  function _emscripten_glUseProgram(program) {
      GLctx.useProgram(program ? GL.programs[program] : null);
    }


  function _emscripten_glValidateProgram(program) {
      GLctx.validateProgram(GL.programs[program]);
    }


  function _emscripten_glIsProgram(program) {
      program = GL.programs[program];
      if (!program) return 0;
      return GLctx.isProgram(program);
    }


  function _emscripten_glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      GLctx.bindAttribLocation(GL.programs[program], index, name);
    }


  function _emscripten_glBindFramebuffer(target, framebuffer) {
  
      GLctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
  
    }


  function _emscripten_glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var framebuffer = GLctx.createFramebuffer();
        if (!framebuffer) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((ids)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.framebuffers);
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        if (!framebuffer) continue; // GL spec: "glDeleteFramebuffers silently ignores 0s and names that do not correspond to existing framebuffer objects".
        GLctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }


  function _emscripten_glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }


  function _emscripten_glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      GLctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }


  function _emscripten_glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
      if (result instanceof WebGLRenderbuffer ||
          result instanceof WebGLTexture) {
        result = result.name | 0;
      }
      HEAP32[((params)>>2)]=result;
    }


  function _emscripten_glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return GLctx.isFramebuffer(fb);
    }


  function _emscripten_glGenVertexArrays(n, arrays) {
  
      for (var i = 0; i < n; i++) {
        var vao = GLctx['createVertexArray']();
        if (!vao) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((arrays)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.vaos);
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }


  function _emscripten_glDeleteVertexArrays(n, vaos) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GLctx['deleteVertexArray'](GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }


  function _emscripten_glBindVertexArray(vao) {
      GLctx['bindVertexArray'](GL.vaos[vao]);
    }


  function _emscripten_glIsVertexArray(array) {
  
      var vao = GL.vaos[array];
      if (!vao) return 0;
      return GLctx['isVertexArray'](vao);
    }


  function _emscripten_glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }


  function _emscripten_glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }


  function _emscripten_glBegin(){ throw 'Legacy GL function (glBegin) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }


  function _emscripten_glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }



  function _emscripten_glGenVertexArraysOES(n, arrays) {
  
      for (var i = 0; i < n; i++) {
        var vao = GLctx['createVertexArray']();
        if (!vao) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
          while(i < n) HEAP32[(((arrays)+(i++*4))>>2)]=0;
          return;
        }
        var id = GL.getNewId(GL.vaos);
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }



  function _emscripten_glDeleteVertexArraysOES(n, vaos) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GLctx['deleteVertexArray'](GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }



  function _emscripten_glBindVertexArrayOES(vao) {
      GLctx['bindVertexArray'](GL.vaos[vao]);
    }



  function _emscripten_glIsVertexArrayOES(array) {
  
      var vao = GL.vaos[array];
      if (!vao) return 0;
      return GLctx['isVertexArray'](vao);
    }


  function _emscripten_gluPerspective(fov, aspect, near, far) {
      GLImmediate.matricesModified = true;
      GLImmediate.matrixVersion[GLImmediate.currentMatrix] = (GLImmediate.matrixVersion[GLImmediate.currentMatrix] + 1)|0;
      GLImmediate.matrix[GLImmediate.currentMatrix] =
        GLImmediate.matrixLib.mat4.perspective(fov, aspect, near, far,
                                                 GLImmediate.matrix[GLImmediate.currentMatrix]);
    }


  function _emscripten_gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GLImmediate.matricesModified = true;
      GLImmediate.matrixVersion[GLImmediate.currentMatrix] = (GLImmediate.matrixVersion[GLImmediate.currentMatrix] + 1)|0;
      GLImmediate.matrixLib.mat4.lookAt(GLImmediate.matrix[GLImmediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }


  function _emscripten_gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
  
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GLImmediate.matrixLib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GLImmediate.matrixLib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
  
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
  
      return 1 /* GL_TRUE */;
    }


  function _emscripten_gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GLImmediate.matrixLib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
  
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
  
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
  
      return 1 /* GL_TRUE */;
    }


  function _emscripten_gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }


  function _emscripten_glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      GLctx.vertexAttribPointer(index, size, type, !!normalized, stride, ptr);
    }


  function _emscripten_glEnableVertexAttribArray(index) {
      GLctx.enableVertexAttribArray(index);
    }


  function _emscripten_glDisableVertexAttribArray(index) {
      GLctx.disableVertexAttribArray(index);
    }


  function _emscripten_glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }


  function _emscripten_glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }


  function _emscripten_glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }


  function _emscripten_glReleaseShaderCompiler() {
      // NOP (as allowed by GLES 2.0 spec)
    }


  function _emscripten_glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }


  function _emscripten_glVertexAttribDivisor(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }


  function _emscripten_glDrawArraysInstanced(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }


  function _emscripten_glDrawElementsInstanced(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }



  function _emscripten_glVertexAttribDivisorNV(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }



  function _emscripten_glDrawArraysInstancedNV(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }



  function _emscripten_glDrawElementsInstancedNV(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }



  function _emscripten_glVertexAttribDivisorEXT(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }



  function _emscripten_glDrawArraysInstancedEXT(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }



  function _emscripten_glDrawElementsInstancedEXT(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }



  function _emscripten_glVertexAttribDivisorARB(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }



  function _emscripten_glDrawArraysInstancedARB(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }



  function _emscripten_glDrawElementsInstancedARB(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }



  function _emscripten_glVertexAttribDivisorANGLE(index, divisor) {
      GLctx['vertexAttribDivisor'](index, divisor);
    }



  function _emscripten_glDrawArraysInstancedANGLE(mode, first, count, primcount) {
      GLctx['drawArraysInstanced'](mode, first, count, primcount);
    }



  function _emscripten_glDrawElementsInstancedANGLE(mode, count, type, indices, primcount) {
      GLctx['drawElementsInstanced'](mode, count, type, indices, primcount);
    }


  function _emscripten_glDrawBuffers(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }



  function _emscripten_glDrawBuffersEXT(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }



  function _emscripten_glDrawBuffersWEBGL(n, bufs) {
  
      var bufArray = GL.tempFixedLengthArray[n];
      for (var i = 0; i < n; i++) {
        bufArray[i] = HEAP32[(((bufs)+(i*4))>>2)];
      }
  
      GLctx['drawBuffers'](bufArray);
    }


  function _emscripten_glColorMask(red, green, blue, alpha) {
      GLctx.colorMask(!!red, !!green, !!blue, !!alpha);
    }


  function _emscripten_glDepthMask(flag) {
      GLctx.depthMask(!!flag);
    }


  function _emscripten_glSampleCoverage(value, invert) {
      GLctx.sampleCoverage(value, !!invert);
    }


  function _emscripten_glFinish() { GLctx['finish']() }


  function _emscripten_glFlush() { GLctx['flush']() }


  function _emscripten_glClearDepth(x0) { GLctx['clearDepth'](x0) }


  function _emscripten_glClearDepthf(x0) { GLctx['clearDepth'](x0) }


  function _emscripten_glDepthFunc(x0) { GLctx['depthFunc'](x0) }


  function _emscripten_glEnable(x0) { GLctx['enable'](x0) }


  function _emscripten_glDisable(x0) { GLctx['disable'](x0) }


  function _emscripten_glFrontFace(x0) { GLctx['frontFace'](x0) }


  function _emscripten_glCullFace(x0) { GLctx['cullFace'](x0) }


  function _emscripten_glClear(x0) { GLctx['clear'](x0) }


  function _emscripten_glLineWidth(x0) { GLctx['lineWidth'](x0) }


  function _emscripten_glClearStencil(x0) { GLctx['clearStencil'](x0) }


  function _emscripten_glStencilMask(x0) { GLctx['stencilMask'](x0) }


  function _emscripten_glCheckFramebufferStatus(x0) { return GLctx['checkFramebufferStatus'](x0) }


  function _emscripten_glGenerateMipmap(x0) { GLctx['generateMipmap'](x0) }


  function _emscripten_glActiveTexture(x0) { GLctx['activeTexture'](x0) }


  function _emscripten_glBlendEquation(x0) { GLctx['blendEquation'](x0) }


  function _emscripten_glIsEnabled(x0) { return GLctx['isEnabled'](x0) }


  function _emscripten_glBlendFunc(x0, x1) { GLctx['blendFunc'](x0, x1) }


  function _emscripten_glBlendEquationSeparate(x0, x1) { GLctx['blendEquationSeparate'](x0, x1) }


  function _emscripten_glDepthRange(x0, x1) { GLctx['depthRange'](x0, x1) }


  function _emscripten_glDepthRangef(x0, x1) { GLctx['depthRange'](x0, x1) }


  function _emscripten_glStencilMaskSeparate(x0, x1) { GLctx['stencilMaskSeparate'](x0, x1) }


  function _emscripten_glHint(x0, x1) { GLctx['hint'](x0, x1) }


  function _emscripten_glPolygonOffset(x0, x1) { GLctx['polygonOffset'](x0, x1) }


  function _emscripten_glVertexAttrib1f(x0, x1) { GLctx['vertexAttrib1f'](x0, x1) }


  function _emscripten_glTexParameteri(x0, x1, x2) { GLctx['texParameteri'](x0, x1, x2) }


  function _emscripten_glTexParameterf(x0, x1, x2) { GLctx['texParameterf'](x0, x1, x2) }


  function _emscripten_glVertexAttrib2f(x0, x1, x2) { GLctx['vertexAttrib2f'](x0, x1, x2) }


  function _emscripten_glStencilFunc(x0, x1, x2) { GLctx['stencilFunc'](x0, x1, x2) }


  function _emscripten_glStencilOp(x0, x1, x2) { GLctx['stencilOp'](x0, x1, x2) }


  function _emscripten_glViewport(x0, x1, x2, x3) { GLctx['viewport'](x0, x1, x2, x3) }


  function _emscripten_glClearColor(x0, x1, x2, x3) { GLctx['clearColor'](x0, x1, x2, x3) }


  function _emscripten_glScissor(x0, x1, x2, x3) { GLctx['scissor'](x0, x1, x2, x3) }


  function _emscripten_glVertexAttrib3f(x0, x1, x2, x3) { GLctx['vertexAttrib3f'](x0, x1, x2, x3) }


  function _emscripten_glRenderbufferStorage(x0, x1, x2, x3) { GLctx['renderbufferStorage'](x0, x1, x2, x3) }


  function _emscripten_glBlendFuncSeparate(x0, x1, x2, x3) { GLctx['blendFuncSeparate'](x0, x1, x2, x3) }


  function _emscripten_glBlendColor(x0, x1, x2, x3) { GLctx['blendColor'](x0, x1, x2, x3) }


  function _emscripten_glStencilFuncSeparate(x0, x1, x2, x3) { GLctx['stencilFuncSeparate'](x0, x1, x2, x3) }


  function _emscripten_glStencilOpSeparate(x0, x1, x2, x3) { GLctx['stencilOpSeparate'](x0, x1, x2, x3) }


  function _emscripten_glVertexAttrib4f(x0, x1, x2, x3, x4) { GLctx['vertexAttrib4f'](x0, x1, x2, x3, x4) }


  function _emscripten_glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }


  function _emscripten_glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx['copyTexSubImage2D'](x0, x1, x2, x3, x4, x5, x6, x7) }


  var GLUT={initTime:null,idleFunc:null,displayFunc:null,keyboardFunc:null,keyboardUpFunc:null,specialFunc:null,specialUpFunc:null,reshapeFunc:null,motionFunc:null,passiveMotionFunc:null,mouseFunc:null,buttons:0,modifiers:0,initWindowWidth:256,initWindowHeight:256,initDisplayMode:18,windowX:0,windowY:0,windowWidth:0,windowHeight:0,requestedAnimationFrame:false,saveModifiers:function (event) {
        GLUT.modifiers = 0;
        if (event['shiftKey'])
          GLUT.modifiers += 1; /* GLUT_ACTIVE_SHIFT */
        if (event['ctrlKey'])
          GLUT.modifiers += 2; /* GLUT_ACTIVE_CTRL */
        if (event['altKey'])
          GLUT.modifiers += 4; /* GLUT_ACTIVE_ALT */
      },onMousemove:function (event) {
        /* Send motion event only if the motion changed, prevents
         * spamming our app with uncessary callback call. It does happen in
         * Chrome on Windows.
         */
        var lastX = Browser.mouseX;
        var lastY = Browser.mouseY;
        Browser.calculateMouseEvent(event);
        var newX = Browser.mouseX;
        var newY = Browser.mouseY;
        if (newX == lastX && newY == lastY) return;
  
        if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_vii'](GLUT.passiveMotionFunc, lastX, lastY);
        } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_vii'](GLUT.motionFunc, lastX, lastY);
        }
      },getSpecialKey:function (keycode) {
          var key = null;
          switch (keycode) {
            case 8:  key = 120 /* backspace */; break;
            case 46: key = 111 /* delete */; break;
  
            case 0x70 /*DOM_VK_F1*/: key = 1 /* GLUT_KEY_F1 */; break;
            case 0x71 /*DOM_VK_F2*/: key = 2 /* GLUT_KEY_F2 */; break;
            case 0x72 /*DOM_VK_F3*/: key = 3 /* GLUT_KEY_F3 */; break;
            case 0x73 /*DOM_VK_F4*/: key = 4 /* GLUT_KEY_F4 */; break;
            case 0x74 /*DOM_VK_F5*/: key = 5 /* GLUT_KEY_F5 */; break;
            case 0x75 /*DOM_VK_F6*/: key = 6 /* GLUT_KEY_F6 */; break;
            case 0x76 /*DOM_VK_F7*/: key = 7 /* GLUT_KEY_F7 */; break;
            case 0x77 /*DOM_VK_F8*/: key = 8 /* GLUT_KEY_F8 */; break;
            case 0x78 /*DOM_VK_F9*/: key = 9 /* GLUT_KEY_F9 */; break;
            case 0x79 /*DOM_VK_F10*/: key = 10 /* GLUT_KEY_F10 */; break;
            case 0x7a /*DOM_VK_F11*/: key = 11 /* GLUT_KEY_F11 */; break;
            case 0x7b /*DOM_VK_F12*/: key = 12 /* GLUT_KEY_F12 */; break;
            case 0x25 /*DOM_VK_LEFT*/: key = 100 /* GLUT_KEY_LEFT */; break;
            case 0x26 /*DOM_VK_UP*/: key = 101 /* GLUT_KEY_UP */; break;
            case 0x27 /*DOM_VK_RIGHT*/: key = 102 /* GLUT_KEY_RIGHT */; break;
            case 0x28 /*DOM_VK_DOWN*/: key = 103 /* GLUT_KEY_DOWN */; break;
            case 0x21 /*DOM_VK_PAGE_UP*/: key = 104 /* GLUT_KEY_PAGE_UP */; break;
            case 0x22 /*DOM_VK_PAGE_DOWN*/: key = 105 /* GLUT_KEY_PAGE_DOWN */; break;
            case 0x24 /*DOM_VK_HOME*/: key = 106 /* GLUT_KEY_HOME */; break;
            case 0x23 /*DOM_VK_END*/: key = 107 /* GLUT_KEY_END */; break;
            case 0x2d /*DOM_VK_INSERT*/: key = 108 /* GLUT_KEY_INSERT */; break;
  
            case 16   /*DOM_VK_SHIFT*/:
            case 0x05 /*DOM_VK_LEFT_SHIFT*/:
              key = 112 /* GLUT_KEY_SHIFT_L */;
              break;
            case 0x06 /*DOM_VK_RIGHT_SHIFT*/:
              key = 113 /* GLUT_KEY_SHIFT_R */;
              break;
  
            case 17   /*DOM_VK_CONTROL*/:
            case 0x03 /*DOM_VK_LEFT_CONTROL*/:
              key = 114 /* GLUT_KEY_CONTROL_L */;
              break;
            case 0x04 /*DOM_VK_RIGHT_CONTROL*/:
              key = 115 /* GLUT_KEY_CONTROL_R */;
              break;
  
            case 18   /*DOM_VK_ALT*/:
            case 0x02 /*DOM_VK_LEFT_ALT*/:
              key = 116 /* GLUT_KEY_ALT_L */;
              break;
            case 0x01 /*DOM_VK_RIGHT_ALT*/:
              key = 117 /* GLUT_KEY_ALT_R */;
              break;
          };
          return key;
      },getASCIIKey:function (event) {
        if (event['ctrlKey'] || event['altKey'] || event['metaKey']) return null;
  
        var keycode = event['keyCode'];
  
        /* The exact list is soooo hard to find in a canonical place! */
  
        if (48 <= keycode && keycode <= 57)
          return keycode; // numeric  TODO handle shift?
        if (65 <= keycode && keycode <= 90)
          return event['shiftKey'] ? keycode : keycode + 32;
        if (96 <= keycode && keycode <= 105)
          return keycode - 48; // numpad numbers    
        if (106 <= keycode && keycode <= 111)
          return keycode - 106 + 42; // *,+-./  TODO handle shift?
  
        switch (keycode) {
          case 9:  // tab key
          case 13: // return key
          case 27: // escape
          case 32: // space
          case 61: // equal
            return keycode;
        }
  
        var s = event['shiftKey'];
        switch (keycode) {
          case 186: return s ? 58 : 59; // colon / semi-colon
          case 187: return s ? 43 : 61; // add / equal (these two may be wrong)
          case 188: return s ? 60 : 44; // less-than / comma
          case 189: return s ? 95 : 45; // dash
          case 190: return s ? 62 : 46; // greater-than / period
          case 191: return s ? 63 : 47; // forward slash
          case 219: return s ? 123 : 91; // open bracket
          case 220: return s ? 124 : 47; // back slash
          case 221: return s ? 125 : 93; // close braket
          case 222: return s ? 34 : 39; // single quote
        }
  
        return null;
      },onKeydown:function (event) {
        if (GLUT.specialFunc || GLUT.keyboardFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if( GLUT.specialFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.specialFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.keyboardFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
        }
      },onKeyup:function (event) {
        if (GLUT.specialUpFunc || GLUT.keyboardUpFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if(GLUT.specialUpFunc) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.specialUpFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardUpFunc ) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Module['dynCall_viii'](GLUT.keyboardUpFunc, key, Browser.mouseX, Browser.mouseY);
            }
          }
        }
      },touchHandler:function (event) {
        if (event.target != Module['canvas']) {
          return;
        }
  
        var touches = event.changedTouches,
            main = touches[0],
            type = "";
  
        switch(event.type) {
          case "touchstart": type = "mousedown"; break;
          case "touchmove": type = "mousemove"; break;
          case "touchend": type = "mouseup"; break;
          default: return;
        }
  
        var simulatedEvent = document.createEvent("MouseEvent");
        simulatedEvent.initMouseEvent(type, true, true, window, 1, 
                                      main.screenX, main.screenY, 
                                      main.clientX, main.clientY, false, 
                                      false, false, false, 0/*main*/, null);
  
        main.target.dispatchEvent(simulatedEvent);
        event.preventDefault();
      },onMouseButtonDown:function (event) {
        Browser.calculateMouseEvent(event);
  
        GLUT.buttons |= (1 << event['button']);
  
        if (event.target == Module["canvas"] && GLUT.mouseFunc) {
          try {
            event.target.setCapture();
          } catch (e) {}
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
        }
      },onMouseButtonUp:function (event) {
        Browser.calculateMouseEvent(event);
  
        GLUT.buttons &= ~(1 << event['button']);
  
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 1/*GLUT_UP*/, Browser.mouseX, Browser.mouseY);
        }
      },onMouseWheel:function (event) {
        Browser.calculateMouseEvent(event);
  
        // cross-browser wheel delta
        var e = window.event || event; // old IE support
        // Note the minus sign that flips browser wheel direction (positive direction scrolls page down) to native wheel direction (positive direction is mouse wheel up)
        var delta = -Browser.getMouseWheelDelta(event);
        delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.
  
        var button = 3; // wheel up
        if (delta < 0) {
          button = 4; // wheel down
        }
  
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Module['dynCall_viiii'](GLUT.mouseFunc, button, 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
        }
      },onFullscreenEventChange:function (event) {
        var width;
        var height;
        if (document["fullscreen"] || document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
          width = screen["width"];
          height = screen["height"];
        } else {
          width = GLUT.windowWidth;
          height = GLUT.windowHeight;
          // TODO set position
          document.removeEventListener('fullscreenchange', GLUT.onFullscreenEventChange, true);
          document.removeEventListener('mozfullscreenchange', GLUT.onFullscreenEventChange, true);
          document.removeEventListener('webkitfullscreenchange', GLUT.onFullscreenEventChange, true);
        }
        Browser.setCanvasSize(width, height, true); // N.B. GLUT.reshapeFunc is also registered as a canvas resize callback.
                                                    // Just call it once here.
        /* Can't call _glutReshapeWindow as that requests cancelling fullscreen. */
        if (GLUT.reshapeFunc) {
          // console.log("GLUT.reshapeFunc (from FS): " + width + ", " + height);
          Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
        }
        _glutPostRedisplay();
      },requestFullscreen:function () {
        Browser.requestFullscreen(/*lockPointer=*/false, /*resizeCanvas=*/false);
      },requestFullScreen:function () {
        err('GLUT.requestFullScreen() is deprecated. Please call GLUT.requestFullscreen instead.');
        GLUT.requestFullScreen = function() {
          return GLUT.requestFullscreen();
        }
        return GLUT.requestFullscreen();
      },exitFullscreen:function () {
        var CFS = document['exitFullscreen'] ||
                  document['cancelFullScreen'] ||
                  document['mozCancelFullScreen'] ||
                  document['webkitCancelFullScreen'] ||
            (function() {});
        CFS.apply(document, []);
      },cancelFullScreen:function () {
        err('GLUT.cancelFullScreen() is deprecated. Please call GLUT.exitFullscreen instead.');
        GLUT.cancelFullScreen = function() {
          return GLUT.exitFullscreen();
        }
        return GLUT.exitFullscreen();
      }};


  function _glutGetModifiers() { return GLUT.modifiers; }


  function _glutInit(argcp, argv) {
      // Ignore arguments
      GLUT.initTime = Date.now();
  
      var isTouchDevice = 'ontouchstart' in document.documentElement;
      if (isTouchDevice) {
        // onMouseButtonDown, onMouseButtonUp and onMousemove handlers
        // depend on Browser.mouseX / Browser.mouseY fields. Those fields
        // don't get updated by touch events. So register a touchHandler
        // function that translates the touch events to mouse events.
  
        // GLUT doesn't support touch, mouse only, so from touch events we
        // are only looking at single finger touches to emulate left click,
        // so we can use workaround and convert all touch events in mouse
        // events. See touchHandler.
        window.addEventListener("touchmove", GLUT.touchHandler, true);
        window.addEventListener("touchstart", GLUT.touchHandler, true);
        window.addEventListener("touchend", GLUT.touchHandler, true);
      }
  
      window.addEventListener("keydown", GLUT.onKeydown, true);
      window.addEventListener("keyup", GLUT.onKeyup, true);
      window.addEventListener("mousemove", GLUT.onMousemove, true);
      window.addEventListener("mousedown", GLUT.onMouseButtonDown, true);
      window.addEventListener("mouseup", GLUT.onMouseButtonUp, true);
      // IE9, Chrome, Safari, Opera
      window.addEventListener("mousewheel", GLUT.onMouseWheel, true);
      // Firefox
      window.addEventListener("DOMMouseScroll", GLUT.onMouseWheel, true);
  
      Browser.resizeListeners.push(function(width, height) {
        if (GLUT.reshapeFunc) {
          Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
        }
      });
  
      __ATEXIT__.push(function() {
        if (isTouchDevice) {
          window.removeEventListener("touchmove", GLUT.touchHandler, true);
          window.removeEventListener("touchstart", GLUT.touchHandler, true);
          window.removeEventListener("touchend", GLUT.touchHandler, true);
        }
  
        window.removeEventListener("keydown", GLUT.onKeydown, true);
        window.removeEventListener("keyup", GLUT.onKeyup, true);
        window.removeEventListener("mousemove", GLUT.onMousemove, true);
        window.removeEventListener("mousedown", GLUT.onMouseButtonDown, true);
        window.removeEventListener("mouseup", GLUT.onMouseButtonUp, true);
        // IE9, Chrome, Safari, Opera
        window.removeEventListener("mousewheel", GLUT.onMouseWheel, true);
        // Firefox
        window.removeEventListener("DOMMouseScroll", GLUT.onMouseWheel, true);
  
        Module["canvas"].width = Module["canvas"].height = 1;
      });
    }


  function _glutInitWindowSize(width, height) {
      Browser.setCanvasSize( GLUT.initWindowWidth = width,
                             GLUT.initWindowHeight = height );
    }


  function _glutInitWindowPosition(x, y) {
      // Ignore for now
    }

  function _glutGet(type) {
      switch (type) {
        case 100: /* GLUT_WINDOW_X */
          return 0; /* TODO */
        case 101: /* GLUT_WINDOW_Y */
          return 0; /* TODO */
        case 102: /* GLUT_WINDOW_WIDTH */
          return Module['canvas'].width;
        case 103: /* GLUT_WINDOW_HEIGHT */
          return Module['canvas'].height;
        case 200: /* GLUT_SCREEN_WIDTH */
          return Module['canvas'].width;
        case 201: /* GLUT_SCREEN_HEIGHT */
          return Module['canvas'].height;
        case 500: /* GLUT_INIT_WINDOW_X */
          return 0; /* TODO */
        case 501: /* GLUT_INIT_WINDOW_Y */
          return 0; /* TODO */
        case 502: /* GLUT_INIT_WINDOW_WIDTH */
          return GLUT.initWindowWidth;
        case 503: /* GLUT_INIT_WINDOW_HEIGHT */
          return GLUT.initWindowHeight;
        case 700: /* GLUT_ELAPSED_TIME */
          var now = Date.now();
          return now - GLUT.initTime;
        case 0x0069: /* GLUT_WINDOW_STENCIL_SIZE */
          return Module.ctx.getContextAttributes().stencil ? 8 : 0;
        case 0x006A: /* GLUT_WINDOW_DEPTH_SIZE */
          return Module.ctx.getContextAttributes().depth ? 8 : 0;
        case 0x006E: /* GLUT_WINDOW_ALPHA_SIZE */
          return Module.ctx.getContextAttributes().alpha ? 8 : 0;
        case 0x0078: /* GLUT_WINDOW_NUM_SAMPLES */
          return Module.ctx.getContextAttributes().antialias ? 1 : 0;
  
        default:
          throw "glutGet(" + type + ") not implemented yet";
      }
    }


  function _glutIdleFunc(func) {
      function callback() {
        if (GLUT.idleFunc) {
          Module['dynCall_v'](GLUT.idleFunc);
          Browser.safeSetTimeout(callback, 4); // HTML spec specifies a 4ms minimum delay on the main thread; workers might get more, but we standardize here
        }
      }
      if (!GLUT.idleFunc) {
        Browser.safeSetTimeout(callback, 0);
      }
      GLUT.idleFunc = func;
    }


  function _glutTimerFunc(msec, func, value) {
      Browser.safeSetTimeout(function() { Module['dynCall_vi'](func, value); }, msec);
    }


  function _glutDisplayFunc(func) {
      GLUT.displayFunc = func;
    }


  function _glutKeyboardFunc(func) {
      GLUT.keyboardFunc = func;
    }


  function _glutKeyboardUpFunc(func) {
      GLUT.keyboardUpFunc = func;
    }


  function _glutSpecialFunc(func) {
      GLUT.specialFunc = func;
    }


  function _glutSpecialUpFunc(func) {
      GLUT.specialUpFunc = func;
    }


  function _glutReshapeFunc(func) {
      GLUT.reshapeFunc = func;
    }


  function _glutMotionFunc(func) {
      GLUT.motionFunc = func;
    }


  function _glutPassiveMotionFunc(func) {
      GLUT.passiveMotionFunc = func;
    }


  function _glutMouseFunc(func) {
      GLUT.mouseFunc = func;
    }


  function _glutSetCursor(cursor) {
      var cursorStyle = 'auto';
      switch(cursor) {
        case 0x0000: /* GLUT_CURSOR_RIGHT_ARROW */
          // No equivalent css cursor style, fallback to 'auto'
          break;
        case 0x0001: /* GLUT_CURSOR_LEFT_ARROW */
          // No equivalent css cursor style, fallback to 'auto'
          break;
        case 0x0002: /* GLUT_CURSOR_INFO */
          cursorStyle = 'pointer';
          break;
        case 0x0003: /* GLUT_CURSOR_DESTROY */
          // No equivalent css cursor style, fallback to 'auto'
          break;
        case 0x0004: /* GLUT_CURSOR_HELP */
          cursorStyle = 'help';
          break;
        case 0x0005: /* GLUT_CURSOR_CYCLE */
          // No equivalent css cursor style, fallback to 'auto'
          break;
        case 0x0006: /* GLUT_CURSOR_SPRAY */
          // No equivalent css cursor style, fallback to 'auto'
          break;
        case 0x0007: /* GLUT_CURSOR_WAIT */
          cursorStyle = 'wait';
          break;
        case 0x0008: /* GLUT_CURSOR_TEXT */
          cursorStyle = 'text';
          break;
        case 0x0009: /* GLUT_CURSOR_CROSSHAIR */
        case 0x0066: /* GLUT_CURSOR_FULL_CROSSHAIR */
          cursorStyle = 'crosshair';
          break;
        case 0x000A: /* GLUT_CURSOR_UP_DOWN */
          cursorStyle = 'ns-resize';
          break;
        case 0x000B: /* GLUT_CURSOR_LEFT_RIGHT */
          cursorStyle = 'ew-resize';
          break;
        case 0x000C: /* GLUT_CURSOR_TOP_SIDE */
          cursorStyle = 'n-resize';
          break;
        case 0x000D: /* GLUT_CURSOR_BOTTOM_SIDE */
          cursorStyle = 's-resize';
          break;
        case 0x000E: /* GLUT_CURSOR_LEFT_SIDE */
          cursorStyle = 'w-resize';
          break;
        case 0x000F: /* GLUT_CURSOR_RIGHT_SIDE */
          cursorStyle = 'e-resize';
          break;
        case 0x0010: /* GLUT_CURSOR_TOP_LEFT_CORNER */
          cursorStyle = 'nw-resize';
          break;
        case 0x0011: /* GLUT_CURSOR_TOP_RIGHT_CORNER */
          cursorStyle = 'ne-resize';
          break;
        case 0x0012: /* GLUT_CURSOR_BOTTOM_RIGHT_CORNER */
          cursorStyle = 'se-resize';
          break;
        case 0x0013: /* GLUT_CURSOR_BOTTOM_LEFT_CORNER */
          cursorStyle = 'sw-resize';
          break;
        case 0x0064: /* GLUT_CURSOR_INHERIT */
          break;
        case 0x0065: /* GLUT_CURSOR_NONE */
          cursorStyle = 'none';
          break;
        default:
          throw "glutSetCursor: Unknown cursor type: " + cursor;
      }
      Module['canvas'].style.cursor = cursorStyle;
    }


  function _glutCreateWindow(name) {
      var contextAttributes = {
        antialias: ((GLUT.initDisplayMode & 0x0080 /*GLUT_MULTISAMPLE*/) != 0),
        depth: ((GLUT.initDisplayMode & 0x0010 /*GLUT_DEPTH*/) != 0),
        stencil: ((GLUT.initDisplayMode & 0x0020 /*GLUT_STENCIL*/) != 0),
        alpha: ((GLUT.initDisplayMode & 0x0008 /*GLUT_ALPHA*/) != 0)
      };
      Module.ctx = Browser.createContext(Module['canvas'], true, true, contextAttributes);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }


  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }


  
  function _glutPostRedisplay() {
      if (GLUT.displayFunc && !GLUT.requestedAnimationFrame) {
        GLUT.requestedAnimationFrame = true;
        Browser.requestAnimationFrame(function() {
          GLUT.requestedAnimationFrame = false;
          Browser.mainLoop.runIter(function() {
            Module['dynCall_v'](GLUT.displayFunc);
          });
        });
      }
    }function _glutReshapeWindow(width, height) {
      GLUT.exitFullscreen();
      Browser.setCanvasSize(width, height, true); // N.B. GLUT.reshapeFunc is also registered as a canvas resize callback.
                                                  // Just call it once here.
      if (GLUT.reshapeFunc) {
        Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
      }
      _glutPostRedisplay();
    }


  function _glutPositionWindow(x, y) {
      GLUT.exitFullscreen();
      /* TODO */
      _glutPostRedisplay();
    }


  function _glutFullScreen() {
      GLUT.windowX = 0; // TODO
      GLUT.windowY = 0; // TODO
      GLUT.windowWidth  = Module['canvas'].width;
      GLUT.windowHeight = Module['canvas'].height;
      document.addEventListener('fullscreenchange', GLUT.onFullscreenEventChange, true);
      document.addEventListener('mozfullscreenchange', GLUT.onFullscreenEventChange, true);
      document.addEventListener('webkitfullscreenchange', GLUT.onFullscreenEventChange, true);
      GLUT.requestFullscreen();
    }


  function _glutInitDisplayMode(mode) {
      GLUT.initDisplayMode = mode;
    }


  function _glutSwapBuffers() {}




  function _glutMainLoop() {
      _glutReshapeWindow(Module['canvas'].width, Module['canvas'].height);
      _glutPostRedisplay();
      throw 'SimulateInfiniteLoop';
    }

  function _XOpenDisplay() {
      return 1; // We support 1 display, the canvas
    }

  function _XCreateWindow(display, parent, x, y, width, height, border_width, depth, class_, visual, valuemask, attributes) {
      // All we can do is set the width and height
      Browser.setCanvasSize(width, height);
      return 2;
    }

  function _XChangeWindowAttributes(){}

  function _XSetWMHints(){}

  function _XMapWindow(){}

  function _XStoreName(){}

  function _XInternAtom(display, name_, hmm) { return 0 }

  function _XSendEvent(){}

  function _XPending(display) { return 0 }

  var EGL={errorCode:12288,defaultDisplayInitialized:false,currentContext:0,currentReadSurface:0,currentDrawSurface:0,alpha:false,depth:true,stencil:true,antialias:true,stringCache:{},setErrorCode:function (code) {
        EGL.errorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
  
        if (attribList) {
          // read attribList if it is non-null
          for(;;) {
            var param = HEAP32[((attribList)>>2)];
            if (param == 0x3021 /*EGL_ALPHA_SIZE*/) {
              var alphaSize = HEAP32[(((attribList)+(4))>>2)];
              EGL.alpha = (alphaSize > 0);
            } else if (param == 0x3025 /*EGL_DEPTH_SIZE*/) {
              var depthSize = HEAP32[(((attribList)+(4))>>2)];
              EGL.depth = (depthSize > 0);
            } else if (param == 0x3026 /*EGL_STENCIL_SIZE*/) {
              var stencilSize = HEAP32[(((attribList)+(4))>>2)];
              EGL.stencil = (stencilSize > 0);
            } else if (param == 0x3031 /*EGL_SAMPLES*/) {
              var samples = HEAP32[(((attribList)+(4))>>2)];
              EGL.antialias = (samples > 0);
            } else if (param == 0x3032 /*EGL_SAMPLE_BUFFERS*/) {
              var samples = HEAP32[(((attribList)+(4))>>2)];
              EGL.antialias = (samples == 1);
            } else if (param == 0x3038 /*EGL_NONE*/) {
                break;
            }
            attribList += 8;
          }
        }
  
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};

  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }

  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.defaultDisplayInitialized = true;
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }

  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.currentContext = 0;
      EGL.currentReadSurface = 0;
      EGL.currentDrawSurface = 0;
      EGL.defaultDisplayInitialized = false;
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _eglGetConfigs(display, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, 0, configs, config_size, numConfigs);
    }

  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }

  function _eglGetConfigAttrib(display, config, attribute, value) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3020: // EGL_BUFFER_SIZE
        HEAP32[((value)>>2)]=32;
        return 1;
      case 0x3021: // EGL_ALPHA_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3022: // EGL_BLUE_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3023: // EGL_GREEN_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3024: // EGL_RED_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3025: // EGL_DEPTH_SIZE
        HEAP32[((value)>>2)]=24;
        return 1;
      case 0x3026: // EGL_STENCIL_SIZE
        HEAP32[((value)>>2)]=8;
        return 1;
      case 0x3027: // EGL_CONFIG_CAVEAT
        // We can return here one of EGL_NONE (0x3038), EGL_SLOW_CONFIG (0x3050) or EGL_NON_CONFORMANT_CONFIG (0x3051).
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
        return 1;
      case 0x3029: // EGL_LEVEL
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302A: // EGL_MAX_PBUFFER_HEIGHT
        HEAP32[((value)>>2)]=4096;
        return 1;
      case 0x302B: // EGL_MAX_PBUFFER_PIXELS
        HEAP32[((value)>>2)]=16777216;
        return 1;
      case 0x302C: // EGL_MAX_PBUFFER_WIDTH
        HEAP32[((value)>>2)]=4096;
        return 1;
      case 0x302D: // EGL_NATIVE_RENDERABLE
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302E: // EGL_NATIVE_VISUAL_ID
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x302F: // EGL_NATIVE_VISUAL_TYPE
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3031: // EGL_SAMPLES
        HEAP32[((value)>>2)]=4;
        return 1;
      case 0x3032: // EGL_SAMPLE_BUFFERS
        HEAP32[((value)>>2)]=1;
        return 1;
      case 0x3033: // EGL_SURFACE_TYPE
        HEAP32[((value)>>2)]=0x0004;
        return 1;
      case 0x3034: // EGL_TRANSPARENT_TYPE
        // If this returns EGL_TRANSPARENT_RGB (0x3052), transparency is used through color-keying. No such thing applies to Emscripten canvas.
        HEAP32[((value)>>2)]=0x3038;
        return 1;
      case 0x3035: // EGL_TRANSPARENT_BLUE_VALUE
      case 0x3036: // EGL_TRANSPARENT_GREEN_VALUE
      case 0x3037: // EGL_TRANSPARENT_RED_VALUE
        // "If EGL_TRANSPARENT_TYPE is EGL_NONE, then the values for EGL_TRANSPARENT_RED_VALUE, EGL_TRANSPARENT_GREEN_VALUE, and EGL_TRANSPARENT_BLUE_VALUE are undefined."
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3039: // EGL_BIND_TO_TEXTURE_RGB
      case 0x303A: // EGL_BIND_TO_TEXTURE_RGBA
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x303B: // EGL_MIN_SWAP_INTERVAL
      case 0x303C: // EGL_MAX_SWAP_INTERVAL
        HEAP32[((value)>>2)]=1;
        return 1;
      case 0x303D: // EGL_LUMINANCE_SIZE
      case 0x303E: // EGL_ALPHA_MASK_SIZE
        HEAP32[((value)>>2)]=0;
        return 1;
      case 0x303F: // EGL_COLOR_BUFFER_TYPE
        // EGL has two types of buffers: EGL_RGB_BUFFER and EGL_LUMINANCE_BUFFER.
        HEAP32[((value)>>2)]=0x308E;
        return 1;
      case 0x3040: // EGL_RENDERABLE_TYPE
        // A bit combination of EGL_OPENGL_ES_BIT,EGL_OPENVG_BIT,EGL_OPENGL_ES2_BIT and EGL_OPENGL_BIT.
        HEAP32[((value)>>2)]=0x0004;
        return 1;
      case 0x3042: // EGL_CONFORMANT
        // "EGL_CONFORMANT is a mask indicating if a client API context created with respect to the corresponding EGLConfig will pass the required conformance tests for that API."
        HEAP32[((value)>>2)]=0;
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }

  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }

  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      if (EGL.currentReadSurface == surface) {
        EGL.currentReadSurface = 0;
      }
      if (EGL.currentDrawSurface == surface) {
        EGL.currentDrawSurface = 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }

  function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
  
      // EGL 1.4 spec says default EGL_CONTEXT_CLIENT_VERSION is GLES1, but this is not supported by Emscripten.
      // So user must pass EGL_CONTEXT_CLIENT_VERSION == 2 to initialize EGL.
      var glesContextVersion = 1;
      for(;;) {
        var param = HEAP32[((contextAttribs)>>2)];
        if (param == 0x3098 /*EGL_CONTEXT_CLIENT_VERSION*/) {
          glesContextVersion = HEAP32[(((contextAttribs)+(4))>>2)];
        } else if (param == 0x3038 /*EGL_NONE*/) {
          break;
        } else {
          /* EGL1.4 specifies only EGL_CONTEXT_CLIENT_VERSION as supported attribute */
          EGL.setErrorCode(0x3004 /*EGL_BAD_ATTRIBUTE*/);
          return 0;
        }
        contextAttribs += 8;
      }
      if (glesContextVersion != 2) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0; /* EGL_NO_CONTEXT */
      }
  
      // convert configuration to GLUT flags
      var displayMode = 0x0000; /*GLUT_RGB/GLUT_RGBA*/
      displayMode |= 0x0002; /*GLUT_DOUBLE*/
      if (EGL.alpha)     displayMode |= 0x0008; /*GLUT_ALPHA*/
      if (EGL.depth)     displayMode |= 0x0010; /*GLUT_DEPTH*/
      if (EGL.stencil)   displayMode |= 0x0020; /*GLUT_STENCIL*/
      if (EGL.antialias) displayMode |= 0x0080; /*GLUT_MULTISAMPLE*/
  
      _glutInitDisplayMode(displayMode);
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        // Note: This function only creates a context, but it shall not make it active.
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }

  function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
  
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
  
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }

  function _eglQueryContext(display, context, attribute, value) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
        case 0x3028: // EGL_CONFIG_ID
          HEAP32[((value)>>2)]=62002;
          return 1;
        case 0x3097: // EGL_CONTEXT_CLIENT_TYPE
          HEAP32[((value)>>2)]=0x30A0;
          return 1;
        case 0x3098: // EGL_CONTEXT_CLIENT_VERSION
          HEAP32[((value)>>2)]=2; // We always report the context to be a GLES2 context (and not a GLES1 context)
          return 1;
        case 0x3086: // EGL_RENDER_BUFFER
          // The context is bound to the visible canvas window - it's always backbuffered. 
          // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
          HEAP32[((value)>>2)]=0x3084; 
          return 1;
        default:
          EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
          return 0;
      }
    }

  function _eglGetError() { 
      return EGL.errorCode;
    }

  function _eglQueryString(display, name) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      if (EGL.stringCache[name]) return EGL.stringCache[name];
      var ret;
      switch(name) {
        case 0x3053 /* EGL_VENDOR */: ret = allocate(intArrayFromString("Emscripten"), 'i8', ALLOC_NORMAL); break;
        case 0x3054 /* EGL_VERSION */: ret = allocate(intArrayFromString("1.4 Emscripten EGL"), 'i8', ALLOC_NORMAL); break;
        case 0x3055 /* EGL_EXTENSIONS */:  ret = allocate(intArrayFromString(""), 'i8', ALLOC_NORMAL); break; // Currently not supporting any EGL extensions.
        case 0x308D /* EGL_CLIENT_APIS */: ret = allocate(intArrayFromString("OpenGL_ES"), 'i8', ALLOC_NORMAL); break;
        default:
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
      }
      EGL.stringCache[name] = ret;
      return ret;
    }

  function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }

  function _eglQueryAPI() {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 0x30A0; // EGL_OPENGL_ES_API
    }

  function _eglWaitClient() {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _eglWaitNative(nativeEngineId) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _eglWaitGL() {
  return _eglWaitClient.apply(null, arguments)
  }

  function _eglSwapInterval(display, interval) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (interval == 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 0);
      else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, interval);
  
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }

  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0 /* EGL_FALSE */;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 0 && context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if ((read != 0 && read != 62006) || (draw != 0 && draw != 62006 /* Magic ID for Emscripten 'default surface' */)) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.currentContext = context;
      EGL.currentDrawSurface = draw;
      EGL.currentReadSurface = read;
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1 /* EGL_TRUE */;
    }

  function _eglGetCurrentContext() {
      return EGL.currentContext;
    }

  function _eglGetCurrentSurface(readdraw) {
      if (readdraw == 0x305A /* EGL_READ */) {
        return EGL.currentReadSurface;
      } else if (readdraw == 0x3059 /* EGL_DRAW */) {
        return EGL.currentDrawSurface;
      } else {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0 /* EGL_NO_SURFACE */;
      }
    }

  function _eglGetCurrentDisplay() {
      return EGL.currentContext ? 62000 /* Magic ID for Emscripten 'default display' */ : 0;
    }

  function _eglSwapBuffers() {
  
      if (!EGL.defaultDisplayInitialized) {
        EGL.setErrorCode(0x3001 /* EGL_NOT_INITIALIZED */);
      } else if (!Module.ctx) {
        EGL.setErrorCode(0x3002 /* EGL_BAD_ACCESS */);
      } else if (Module.ctx.isContextLost()) {
        EGL.setErrorCode(0x300E /* EGL_CONTEXT_LOST */);
      } else {
        // According to documentation this does an implicit flush.
        // Due to discussion at https://github.com/kripken/emscripten/pull/1871
        // the flush was removed since this _may_ result in slowing code down.
        //_glFlush();
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1 /* EGL_TRUE */;
      }
      return 0 /* EGL_FALSE */;
    }

  function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(name_);
    }

  function _eglReleaseThread() {
      // Equivalent to eglMakeCurrent with EGL_NO_CONTEXT and EGL_NO_SURFACE.
      EGL.currentContext = 0;
      EGL.currentReadSurface = 0;
      EGL.currentDrawSurface = 0;
      // EGL spec v1.4 p.55:
      // "calling eglGetError immediately following a successful call to eglReleaseThread should not be done.
      //  Such a call will return EGL_SUCCESS - but will also result in reallocating per-thread state."                     
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1 /* EGL_TRUE */;
    }

  var AL={QUEUE_INTERVAL:25,QUEUE_LOOKAHEAD:0.1,DEVICE_NAME:"Emscripten OpenAL",CAPTURE_DEVICE_NAME:"Emscripten OpenAL capture",ALC_EXTENSIONS:{ALC_SOFT_pause_device:true,ALC_SOFT_HRTF:true},AL_EXTENSIONS:{AL_EXT_float32:true,AL_SOFT_loop_points:true,AL_SOFT_source_length:true,AL_EXT_source_distance_model:true,AL_SOFT_source_spatialize:true},_alcErr:0,alcErr:0,deviceRefCounts:{},alcStringCache:{},paused:false,stringCache:{},contexts:{},currentCtx:null,buffers:{0:{id:0,refCount:0,audioBuf:null,frequency:0,bytesPerSample:2,channels:1,length:0}},paramArray:[],_nextId:1,newId:function () {
        return AL.freeIds.length > 0 ? AL.freeIds.pop() : AL._nextId++;
      },freeIds:[],scheduleContextAudio:function (ctx) {
        // If we are animating using the requestAnimationFrame method, then the main loop does not run when in the background.
        // To give a perfect glitch-free audio stop when switching from foreground to background, we need to avoid updating
        // audio altogether when in the background, so detect that case and kill audio buffer streaming if so.
        if (Browser.mainLoop.timingMode === 1 /* EM_TIMING_RAF */ && document['visibilityState'] != 'visible') {
          return;
        }
  
        for (var i in ctx.sources) {
          AL.scheduleSourceAudio(ctx.sources[i]);
        }
      },scheduleSourceAudio:function (src, lookahead) {
        // See comment on scheduleContextAudio above.
        if (Browser.mainLoop.timingMode === 1 /*EM_TIMING_RAF*/ && document['visibilityState'] != 'visible') {
          return;
        }
        if (src.state !== 0x1012 /* AL_PLAYING */) {
          return;
        }
  
        var currentTime = AL.updateSourceTime(src);
  
        var startTime = src.bufStartTime;
        var startOffset = src.bufOffset;
        var bufCursor = src.bufsProcessed;
  
        // Advance past any audio that is already scheduled
        for (var i = 0; i < src.audioQueue.length; i++) {
          var audioSrc = src.audioQueue[i];
          startTime = audioSrc._startTime + audioSrc._duration;
          startOffset = 0.0;
          bufCursor += audioSrc._skipCount + 1;
        }
  
        if (!lookahead) {
          lookahead = AL.QUEUE_LOOKAHEAD;
        }
        var lookaheadTime = currentTime + lookahead;
        var skipCount = 0;
        while (startTime < lookaheadTime) {
          if (bufCursor >= src.bufQueue.length) {
            if (src.looping) {
              bufCursor %= src.bufQueue.length;
            } else {
              break;
            }
          }
  
          var buf = src.bufQueue[bufCursor % src.bufQueue.length];
          // If the buffer contains no data, skip it
          if (buf.length === 0) {
            skipCount++;
            // If we've gone through the whole queue and everything is 0 length, just give up
            if (skipCount === src.bufQueue.length) {
              break;
            }
          } else {
            var audioSrc = src.context.audioCtx.createBufferSource();
            audioSrc.buffer = buf.audioBuf;
            audioSrc.playbackRate.value = src.playbackRate;
            if (buf.audioBuf._loopStart || buf.audioBuf._loopEnd) {
              audioSrc.loopStart = buf.audioBuf._loopStart;
              audioSrc.loopEnd = buf.audioBuf._loopEnd;
            }
  
            var duration = 0.0;
            // If the source is a looping static buffer, use native looping for gapless playback
            if (src.type === 0x1028 /* AL_STATIC */ && src.looping) {
              duration = Number.POSITIVE_INFINITY;
              audioSrc.loop = true;
              if (buf.audioBuf._loopStart) {
                audioSrc.loopStart = buf.audioBuf._loopStart;
              }
              if (buf.audioBuf._loopEnd) {
                audioSrc.loopEnd = buf.audioBuf._loopEnd;
              }
            } else {
              duration = (buf.audioBuf.duration - startOffset) / src.playbackRate;
            }
  
            audioSrc._startOffset = startOffset;
            audioSrc._duration = duration;
            audioSrc._skipCount = skipCount;
            skipCount = 0;
  
            audioSrc.connect(src.gain);
  
            if (typeof(audioSrc.start) !== 'undefined') {
              // Sample the current time as late as possible to mitigate drift
              startTime = Math.max(startTime, src.context.audioCtx.currentTime);
              audioSrc.start(startTime, startOffset);
            } else if (typeof(audioSrc.noteOn) !== 'undefined') {
              startTime = Math.max(startTime, src.context.audioCtx.currentTime);
              audioSrc.noteOn(startTime);
            }
            audioSrc._startTime = startTime;
            src.audioQueue.push(audioSrc);
  
            startTime += duration;
          }
  
          startOffset = 0.0;
          bufCursor++;
        }
      },updateSourceTime:function (src) {
        var currentTime = src.context.audioCtx.currentTime;
        if (src.state !== 0x1012 /* AL_PLAYING */) {
          return currentTime;
        }
  
        // if the start time is unset, determine it based on the current offset.
        // This will be the case when a source is resumed after being paused, and
        // allows us to pretend that the source actually started playing some time
        // in the past such that it would just now have reached the stored offset.
        if (!isFinite(src.bufStartTime)) {
          src.bufStartTime = currentTime - src.bufOffset / src.playbackRate;
          src.bufOffset = 0.0;
        }
  
        var nextStartTime = 0.0;
        while (src.audioQueue.length) {
          var audioSrc = src.audioQueue[0];
          src.bufsProcessed += audioSrc._skipCount;
          nextStartTime = audioSrc._startTime + audioSrc._duration; // n.b. audioSrc._duration already factors in playbackRate, so no divide by src.playbackRate on it.
  
          if (currentTime < nextStartTime) {
            break;
          }
  
          src.audioQueue.shift();
          src.bufStartTime = nextStartTime;
          src.bufOffset = 0.0;
          src.bufsProcessed++;
        }
  
        if (src.bufsProcessed >= src.bufQueue.length && !src.looping) {
          // The source has played its entire queue and is non-looping, so just mark it as stopped.
          AL.setSourceState(src, 0x1014 /* AL_STOPPED */);
        } else if (src.type === 0x1028 /* AL_STATIC */ && src.looping) {
          // If the source is a looping static buffer, determine the buffer offset based on the loop points
          var buf = src.bufQueue[0];
          if (buf.length === 0) {
            src.bufOffset = 0.0;
          } else {
            var delta = (currentTime - src.bufStartTime) * src.playbackRate;
            var loopStart = buf.audioBuf._loopStart || 0.0;
            var loopEnd = buf.audioBuf._loopEnd || buf.audioBuf.duration;
            if (loopEnd <= loopStart) {
              loopEnd = buf.audioBuf.duration;
            }
  
            if (delta < loopEnd) {
              src.bufOffset = delta;
            } else {
              src.bufOffset = loopStart + (delta - loopStart) % (loopEnd - loopStart);
            }
          }
        } else if (src.audioQueue[0]) {
          // The source is still actively playing, so we just need to calculate where we are in the current buffer
          // so it can be remembered if the source gets paused.
          src.bufOffset = (currentTime - src.audioQueue[0]._startTime) * src.playbackRate;
        } else {
          // The source hasn't finished yet, but there is no scheduled audio left for it. This can be because
          // the source has just been started/resumed, or due to an underrun caused by a long blocking operation.
          // We need to determine what state we would be in by this point in time so that when we next schedule
          // audio playback, it will be just as if no underrun occurred.
  
          if (src.type !== 0x1028 /* AL_STATIC */ && src.looping) {
            // if the source is a looping buffer queue, let's first calculate the queue duration, so we can
            // quickly fast forward past any full loops of the queue and only worry about the remainder.
            var srcDuration = AL.sourceDuration(src) / src.playbackRate;
            if (srcDuration > 0.0) {
              src.bufStartTime += Math.floor((currentTime - src.bufStartTime) / srcDuration) * srcDuration;
            }
          }
  
          // Since we've already skipped any full-queue loops if there were any, we just need to find
          // out where in the queue the remaining time puts us, which won't require stepping through the
          // entire queue more than once.
          for (var i = 0; i < src.bufQueue.length; i++) {
            if (src.bufsProcessed >= src.bufQueue.length) {
              if (src.looping) {
                src.bufsProcessed %= src.bufQueue.length;
              } else {
                AL.setSourceState(src, 0x1014 /* AL_STOPPED */);
                break;
              }
            }
  
            var buf = src.bufQueue[src.bufsProcessed];
            if (buf.length > 0) {
              nextStartTime = src.bufStartTime + buf.audioBuf.duration / src.playbackRate;
  
              if (currentTime < nextStartTime) {
                src.bufOffset = (currentTime - src.bufStartTime) * src.playbackRate;
                break;
              }
  
              src.bufStartTime = nextStartTime;
            }
  
            src.bufOffset = 0.0;
            src.bufsProcessed++;
          }
        }
  
        return currentTime;
      },cancelPendingSourceAudio:function (src) {
        AL.updateSourceTime(src);
  
        for (var i = 1; i < src.audioQueue.length; i++) {
          var audioSrc = src.audioQueue[i];
          audioSrc.stop();
        }
  
        if (src.audioQueue.length > 1) {
          src.audioQueue.length = 1;
        }
      },stopSourceAudio:function (src) {
        for (var i = 0; i < src.audioQueue.length; i++) {
          src.audioQueue[i].stop();
        }
        src.audioQueue.length = 0;
      },setSourceState:function (src, state) {
        if (state === 0x1012 /* AL_PLAYING */) {
          if (src.state === 0x1012 /* AL_PLAYING */ || src.state == 0x1014 /* AL_STOPPED */) {
            src.bufsProcessed = 0;
            src.bufOffset = 0.0;
          } else {
          }
  
          AL.stopSourceAudio(src);
  
          src.state = 0x1012 /* AL_PLAYING */;
          src.bufStartTime = Number.NEGATIVE_INFINITY;
          AL.scheduleSourceAudio(src);
        } else if (state === 0x1013 /* AL_PAUSED */) {
          if (src.state === 0x1012 /* AL_PLAYING */) {
            // Store off the current offset to restore with on resume.
            AL.updateSourceTime(src);
            AL.stopSourceAudio(src);
  
            src.state = 0x1013 /* AL_PAUSED */;
          }
        } else if (state === 0x1014 /* AL_STOPPED */) {
          if (src.state !== 0x1011 /* AL_INITIAL */) {
            src.state = 0x1014 /* AL_STOPPED */;
            src.bufsProcessed = src.bufQueue.length;
            src.bufStartTime = Number.NEGATIVE_INFINITY;
            src.bufOffset = 0.0;
            AL.stopSourceAudio(src);
          }
        } else if (state === 0x1011 /* AL_INITIAL */) {
          if (src.state !== 0x1011 /* AL_INITIAL */) {
            src.state = 0x1011 /* AL_INITIAL */;
            src.bufsProcessed = 0;
            src.bufStartTime = Number.NEGATIVE_INFINITY;
            src.bufOffset = 0.0;
            AL.stopSourceAudio(src);
          }
        }
      },initSourcePanner:function (src) {
        if (src.type === 0x1030 /* AL_UNDETERMINED */) {
          return;
        }
  
        // Find the first non-zero buffer in the queue to determine the proper format
        var templateBuf = AL.buffers[0];
        for (var i = 0; i < src.bufQueue.length; i++) {
          if (src.bufQueue[i].id !== 0) {
            templateBuf = src.bufQueue[i];
            break;
          }
        }
        // Create a panner if AL_SOURCE_SPATIALIZE_SOFT is set to true, or alternatively if it's set to auto and the source is mono
        if (src.spatialize === 1 /* AL_TRUE */ || (src.spatialize === 2 /* AL_AUTO_SOFT */ && templateBuf.channels === 1)) {
          if (src.panner) {
            return;
          }
          src.panner = src.context.audioCtx.createPanner();
  
          AL.updateSourceGlobal(src);
          AL.updateSourceSpace(src);
  
          src.panner.connect(src.context.gain);
          src.gain.disconnect();
          src.gain.connect(src.panner);
        } else {
          if (!src.panner) {
            return;
          }
  
          src.panner.disconnect();
          src.gain.disconnect();
          src.gain.connect(src.context.gain);
          src.panner = null;
        }
      },updateContextGlobal:function (ctx) {
        for (var i in ctx.sources) {
          AL.updateSourceGlobal(ctx.sources[i]);
        }
      },updateSourceGlobal:function (src) {
        var panner = src.panner;
        if (!panner) {
          return;
        }
  
        panner.refDistance = src.refDistance;
        panner.maxDistance = src.maxDistance;
        panner.rolloffFactor = src.rolloffFactor;
  
        panner.panningModel = src.context.hrtf ? 'HRTF' : 'equalpower';
  
        // Use the source's distance model if AL_SOURCE_DISTANCE_MODEL is enabled
        var distanceModel = src.context.sourceDistanceModel ? src.distanceModel : src.context.distanceModel;
        switch (distanceModel) {
        case 0 /* AL_NONE */:
          panner.distanceModel = 'inverse';
          panner.refDistance = 3.40282e38 /* FLT_MAX */;
          break;
        case 0xd001 /* AL_INVERSE_DISTANCE */:
        case 0xd002 /* AL_INVERSE_DISTANCE_CLAMPED */:
          panner.distanceModel = 'inverse';
          break;
        case 0xd003 /* AL_LINEAR_DISTANCE */:
        case 0xd004 /* AL_LINEAR_DISTANCE_CLAMPED */:
          panner.distanceModel = 'linear';
          break;
        case 0xd005 /* AL_EXPONENT_DISTANCE */:
        case 0xd006 /* AL_EXPONENT_DISTANCE_CLAMPED */:
          panner.distanceModel = 'exponential';
          break;
        }
      },updateListenerSpace:function (ctx) {
        var listener = ctx.audioCtx.listener;
        if (listener.positionX) {
          listener.positionX.value = ctx.listener.position[0];
          listener.positionY.value = ctx.listener.position[1];
          listener.positionZ.value = ctx.listener.position[2];
        } else {
          listener.setPosition(ctx.listener.position[0], ctx.listener.position[1], ctx.listener.position[2]);
        }
        if (listener.forwardX) {
          listener.forwardX.value = ctx.listener.direction[0];
          listener.forwardY.value = ctx.listener.direction[1];
          listener.forwardZ.value = ctx.listener.direction[2];
          listener.upX.value = ctx.listener.up[0];
          listener.upY.value = ctx.listener.up[1];
          listener.upZ.value = ctx.listener.up[2];
        } else {
          listener.setOrientation(
            ctx.listener.direction[0], ctx.listener.direction[1], ctx.listener.direction[2],
            ctx.listener.up[0], ctx.listener.up[1], ctx.listener.up[2]);
        }
  
        // Update sources that are relative to the listener
        for (var i in ctx.sources) {
          AL.updateSourceSpace(ctx.sources[i]);
        }
      },updateSourceSpace:function (src) {
        if (!src.panner) {
          return;
        }
        var panner = src.panner;
  
        var posX = src.position[0];
        var posY = src.position[1];
        var posZ = src.position[2];
        var dirX = src.direction[0];
        var dirY = src.direction[1];
        var dirZ = src.direction[2];
  
        var listener = src.context.listener;
        var lPosX = listener.position[0];
        var lPosY = listener.position[1];
        var lPosZ = listener.position[2];
  
        // WebAudio does spatialization in world-space coordinates, meaning both the buffer sources and
        // the listener position are in the same absolute coordinate system relative to a fixed origin.
        // By default, OpenAL works this way as well, but it also provides a "listener relative" mode, where
        // a buffer source's coordinate are interpreted not in absolute world space, but as being relative
        // to the listener object itself, so as the listener moves the source appears to move with it
        // with no update required. Since web audio does not support this mode, we must transform the source
        // coordinates from listener-relative space to absolute world space.
        //
        // We do this via affine transformation matrices applied to the source position and source direction.
        // A change-of-basis converts from listener-space displacements to world-space displacements,
        // which must be done for both the source position and direction. Lastly, the source position must be
        // added to the listener position to get the final source position, since the source position represents
        // a displacement from the listener.
        if (src.relative) {
          // Negate the listener direction since forward is -Z.
          var lBackX = -listener.direction[0];
          var lBackY = -listener.direction[1];
          var lBackZ = -listener.direction[2];
          var lUpX = listener.up[0];
          var lUpY = listener.up[1];
          var lUpZ = listener.up[2];
  
          function inverseMagnitude(x, y, z) {
            var length = Math.sqrt(x * x + y * y + z * z);
  
            if (length < Number.EPSILON) {
              return 0.0;
            }
  
            return 1.0 / length;
          }
  
          // Normalize the Back vector
          var invMag = inverseMagnitude(lBackX, lBackY, lBackZ);
          lBackX *= invMag;
          lBackY *= invMag;
          lBackZ *= invMag;
  
          // ...and the Up vector
          var invMag = inverseMagnitude(lUpX, lUpY, lUpZ);
          lUpX *= invMag;
          lUpY *= invMag;
          lUpZ *= invMag;
  
          // Calculate the Right vector as the cross product of the Up and Back vectors
          var lRightX = (lUpY * lBackZ - lUpZ * lBackY);
          var lRightY = (lUpZ * lBackX - lUpX * lBackZ);
          var lRightZ = (lUpX * lBackY - lUpY * lBackX);
  
          // Back and Up might not be exactly perpendicular, so the cross product also needs normalization
          var invMag = inverseMagnitude(lRightX, lRightY, lRightZ);
          lRightX *= invMag;
          lRightY *= invMag;
          lRightZ *= invMag;
  
          // Recompute Up from the now orthonormal Right and Back vectors so we have a fully orthonormal basis
          var lUpX = (lBackY * lRightZ - lBackZ * lRightY);
          var lUpY = (lBackZ * lRightX - lBackX * lRightZ);
          var lUpZ = (lBackX * lRightY - lBackY * lRightX);
  
          var oldX = dirX;
          var oldY = dirY;
          var oldZ = dirZ;
  
          // Use our 3 vectors to apply a change-of-basis matrix to the source direction
          dirX = oldX * lRightX + oldY * lUpX + oldZ * lBackX;
          dirY = oldX * lRightY + oldY * lUpY + oldZ * lBackY;
          dirZ = oldX * lRightZ + oldY * lUpZ + oldZ * lBackZ;
  
          var oldX = posX;
          var oldY = posY;
          var oldZ = posZ;
  
          // ...and to the source position
          posX = oldX * lRightX + oldY * lUpX + oldZ * lBackX;
          posY = oldX * lRightY + oldY * lUpY + oldZ * lBackY;
          posZ = oldX * lRightZ + oldY * lUpZ + oldZ * lBackZ;
  
          // The change-of-basis corrects the orientation, but the origin is still the listener.
          // Translate the source position by the listener position to finish.
          posX += lPosX;
          posY += lPosY;
          posZ += lPosZ;
        }
  
        if (panner.positionX) {
          panner.positionX.value = posX;
          panner.positionY.value = posY;
          panner.positionZ.value = posZ;
        } else {
          panner.setPosition(posX, posY, posZ);
        }
        if (panner.orientationX) {
          panner.orientationX.value = dirX;
          panner.orientationY.value = dirY;
          panner.orientationZ.value = dirZ;
        } else {
          panner.setOrientation(dirX, dirY, dirZ);
        }
  
        var oldShift = src.dopplerShift;
        var velX = src.velocity[0];
        var velY = src.velocity[1];
        var velZ = src.velocity[2];
        var lVelX = listener.velocity[0];
        var lVelY = listener.velocity[1];
        var lVelZ = listener.velocity[2];
        if (posX === lPosX && posY === lPosY && posZ === lPosZ
          || velX === lVelX && velY === lVelY && velZ === lVelZ)
        {
          src.dopplerShift = 1.0;
        } else {
          // Doppler algorithm from 1.1 spec
          var speedOfSound = src.context.speedOfSound;
          var dopplerFactor = src.context.dopplerFactor;
  
          var slX = lPosX - posX;
          var slY = lPosY - posY;
          var slZ = lPosZ - posZ;
  
          var magSl = Math.sqrt(slX * slX + slY * slY + slZ * slZ);
          var vls = (slX * lVelX + slY * lVelY + slZ * lVelZ) / magSl;
          var vss = (slX * velX + slY * velY + slZ * velZ) / magSl;
  
          vls = Math.min(vls, speedOfSound / dopplerFactor);
          vss = Math.min(vss, speedOfSound / dopplerFactor);
  
          src.dopplerShift = (speedOfSound - dopplerFactor * vls) / (speedOfSound - dopplerFactor * vss);
        }
        if (src.dopplerShift !== oldShift) {
          AL.updateSourceRate(src);
        }
      },updateSourceRate:function (src) {
        if (src.state === 0x1012 /* AL_PLAYING */) {
          // clear scheduled buffers
          AL.cancelPendingSourceAudio(src);
  
          var audioSrc = src.audioQueue[0];
          if (!audioSrc) {
            return; // It is possible that AL.scheduleContextAudio() has not yet fed the next buffer, if so, skip.
          }
  
          var duration;
          if (src.type === 0x1028 /* AL_STATIC */ && src.looping) {
            duration = Number.POSITIVE_INFINITY;
          } else {
            // audioSrc._duration is expressed after factoring in playbackRate, so when changing playback rate, need
            // to recompute/rescale the rate to the new playback speed.
            duration = (audioSrc.buffer.duration - audioSrc._startOffset) / src.playbackRate;
          }
  
          audioSrc._duration = duration;
          audioSrc.playbackRate.value = src.playbackRate;
  
          // reschedule buffers with the new playbackRate
          AL.scheduleSourceAudio(src);
        }
      },sourceDuration:function (src) {
        var length = 0.0;
        for (var i = 0; i < src.bufQueue.length; i++) {
          var audioBuf = src.bufQueue[i].audioBuf;
          length += audioBuf ? audioBuf.duration : 0.0;
        }
        return length;
      },sourceTell:function (src) {
        AL.updateSourceTime(src);
  
        var offset = 0.0;
        for (var i = 0; i < src.bufsProcessed; i++) {
          offset += src.bufQueue[i].audioBuf.duration;
        }
        offset += src.bufOffset;
  
        return offset;
      },sourceSeek:function (src, offset) {
        var playing = src.state == 0x1012 /* AL_PLAYING */;
        if (playing) {
          AL.setSourceState(src, 0x1011 /* AL_INITIAL */);
        }
  
        src.bufsProcessed = 0;
        while (offset > src.bufQueue[src.bufsProcessed].audioBuf.duration) {
          offset -= src.bufQueue[src.bufsProcessed].audiobuf.duration;
          src.bufsProcessed++;
        }
  
        src.bufOffset = offset;
        if (playing) {
          AL.setSourceState(src, 0x1012 /* AL_PLAYING */);
        }
      },getGlobalParam:function (funcname, param) {
        if (!AL.currentCtx) {
          return null;
        }
  
        switch (param) {
        case 0xC000 /* AL_DOPPLER_FACTOR */:
          return AL.currentCtx.dopplerFactor;
        case 0xC003 /* AL_SPEED_OF_SOUND */:
          return AL.currentCtx.speedOfSound;
        case 0xD000 /* AL_DISTANCE_MODEL */:
          return AL.currentCtx.distanceModel;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return null;
        }
      },setGlobalParam:function (funcname, param, value) {
        if (!AL.currentCtx) {
          return;
        }
  
        switch (param) {
        case 0xC000 /* AL_DOPPLER_FACTOR */:
          if (!Number.isFinite(value) || value < 0.0) { // Strictly negative values are disallowed
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.currentCtx.dopplerFactor = value;
          AL.updateListenerSpace(AL.currentCtx);
          break;
        case 0xC003 /* AL_SPEED_OF_SOUND */:
          if (!Number.isFinite(value) || value <= 0.0) { // Negative or zero values are disallowed
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.currentCtx.speedOfSound = value;
          AL.updateListenerSpace(AL.currentCtx);
          break;
        case 0xD000 /* AL_DISTANCE_MODEL */:
          switch (value) {
          case 0 /* AL_NONE */:
          case 0xd001 /* AL_INVERSE_DISTANCE */:
          case 0xd002 /* AL_INVERSE_DISTANCE_CLAMPED */:
          case 0xd003 /* AL_LINEAR_DISTANCE */:
          case 0xd004 /* AL_LINEAR_DISTANCE_CLAMPED */:
          case 0xd005 /* AL_EXPONENT_DISTANCE */:
          case 0xd006 /* AL_EXPONENT_DISTANCE_CLAMPED */:
            AL.currentCtx.distanceModel = value;
            AL.updateContextGlobal(AL.currentCtx);
            break;
          default:
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          break;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
      },getListenerParam:function (funcname, param) {
        if (!AL.currentCtx) {
          return null;
        }
  
        switch (param) {
        case 0x1004 /* AL_POSITION */:
          return AL.currentCtx.listener.position;
        case 0x1006 /* AL_VELOCITY */:
          return AL.currentCtx.listener.velocity;
        case 0x100F /* AL_ORIENTATION */:
          return AL.currentCtx.listener.direction.concat(AL.currentCtx.listener.up);
        case 0x100A /* AL_GAIN */:
          return AL.currentCtx.gain.gain.value;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return null;
        }
      },setListenerParam:function (funcname, param, value) {
        if (!AL.currentCtx) {
          return;
        }
        if (value === null) {
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
  
        var listener = AL.currentCtx.listener;
        switch (param) {
        case 0x1004 /* AL_POSITION */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          listener.position[0] = value[0];
          listener.position[1] = value[1];
          listener.position[2] = value[2];
          AL.updateListenerSpace(AL.currentCtx);
          break;
        case 0x1006 /* AL_VELOCITY */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          listener.velocity[0] = value[0];
          listener.velocity[1] = value[1];
          listener.velocity[2] = value[2];
          AL.updateListenerSpace(AL.currentCtx);
          break;
        case 0x100A /* AL_GAIN */:
          if (!Number.isFinite(value) || value < 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.currentCtx.gain.gain.value = value;
          break;
        case 0x100F /* AL_ORIENTATION */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])
            || !Number.isFinite(value[3]) || !Number.isFinite(value[4]) || !Number.isFinite(value[5])
          ) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          listener.direction[0] = value[0];
          listener.direction[1] = value[1];
          listener.direction[2] = value[2];
          listener.up[0] = value[3];
          listener.up[1] = value[4];
          listener.up[2] = value[5];
          AL.updateListenerSpace(AL.currentCtx);
          break;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
      },getBufferParam:function (funcname, bufferId, param) {
        if (!AL.currentCtx) {
          return;
        }
        var buf = AL.buffers[bufferId];
        if (!buf || bufferId === 0) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
  
        switch (param) {
        case 0x2001 /* AL_FREQUENCY */:
          return buf.frequency;
        case 0x2002 /* AL_BITS */:
          return buf.bytesPerSample * 8;
        case 0x2003 /* AL_CHANNELS */:
          return buf.channels;
        case 0x2004 /* AL_SIZE */:
          return buf.length * buf.bytesPerSample * buf.channels;
        case 0x2015 /* AL_LOOP_POINTS_SOFT */:
          if (buf.length === 0) {
            return [0, 0];
          } else {
            return [
              (buf.audioBuf._loopStart || 0.0) * buf.frequency,
              (buf.audioBuf._loopEnd || buf.length) * buf.frequency
            ];
          }
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return null;
        }
      },setBufferParam:function (funcname, bufferId, param, value) {
        if (!AL.currentCtx) {
          return;
        }
        var buf = AL.buffers[bufferId];
        if (!buf || bufferId === 0) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
        if (value === null) {
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
  
        switch (param) {
        case 0x2004 /* AL_SIZE */:
          if (value !== 0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          // Per the spec, setting AL_SIZE to 0 is a legal NOP.
          break;
        case 0x2015 /* AL_LOOP_POINTS_SOFT */:
          if (value[0] < 0 || value[0] > buf.length || value[1] < 0 || value[1] > buf.Length || value[0] >= value[1]) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          if (buf.refCount > 0) {
            AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
            return;
          }
  
          if (buf.audioBuf) {
            buf.audioBuf._loopStart = value[0] / buf.frequency;
            buf.audioBuf._loopEnd = value[1] / buf.frequency;
          }
          break;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
      },getSourceParam:function (funcname, sourceId, param) {
        if (!AL.currentCtx) {
          return null;
        }
        var src = AL.currentCtx.sources[sourceId];
        if (!src) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return null;
        }
  
        switch (param) {
        case 0x202 /* AL_SOURCE_RELATIVE */:
          return src.relative;
        case 0x1001 /* AL_CONE_INNER_ANGLE */:
          return src.coneInnerAngle;
        case 0x1002 /* AL_CONE_OUTER_ANGLE */:
          return src.coneOuterAngle;
        case 0x1003 /* AL_PITCH */:
          return src.pitch;
        case 0x1004 /* AL_POSITION */:
          return src.position;
        case 0x1005 /* AL_DIRECTION */:
          return src.direction;
        case 0x1006 /* AL_VELOCITY */:
          return src.velocity;
        case 0x1007 /* AL_LOOPING */:
          return src.looping;
        case 0x1009 /* AL_BUFFER */:
          if (src.type === 0x1028 /* AL_STATIC */) {
            return src.bufQueue[0].id;
          } else {
            return 0;
          }
        case 0x100A /* AL_GAIN */:
          return src.gain.gain.value;
         case 0x100D /* AL_MIN_GAIN */:
          return src.minGain;
        case 0x100E /* AL_MAX_GAIN */:
          return src.maxGain;
        case 0x1010 /* AL_SOURCE_STATE */:
          return src.state;
        case 0x1015 /* AL_BUFFERS_QUEUED */:
          if (src.bufQueue.length === 1 && src.bufQueue[0].id === 0) {
            return 0;
          } else {
            return src.bufQueue.length;
          }
        case 0x1016 /* AL_BUFFERS_PROCESSED */:
          if ((src.bufQueue.length === 1 && src.bufQueue[0].id === 0) || src.looping) {
            return 0;
          } else {
            return src.bufsProcessed;
          }
        case 0x1020 /* AL_REFERENCE_DISTANCE */:
          return src.refDistance;
        case 0x1021 /* AL_ROLLOFF_FACTOR */:
          return src.rolloffFactor;
        case 0x1022 /* AL_CONE_OUTER_GAIN */:
          return src.coneOuterGain;
        case 0x1023 /* AL_MAX_DISTANCE */:
          return src.maxDistance;
        case 0x1024 /* AL_SEC_OFFSET */:
          return AL.sourceTell(src);
        case 0x1025 /* AL_SAMPLE_OFFSET */:
          var offset = AL.sourceTell(src);
          if (offset > 0.0) {
            offset *= src.bufQueue[0].frequency;
          }
          return offset;
        case 0x1026 /* AL_BYTE_OFFSET */:
          var offset = AL.sourceTell(src);
          if (offset > 0.0) {
            offset *= src.bufQueue[0].frequency * src.bufQueue[0].bytesPerSample;
          }
          return offset;
        case 0x1027 /* AL_SOURCE_TYPE */:
          return src.type;
        case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
          return src.spatialize;
        case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
          var length = 0;
          var bytesPerFrame = 0;
          for (var i = 0; i < src.bufQueue.length; i++) {
            length += src.bufQueue[i].length;
            if (src.bufQueue[i].id !== 0) {
              bytesPerFrame = src.bufQueue[i].bytesPerSample * src.bufQueue[i].channels;
            }
          }
          return length * bytesPerFrame;
        case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
          var length = 0;
          for (var i = 0; i < src.bufQueue.length; i++) {
            length += src.bufQueue[i].length;
          }
          return length;
        case 0x200B /* AL_SEC_LENGTH_SOFT */:
          return AL.sourceDuration(src);
        case 0xD000 /* AL_DISTANCE_MODEL */:
          return src.distanceModel;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return null;
        }
      },setSourceParam:function (funcname, sourceId, param, value) {
        if (!AL.currentCtx) {
          return;
        }
        var src = AL.currentCtx.sources[sourceId];
        if (!src) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
        if (value === null) {
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
  
        switch (param) {
        case 0x202 /* AL_SOURCE_RELATIVE */:
          if (value === 1 /* AL_TRUE */) {
            src.relative = true;
            AL.updateSourceSpace(src);
          } else if (value === 0 /* AL_FALSE */) {
            src.relative = false;
            AL.updateSourceSpace(src);
          } else {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          break;
        case 0x1001 /* AL_CONE_INNER_ANGLE */:
          if (!Number.isFinite(value)) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.coneInnerAngle = value;
          if (src.panner) {
            src.panner.coneInnerAngle = value % 360.0;
          }
          break;
        case 0x1002 /* AL_CONE_OUTER_ANGLE */:
          if (!Number.isFinite(value)) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.coneOuterAngle = value;
          if (src.panner) {
            src.panner.coneOuterAngle = value % 360.0;
          }
          break;
        case 0x1003 /* AL_PITCH */:
          if (!Number.isFinite(value) || value <= 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          if (src.pitch === value) {
            break;
          }
  
          src.pitch = value;
          AL.updateSourceRate(src);
          break;
        case 0x1004 /* AL_POSITION */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.position[0] = value[0];
          src.position[1] = value[1];
          src.position[2] = value[2];
          AL.updateSourceSpace(src);
          break;
        case 0x1005 /* AL_DIRECTION */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.direction[0] = value[0];
          src.direction[1] = value[1];
          src.direction[2] = value[2];
          AL.updateSourceSpace(src);
          break;
        case 0x1006 /* AL_VELOCITY */:
          if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.velocity[0] = value[0];
          src.velocity[1] = value[1];
          src.velocity[2] = value[2];
          AL.updateSourceSpace(src);
          break;
        case 0x1007 /* AL_LOOPING */:
          if (value === 1 /* AL_TRUE */) {
            src.looping = true;
            AL.updateSourceTime(src);
            if (src.type === 0x1028 /* AL_STATIC */ && src.audioQueue.length > 0) {
              var audioSrc  = src.audioQueue[0];
              audioSrc.loop = true;
              audioSrc._duration = Number.POSITIVE_INFINITY;
            }
          } else if (value === 0 /* AL_FALSE */) {
            src.looping = false;
            var currentTime = AL.updateSourceTime(src);
            if (src.type === 0x1028 /* AL_STATIC */ && src.audioQueue.length > 0) {
              var audioSrc  = src.audioQueue[0];
              audioSrc.loop = false;
              audioSrc._duration = src.bufQueue[0].audioBuf.duration / src.playbackRate;
              audioSrc._startTime = currentTime - src.bufOffset / src.playbackRate;
            }
          } else {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          break;
        case 0x1009 /* AL_BUFFER */:
          if (src.state === 0x1012 /* AL_PLAYING */ || src.state === 0x1013 /* AL_PAUSED */) {
            AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
            return;
          }
  
          if (value === 0) {
            for (var i in src.bufQueue) {
              src.bufQueue[i].refCount--;
            }
            src.bufQueue.length = 1;
            src.bufQueue[0] = AL.buffers[0];
  
            src.bufsProcessed = 0;
            src.type = 0x1030 /* AL_UNDETERMINED */;
          } else {
            var buf = AL.buffers[value];
            if (!buf) {
              AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
              return;
            }
  
            for (var i in src.bufQueue) {
              src.bufQueue[i].refCount--;
            }
            src.bufQueue.length = 0;
  
            buf.refCount++;
            src.bufQueue = [buf];
            src.bufsProcessed = 0;
            src.type = 0x1028 /* AL_STATIC */;
          }
  
          AL.initSourcePanner(src);
          AL.scheduleSourceAudio(src);
          break;
        case 0x100A /* AL_GAIN */:
          if (!Number.isFinite(value) || value < 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.gain.gain.value = value;
          break;
        case 0x100D /* AL_MIN_GAIN */:
          if (!Number.isFinite(value) || value < 0.0 || value > Math.min(src.maxGain, 1.0)) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.minGain = value;
          break;
        case 0x100E /* AL_MAX_GAIN */:
          if (!Number.isFinite(value) || value < Math.max(0.0, src.minGain) || value > 1.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.maxGain = value;
          break;
        case 0x1020 /* AL_REFERENCE_DISTANCE */:
          if (!Number.isFinite(value) || value < 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.refDistance = value;
          if (src.panner) {
            src.panner.refDistance = value;
          }
          break;
        case 0x1021 /* AL_ROLLOFF_FACTOR */:
          if (!Number.isFinite(value) || value < 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.rolloffFactor = value;
          if (src.panner) {
            src.panner.rolloffFactor = value;
          }
          break;
        case 0x1022 /* AL_CONE_OUTER_GAIN */:
          if (!Number.isFinite(value) || value < 0.0 || value > 1.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.coneOuterGain = value;
          if (src.panner) {
            src.panner.coneOuterGain = value;
          }
          break;
        case 0x1023 /* AL_MAX_DISTANCE */:
          if (!Number.isFinite(value) || value < 0.0) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          src.maxDistance = value;
          if (src.panner) {
            src.panner.maxDistance = value;
          }
          break;
        case 0x1024 /* AL_SEC_OFFSET */:
          if (value < 0.0 || value > AL.sourceDuration(src)) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.sourceSeek(src, value);
          break;
        case 0x1025 /* AL_SAMPLE_OFFSET */:
          var srcLen = AL.sourceDuration(src);
          if (srcLen > 0.0) {
            var frequency;
            for (var bufId in src.bufQueue) {
              if (bufId !== 0) {
                frequency = src.bufQueue[bufId].frequency;
                break;
              }
            }
            value /= frequency;
          }
          if (value < 0.0 || value > srcLen) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.sourceSeek(src, value);
          break;
        case 0x1026 /* AL_BYTE_OFFSET */:
          var srcLen = AL.sourceDuration(src);
          if (srcLen > 0.0) {
            var bytesPerSec;
            for (var bufId in src.bufQueue) {
              if (bufId !== 0) {
                var buf = src.bufQueue[bufId];
                bytesPerSec = buf.frequency * buf.bytesPerSample * buf.channels;
                break;
              }
            }
            value /= bytesPerSec;
          }
          if (value < 0.0 || value > srcLen) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          AL.sourceSeek(src, value);
          break;
        case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
          if (value !== 0 /* AL_FALSE */ && value !== 1 /* AL_TRUE */ && value !== 2 /* AL_AUTO_SOFT */) {
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
  
          src.spatialize = value;
          AL.initSourcePanner(src);
          break;
        case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
        case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
        case 0x200B /* AL_SEC_LENGTH_SOFT */:
          AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
          break;
        case 0xD000 /* AL_DISTANCE_MODEL */:
          switch (value) {
          case 0 /* AL_NONE */:
          case 0xd001 /* AL_INVERSE_DISTANCE */:
          case 0xd002 /* AL_INVERSE_DISTANCE_CLAMPED */:
          case 0xd003 /* AL_LINEAR_DISTANCE */:
          case 0xd004 /* AL_LINEAR_DISTANCE_CLAMPED */:
          case 0xd005 /* AL_EXPONENT_DISTANCE */:
          case 0xd006 /* AL_EXPONENT_DISTANCE_CLAMPED */:
            src.distanceModel = value;
            if (AL.currentCtx.sourceDistanceModel) {
              AL.updateContextGlobal(AL.currentCtx);
            }
            break;
          default:
            AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
            return;
          }
          break;
        default:
          AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
          return;
        }
      },captures:{},sharedCaptureAudioCtx:null,requireValidCaptureDevice:function (deviceId, funcname) {
        if (deviceId === 0) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return null;
        }
        var c = AL.captures[deviceId];
        if (!c) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return null;
        }
        var err = c.mediaStreamError;
        if (err) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return null;
        }
        return c;
      }};


  function _alcCaptureOpenDevice(pDeviceName, requestedSampleRate, format, bufferFrameCapacity) {
  
      var resolvedDeviceName = AL.CAPTURE_DEVICE_NAME;
  
      // NULL is a valid device name here (resolves to default);
      if (pDeviceName !== 0) {
        resolvedDeviceName = Pointer_stringify(pDeviceName);
        if (resolvedDeviceName !== AL.CAPTURE_DEVICE_NAME) {
          // ALC_OUT_OF_MEMORY
          // From the programmer's guide, ALC_OUT_OF_MEMORY's meaning is
          // overloaded here, to mean:
          // 'The specified device is invalid, or can not capture audio.'
          // This may be misleading to API users, but well...
          AL.alcErr = 0xA005 /* ALC_OUT_OF_MEMORY */;
          return 0;
        }
      }
  
      // Otherwise it's probably okay (though useless) for bufferFrameCapacity to be zero.
      if (bufferFrameCapacity < 0) { // ALCsizei is signed int
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return 0;
      }
  
      navigator.getUserMedia = navigator.getUserMedia 
        || navigator.webkitGetUserMedia 
        || navigator.mozGetUserMedia 
        || navigator.msGetUserMedia;
      var has_getUserMedia = navigator.getUserMedia 
        || (navigator.mediaDevices 
        &&  navigator.mediaDevices.getUserMedia);
  
      if (!has_getUserMedia) {
        // See previously mentioned rationale for ALC_OUT_OF_MEMORY
        AL.alcErr = 0xA005 /* ALC_OUT_OF_MEMORY */;
        return 0;
      }
  
      var AudioContext = window.AudioContext || window.webkitAudioContext;
  
      if (!AL.sharedCaptureAudioCtx) {
        try {
          AL.sharedCaptureAudioCtx = new AudioContext();
        } catch(e) {
          // See previously mentioned rationale for ALC_OUT_OF_MEMORY
          AL.alcErr = 0xA005 /* ALC_OUT_OF_MEMORY */;
          return 0;
        }
      }
  
      var outputChannelCount;
  
      switch (format) {
      case 0x10010: /* AL_FORMAT_MONO_FLOAT32 */
      case 0x1101:  /* AL_FORMAT_MONO16 */
      case 0x1100:  /* AL_FORMAT_MONO8 */
        outputChannelCount = 1;
        break;
      case 0x10011: /* AL_FORMAT_STEREO_FLOAT32 */
      case 0x1103:  /* AL_FORMAT_STEREO16 */
      case 0x1102:  /* AL_FORMAT_STEREO8 */
        outputChannelCount = 2;
        break;
      default:
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return 0;
      }
  
      function newF32Array(cap) { return new Float32Array(cap);}
      function newI16Array(cap) { return new Int16Array(cap);  }
      function newU8Array(cap)  { return new Uint8Array(cap);  }
  
      var requestedSampleType;
      var newSampleArray;
  
      switch (format) {
      case 0x10010: /* AL_FORMAT_MONO_FLOAT32 */
      case 0x10011: /* AL_FORMAT_STEREO_FLOAT32 */
        requestedSampleType = 'f32';
        newSampleArray = newF32Array;
        break;
      case 0x1101:  /* AL_FORMAT_MONO16 */
      case 0x1103:  /* AL_FORMAT_STEREO16 */
        requestedSampleType = 'i16';
        newSampleArray = newI16Array;
        break;
      case 0x1100:  /* AL_FORMAT_MONO8 */
      case 0x1102:  /* AL_FORMAT_STEREO8 */
        requestedSampleType = 'u8';
        newSampleArray = newU8Array;
        break;
      }
  
      var buffers = [];
      try {
        for (var chan=0; chan < outputChannelCount; ++chan) {
          buffers[chan] = newSampleArray(bufferFrameCapacity);
        }
      } catch(e) {
        AL.alcErr = 0xA005 /* ALC_OUT_OF_MEMORY */;
        return 0;
      }
  
  
      // What we'll place into the `AL.captures` array in the end,
      // declared here for closures to access it
      var newCapture = {
        audioCtx: AL.sharedCaptureAudioCtx,
        deviceName: resolvedDeviceName,
        requestedSampleRate: requestedSampleRate,
        requestedSampleType: requestedSampleType,
        outputChannelCount: outputChannelCount,
        inputChannelCount: null, // Not known until the getUserMedia() promise resolves
        mediaStreamError: null, // Used by other functions to return early and report an error.
        mediaStreamSourceNode: null,
        // Either one, or none of the below two, is active.
        mergerNode: null,
        splitterNode: null,
        scriptProcessorNode: null,
        isCapturing: false,
        buffers: buffers,
        get bufferFrameCapacity() {
          return buffers[0].length;
        },
        capturePlayhead: 0, // current write position, in sample frames
        capturedFrameCount: 0
      };
  
      // Preparing for getUserMedia()
  
      var onError = function(mediaStreamError) {
        newCapture.mediaStreamError = mediaStreamError;
      };
      var onSuccess = function(mediaStream) {
        newCapture.mediaStreamSourceNode = newCapture.audioCtx.createMediaStreamSource(mediaStream);
  
        var inputChannelCount = 1;
        switch(newCapture.mediaStreamSourceNode.channelCountMode) {
        case 'max':
          inputChannelCount = outputChannelCount;
          break;
        case 'clamped-max':
          inputChannelCount = Math.min(outputChannelCount, newCapture.mediaStreamSourceNode.channelCount);
          break;
        case 'explicit':
          inputChannelCount = newCapture.mediaStreamSourceNode.channelCount;
          break;
        }
  
        newCapture.inputChannelCount = inputChannelCount;
  
  
        // Have to pick a size from 256, 512, 1024, 2048, 4096, 8192, 16384.
        // One can also set it to zero, which leaves the decision up to the impl.
        // An extension could allow specifying this value.
        var processorFrameCount = 512;
  
        newCapture.scriptProcessorNode = newCapture.audioCtx.createScriptProcessor(
          processorFrameCount, inputChannelCount, outputChannelCount
        );
  
        if (inputChannelCount > outputChannelCount) {
          newCapture.mergerNode = newCapture.audioCtx.createChannelMerger(inputChannelCount);
          newCapture.mediaStreamSourceNode.connect(newCapture.mergerNode);
          newCapture.mergerNode.connect(newCapture.scriptProcessorNode);
        } else if (inputChannelCount < outputChannelCount) {
          newCapture.splitterNode = newCapture.audioCtx.createChannelSplitter(outputChannelCount);
          newCapture.mediaStreamSourceNode.connect(newCapture.splitterNode);
          newCapture.splitterNode.connect(newCapture.scriptProcessorNode);
        } else {
          newCapture.mediaStreamSourceNode.connect(newCapture.scriptProcessorNode);
        }
  
        newCapture.scriptProcessorNode.connect(newCapture.audioCtx.destination);
  
        newCapture.scriptProcessorNode.onaudioprocess = function(audioProcessingEvent) {
  
          if (!newCapture.isCapturing) {
            return;
          }
  
          var c = newCapture;
          var srcBuf = audioProcessingEvent.inputBuffer;
  
          // Actually just copy srcBuf's channel data into
          // c.buffers, optimizing for each case.
          switch (format) {
          case 0x10010: /* AL_FORMAT_MONO_FLOAT32 */
            var channel0 = srcBuf.getChannelData(0);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = channel0[i];
            }
            break;
          case 0x10011: /* AL_FORMAT_STEREO_FLOAT32 */
            var channel0 = srcBuf.getChannelData(0);
            var channel1 = srcBuf.getChannelData(1);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = channel0[i];
              c.buffers[1][wi] = channel1[i];
            }
            break;
          case 0x1101:  /* AL_FORMAT_MONO16 */
            var channel0 = srcBuf.getChannelData(0);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = channel0[i] * 32767;
            }
            break;
          case 0x1103:  /* AL_FORMAT_STEREO16 */
            var channel0 = srcBuf.getChannelData(0);
            var channel1 = srcBuf.getChannelData(1);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = channel0[i] * 32767;
              c.buffers[1][wi] = channel1[i] * 32767;
            }
            break;
          case 0x1100:  /* AL_FORMAT_MONO8 */
            var channel0 = srcBuf.getChannelData(0);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = (channel0[i] + 1.0) * 127;
            }
            break;
          case 0x1102:  /* AL_FORMAT_STEREO8 */
            var channel0 = srcBuf.getChannelData(0);
            var channel1 = srcBuf.getChannelData(1);
            for (var i = 0 ; i < srcBuf.length; ++i) {
              var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
              c.buffers[0][wi] = (channel0[i] + 1.0) * 127;
              c.buffers[1][wi] = (channel1[i] + 1.0) * 127;
            }
            break;
          }
  
          c.capturePlayhead += srcBuf.length;
          c.capturePlayhead %= c.bufferFrameCapacity;
          c.capturedFrameCount += srcBuf.length;
          c.capturedFrameCount = Math.min(c.capturedFrameCount, c.bufferFrameCapacity);
        };
      };
  
      // The latest way to call getUserMedia()
      if (navigator.mediaDevices && navigator.mediaDevices.getUserMedia) {
        navigator.mediaDevices
             .getUserMedia({audio: true})
             .then(onSuccess)
             .catch(onError);
      } else { // The usual (now deprecated) way
        navigator.getUserMedia({audio: true}, onSuccess, onError);
      }
  
      var id = AL.newId();
      AL.captures[id] = newCapture;
      return id;
    }


  function _alcCaptureCloseDevice(deviceId) {
      var c = AL.requireValidCaptureDevice(deviceId, 'alcCaptureCloseDevice');
      if (!c) return false;
  
      delete AL.captures[deviceId];
      AL.freeIds.push(deviceId);
  
      // This clean-up might be unnecessary (paranoid) ?
  
      // May happen if user hasn't decided to grant or deny input
      if (c.mediaStreamSourceNode) c.mediaStreamSourceNode.disconnect();
      if (c.mergerNode) c.mergerNode.disconnect();
      if (c.splitterNode) c.splitterNode.disconnect();
      // May happen if user hasn't decided to grant or deny input
      if (c.scriptProcessorNode) c.scriptProcessorNode.disconnect();
  
      delete c.buffers;
  
      c.capturedFrameCount = 0;
      c.isCapturing = false;
  
      return true;
    }


  function _alcCaptureStart(deviceId) {
      var c = AL.requireValidCaptureDevice(deviceId, 'alcCaptureStart');
      if (!c) return;
  
      if (c.isCapturing) {
        // NOTE: Spec says (emphasis mine):
        //     The amount of audio samples available after **restarting** a 
        //     stopped capture device is reset to zero.
        // So redundant calls to alcCaptureStart() must have no effect.
        return;
      }
      c.isCapturing = true;
      c.capturedFrameCount = 0;
      c.capturePlayhead = 0;
    }


  function _alcCaptureStop(deviceId) {
      var c = AL.requireValidCaptureDevice(deviceId, 'alcCaptureStop');
      if (!c) return;
  
      c.isCapturing = false;
    }


  function _alcCaptureSamples(deviceId, pFrames, requestedFrameCount) {
      var c = AL.requireValidCaptureDevice(deviceId, 'alcCaptureSamples');
      if (!c) return;
  
      // ALCsizei is actually 32-bit signed int, so could be negative
      // Also, spec says :
      //   Requesting more sample frames than are currently available is 
      //   an error.
      if (requestedFrameCount < 0
      ||  requestedFrameCount > c.capturedFrameCount) 
      {
    // if OPENAL_DEBUG
        console.error('alcCaptureSamples() with invalid bufferSize');
    // endif
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return;
      }
      
      function setF32Sample(i, sample) {
        HEAPF32[(((pFrames)+(4*i))>>2)]=sample;
      }
      function setI16Sample(i, sample) {
        HEAP16[(((pFrames)+(2*i))>>1)]=sample;
      }
      function setU8Sample(i, sample) {
        HEAP8[(((pFrames)+(i))>>0)]=sample;
      }
  
      var setSample;
  
      switch(c.requestedSampleType) {
      case 'f32': setSample = setF32Sample; break;
      case 'i16': setSample = setI16Sample; break;
      case 'u8' : setSample = setU8Sample ; break;
      default: 
        return;
      }
  
      var dstfreq = c.requestedSampleRate;
      var srcfreq = c.audioCtx.sampleRate;
  
      if (srcfreq == dstfreq) {
        for (var i = 0, frame_i = 0; frame_i < requestedFrameCount; ++frame_i) {
          for (var chan = 0; chan < c.buffers.length; ++chan, ++i) {
            var src_i = (frame_i + c.capturePlayhead) % c.capturedFrameCount;
            setSample(i, c.buffers[chan][src_i]);
          }
        }
      } else {
        // Perform linear resampling.
  
        // There is room for improvement - right now we're fine with linear resampling.
        // We don't use OfflineAudioContexts for this: See the discussion at
        // https://github.com/jpernst/emscripten/issues/2#issuecomment-312729735
        // if you're curious about why.
  
        function lerp(from, to, progress) {
          return (1 - progress) * from + progress * to;
        }
  
        for (var i = 0, frame_i = 0; frame_i < requestedFrameCount; ++frame_i) {
  
          var t = frame_i / dstfreq; // Most exact time for the current output sample
          var src_i = (Math.floor(t*srcfreq) + c.capturePlayhead) % c.capturedFrameCount;
          var src_next_i = (src_i+1) % c.capturedFrameCount;
          var between = t*srcfreq - src_i; //(t - src_i/srcfreq) / ((src_i+1)/srcfreq - src_i/srcfreq);
  
          for (var chan = 0; chan < c.buffers.length; ++chan, ++i) {
            var cb = c.buffers[chan];
            var sample = lerp(cb[src_i], cb[src_next_i], between);
            setSample(i, sample);
          }
        }
      }
  
      // Spec doesn't say if alcCaptureSamples() must zero the number
      // of available captured sample-frames, but not only would it
      // be insane not to do, OpenAL-Soft happens to do that as well.
      c.capturedFrameCount = 0;
    }


  function _alcOpenDevice(pDeviceName) {
      if (pDeviceName) {
        var name = Pointer_stringify(pDeviceName);
        if (name !== AL.DEVICE_NAME) {
          return 0;
        }
      }
  
      if (typeof(AudioContext) !== 'undefined' || typeof(webkitAudioContext) !== 'undefined') {
        var deviceId = AL.newId();
        AL.deviceRefCounts[deviceId] = 0;
        return deviceId;
      } else {
        return 0;
      }
    }


  function _alcCloseDevice(deviceId) {
      if (!deviceId in AL.deviceRefCounts || AL.deviceRefCounts[deviceId] > 0) {
        return 0 /* ALC_FALSE */;
      }
  
      delete AL.deviceRefCounts[deviceId];
      AL.freeIds.push(deviceId);
      return 1 /* ALC_TRUE */;
    }


  function _alcCreateContext(deviceId, pAttrList) {
      if (!deviceId in AL.deviceRefCounts) {
        AL.alcErr = 0xA001; /* ALC_INVALID_DEVICE */
        return 0;
      }
  
      var options = null;
      var attrs = [];
      var hrtf = null;
      pAttrList >>= 2;
      if (pAttrList) {
        var attr = 0;
        var val = 0;
        while (true) {
          attr = HEAP32[pAttrList++];
          attrs.push(attr);
          if (attr === 0) {
            break;
          }
          val = HEAP32[pAttrList++];
          attrs.push(val);
  
          switch (attr) {
          case 0x1007 /* ALC_FREQUENCY */:
            if (!options) {
              options = {};
            }
  
            options.sampleRate = val;
            break;
          case 0x1010 /* ALC_MONO_SOURCES */: // fallthrough
          case 0x1011 /* ALC_STEREO_SOURCES */:
            // Do nothing; these hints are satisfied by default
            break
          case 0x1992 /* ALC_HRTF_SOFT */:
            switch (val) {
              case 0 /* ALC_FALSE */:
                hrtf = false;
                break;
              case 1 /* ALC_TRUE */:
                hrtf = true;
                break;
              case 2 /* ALC_DONT_CARE_SOFT */:
                break;
              default:
                AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
                return 0;
            }
            break;
          case 0x1996 /* ALC_HRTF_ID_SOFT */:
            if (val !== 0) {
              AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
              return 0;
            }
            break;
          default:
            AL.alcErr = 0xA004; /* ALC_INVALID_VALUE */
            return 0;
          }
        }
      }
  
      var AudioContext = window.AudioContext || window.webkitAudioContext;
      var ac = null;
      try {
        // Only try to pass options if there are any, for compat with browsers that don't support this
        if (options) {
          ac = new AudioContext(options);
        } else {
          ac = new AudioContext();
        }
      } catch (e) {
        if (e.name === 'NotSupportedError') {
          AL.alcErr = 0xA004; /* ALC_INVALID_VALUE */
        } else {
          AL.alcErr = 0xA001; /* ALC_INVALID_DEVICE */
        }
  
        return 0;
      }
  
      // Old Web Audio API (e.g. Safari 6.0.5) had an inconsistently named createGainNode function.
      if (typeof(ac.createGain) === 'undefined') {
        ac.createGain = ac.createGainNode;
      }
  
      var gain = ac.createGain();
      gain.connect(ac.destination);
      var ctx = {
        deviceId: deviceId,
        id: AL.newId(),
        attrs: attrs,
        audioCtx: ac,
        listener: {
      	  position: [0.0, 0.0, 0.0],
      	  velocity: [0.0, 0.0, 0.0],
      	  direction: [0.0, 0.0, 0.0],
      	  up: [0.0, 0.0, 0.0]
        },
        sources: [],
        interval: setInterval(function() { AL.scheduleContextAudio(ctx); }, AL.QUEUE_INTERVAL),
        gain: gain,
        distanceModel: 0xd002 /* AL_INVERSE_DISTANCE_CLAMPED */,
        speedOfSound: 343.3,
        dopplerFactor: 1.0,
        sourceDistanceModel: false,
        hrtf: hrtf || false,
  
        _err: 0,
        get err() {
          return this._err;
        },
        set err(val) {
          // Errors should not be overwritten by later errors until they are cleared by a query.
          if (this._err === 0 /* AL_NO_ERROR */ || val === 0 /* AL_NO_ERROR */) {
            this._err = val;
          }
        }
      };
      AL.deviceRefCounts[deviceId]++;
      AL.contexts[ctx.id] = ctx;
  
      if (hrtf !== null) {
        // Apply hrtf attrib to all contexts for this device
        for (var ctxId in AL.contexts) {
          var c = AL.contexts[ctxId];
          if (c.deviceId === deviceId) {
            c.hrtf = hrtf;
            AL.updateContextGlobal(c);
          }
        }
      }
  
      return ctx.id;
    }


  function _alcDestroyContext(contextId) {
      var ctx = AL.contexts[contextId];
      if (AL.currentCtx === ctx) {
        AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
        return;
      }
  
      // Stop playback, etc
      if (AL.contexts[contextId].interval) {
        clearInterval(AL.contexts[contextId].interval);
      }
      AL.deviceRefCounts[ctx.deviceId]--;
      delete AL.contexts[contextId];
      AL.freeIds.push(contextId);
    }


  function _alcGetError(deviceId) {
      var err = AL.alcErr;
      AL.alcErr = 0 /* ALC_NO_ERROR */;
      return err;
    }


  function _alcGetCurrentContext() {
      if (AL.currentCtx !== null) {
        return AL.currentCtx.id;
      } else {
        return 0;
      }
    }


  function _alcMakeContextCurrent(contextId) {
      if (contextId === 0) {
        AL.currentCtx = null;
        return 0;
      } else {
        AL.currentCtx = AL.contexts[contextId];
        return 1;
      }
    }


  function _alcGetContextsDevice(contextId) {
      if (contextId in AL.contexts) {
        return AL.contexts[contextId].deviceId;
      } else {
        return 0;
      }
    }

  function _alcProcessContext(contextId) {}

  function _alcSuspendContext(contextId) {}


  function _alcIsExtensionPresent(deviceId, pExtName) {
      name = Pointer_stringify(pExtName);
  
      return AL.ALC_EXTENSIONS[name] ? 1 : 0;
    }


  
  var _emscripten_GetAlcProcAddress=undefined;function _alcGetProcAddress(deviceId, pProcName) {
      if (!pProcName) {
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return 0; /* ALC_NONE */
      }
      return _emscripten_GetAlcProcAddress(pProcName);
    }


  function _alcGetEnumValue(deviceId, pEnumName) {
      // Spec says :
      // Using a NULL handle is legal, but only the
      // tokens defined by the AL core are guaranteed.
      if (deviceId !== 0 && !deviceId in AL.deviceRefCounts) {
        // ALC_INVALID_DEVICE is not listed as a possible error state for
        // this function, sadly.
        return 0 /* ALC_NONE */;
      } else if (!pEnumName) {
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return 0; /* ALC_NONE */
      }
      name = Pointer_stringify(pEnumName);
      // See alGetEnumValue(), but basically behave the same as OpenAL-Soft
      switch(name) {
      case 'ALC_NO_ERROR': return 0;
      case 'ALC_INVALID_DEVICE': return 0xA001;
      case 'ALC_INVALID_CONTEXT': return 0xA002;
      case 'ALC_INVALID_ENUM': return 0xA003;
      case 'ALC_INVALID_VALUE': return 0xA004;
      case 'ALC_OUT_OF_MEMORY': return 0xA005;
      case 'ALC_MAJOR_VERSION': return 0x1000;
      case 'ALC_MINOR_VERSION': return 0x1001;
      case 'ALC_ATTRIBUTES_SIZE': return 0x1002;
      case 'ALC_ALL_ATTRIBUTES': return 0x1003;
      case 'ALC_DEFAULT_DEVICE_SPECIFIER': return 0x1004;
      case 'ALC_DEVICE_SPECIFIER': return 0x1005;
      case 'ALC_EXTENSIONS': return 0x1006;
      case 'ALC_FREQUENCY': return 0x1007;
      case 'ALC_REFRESH': return 0x1008;
      case 'ALC_SYNC': return 0x1009;
      case 'ALC_MONO_SOURCES': return 0x1010;
      case 'ALC_STEREO_SOURCES': return 0x1011;
      case 'ALC_CAPTURE_DEVICE_SPECIFIER': return 0x310;
      case 'ALC_CAPTURE_DEFAULT_DEVICE_SPECIFIER': return 0x311;
      case 'ALC_CAPTURE_SAMPLES': return 0x312;
  
      /* Extensions */
      case 'ALC_HRTF_SOFT': return 0x1992;
      case 'ALC_HRTF_ID_SOFT': return 0x1996;
      case 'ALC_DONT_CARE_SOFT': return 0x0002;
      case 'ALC_HRTF_STATUS_SOFT': return 0x1993;
      case 'ALC_NUM_HRTF_SPECIFIERS_SOFT': return 0x1994;
      case 'ALC_HRTF_SPECIFIER_SOFT': return 0x1995;
      case 'ALC_HRTF_DISABLED_SOFT': return 0x0000;
      case 'ALC_HRTF_ENABLED_SOFT': return 0x0001;
      case 'ALC_HRTF_DENIED_SOFT': return 0x0002;
      case 'ALC_HRTF_REQUIRED_SOFT': return 0x0003;
      case 'ALC_HRTF_HEADPHONES_DETECTED_SOFT': return 0x0004;
      case 'ALC_HRTF_UNSUPPORTED_FORMAT_SOFT': return 0x0005;
  
      default:
        AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
        return 0 /* AL_NONE */;
      }
    }


  function _alcGetString(deviceId, param) {
      if (AL.alcStringCache[param]) {
        return AL.alcStringCache[param];
      }
  
      var ret;
      switch (param) {
      case 0 /* ALC_NO_ERROR */:
        ret = 'No Error';
        break;
      case 0xA001 /* ALC_INVALID_DEVICE */:
        ret = 'Invalid Device';
        break;
      case 0xA002 /* ALC_INVALID_CONTEXT */:
        ret = 'Invalid Context';
        break;
      case 0xA003 /* ALC_INVALID_ENUM */:
        ret = 'Invalid Enum';
        break;
      case 0xA004 /* ALC_INVALID_VALUE */:
        ret = 'Invalid Value';
        break;
      case 0xA005 /* ALC_OUT_OF_MEMORY */:
        ret = 'Out of Memory';
        break;
      case 0x1004 /* ALC_DEFAULT_DEVICE_SPECIFIER */:
        if (typeof(AudioContext) !== 'undefined' ||
            typeof(webkitAudioContext) !== 'undefined') {
          ret = AL.DEVICE_NAME;
        } else {
          return 0;
        }
        break;
      case 0x1005 /* ALC_DEVICE_SPECIFIER */:
        if (typeof(AudioContext) !== 'undefined' ||
            typeof(webkitAudioContext) !== 'undefined') {
          ret = AL.DEVICE_NAME.concat('\0');
        } else {
          ret = '\0';
        }
        break;
      case 0x311 /* ALC_CAPTURE_DEFAULT_DEVICE_SPECIFIER */:
        ret = AL.CAPTURE_DEVICE_NAME;
        break;
      case 0x310 /* ALC_CAPTURE_DEVICE_SPECIFIER */:
        if (deviceId === 0) 
          ret = AL.CAPTURE_DEVICE_NAME.concat('\0');
          else {
          var c = AL.requireValidCaptureDevice(deviceId, 'alcGetString');
          if (!c) {
            return 0;
          }
          ret = c.deviceName;
        }  
        break;
      case 0x1006 /* ALC_EXTENSIONS */:
        if (!deviceId) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return 0;
        }
  
        ret = '';
        for (var ext in AL.ALC_EXTENSIONS) {
          ret = ret.concat(ext);
          ret = ret.concat(' ');
        }
        ret = ret.trim();
        break;
      default:
        AL.alcErr = 0xA003 /* ALC_INVALID_ENUM */;
        return 0;
      }
  
      ret = allocate(intArrayFromString(ret), 'i8', ALLOC_NORMAL);
      AL.alcStringCache[param] = ret;
      return ret;
    }


  function _alcGetIntegerv(deviceId, param, size, pValues) {
      if (size === 0 || !pValues) {
        // Ignore the query, per the spec
        return;
      }
  
      switch(param) {
      case 0x1000 /* ALC_MAJOR_VERSION */:
        HEAP32[((pValues)>>2)]=1;
        break;
      case 0x1001 /* ALC_MINOR_VERSION */:
        HEAP32[((pValues)>>2)]=1;
        break;
      case 0x1002 /* ALC_ATTRIBUTES_SIZE */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        if (!AL.currentCtx) {
          AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
          return;
        }
  
        HEAP32[((pValues)>>2)]=AL.currentCtx.attrs.length;
        break;
      case 0x1003 /* ALC_ALL_ATTRIBUTES */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        if (!AL.currentCtx) {
          AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
          return;
        }
  
        for (var i = 0; i < AL.currentCtx.attrs.length; i++) {
          HEAP32[(((pValues)+(i*4))>>2)]=AL.currentCtx.attrs[i];
        }
        break;
      case 0x1007 /* ALC_FREQUENCY */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        if (!AL.currentCtx) {
          AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
          return;
        }
  
        HEAP32[((pValues)>>2)]=AL.currentCtx.audioCtx.sampleRate;
        break;
      case 0x1010 /* ALC_MONO_SOURCES */:
      case 0x1011 /* ALC_STEREO_SOURCES */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        if (!AL.currentCtx) {
          AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
          return;
        }
  
        HEAP32[((pValues)>>2)]=0x7FFFFFFF;
        break;
      case 0x1992 /* ALC_HRTF_SOFT */:
      case 0x1993 /* ALC_HRTF_STATUS_SOFT */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
  
        var hrtfStatus = 0 /* ALC_HRTF_DISABLED_SOFT */;
        for (var ctxId in AL.contexts) {
          var ctx = AL.contexts[ctxId];
          if (ctx.deviceId === deviceId) {
            hrtfStatus = ctx.hrtf ? 1 /* ALC_HRTF_ENABLED_SOFT */ : 0 /* ALC_HRTF_DISABLED_SOFT */;
          }
        }
        HEAP32[((pValues)>>2)]=hrtfStatus;
        break;
      case 0x1994 /* ALC_NUM_HRTF_SPECIFIERS_SOFT */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        HEAP32[((pValues)>>2)]=1;
        break;
      case 0x20003 /* ALC_MAX_AUXILIARY_SENDS */:
        if (!deviceId in AL.deviceRefCounts) {
          AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
          return;
        }
        if (!AL.currentCtx) {
          AL.alcErr = 0xA002 /* ALC_INVALID_CONTEXT */;
          return;
        }
  
        HEAP32[((pValues)>>2)]=1;
      case 0x312 /* ALC_CAPTURE_SAMPLES */:
        var c = AL.requireValidCaptureDevice(deviceId, 'alcGetIntegerv');
        if (!c) {
          return;
        }
        var n = c.capturedFrameCount;
        var dstfreq = c.requestedSampleRate;
        var srcfreq = c.audioCtx.sampleRate;
        var nsamples = Math.floor(n * (dstfreq/srcfreq));
        HEAP32[((pValues)>>2)]=nsamples;
        break;
      default:
        AL.alcErr = 0xA003 /* ALC_INVALID_ENUM */;
        return;
      }
    }


  function _emscripten_alcDevicePauseSOFT(deviceId) {
      if (!deviceId in AL.deviceRefCounts) {
        AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
        return;
      }
  
      if (AL.paused) {
        return;
      }
      AL.paused = true;
  
      for (ctxId in AL.contexts) {
        var ctx = AL.contexts[ctxId];
        if (ctx.deviceId !== deviceId) {
          continue;
        }
  
        ctx.audioCtx.suspend();
        clearInterval(ctx.interval);
        ctx.interval = null;
      }
    }


  function _emscripten_alcDeviceResumeSOFT(deviceId) {
      if (!deviceId in AL.deviceRefCounts) {
        AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
        return;
      }
  
      if (!AL.paused) {
        return;
      }
      AL.paused = false;
  
      for (ctxId in AL.contexts) {
        var ctx = AL.contexts[ctxId];
        if (ctx.deviceId !== deviceId) {
          continue;
        }
  
        ctx.interval = setInterval(function() { AL.scheduleContextAudio(ctx); }, AL.QUEUE_INTERVAL);
        ctx.audioCtx.resume();
      }
    }


  function _emscripten_alcGetStringiSOFT(deviceId, param, index) {
      if (!deviceId in AL.deviceRefCounts) {
        AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
        return 0;
      }
  
      if (AL.alcStringCache[param]) {
        return AL.alcStringCache[param];
      }
  
      var ret;
      switch (param) {
      case 0x1995 /* ALC_HRTF_SPECIFIER_SOFT */:
        if (index === 0) {
          ret = 'Web Audio HRTF';
        } else {
          AL.alcErr = 0xA004 /* ALC_INVALID_VALUE */;
          return 0;
        }
      default:
        if (index === 0) {
          return _alcGetString(deviceId, param);
        } else {
          AL.alcErr = 0xA003 /* ALC_INVALID_ENUM */;
          return 0;
        }
      }
  
      ret = allocate(intArrayFromString(ret), 'i8', ALLOC_NORMAL);
      AL.alcStringCache[param] = ret;
      return ret;
    }


  function _emscripten_alcResetDeviceSOFT(deviceId, pAttrList) {
      if (!deviceId in AL.deviceRefCounts) {
        AL.alcErr = 0xA001 /* ALC_INVALID_DEVICE */;
        return 0 /* ALC_FALSE */;
      }
  
      var hrtf = null;
      pAttrList >>= 2;
      if (pAttrList) {
        var attr = 0;
        var val = 0;
        while (true) {
          attr = HEAP32[pAttrList++];
          if (attr === 0) {
            break;
          }
          val = HEAP32[pAttrList++];
  
          switch (attr) {
          case 0x1992 /* ALC_HRTF_SOFT */:
            if (val === 1 /* ALC_TRUE */) {
              hrtf = true;
            } else if (val === 0 /* ALC_FALSE */) {
              hrtf = false;
            }
            break;
          }
        }
      }
  
      if (hrtf !== null) {
        // Apply hrtf attrib to all contexts for this device
        for (var ctxId in AL.contexts) {
          var ctx = AL.contexts[ctxId];
          if (ctx.deviceId === deviceId) {
            ctx.hrtf = hrtf;
            AL.updateContextGlobal(ctx);
          }
        }
      }
  
      return 1 /* ALC_TRUE */;
    }


  function _alGenBuffers(count, pBufferIds) {
      if (!AL.currentCtx) {
        return;
      }
  
      for (var i = 0; i < count; ++i) {
        var buf = {
          deviceId: AL.currentCtx.deviceId,
          id: AL.newId(),
          refCount: 0,
          audioBuf: null,
          frequency: 0,
          bytesPerSample: 2,
          channels: 1,
          length: 0,
        };
        AL.deviceRefCounts[buf.deviceId]++;
        AL.buffers[buf.id] = buf;
        HEAP32[(((pBufferIds)+(i*4))>>2)]=buf.id;
      }
    }


  function _alDeleteBuffers(count, pBufferIds) {
      if (!AL.currentCtx) {
        return;
      }
  
      for (var i = 0; i < count; ++i) {
        var bufId = HEAP32[(((pBufferIds)+(i*4))>>2)];
        /// Deleting the zero buffer is a legal NOP, so ignore it
        if (bufId === 0) {
          continue;
        }
  
        // Make sure the buffer index is valid.
        if (!AL.buffers[bufId]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
  
        // Make sure the buffer is no longer in use.
        if (AL.buffers[bufId].refCount) {
          AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        var bufId = HEAP32[(((pBufferIds)+(i*4))>>2)];
        if (bufId === 0) {
          continue;
        }
  
        AL.deviceRefCounts[AL.buffers[bufId].deviceId]--;
        delete AL.buffers[bufId];
        AL.freeIds.push(bufId);
      }
    }


  function _alGenSources(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
      for (var i = 0; i < count; ++i) {
        var gain = AL.currentCtx.audioCtx.createGain();
        gain.connect(AL.currentCtx.gain);
        var src = {
          context: AL.currentCtx,
          id: AL.newId(),
          type: 0x1030 /* AL_UNDETERMINED */,
          state: 0x1011 /* AL_INITIAL */,
          bufQueue: [AL.buffers[0]],
          audioQueue: [],
          looping: false,
          pitch: 1.0,
          dopplerShift: 1.0,
          gain: gain,
          minGain: 0.0,
          maxGain: 1.0,
          panner: null,
          bufsProcessed: 0,
          bufStartTime: Number.NEGATIVE_INFINITY,
          bufOffset: 0.0,
          relative: false,
          refDistance: 1.0,
          maxDistance: 3.40282e38 /* FLT_MAX */,
          rolloffFactor: 1.0,
          position: [0.0, 0.0, 0.0],
          velocity: [0.0, 0.0, 0.0],
          direction: [0.0, 0.0, 0.0],
          coneOuterGain: 0.0,
          coneInnerAngle: 360.0,
          coneOuterAngle: 360.0,
          distanceModel: 0xd002 /* AL_INVERSE_DISTANCE_CLAMPED */,
          spatialize: 2 /* AL_AUTO_SOFT */,
  
          get playbackRate() {
            return this.pitch * this.dopplerShift;
          }
        };
        AL.currentCtx.sources[src.id] = src;
        HEAP32[(((pSourceIds)+(i*4))>>2)]=src.id;
      }
    }


  
  function _alSourcei(sourceId, param, value) {
      switch (param) {
      case 0x202 /* AL_SOURCE_RELATIVE */:
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1007 /* AL_LOOPING */:
      case 0x1009 /* AL_BUFFER */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
      case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
      case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        AL.setSourceParam('alSourcei', sourceId, param, value);
        break;
      default:
        AL.setSourceParam('alSourcei', sourceId, param, null);
        break;
      }
    }function _alDeleteSources(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
  
      for (var i = 0; i < count; ++i) {
        var srcId = HEAP32[(((pSourceIds)+(i*4))>>2)];
        if (!AL.currentCtx.sources[srcId]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        var srcId = HEAP32[(((pSourceIds)+(i*4))>>2)];
        AL.setSourceState(AL.currentCtx.sources[srcId], 0x1014 /* AL_STOPPED */);
        _alSourcei(srcId, 0x1009 /* AL_BUFFER */, 0);
        delete AL.currentCtx.sources[srcId];
        AL.freeIds.push(srcId);
      }
    }


  function _alGetError() {
      if (!AL.currentCtx) {
        return 0xA004 /* AL_INVALID_OPERATION */;
      } else {
        // Reset error on get.
        var err = AL.currentCtx.err;
        AL.currentCtx.err = 0 /* AL_NO_ERROR */;
        return err;
      }
    }


  function _alIsExtensionPresent(pExtName) {
      name = Pointer_stringify(pExtName);
  
      return AL.AL_EXTENSIONS[name] ? 1 : 0;
    }


  
  var _emscripten_GetAlProcAddress=undefined;function _alGetProcAddress(pProcName) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pProcName) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return 0; /* ALC_NONE */
      }
      return _emscripten_GetAlProcAddress(pProcName);
    }


  function _alGetEnumValue(pEnumName) {
      if (!AL.currentCtx) {
        return 0;
      }
  
      if (!pEnumName) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return 0 /* AL_NONE */;
      }
      name = Pointer_stringify(pEnumName);
  
      switch(name) {
      // Spec doesn't clearly state that alGetEnumValue() is required to
      // support _only_ extension tokens.
      // We should probably follow OpenAL-Soft's example and support all
      // of the names we know.
      // See http://repo.or.cz/openal-soft.git/blob/HEAD:/Alc/ALc.c
      case 'AL_BITS': return 0x2002;
      case 'AL_BUFFER': return 0x1009;
      case 'AL_BUFFERS_PROCESSED': return 0x1016;
      case 'AL_BUFFERS_QUEUED': return 0x1015;
      case 'AL_BYTE_OFFSET': return 0x1026;
      case 'AL_CHANNELS': return 0x2003;
      case 'AL_CONE_INNER_ANGLE': return 0x1001;
      case 'AL_CONE_OUTER_ANGLE': return 0x1002;
      case 'AL_CONE_OUTER_GAIN': return 0x1022;
      case 'AL_DIRECTION': return 0x1005;
      case 'AL_DISTANCE_MODEL': return 0xD000;
      case 'AL_DOPPLER_FACTOR': return 0xC000;
      case 'AL_DOPPLER_VELOCITY': return 0xC001;
      case 'AL_EXPONENT_DISTANCE': return 0xD005;
      case 'AL_EXPONENT_DISTANCE_CLAMPED': return 0xD006;
      case 'AL_EXTENSIONS': return 0xB004;
      case 'AL_FORMAT_MONO16': return 0x1101;
      case 'AL_FORMAT_MONO8': return 0x1100;
      case 'AL_FORMAT_STEREO16': return 0x1103;
      case 'AL_FORMAT_STEREO8': return 0x1102;
      case 'AL_FREQUENCY': return 0x2001;
      case 'AL_GAIN': return 0x100A;
      case 'AL_INITIAL': return 0x1011;
      case 'AL_INVALID': return -1;
      case 'AL_ILLEGAL_ENUM': // fallthrough
      case 'AL_INVALID_ENUM': return 0xA002;
      case 'AL_INVALID_NAME': return 0xA001;
      case 'AL_ILLEGAL_COMMAND': // fallthrough
      case 'AL_INVALID_OPERATION': return 0xA004;
      case 'AL_INVALID_VALUE': return 0xA003;
      case 'AL_INVERSE_DISTANCE': return 0xD001;
      case 'AL_INVERSE_DISTANCE_CLAMPED': return 0xD002;
      case 'AL_LINEAR_DISTANCE': return 0xD003;
      case 'AL_LINEAR_DISTANCE_CLAMPED': return 0xD004;
      case 'AL_LOOPING': return 0x1007;
      case 'AL_MAX_DISTANCE': return 0x1023;
      case 'AL_MAX_GAIN': return 0x100E;
      case 'AL_MIN_GAIN': return 0x100D;
      case 'AL_NONE': return 0;
      case 'AL_NO_ERROR': return 0;
      case 'AL_ORIENTATION': return 0x100F;
      case 'AL_OUT_OF_MEMORY': return 0xA005;
      case 'AL_PAUSED': return 0x1013;
      case 'AL_PENDING': return 0x2011;
      case 'AL_PITCH': return 0x1003;
      case 'AL_PLAYING': return 0x1012;
      case 'AL_POSITION': return 0x1004;
      case 'AL_PROCESSED': return 0x2012;
      case 'AL_REFERENCE_DISTANCE': return 0x1020;
      case 'AL_RENDERER': return 0xB003;
      case 'AL_ROLLOFF_FACTOR': return 0x1021;
      case 'AL_SAMPLE_OFFSET': return 0x1025;
      case 'AL_SEC_OFFSET': return 0x1024;
      case 'AL_SIZE': return 0x2004;
      case 'AL_SOURCE_RELATIVE': return 0x202;
      case 'AL_SOURCE_STATE': return 0x1010;
      case 'AL_SOURCE_TYPE': return 0x1027;
      case 'AL_SPEED_OF_SOUND': return 0xC003;
      case 'AL_STATIC': return 0x1028;
      case 'AL_STOPPED': return 0x1014;
      case 'AL_STREAMING': return 0x1029;
      case 'AL_UNDETERMINED': return 0x1030;
      case 'AL_UNUSED': return 0x2010;
      case 'AL_VELOCITY': return 0x1006;
      case 'AL_VENDOR': return 0xB001;
      case 'AL_VERSION': return 0xB002;
  
      /* Extensions */
      case 'AL_AUTO_SOFT': return 0x0002;
      case 'AL_SOURCE_DISTANCE_MODEL': return 0x200;
      case 'AL_SOURCE_SPATIALIZE_SOFT': return 0x1214;
      case 'AL_LOOP_POINTS_SOFT': return 0x2015;
      case 'AL_BYTE_LENGTH_SOFT': return 0x2009;
      case 'AL_SAMPLE_LENGTH_SOFT': return 0x200A;
      case 'AL_SEC_LENGTH_SOFT': return 0x200B;
      case 'AL_FORMAT_MONO_FLOAT32': return 0x10010;
      case 'AL_FORMAT_STEREO_FLOAT32': return 0x10011;
  
      default:
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return 0;
      }
    }


  function _alGetString(param) {
      if (!AL.currentCtx) {
        return 0;
      }
  
      if (AL.stringCache[param]) {
        return AL.stringCache[param];
      }
  
      var ret;
      switch (param) {
      case 0 /* AL_NO_ERROR */:
        ret = 'No Error';
        break;
      case 0xA001 /* AL_INVALID_NAME */:
        ret = 'Invalid Name';
        break;
      case 0xA002 /* AL_INVALID_ENUM */:
        ret = 'Invalid Enum';
        break;
      case 0xA003 /* AL_INVALID_VALUE */:
        ret = 'Invalid Value';
        break;
      case 0xA004 /* AL_INVALID_OPERATION */:
        ret = 'Invalid Operation';
        break;
      case 0xA005 /* AL_OUT_OF_MEMORY */:
        ret = 'Out of Memory';
        break;
      case 0xB001 /* AL_VENDOR */:
        ret = 'Emscripten';
        break;
      case 0xB002 /* AL_VERSION */:
        ret = '1.1';
        break;
      case 0xB003 /* AL_RENDERER */:
        ret = 'WebAudio';
        break;
      case 0xB004 /* AL_EXTENSIONS */:
        ret = '';
        for (ext in AL.AL_EXTENSIONS) {
          ret = ret.concat(ext);
          ret = ret.concat(' ');
        }
        ret = ret.trim();
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return 0;
      }
  
      ret = allocate(intArrayFromString(ret), 'i8', ALLOC_NORMAL);
      AL.stringCache[param] = ret;
      return ret;
    }


  function _alEnable(param) {
      if (!AL.currentCtx) {
        return;
      }
      switch (param) {
      case 'AL_SOURCE_DISTANCE_MODEL':
        AL.currentCtx.sourceDistanceModel = true;
        AL.updateContextGlobal(AL.currentCtx);
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alDisable(param) {
      if (!AL.currentCtx) {
        return;
      }
      switch (pname) {
      case 'AL_SOURCE_DISTANCE_MODEL':
        AL.currentCtx.sourceDistanceModel = false;
        AL.updateContextGlobal(AL.currentCtx);
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alIsEnabled(param) {
      if (!AL.currentCtx) {
        return 0;
      }
      switch (pname) {
      case 'AL_SOURCE_DISTANCE_MODEL':
        return AL.currentCtx.sourceDistanceModel ? 0 /* AL_FALSE */ : 1 /* AL_TRUE */;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return 0;
      }
    }


  function _alGetDouble(param) {
      var val = AL.getGlobalParam('alGetDouble', param);
      if (val === null) {
        return 0.0;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        return val;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return 0.0;
      }
    }


  function _alGetDoublev(param, pValues) {
      var val = AL.getGlobalParam('alGetDoublev', param);
      // Silently ignore null destinations, as per the spec for global state functions
      if (val === null || !pValues) {
        return;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAPF64[((pValues)>>3)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetFloat(param) {
      var val = AL.getGlobalParam('alGetFloat', param);
      if (val === null) {
        return 0.0;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        return val;
      default:
        return 0.0;
      }
    }


  function _alGetFloatv(param, pValues) {
      var val = AL.getGlobalParam('alGetFloatv', param);
      // Silently ignore null destinations, as per the spec for global state functions
      if (val === null || !pValues) {
        return;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAPF32[((pValues)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetInteger(param) {
      var val = AL.getGlobalParam('alGetInteger', param);
      if (val === null) {
        return 0;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        return val;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return 0;
      }
    }


  function _alGetIntegerv(param, pValues) {
      var val = AL.getGlobalParam('alGetIntegerv', param);
      // Silently ignore null destinations, as per the spec for global state functions
      if (val === null || !pValues) {
        return;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAP32[((pValues)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetBoolean(param) {
      var val = AL.getGlobalParam('alGetBoolean', param);
      if (val === null) {
        return 0 /* AL_FALSE */;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        return val !== 0 ? 1 /* AL_TRUE */ : 0 /* AL_FALSE */;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return 0 /* AL_FALSE */;
      }
    }


  function _alGetBooleanv(param, pValues) {
      var val = AL.getGlobalParam('alGetBooleanv', param);
      // Silently ignore null destinations, as per the spec for global state functions
      if (val === null || !pValues) {
        return;
      }
  
      switch (param) {
      case 0xC000 /* AL_DOPPLER_FACTOR */:
      case 0xC003 /* AL_SPEED_OF_SOUND */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAP8[((pValues)>>0)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alDistanceModel(model) {
      AL.setGlobalParam('alDistanceModel', 0xD000 /* AL_DISTANCE_MODEL */, model);
    }


  function _alSpeedOfSound(value) {
      AL.setGlobalParam('alSpeedOfSound', 0xC003 /* AL_SPEED_OF_SOUND */, value);
    }


  function _alDopplerFactor(value) {
      AL.setGlobalParam('alDopplerFactor', 0xC000 /* AL_DOPPLER_FACTOR */, value);
    }


  function _alDopplerVelocity(value) {
      warnOnce('alDopplerVelocity() is deprecated, and only kept for compatibility with OpenAL 1.0. Use alSpeedOfSound() instead.');
      if (!AL.currentCtx) {
        return;
      }
      if (value <= 0) { // Negative or zero values are disallowed
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
    }


  function _alGetListenerf(param, pValue) {
      var val = AL.getListenerParam('alGetListenerf', param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x100A /* AL_GAIN */:
        HEAPF32[((pValue)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetListener3f(param, pValue0, pValue1, pValue2) {
      var val = AL.getListenerParam('alGetListener3f', param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAPF32[((pValue0)>>2)]=val[0];
        HEAPF32[((pValue1)>>2)]=val[1];
        HEAPF32[((pValue2)>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetListenerfv(param, pValues) {
      var val = AL.getListenerParam('alGetListenerfv', param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAPF32[((pValues)>>2)]=val[0];
        HEAPF32[(((pValues)+(4))>>2)]=val[1];
        HEAPF32[(((pValues)+(8))>>2)]=val[2];
        break;
      case 0x100F /* AL_ORIENTATION */:
        HEAPF32[((pValues)>>2)]=val[0];
        HEAPF32[(((pValues)+(4))>>2)]=val[1];
        HEAPF32[(((pValues)+(8))>>2)]=val[2];
        HEAPF32[(((pValues)+(12))>>2)]=val[3];
        HEAPF32[(((pValues)+(16))>>2)]=val[4];
        HEAPF32[(((pValues)+(20))>>2)]=val[5];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetListeneri(param, pValue) {
      var val = AL.getListenerParam('alGetListeneri', param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
    }


  function _alGetListener3i(param, pValue0, pValue1, pValue2) {
      var val = AL.getListenerParam('alGetListener3i', param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAP32[((pValue0)>>2)]=val[0];
        HEAP32[((pValue1)>>2)]=val[1];
        HEAP32[((pValue2)>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetListeneriv(param, pValues) {
      var val = AL.getListenerParam('alGetListeneriv', param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAP32[((pValues)>>2)]=val[0];
        HEAP32[(((pValues)+(4))>>2)]=val[1];
        HEAP32[(((pValues)+(8))>>2)]=val[2];
        break;
      case 0x100F /* AL_ORIENTATION */:
        HEAP32[((pValues)>>2)]=val[0];
        HEAP32[(((pValues)+(4))>>2)]=val[1];
        HEAP32[(((pValues)+(8))>>2)]=val[2];
        HEAP32[(((pValues)+(12))>>2)]=val[3];
        HEAP32[(((pValues)+(16))>>2)]=val[4];
        HEAP32[(((pValues)+(20))>>2)]=val[5];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alListenerf(param, value) {
      switch (param) {
      case 0x100A /* AL_GAIN */:
        AL.setListenerParam('alListenerf', param, value);
        break;
      default:
        AL.setListenerParam('alListenerf', param, null);
        break;
      }
    }


  function _alListener3f(param, value0, value1, value2) {
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = value0;
        AL.paramArray[1] = value1;
        AL.paramArray[2] = value2;
        AL.setListenerParam('alListener3f', param, AL.paramArray);
        break;
      default:
        AL.setListenerParam('alListener3f', param, null);
        break;
      }
    }


  function _alListenerfv(param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = HEAPF32[((pValues)>>2)];
        AL.paramArray[1] = HEAPF32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAPF32[(((pValues)+(8))>>2)];
        AL.setListenerParam('alListenerfv', param, AL.paramArray);
        break;
      case 0x100F /* AL_ORIENTATION */:
        AL.paramArray[0] = HEAPF32[((pValues)>>2)];
        AL.paramArray[1] = HEAPF32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAPF32[(((pValues)+(8))>>2)];
        AL.paramArray[3] = HEAPF32[(((pValues)+(12))>>2)];
        AL.paramArray[4] = HEAPF32[(((pValues)+(16))>>2)];
        AL.paramArray[5] = HEAPF32[(((pValues)+(20))>>2)];
        AL.setListenerParam('alListenerfv', param, AL.paramArray);
        break;
      default:
        AL.setListenerParam('alListenerfv', param, null);
        break;
      }
    }


  function _alListeneri(param, value) {
      AL.setListenerParam('alListeneri', param, null);
    }


  function _alListener3i(param, value0, value1, value2) {
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = value0;
        AL.paramArray[1] = value1;
        AL.paramArray[2] = value2;
        AL.setListenerParam('alListener3i', param, AL.paramArray);
        break;
      default:
        AL.setListenerParam('alListener3i', param, null);
        break;
      }
    }


  function _alListeneriv(param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = HEAP32[((pValues)>>2)];
        AL.paramArray[1] = HEAP32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAP32[(((pValues)+(8))>>2)];
        AL.setListenerParam('alListeneriv', param, AL.paramArray);
        break;
      case 0x100F /* AL_ORIENTATION */:
        AL.paramArray[0] = HEAP32[((pValues)>>2)];
        AL.paramArray[1] = HEAP32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAP32[(((pValues)+(8))>>2)];
        AL.paramArray[3] = HEAP32[(((pValues)+(12))>>2)];
        AL.paramArray[4] = HEAP32[(((pValues)+(16))>>2)];
        AL.paramArray[5] = HEAP32[(((pValues)+(20))>>2)];
        AL.setListenerParam('alListeneriv', param, AL.paramArray);
        break;
      default:
        AL.setListenerParam('alListeneriv', param, null);
        break;
      }
    }


  function _alIsBuffer(bufferId) {
      if (!AL.currentCtx) {
        return false;
      }
      if (bufferId > AL.buffers.length) {
        return false;
      }
  
      if (!AL.buffers[bufferId]) {
        return false;
      } else {
        return true;
      }
    }


  function _alBufferData(bufferId, format, pData, size, freq) {
      if (!AL.currentCtx) {
        return;
      }
      var buf = AL.buffers[bufferId];
      if (!buf) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
      if (freq <= 0) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      var audioBuf = null;
      try {
        switch (format) {
        case 0x1100 /* AL_FORMAT_MONO8 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size, freq);
            var channel0 = audioBuf.getChannelData(0);
            for (var i = 0; i < size; ++i) {
              channel0[i] = HEAPU8[pData++] * 0.0078125 /* 1/128 */ - 1.0;
            }
          }
          buf.bytesPerSample = 1;
          buf.channels = 1;
          buf.length = size;
          break;
        case 0x1101 /* AL_FORMAT_MONO16 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size >> 1, freq);
            var channel0 = audioBuf.getChannelData(0);
            pData >>= 1;
            for (var i = 0; i < size >> 1; ++i) {
              channel0[i] = HEAP16[pData++] * 0.000030517578125 /* 1/32768 */;
            }
          }
          buf.bytesPerSample = 2;
          buf.channels = 1;
          buf.length = size >> 1;
          break;
        case 0x1102 /* AL_FORMAT_STEREO8 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 1, freq);
            var channel0 = audioBuf.getChannelData(0);
            var channel1 = audioBuf.getChannelData(1);
            for (var i = 0; i < size >> 1; ++i) {
              channel0[i] = HEAPU8[pData++] * 0.0078125 /* 1/128 */ - 1.0;
              channel1[i] = HEAPU8[pData++] * 0.0078125 /* 1/128 */ - 1.0;
            }
          }
          buf.bytesPerSample = 1;
          buf.channels = 2;
          buf.length = size >> 1;
          break;
        case 0x1103 /* AL_FORMAT_STEREO16 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 2, freq);
            var channel0 = audioBuf.getChannelData(0);
            var channel1 = audioBuf.getChannelData(1);
            pData >>= 1;
            for (var i = 0; i < size >> 2; ++i) {
              channel0[i] = HEAP16[pData++] * 0.000030517578125 /* 1/32768 */;
              channel1[i] = HEAP16[pData++] * 0.000030517578125 /* 1/32768 */;
            }
          }
          buf.bytesPerSample = 2;
          buf.channels = 2;
          buf.length = size >> 2;
          break;
        case 0x10010 /* AL_FORMAT_MONO_FLOAT32 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size >> 2, freq);
            var channel0 = audioBuf.getChannelData(0);
            pData >>= 2;
            for (var i = 0; i < size >> 2; ++i) {
              channel0[i] = HEAPF32[pData++];
            }
          }
          buf.bytesPerSample = 4;
          buf.channels = 1;
          buf.length = size >> 2;
          break;
        case 0x10011 /* AL_FORMAT_STEREO_FLOAT32 */:
          if (size > 0) {
            audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 3, freq);
            var channel0 = audioBuf.getChannelData(0);
            var channel1 = audioBuf.getChannelData(1);
            pData >>= 2;
            for (var i = 0; i < size >> 3; ++i) {
              channel0[i] = HEAPF32[pData++];
              channel1[i] = HEAPF32[pData++];
            }
          }
          buf.bytesPerSample = 4;
          buf.channels = 2;
          buf.length = size >> 3;
          break;
        default:
          AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
          return;
        }
        buf.frequency = freq;
        buf.audioBuf = audioBuf;
      } catch (e) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
    }


  function _alGetBufferf(bufferId, param, pValue) {
      var val = AL.getBufferParam('alGetBufferf', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
    }


  function _alGetBuffer3f(bufferId, param, pValue0, pValue1, pValue2) {
      var val = AL.getBufferParam('alGetBuffer3f', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
    }


  function _alGetBufferfv(bufferId, param, pValues) {
      var val = AL.getBufferParam('alGetBufferfv', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
    }


  function _alGetBufferi(bufferId, param, pValue) {
      var val = AL.getBufferParam('alGetBufferi', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x2001 /* AL_FREQUENCY */:
      case 0x2002 /* AL_BITS */:
      case 0x2003 /* AL_CHANNELS */:
      case 0x2004 /* AL_SIZE */:
        HEAP32[((pValue)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetBuffer3i(bufferId, param, pValue0, pValue1, pValue2) {
      var val = AL.getBufferParam('alGetBuffer3i', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
    }


  function _alGetBufferiv(bufferId, param, pValues) {
      var val = AL.getBufferParam('alGetBufferiv', bufferId, param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x2001 /* AL_FREQUENCY */:
      case 0x2002 /* AL_BITS */:
      case 0x2003 /* AL_CHANNELS */:
      case 0x2004 /* AL_SIZE */:
        HEAP32[((pValues)>>2)]=val;
        break;
      case 0x2015 /* AL_LOOP_POINTS_SOFT */:
        HEAP32[((pValues)>>2)]=val[0];
        HEAP32[(((pValues)+(4))>>2)]=val[1];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alBufferf(bufferId, param, value) {
      AL.setBufferParam('alBufferf', bufferId, param, null);
    }


  function _alBuffer3f(bufferId, param, value0, value1, value2) {
      AL.setBufferParam('alBuffer3f', bufferId, param, null);
    }


  function _alBufferfv(bufferId, param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      AL.setBufferParam('alBufferfv', bufferId, param, null);
    }


  function _alBufferi(bufferId, param, value) {
      AL.setBufferParam('alBufferi', bufferId, param, null);
    }


  function _alBuffer3i(bufferId, param, value0, value1, value2) {
      AL.setBufferParam('alBuffer3i', bufferId, param, null);
    }


  function _alBufferiv(bufferId, param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x2015 /* AL_LOOP_POINTS_SOFT */:
        AL.paramArray[0] = HEAP32[((pValues)>>2)];
        AL.paramArray[1] = HEAP32[(((pValues)+(4))>>2)];
        AL.setBufferParam('alBufferiv', bufferId, param, AL.paramArray);
        break;
      default:
        AL.setBufferParam('alBufferiv', bufferId, param, null);
        break;
      }
    }


  function _alIsSource(sourceId) {
      if (!AL.currentCtx) {
        return false;
      }
  
      if (!AL.currentCtx.sources[sourceId]) {
        return false;
      } else {
        return true;
      }
    }


  function _alSourceQueueBuffers(sourceId, count, pBufferIds) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      if (src.type === 0x1028 /* AL_STATIC */) {
        AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
        return;
      }
  
      if (count === 0) {
        return;
      }
  
      // Find the first non-zero buffer in the queue to determine the proper format
      var templateBuf = AL.buffers[0];
      for (var i = 0; i < src.bufQueue.length; i++) {
        if (src.bufQueue[i].id !== 0) {
          templateBuf = src.bufQueue[i];
          break;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        var bufId = HEAP32[(((pBufferIds)+(i*4))>>2)];
        var buf = AL.buffers[bufId];
        if (!buf) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
  
        // Check that the added buffer has the correct format. If the template is the zero buffer, any format is valid.
        if (templateBuf.id !== 0 && (
          buf.frequency !== templateBuf.frequency
          || buf.bytesPerSample !== templateBuf.bytesPerSample
          || buf.channels !== templateBuf.channels)
        ) {
          AL.currentCtx.err = 0xA004 /* AL_INVALID_OPERATION */;
        }
      }
  
      // If the only buffer in the queue is the zero buffer, clear the queue before we add anything.
      if (src.bufQueue.length === 1 && src.bufQueue[0].id === 0) {
        src.bufQueue.length = 0;
      }
  
      src.type = 0x1029 /* AL_STREAMING */;
      for (var i = 0; i < count; ++i) {
        var bufId = HEAP32[(((pBufferIds)+(i*4))>>2)];
        var buf = AL.buffers[bufId];
        buf.refCount++;
        src.bufQueue.push(buf);
      }
  
      // if the source is looping, cancel the schedule so we can reschedule the loop order
      if (src.looping) {
        AL.cancelPendingSourceAudio(src);
      }
  
      AL.initSourcePanner(src);
      AL.scheduleSourceAudio(src);
    }


  function _alSourceUnqueueBuffers(sourceId, count, pBufferIds) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      if (count > (src.bufQueue.length === 1 && src.bufQueue[0].id === 0 ? 0 : src.bufsProcessed)) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      if (count === 0) {
        return;
      }
  
      for (var i = 0; i < count; i++) {
        var buf = src.bufQueue.shift();
        buf.refCount--;
        // Write the buffers index out to the return list.
        HEAP32[(((pBufferIds)+(i*4))>>2)]=buf.id;
        src.bufsProcessed--;
      }
  
      /// If the queue is empty, put the zero buffer back in
      if (src.bufQueue.length === 0) {
        src.bufQueue.push(AL.buffers[0]);
      }
  
      AL.initSourcePanner(src);
      AL.scheduleSourceAudio(src);
    }


  function _alSourcePlay(sourceId) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      AL.setSourceState(src, 0x1012 /* AL_PLAYING */);
    }


  function _alSourcePlayv(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pSourceIds) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
      }
      for (var i = 0; i < count; ++i) {
        if (!AL.currentCtx.sources[HEAP32[(((pSourceIds)+(i*4))>>2)]]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        AL.setSourceState(HEAP32[(((pSourceIds)+(i*4))>>2)], 0x1012 /* AL_PLAYING */);
      }
    }


  function _alSourceStop(sourceId) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      AL.setSourceState(src, 0x1014 /* AL_STOPPED */);
    }


  function _alSourceStopv(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pSourceIds) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
      }
      for (var i = 0; i < count; ++i) {
        if (!AL.currentCtx.sources[HEAP32[(((pSourceIds)+(i*4))>>2)]]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        AL.setSourceState(HEAP32[(((pSourceIds)+(i*4))>>2)], 0x1014 /* AL_STOPPED */);
      }
    }


  function _alSourceRewind(sourceId) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      // Stop the source first to clear the source queue
      AL.setSourceState(src, 0x1014 /* AL_STOPPED */);
      // Now set the state of AL_INITIAL according to the specification
      AL.setSourceState(src, 0x1011 /* AL_INITIAL */);
    }


  function _alSourceRewindv(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pSourceIds) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
      }
      for (var i = 0; i < count; ++i) {
        if (!AL.currentCtx.sources[HEAP32[(((pSourceIds)+(i*4))>>2)]]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        AL.setSourceState(HEAP32[(((pSourceIds)+(i*4))>>2)], 0x1011 /* AL_INITIAL */);
      }
    }


  function _alSourcePause(sourceId) {
      if (!AL.currentCtx) {
        return;
      }
      var src = AL.currentCtx.sources[sourceId];
      if (!src) {
        AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
        return;
      }
      AL.setSourceState(src, 0x1013 /* AL_PAUSED */);
    }


  function _alSourcePausev(count, pSourceIds) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pSourceIds) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
      }
      for (var i = 0; i < count; ++i) {
        if (!AL.currentCtx.sources[HEAP32[(((pSourceIds)+(i*4))>>2)]]) {
          AL.currentCtx.err = 0xA001 /* AL_INVALID_NAME */;
          return;
        }
      }
  
      for (var i = 0; i < count; ++i) {
        AL.setSourceState(HEAP32[(((pSourceIds)+(i*4))>>2)], 0x1013 /* AL_PAUSED */);
      }
    }


  function _alGetSourcef(sourceId, param, pValue) {
      var val = AL.getSourceParam('alGetSourcef', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1003 /* AL_PITCH */:
      case 0x100A /* AL_GAIN */:
      case 0x100D /* AL_MIN_GAIN */:
      case 0x100E /* AL_MAX_GAIN */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1022 /* AL_CONE_OUTER_GAIN */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x200B /* AL_SEC_LENGTH_SOFT */:
        HEAPF32[((pValue)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetSource3f(source, param, pValue0, pValue1, pValue2) {
      var val = AL.getSourceParam('alGetSource3f', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAPF32[((pValue0)>>2)]=val[0];
        HEAPF32[((pValue1)>>2)]=val[1];
        HEAPF32[((pValue2)>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetSourcefv(sourceId, param, pValues) {
      var val = AL.getSourceParam('alGetSourcefv', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1003 /* AL_PITCH */:
      case 0x100A /* AL_GAIN */:
      case 0x100D /* AL_MIN_GAIN */:
      case 0x100E /* AL_MAX_GAIN */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1022 /* AL_CONE_OUTER_GAIN */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x200B /* AL_SEC_LENGTH_SOFT */:
        HEAPF32[((pValues)>>2)]=val[0];
        break;
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAPF32[((pValues)>>2)]=val[0];
        HEAPF32[(((pValues)+(4))>>2)]=val[1];
        HEAPF32[(((pValues)+(8))>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetSourcei(sourceId, param, pValue) {
      var val = AL.getSourceParam('alGetSourcei', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValue) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x202 /* AL_SOURCE_RELATIVE */:
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1007 /* AL_LOOPING */:
      case 0x1009 /* AL_BUFFER */:
      case 0x1010 /* AL_SOURCE_STATE */:
      case 0x1015 /* AL_BUFFERS_QUEUED */:
      case 0x1016 /* AL_BUFFERS_PROCESSED */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x1027 /* AL_SOURCE_TYPE */:
      case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
      case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
      case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAP32[((pValue)>>2)]=val;
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetSource3i(source, param, pValue0, pValue1, pValue2) {
      var val = AL.getSourceParam('alGetSource3i', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValue0 || !pValue1 || !pValue2) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAP32[((pValue0)>>2)]=val[0];
        HEAP32[((pValue1)>>2)]=val[1];
        HEAP32[((pValue2)>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alGetSourceiv(sourceId, param, pValues) {
      var val = AL.getSourceParam('alGetSourceiv', sourceId, param);
      if (val === null) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x202 /* AL_SOURCE_RELATIVE */:
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1007 /* AL_LOOPING */:
      case 0x1009 /* AL_BUFFER */:
      case 0x1010 /* AL_SOURCE_STATE */:
      case 0x1015 /* AL_BUFFERS_QUEUED */:
      case 0x1016 /* AL_BUFFERS_PROCESSED */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x1027 /* AL_SOURCE_TYPE */:
      case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
      case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
      case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        HEAP32[((pValues)>>2)]=val;
        break;
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        HEAP32[((pValues)>>2)]=val[0];
        HEAP32[(((pValues)+(4))>>2)]=val[1];
        HEAP32[(((pValues)+(8))>>2)]=val[2];
        break;
      default:
        AL.currentCtx.err = 0xA002 /* AL_INVALID_ENUM */;
        return;
      }
    }


  function _alSourcef(sourceId, param, value) {
      switch (param) {
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1003 /* AL_PITCH */:
      case 0x100A /* AL_GAIN */:
      case 0x100D /* AL_MIN_GAIN */:
      case 0x100E /* AL_MAX_GAIN */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1022 /* AL_CONE_OUTER_GAIN */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x200B /* AL_SEC_LENGTH_SOFT */:
        AL.setSourceParam('alSourcef', sourceId, param, value);
        break;
      default:
        AL.setSourceParam('alSourcef', sourceId, param, null);
        break;
      }
    }


  function _alSource3f(sourceId, param, value0, value1, value2) {
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = value0;
        AL.paramArray[1] = value1;
        AL.paramArray[2] = value2;
        AL.setSourceParam('alSource3f', sourceId, param, AL.paramArray);
        break;
      default:
        AL.setSourceParam('alSource3f', sourceId, param, null);
        break;
      }
    }


  function _alSourcefv(sourceId, param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1003 /* AL_PITCH */:
      case 0x100A /* AL_GAIN */:
      case 0x100D /* AL_MIN_GAIN */:
      case 0x100E /* AL_MAX_GAIN */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1022 /* AL_CONE_OUTER_GAIN */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x200B /* AL_SEC_LENGTH_SOFT */:
        var val = HEAPF32[((pValues)>>2)];
        AL.setSourceParam('alSourcefv', sourceId, param, val);
        break;
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = HEAPF32[((pValues)>>2)];
        AL.paramArray[1] = HEAPF32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAPF32[(((pValues)+(8))>>2)];
        AL.setSourceParam('alSourcefv', sourceId, param, AL.paramArray);
        break;
      default:
        AL.setSourceParam('alSourcefv', sourceId, param, null);
        break;
      }
    }




  function _alSource3i(sourceId, param, value0, value1, value2) {
      switch (param) {
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = value0;
        AL.paramArray[1] = value1;
        AL.paramArray[2] = value2;
        AL.setSourceParam('alSource3i', sourceId, param, AL.paramArray);
        break;
      default:
        AL.setSourceParam('alSource3i', sourceId, param, null);
        break;
      }
    }


  function _alSourceiv(source, param, pValues) {
      if (!AL.currentCtx) {
        return;
      }
      if (!pValues) {
        AL.currentCtx.err = 0xA003 /* AL_INVALID_VALUE */;
        return;
      }
  
      switch (param) {
      case 0x202 /* AL_SOURCE_RELATIVE */:
      case 0x1001 /* AL_CONE_INNER_ANGLE */:
      case 0x1002 /* AL_CONE_OUTER_ANGLE */:
      case 0x1007 /* AL_LOOPING */:
      case 0x1009 /* AL_BUFFER */:
      case 0x1020 /* AL_REFERENCE_DISTANCE */:
      case 0x1021 /* AL_ROLLOFF_FACTOR */:
      case 0x1023 /* AL_MAX_DISTANCE */:
      case 0x1024 /* AL_SEC_OFFSET */:
      case 0x1025 /* AL_SAMPLE_OFFSET */:
      case 0x1026 /* AL_BYTE_OFFSET */:
      case 0x1214 /* AL_SOURCE_SPATIALIZE_SOFT */:
      case 0x2009 /* AL_BYTE_LENGTH_SOFT */: 
      case 0x200A /* AL_SAMPLE_LENGTH_SOFT */:
      case 0xD000 /* AL_DISTANCE_MODEL */:
        var val = HEAP32[((pValues)>>2)];
        AL.setSourceParam('alSourceiv', sourceId, param, val);
        break;
      case 0x1004 /* AL_POSITION */:
      case 0x1005 /* AL_DIRECTION */:
      case 0x1006 /* AL_VELOCITY */:
        AL.paramArray[0] = HEAP32[((pValues)>>2)];
        AL.paramArray[1] = HEAP32[(((pValues)+(4))>>2)];
        AL.paramArray[2] = HEAP32[(((pValues)+(8))>>2)];
        AL.setSourceParam('alSourceiv', sourceId, param, AL.paramArray);
        break;
      default:
        AL.setSourceParam('alSourceiv', sourceId, param, null);
        break;
      }
    }

  var GLFW={Window:function (id, width, height, title, monitor, share) {
        this.id = id;
        this.x = 0;
        this.y = 0;
        this.fullscreen = false; // Used to determine if app in fullscreen mode
        this.storedX = 0; // Used to store X before fullscreen
        this.storedY = 0; // Used to store Y before fullscreen
        this.width = width;
        this.height = height;
        this.storedWidth = width; // Used to store width before fullscreen
        this.storedHeight = height; // Used to store height before fullscreen
        this.title = title;
        this.monitor = monitor;
        this.share = share;
        this.attributes = GLFW.hints;
        this.inputModes = {
          0x00033001:0x00034001, // GLFW_CURSOR (GLFW_CURSOR_NORMAL)
          0x00033002:0, // GLFW_STICKY_KEYS
          0x00033003:0, // GLFW_STICKY_MOUSE_BUTTONS
        };
        this.buttons = 0;
        this.keys = new Array();
        this.domKeys = new Array();
        this.shouldClose = 0;
        this.title = null;
        this.windowPosFunc = null; // GLFWwindowposfun
        this.windowSizeFunc = null; // GLFWwindowsizefun
        this.windowCloseFunc = null; // GLFWwindowclosefun
        this.windowRefreshFunc = null; // GLFWwindowrefreshfun
        this.windowFocusFunc = null; // GLFWwindowfocusfun
        this.windowIconifyFunc = null; // GLFWwindowiconifyfun
        this.framebufferSizeFunc = null; // GLFWframebuffersizefun
        this.mouseButtonFunc = null; // GLFWmousebuttonfun
        this.cursorPosFunc = null; // GLFWcursorposfun
        this.cursorEnterFunc = null; // GLFWcursorenterfun
        this.scrollFunc = null; // GLFWscrollfun
        this.dropFunc = null; // GLFWdropfun
        this.keyFunc = null; // GLFWkeyfun
        this.charFunc = null; // GLFWcharfun
        this.userptr = null;
      },WindowFromId:function (id) {
        if (id <= 0 || !GLFW.windows) return null;
        return GLFW.windows[id - 1];
      },joystickFunc:null,errorFunc:null,monitorFunc:null,active:null,windows:null,monitors:null,monitorString:null,versionString:null,initialTime:null,extensions:null,hints:null,defaultHints:{131073:0,131074:0,131075:1,131076:1,131077:1,135169:8,135170:8,135171:8,135172:8,135173:24,135174:8,135175:0,135176:0,135177:0,135178:0,135179:0,135180:0,135181:0,135182:0,135183:0,139265:196609,139266:1,139267:0,139268:0,139269:0,139270:0,139271:0,139272:0},DOMToGLFWKeyCode:function (keycode) {
        switch (keycode) {
          // these keycodes are only defined for GLFW3, assume they are the same for GLFW2
          case 0x20:return 32; // DOM_VK_SPACE -> GLFW_KEY_SPACE
          case 0xDE:return 39; // DOM_VK_QUOTE -> GLFW_KEY_APOSTROPHE
          case 0xBC:return 44; // DOM_VK_COMMA -> GLFW_KEY_COMMA
          case 0xAD:return 45; // DOM_VK_HYPHEN_MINUS -> GLFW_KEY_MINUS
          case 0xBD:return 45; // DOM_VK_MINUS -> GLFW_KEY_MINUS
          case 0xBE:return 46; // DOM_VK_PERIOD -> GLFW_KEY_PERIOD
          case 0xBF:return 47; // DOM_VK_SLASH -> GLFW_KEY_SLASH
          case 0x30:return 48; // DOM_VK_0 -> GLFW_KEY_0
          case 0x31:return 49; // DOM_VK_1 -> GLFW_KEY_1
          case 0x32:return 50; // DOM_VK_2 -> GLFW_KEY_2
          case 0x33:return 51; // DOM_VK_3 -> GLFW_KEY_3
          case 0x34:return 52; // DOM_VK_4 -> GLFW_KEY_4
          case 0x35:return 53; // DOM_VK_5 -> GLFW_KEY_5
          case 0x36:return 54; // DOM_VK_6 -> GLFW_KEY_6
          case 0x37:return 55; // DOM_VK_7 -> GLFW_KEY_7
          case 0x38:return 56; // DOM_VK_8 -> GLFW_KEY_8
          case 0x39:return 57; // DOM_VK_9 -> GLFW_KEY_9
          case 0x3B:return 59; // DOM_VK_SEMICOLON -> GLFW_KEY_SEMICOLON
          case 0x3D:return 61; // DOM_VK_EQUALS -> GLFW_KEY_EQUAL
          case 0xBB:return 61; // DOM_VK_EQUALS -> GLFW_KEY_EQUAL
          case 0x41:return 65; // DOM_VK_A -> GLFW_KEY_A
          case 0x42:return 66; // DOM_VK_B -> GLFW_KEY_B
          case 0x43:return 67; // DOM_VK_C -> GLFW_KEY_C
          case 0x44:return 68; // DOM_VK_D -> GLFW_KEY_D
          case 0x45:return 69; // DOM_VK_E -> GLFW_KEY_E
          case 0x46:return 70; // DOM_VK_F -> GLFW_KEY_F
          case 0x47:return 71; // DOM_VK_G -> GLFW_KEY_G
          case 0x48:return 72; // DOM_VK_H -> GLFW_KEY_H
          case 0x49:return 73; // DOM_VK_I -> GLFW_KEY_I
          case 0x4A:return 74; // DOM_VK_J -> GLFW_KEY_J
          case 0x4B:return 75; // DOM_VK_K -> GLFW_KEY_K
          case 0x4C:return 76; // DOM_VK_L -> GLFW_KEY_L
          case 0x4D:return 77; // DOM_VK_M -> GLFW_KEY_M
          case 0x4E:return 78; // DOM_VK_N -> GLFW_KEY_N
          case 0x4F:return 79; // DOM_VK_O -> GLFW_KEY_O
          case 0x50:return 80; // DOM_VK_P -> GLFW_KEY_P
          case 0x51:return 81; // DOM_VK_Q -> GLFW_KEY_Q
          case 0x52:return 82; // DOM_VK_R -> GLFW_KEY_R
          case 0x53:return 83; // DOM_VK_S -> GLFW_KEY_S
          case 0x54:return 84; // DOM_VK_T -> GLFW_KEY_T
          case 0x55:return 85; // DOM_VK_U -> GLFW_KEY_U
          case 0x56:return 86; // DOM_VK_V -> GLFW_KEY_V
          case 0x57:return 87; // DOM_VK_W -> GLFW_KEY_W
          case 0x58:return 88; // DOM_VK_X -> GLFW_KEY_X
          case 0x59:return 89; // DOM_VK_Y -> GLFW_KEY_Y
          case 0x5a:return 90; // DOM_VK_Z -> GLFW_KEY_Z
          case 0xDB:return 91; // DOM_VK_OPEN_BRACKET -> GLFW_KEY_LEFT_BRACKET
          case 0xDC:return 92; // DOM_VK_BACKSLASH -> GLFW_KEY_BACKSLASH
          case 0xDD:return 93; // DOM_VK_CLOSE_BRACKET -> GLFW_KEY_RIGHT_BRACKET
          case 0xC0:return 94; // DOM_VK_BACK_QUOTE -> GLFW_KEY_GRAVE_ACCENT
          
          //#define GLFW_KEY_SPECIAL      256
          case 0x1B:return (256+1); // DOM_VK_ESCAPE -> GLFW_KEY_ESC
          case 0x70:return (256+2); // DOM_VK_F1 -> GLFW_KEY_F1
          case 0x71:return (256+3); // DOM_VK_F2 -> GLFW_KEY_F2
          case 0x72:return (256+4); // DOM_VK_F3 -> GLFW_KEY_F3
          case 0x73:return (256+5); // DOM_VK_F4 -> GLFW_KEY_F4
          case 0x74:return (256+6); // DOM_VK_F5 -> GLFW_KEY_F5
          case 0x75:return (256+7); // DOM_VK_F6 -> GLFW_KEY_F6
          case 0x76:return (256+8); // DOM_VK_F7 -> GLFW_KEY_F7
          case 0x77:return (256+9); // DOM_VK_F8 -> GLFW_KEY_F8
          case 0x78:return (256+10); // DOM_VK_F9 -> GLFW_KEY_F9
          case 0x79:return (256+11); // DOM_VK_F10 -> GLFW_KEY_F10
          case 0x7A:return (256+12); // DOM_VK_F11 -> GLFW_KEY_F11
          case 0x7B:return (256+13); // DOM_VK_F12 -> GLFW_KEY_F12
          case 0x7C:return (256+14); // DOM_VK_F13 -> GLFW_KEY_F13
          case 0x7D:return (256+15); // DOM_VK_F14 -> GLFW_KEY_F14
          case 0x7E:return (256+16); // DOM_VK_F15 -> GLFW_KEY_F15
          case 0x7F:return (256+17); // DOM_VK_F16 -> GLFW_KEY_F16
          case 0x80:return (256+18); // DOM_VK_F17 -> GLFW_KEY_F17
          case 0x81:return (256+19); // DOM_VK_F18 -> GLFW_KEY_F18
          case 0x82:return (256+20); // DOM_VK_F19 -> GLFW_KEY_F19
          case 0x83:return (256+21); // DOM_VK_F20 -> GLFW_KEY_F20
          case 0x84:return (256+22); // DOM_VK_F21 -> GLFW_KEY_F21
          case 0x85:return (256+23); // DOM_VK_F22 -> GLFW_KEY_F22
          case 0x86:return (256+24); // DOM_VK_F23 -> GLFW_KEY_F23
          case 0x87:return (256+25); // DOM_VK_F24 -> GLFW_KEY_F24
          case 0x88:return (256+26); // 0x88 (not used?) -> GLFW_KEY_F25
          case 0x27:return (256+30); // DOM_VK_RIGHT -> GLFW_KEY_RIGHT
          case 0x25:return (256+29); // DOM_VK_LEFT -> GLFW_KEY_LEFT
          case 0x28:return (256+28); // DOM_VK_DOWN -> GLFW_KEY_DOWN
          case 0x26:return (256+27); // DOM_VK_UP -> GLFW_KEY_UP
          case 0x10:return (256+31); // DOM_VK_SHIFT -> GLFW_KEY_LSHIFT
          // #define GLFW_KEY_RSHIFT       (GLFW_KEY_SPECIAL+32)
          case 0x11:return (256+33); // DOM_VK_CONTROL -> GLFW_KEY_LCTRL
          // #define GLFW_KEY_RCTRL        (GLFW_KEY_SPECIAL+34)
          case 0x12:return (256+35); // DOM_VK_ALT -> GLFW_KEY_LALT
          // #define GLFW_KEY_RALT         (GLFW_KEY_SPECIAL+36)
          case 0x09:return (256+37); // DOM_VK_TAB -> GLFW_KEY_TAB
          case 0x0D:return (256+38); // DOM_VK_RETURN -> GLFW_KEY_ENTER
          case 0x08:return (256+39); // DOM_VK_BACK -> GLFW_KEY_BACKSPACE
          case 0x2D:return (256+40); // DOM_VK_INSERT -> GLFW_KEY_INSERT
          case 0x2E:return (256+41); // DOM_VK_DELETE -> GLFW_KEY_DEL
          case 0x21:return (256+42); // DOM_VK_PAGE_UP -> GLFW_KEY_PAGEUP
          case 0x22:return (256+43); // DOM_VK_PAGE_DOWN -> GLFW_KEY_PAGEDOWN
          case 0x24:return (256+44); // DOM_VK_HOME -> GLFW_KEY_HOME
          case 0x23:return (256+45); // DOM_VK_END -> GLFW_KEY_END
          case 0x60:return (256+46); // DOM_VK_NUMPAD0 -> GLFW_KEY_KP_0
          case 0x61:return (256+47); // DOM_VK_NUMPAD1 -> GLFW_KEY_KP_1
          case 0x62:return (256+48); // DOM_VK_NUMPAD2 -> GLFW_KEY_KP_2
          case 0x63:return (256+49); // DOM_VK_NUMPAD3 -> GLFW_KEY_KP_3
          case 0x64:return (256+50); // DOM_VK_NUMPAD4 -> GLFW_KEY_KP_4
          case 0x65:return (256+51); // DOM_VK_NUMPAD5 -> GLFW_KEY_KP_5
          case 0x66:return (256+52); // DOM_VK_NUMPAD6 -> GLFW_KEY_KP_6
          case 0x67:return (256+53); // DOM_VK_NUMPAD7 -> GLFW_KEY_KP_7
          case 0x68:return (256+54); // DOM_VK_NUMPAD8 -> GLFW_KEY_KP_8
          case 0x69:return (256+55); // DOM_VK_NUMPAD9 -> GLFW_KEY_KP_9
          case 0x6F:return (256+56); // DOM_VK_DIVIDE -> GLFW_KEY_KP_DIVIDE
          case 0x6A:return (256+57); // DOM_VK_MULTIPLY -> GLFW_KEY_KP_MULTIPLY
          case 0x6D:return (256+58); // DOM_VK_SUBTRACT -> GLFW_KEY_KP_SUBTRACT
          case 0x6B:return (256+59); // DOM_VK_ADD -> GLFW_KEY_KP_ADD
          case 0x6E:return (256+60); // DOM_VK_DECIMAL -> GLFW_KEY_KP_DECIMAL
          // #define GLFW_KEY_KP_EQUAL     (GLFW_KEY_SPECIAL+61)
          // #define GLFW_KEY_KP_ENTER     (GLFW_KEY_SPECIAL+62)
          case 0x90:return (256+63); // DOM_VK_NUM_LOCK -> GLFW_KEY_KP_NUM_LOCK
          case 0x14:return (256+64); // DOM_VK_CAPS_LOCK -> GLFW_KEY_CAPS_LOCK
          case 0x91:return (256+65); // DOM_VK_SCROLL_LOCK -> GLFW_KEY_SCROLL_LOCK
          case 0x13:return (256+66); // DOM_VK_PAUSE -> GLFW_KEY_PAUSE
          case 0x5B:return (256+67); // DOM_VK_WIN -> GLFW_KEY_LSUPER
          // #define GLFW_KEY_RSUPER       (GLFW_KEY_SPECIAL+68)
          case 0x5D:return (256+69); // DOM_VK_CONTEXT_MENU -> GLFW_KEY_MENU
  
          default:return -1; // GLFW_KEY_UNKNOWN
        };
      },getModBits:function (win) {
        var mod = 0;
        if (win.keys[340]) mod |= 0x0001; // GLFW_MOD_SHIFT
        if (win.keys[341]) mod |= 0x0002; // GLFW_MOD_CONTROL
        if (win.keys[342]) mod |= 0x0004; // GLFW_MOD_ALT
        if (win.keys[343]) mod |= 0x0008; // GLFW_MOD_SUPER
        return mod;
      },onKeyPress:function (event) {
        if (!GLFW.active || !GLFW.active.charFunc) return;
        if (event.ctrlKey || event.metaKey) return;
  
        // correct unicode charCode is only available with onKeyPress event
        var charCode = event.charCode;
        if (charCode == 0 || (charCode >= 0x00 && charCode <= 0x1F)) return;
  
        Module['dynCall_vii'](GLFW.active.charFunc, charCode, 1);
  
      },onKeyChanged:function (keyCode, status) {
        if (!GLFW.active) return;
  
        var key = GLFW.DOMToGLFWKeyCode(keyCode);
        if (key == -1) return;
  
        GLFW.active.keys[key] = status;
        GLFW.active.domKeys[keyCode] = status;
        if (!GLFW.active.keyFunc) return;
  
        Module['dynCall_vii'](GLFW.active.keyFunc, key, status);
  
      },onGamepadConnected:function (event) {
        GLFW.refreshJoysticks();
      },onGamepadDisconnected:function (event) {
        GLFW.refreshJoysticks();
      },onKeydown:function (event) {
        GLFW.onKeyChanged(event.keyCode, 1); // GLFW_PRESS or GLFW_REPEAT
  
        // This logic comes directly from the sdl implementation. We cannot
        // call preventDefault on all keydown events otherwise onKeyPress will
        // not get called
        if (event.keyCode === 8 /* backspace */ || event.keyCode === 9 /* tab */) {
          event.preventDefault();
        }
      },onKeyup:function (event) {
        GLFW.onKeyChanged(event.keyCode, 0); // GLFW_RELEASE
      },onBlur:function (event) {
        if (!GLFW.active) return;
  
        for (var i = 0; i < GLFW.active.domKeys.length; ++i) {
          if (GLFW.active.domKeys[i]) {
            GLFW.onKeyChanged(i, 0); // GLFW_RELEASE
          }
        }
      },onMousemove:function (event) {
        if (!GLFW.active) return;
  
        Browser.calculateMouseEvent(event);
  
        if (event.target != Module["canvas"] || !GLFW.active.cursorPosFunc) return;
  
        Module['dynCall_vii'](GLFW.active.cursorPosFunc, Browser.mouseX, Browser.mouseY);
  
      },DOMToGLFWMouseButton:function (event) {
        // DOM and glfw have different button codes.
        // See http://www.w3schools.com/jsref/event_button.asp.
        var eventButton = event['button'];
        if (eventButton > 0) {
          if (eventButton == 1) {
            eventButton = 2;
          } else {
            eventButton = 1;
          }
        }
        return eventButton;
      },onMouseenter:function (event) {
        if (!GLFW.active) return;
  
        if (event.target != Module["canvas"] || !GLFW.active.cursorEnterFunc) return;
  
      },onMouseleave:function (event) {
        if (!GLFW.active) return;
  
        if (event.target != Module["canvas"] || !GLFW.active.cursorEnterFunc) return;
  
      },onMouseButtonChanged:function (event, status) {
        if (!GLFW.active) return;
  
        Browser.calculateMouseEvent(event);
  
        if (event.target != Module["canvas"]) return;
  
        var eventButton = GLFW.DOMToGLFWMouseButton(event);
  
        if (status == 1) { // GLFW_PRESS
          GLFW.active.buttons |= (1 << eventButton);
          try {
            event.target.setCapture();
          } catch (e) {}
        } else {  // GLFW_RELEASE
          GLFW.active.buttons &= ~(1 << eventButton);
        }
  
        if (!GLFW.active.mouseButtonFunc) return;
  
        Module['dynCall_vii'](GLFW.active.mouseButtonFunc, eventButton, status);
  
      },onMouseButtonDown:function (event) {
        if (!GLFW.active) return;
        GLFW.onMouseButtonChanged(event, 1); // GLFW_PRESS
      },onMouseButtonUp:function (event) {
        if (!GLFW.active) return;
        GLFW.onMouseButtonChanged(event, 0); // GLFW_RELEASE
      },onMouseWheel:function (event) {
        // Note the minus sign that flips browser wheel direction (positive direction scrolls page down) to native wheel direction (positive direction is mouse wheel up)
        var delta = -Browser.getMouseWheelDelta(event);
        delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.
        GLFW.wheelPos += delta;
  
        if (!GLFW.active || !GLFW.active.scrollFunc || event.target != Module['canvas']) return;
  
        Module['dynCall_vi'](GLFW.active.scrollFunc, GLFW.wheelPos);
  
  
        event.preventDefault();
      },onCanvasResize:function (width, height) {
        if (!GLFW.active) return;
  
        var resizeNeeded = true;
  
        // If the client is requesting fullscreen mode
        if (document["fullscreen"] || document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
          GLFW.active.storedX = GLFW.active.x;
          GLFW.active.storedY = GLFW.active.y;
          GLFW.active.storedWidth = GLFW.active.width;
          GLFW.active.storedHeight = GLFW.active.height;
          GLFW.active.x = GLFW.active.y = 0;
          GLFW.active.width = screen.width;
          GLFW.active.height = screen.height;
          GLFW.active.fullscreen = true;
  
        // If the client is reverting from fullscreen mode
        } else if (GLFW.active.fullscreen == true) {
          GLFW.active.x = GLFW.active.storedX;
          GLFW.active.y = GLFW.active.storedY;
          GLFW.active.width = GLFW.active.storedWidth;
          GLFW.active.height = GLFW.active.storedHeight;
          GLFW.active.fullscreen = false;
  
        // If the width/height values do not match current active window sizes
        } else if (GLFW.active.width != width || GLFW.active.height != height) {
            GLFW.active.width = width;
            GLFW.active.height = height;
        } else {
          resizeNeeded = false;
        }
  
        // If any of the above conditions were true, we need to resize the canvas
        if (resizeNeeded) {
          // resets the canvas size to counter the aspect preservation of Browser.updateCanvasDimensions
          Browser.setCanvasSize(GLFW.active.width, GLFW.active.height, true);
          // TODO: Client dimensions (clientWidth/clientHeight) vs pixel dimensions (width/height) of
          // the canvas should drive window and framebuffer size respectfully.
          GLFW.onWindowSizeChanged();
          GLFW.onFramebufferSizeChanged();
        }
      },onWindowSizeChanged:function () {
        if (!GLFW.active) return;
  
        if (!GLFW.active.windowSizeFunc) return;
  
        Module['dynCall_vii'](GLFW.active.windowSizeFunc, GLFW.active.width, GLFW.active.height);
  
      },onFramebufferSizeChanged:function () {
        if (!GLFW.active) return;
  
        if (!GLFW.active.framebufferSizeFunc) return;
  
      },requestFullscreen:function () {
        var RFS = Module["canvas"]['requestFullscreen'] ||
                  Module["canvas"]['mozRequestFullScreen'] ||
                  Module["canvas"]['webkitRequestFullScreen'] ||
                  (function() {});
        RFS.apply(Module["canvas"], []);
      },requestFullScreen:function () {
        err('GLFW.requestFullScreen() is deprecated. Please call GLFW.requestFullscreen instead.');
        GLFW.requestFullScreen = function() {
          return GLFW.requestFullscreen();
        }
        return GLFW.requestFullscreen();
      },exitFullscreen:function () {
        var CFS = document['exitFullscreen'] ||
                  document['cancelFullScreen'] ||
                  document['mozCancelFullScreen'] ||
                  document['webkitCancelFullScreen'] ||
            (function() {});
        CFS.apply(document, []);
      },cancelFullScreen:function () {
        err('GLFW.cancelFullScreen() is deprecated. Please call GLFW.exitFullscreen instead.');
        GLFW.cancelFullScreen = function() {
          return GLFW.exitFullscreen();
        }
        return GLFW.exitFullscreen();
      },getTime:function () {
        return _emscripten_get_now() / 1000;
      },setWindowTitle:function (winid, title) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
  
        win.title = Pointer_stringify(title);
        if (GLFW.active.id == win.id) {
          document.title = win.title;
        }
      },setJoystickCallback:function (cbfun) {
        GLFW.joystickFunc = cbfun;
        GLFW.refreshJoysticks();
      },joys:{},lastGamepadState:null,lastGamepadStateFrame:null,refreshJoysticks:function () {
        // Produce a new Gamepad API sample if we are ticking a new game frame, or if not using emscripten_set_main_loop() at all to drive animation.
        if (Browser.mainLoop.currentFrameNumber !== GLFW.lastGamepadStateFrame || !Browser.mainLoop.currentFrameNumber) {
          GLFW.lastGamepadState = navigator.getGamepads ? navigator.getGamepads() : (navigator.webkitGetGamepads ? navigator.webkitGetGamepads : null);
          GLFW.lastGamepadStateFrame = Browser.mainLoop.currentFrameNumber;
  
          for (var joy = 0; joy < GLFW.lastGamepadState.length; ++joy) {
            var gamepad = GLFW.lastGamepadState[joy];
  
            if (gamepad) {
              if (!GLFW.joys[joy]) {
                console.log('glfw joystick connected:',joy);
                GLFW.joys[joy] = {
                  id: allocate(intArrayFromString(gamepad.id), 'i8', ALLOC_NORMAL),
                  buttonsCount: gamepad.buttons.length,
                  axesCount: gamepad.axes.length,
                  buttons: allocate(new Array(gamepad.buttons.length), 'i8', ALLOC_NORMAL),
                  axes: allocate(new Array(gamepad.axes.length*4), 'float', ALLOC_NORMAL)
                };
  
                if (GLFW.joystickFunc) {
                  Module['dynCall_vii'](GLFW.joystickFunc, joy, 0x00040001); // GLFW_CONNECTED
                }
              }
  
              var data = GLFW.joys[joy];
  
              for (var i = 0; i < gamepad.buttons.length;  ++i) {
                setValue(data.buttons + i, gamepad.buttons[i].pressed, 'i8');
              }
  
              for (var i = 0; i < gamepad.axes.length; ++i) {
                setValue(data.axes + i*4, gamepad.axes[i], 'float');
              }
            } else {
              if (GLFW.joys[joy]) {
                console.log('glfw joystick disconnected',joy);
  
                if (GLFW.joystickFunc) {
                  Module['dynCall_vii'](GLFW.joystickFunc, joy, 0x00040002); // GLFW_DISCONNECTED
                }
  
                _free(GLFW.joys[joy].id);
                _free(GLFW.joys[joy].buttons);
                _free(GLFW.joys[joy].axes);
  
                delete GLFW.joys[joy];
              }
            }
          }
        }
      },setKeyCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.keyFunc = cbfun;
      },setCharCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.charFunc = cbfun;
      },setMouseButtonCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.mouseButtonFunc = cbfun;
      },setCursorPosCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.cursorPosFunc = cbfun;
      },setScrollCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.scrollFunc = cbfun;
      },setDropCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.dropFunc = cbfun;
      },onDrop:function (event) {
        if (!GLFW.active || !GLFW.active.dropFunc) return;
        if (!event.dataTransfer || !event.dataTransfer.files || event.dataTransfer.files.length == 0) return;
  
        event.preventDefault();
  
        var filenames = allocate(new Array(event.dataTransfer.files.length*4), 'i8*', ALLOC_NORMAL);
        var filenamesArray = [];
        var count = event.dataTransfer.files.length;
  
        // Read and save the files to emscripten's FS
        var written = 0;
        var drop_dir = '.glfw_dropped_files';
        FS.createPath('/', drop_dir);
  
        function save(file) {
          var path = '/' + drop_dir + '/' + file.name.replace(/\//g, '_');
          var reader = new FileReader();
          reader.onloadend = function(e) {
            if (reader.readyState != 2) { // not DONE
              ++written;
              console.log('failed to read dropped file: '+file.name+': '+reader.error);
              return;
            }
  
            var data = e.target.result;
            FS.writeFile(path, new Uint8Array(data));
            if (++written === count) {
              Module['dynCall_viii'](GLFW.active.dropFunc, GLFW.active.id, count, filenames);
  
              for (var i = 0; i < filenamesArray.length; ++i) {
                _free(filenamesArray[i]);
              }
              _free(filenames);
            }
          };
          reader.readAsArrayBuffer(file);
  
          var filename = allocate(intArrayFromString(path), 'i8', ALLOC_NORMAL);
          filenamesArray.push(filename);
          setValue(filenames + i*4, filename, 'i8*');
        }
  
        for (var i = 0; i < count; ++i) {
          save(event.dataTransfer.files[i]);
        }
  
        return false;
      },onDragover:function (event) {
        if (!GLFW.active || !GLFW.active.dropFunc) return;
  
        event.preventDefault();
        return false;
      },setWindowSizeCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.windowSizeFunc = cbfun;
       
        // As documented in GLFW2 API (http://www.glfw.org/GLFWReference27.pdf#page=22), when size
        // callback function is set, it will be called with the current window size before this
        // function returns.
        // GLFW3 on the over hand doesn't have this behavior (https://github.com/glfw/glfw/issues/62).
        if (!win.windowSizeFunc) return;
        Module['dynCall_vii'](win.windowSizeFunc, win.width, win.height);
      },setWindowCloseCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.windowCloseFunc = cbfun;
      },setWindowRefreshCallback:function (winid, cbfun) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.windowRefreshFunc = cbfun;
      },onClickRequestPointerLock:function (e) {
        if (!Browser.pointerLock && Module['canvas'].requestPointerLock) {
          Module['canvas'].requestPointerLock();
          e.preventDefault();
        }
      },setInputMode:function (winid, mode, value) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
  
        switch(mode) {
          case 0x00033001: { // GLFW_CURSOR
            switch(value) {
              case 0x00034001: { // GLFW_CURSOR_NORMAL
                win.inputModes[mode] = value;
                Module['canvas'].removeEventListener('click', GLFW.onClickRequestPointerLock, true);
                Module['canvas'].exitPointerLock();
                break;
              }
              case 0x00034002: { // GLFW_CURSOR_HIDDEN
                console.log("glfwSetInputMode called with GLFW_CURSOR_HIDDEN value not implemented.");
                break;
              }
              case 0x00034003: { // GLFW_CURSOR_DISABLED
                win.inputModes[mode] = value;
                Module['canvas'].addEventListener('click', GLFW.onClickRequestPointerLock, true);
                Module['canvas'].requestPointerLock();
                break;
              }
              default: {
                console.log("glfwSetInputMode called with unknown value parameter value: " + value + ".");
                break;
              }
            }
            break;
          }
          case 0x00033002: { // GLFW_STICKY_KEYS
            console.log("glfwSetInputMode called with GLFW_STICKY_KEYS mode not implemented.");
            break;
          }
          case 0x00033003: { // GLFW_STICKY_MOUSE_BUTTONS
            console.log("glfwSetInputMode called with GLFW_STICKY_MOUSE_BUTTONS mode not implemented.");
            break;
          }
          default: {
            console.log("glfwSetInputMode called with unknown mode parameter value: " + mode + ".");
            break;
          }
        }
      },getKey:function (winid, key) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return 0;
        return win.keys[key];
      },getMouseButton:function (winid, button) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return 0;
        return (win.buttons & (1 << button)) > 0;
      },getCursorPos:function (winid, x, y) {
        setValue(x, Browser.mouseX, 'double');
        setValue(y, Browser.mouseY, 'double');
      },getMousePos:function (winid, x, y) {
        setValue(x, Browser.mouseX, 'i32');
        setValue(y, Browser.mouseY, 'i32');
      },setCursorPos:function (winid, x, y) {
      },getWindowPos:function (winid, x, y) {
        var wx = 0;
        var wy = 0;
  
        var win = GLFW.WindowFromId(winid);
        if (win) {
          wx = win.x;
          wy = win.y;
        }
  
        setValue(x, wx, 'i32');
        setValue(y, wy, 'i32');
      },setWindowPos:function (winid, x, y) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
        win.x = x;
        win.y = y;
      },getWindowSize:function (winid, width, height) {
        var ww = 0;
        var wh = 0;
  
        var win = GLFW.WindowFromId(winid);
        if (win) {
          ww = win.width;
          wh = win.height;
        }
  
        setValue(width, ww, 'i32');
        setValue(height, wh, 'i32');
      },setWindowSize:function (winid, width, height) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
  
        if (GLFW.active.id == win.id) {
          if (width == screen.width && height == screen.height) {
            GLFW.requestFullscreen();
          } else {
            GLFW.exitFullscreen();
            Browser.setCanvasSize(width, height);
            win.width = width;
            win.height = height;
          }
        }
  
        if (!win.windowSizeFunc) return;
  
        Module['dynCall_vii'](win.windowSizeFunc, width, height);
  
      },createWindow:function (width, height, title, monitor, share) {
        var i, id;
        for (i = 0; i < GLFW.windows.length && GLFW.windows[i] !== null; i++);
        if (i > 0) throw "glfwCreateWindow only supports one window at time currently";
  
        // id for window
        id = i + 1;
  
        // not valid
        if (width <= 0 || height <= 0) return 0;
  
        if (monitor) {
          GLFW.requestFullscreen();
        } else {
          Browser.setCanvasSize(width, height);
        }
  
        // Create context when there are no existing alive windows
        for (i = 0; i < GLFW.windows.length && GLFW.windows[i] == null; i++);
        if (i == GLFW.windows.length) {
          var contextAttributes = {
            antialias: (GLFW.hints[0x0002100D] > 1), // GLFW_SAMPLES
            depth: (GLFW.hints[0x00021005] > 0),     // GLFW_DEPTH_BITS
            stencil: (GLFW.hints[0x00021006] > 0),   // GLFW_STENCIL_BITS
            alpha: (GLFW.hints[0x00021004] > 0)      // GLFW_ALPHA_BITS 
          }
          Module.ctx = Browser.createContext(Module['canvas'], true, true, contextAttributes);
        }
  
        // If context creation failed, do not return a valid window
        if (!Module.ctx) return 0;
  
        // Get non alive id
        var win = new GLFW.Window(id, width, height, title, monitor, share);
  
        // Set window to array
        if (id - 1 == GLFW.windows.length) {
          GLFW.windows.push(win);
        } else {
          GLFW.windows[id - 1] = win;
        }
  
        GLFW.active = win;
        return win.id;
      },destroyWindow:function (winid) {
        var win = GLFW.WindowFromId(winid);
        if (!win) return;
  
  
        GLFW.windows[win.id - 1] = null;
        if (GLFW.active.id == win.id)
          GLFW.active = null;
  
        // Destroy context when no alive windows
        for (var i = 0; i < GLFW.windows.length; i++)
          if (GLFW.windows[i] !== null) return;
  
        Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      },swapBuffers:function (winid) {
      },GLFW2ParamToGLFW3Param:function (param) {
        var table = {
          0x00030001:0, // GLFW_MOUSE_CURSOR
          0x00030002:0, // GLFW_STICKY_KEYS
          0x00030003:0, // GLFW_STICKY_MOUSE_BUTTONS
          0x00030004:0, // GLFW_SYSTEM_KEYS
          0x00030005:0, // GLFW_KEY_REPEAT
          0x00030006:0, // GLFW_AUTO_POLL_EVENTS
          0x00020001:0, // GLFW_OPENED
          0x00020002:0, // GLFW_ACTIVE
          0x00020003:0, // GLFW_ICONIFIED
          0x00020004:0, // GLFW_ACCELERATED
          0x00020005:0x00021001, // GLFW_RED_BITS
          0x00020006:0x00021002, // GLFW_GREEN_BITS
          0x00020007:0x00021003, // GLFW_BLUE_BITS
          0x00020008:0x00021004, // GLFW_ALPHA_BITS
          0x00020009:0x00021005, // GLFW_DEPTH_BITS
          0x0002000A:0x00021006, // GLFW_STENCIL_BITS
          0x0002000B:0x0002100F, // GLFW_REFRESH_RATE
          0x0002000C:0x00021007, // GLFW_ACCUM_RED_BITS
          0x0002000D:0x00021008, // GLFW_ACCUM_GREEN_BITS
          0x0002000E:0x00021009, // GLFW_ACCUM_BLUE_BITS
          0x0002000F:0x0002100A, // GLFW_ACCUM_ALPHA_BITS
          0x00020010:0x0002100B, // GLFW_AUX_BUFFERS
          0x00020011:0x0002100C, // GLFW_STEREO
          0x00020012:0, // GLFW_WINDOW_NO_RESIZE
          0x00020013:0x0002100D, // GLFW_FSAA_SAMPLES
          0x00020014:0x00022002, // GLFW_OPENGL_VERSION_MAJOR
          0x00020015:0x00022003, // GLFW_OPENGL_VERSION_MINOR
          0x00020016:0x00022006, // GLFW_OPENGL_FORWARD_COMPAT
          0x00020017:0x00022007, // GLFW_OPENGL_DEBUG_CONTEXT
          0x00020018:0x00022008, // GLFW_OPENGL_PROFILE
        };
        return table[param];
      }};

  function _glfwInit() {
      if (GLFW.windows) return 1; // GL_TRUE
  
      GLFW.initialTime = GLFW.getTime();
      GLFW.hints = GLFW.defaultHints;
      GLFW.windows = new Array()
      GLFW.active = null;
  
      window.addEventListener("gamepadconnected", GLFW.onGamepadConnected, true);
      window.addEventListener("gamepaddisconnected", GLFW.onGamepadDisconnected, true);
      window.addEventListener("keydown", GLFW.onKeydown, true);
      window.addEventListener("keypress", GLFW.onKeyPress, true);
      window.addEventListener("keyup", GLFW.onKeyup, true);
      window.addEventListener("blur", GLFW.onBlur, true);
      Module["canvas"].addEventListener("mousemove", GLFW.onMousemove, true);
      Module["canvas"].addEventListener("mousedown", GLFW.onMouseButtonDown, true);
      Module["canvas"].addEventListener("mouseup", GLFW.onMouseButtonUp, true);
      Module["canvas"].addEventListener('wheel', GLFW.onMouseWheel, true);
      Module["canvas"].addEventListener('mousewheel', GLFW.onMouseWheel, true);
      Module["canvas"].addEventListener('mouseenter', GLFW.onMouseenter, true);
      Module["canvas"].addEventListener('mouseleave', GLFW.onMouseleave, true);
      Module["canvas"].addEventListener('drop', GLFW.onDrop, true);
      Module["canvas"].addEventListener('dragover', GLFW.onDragover, true);
  
      Browser.resizeListeners.push(function(width, height) {
         GLFW.onCanvasResize(width, height);
      });
      return 1; // GL_TRUE
    }

  function _glfwTerminate() {
      window.removeEventListener("gamepadconnected", GLFW.onGamepadConnected, true);
      window.removeEventListener("gamepaddisconnected", GLFW.onGamepadDisconnected, true);
      window.removeEventListener("keydown", GLFW.onKeydown, true);
      window.removeEventListener("keypress", GLFW.onKeyPress, true);
      window.removeEventListener("keyup", GLFW.onKeyup, true);
      window.removeEventListener("blur", GLFW.onBlur, true);
      Module["canvas"].removeEventListener("mousemove", GLFW.onMousemove, true);
      Module["canvas"].removeEventListener("mousedown", GLFW.onMouseButtonDown, true);
      Module["canvas"].removeEventListener("mouseup", GLFW.onMouseButtonUp, true);
      Module["canvas"].removeEventListener('wheel', GLFW.onMouseWheel, true);
      Module["canvas"].removeEventListener('mousewheel', GLFW.onMouseWheel, true);
      Module["canvas"].removeEventListener('mouseenter', GLFW.onMouseenter, true);
      Module["canvas"].removeEventListener('mouseleave', GLFW.onMouseleave, true);
      Module["canvas"].removeEventListener('drop', GLFW.onDrop, true);
      Module["canvas"].removeEventListener('dragover', GLFW.onDragover, true);
  
  
      Module["canvas"].width = Module["canvas"].height = 1;
      GLFW.windows = null;
      GLFW.active = null;
    }

  function _glfwGetVersion(major, minor, rev) {
      setValue(major, 2, 'i32');
      setValue(minor, 7, 'i32');
      setValue(rev, 7, 'i32');
  
    }

  function _glfwPollEvents() {}

  function _glfwWaitEvents() {}

  function _glfwGetTime() {
      return GLFW.getTime() - GLFW.initialTime;
    }

  function _glfwSetTime(time) {
      GLFW.initialTime = GLFW.getTime() - time;
    }

  function _glfwExtensionSupported(extension) {
      if (!GLFW.extensions) {
        GLFW.extensions = Pointer_stringify(_glGetString(0x1F03)).split(' ');
      }
  
      if (GLFW.extensions.indexOf(extension) != -1) return 1;
  
      // extensions from GLEmulations do not come unprefixed
      // so, try with prefix
      return (GLFW.extensions.indexOf("GL_" + extension) != -1);
    }

  function _glfwGetProcAddress(procname) {
      return _emscripten_GetProcAddress(procname);
    }

  function _glfwSwapInterval(interval) {
      interval = Math.abs(interval); // GLFW uses negative values to enable GLX_EXT_swap_control_tear, which we don't have, so just treat negative and positive the same.
      if (interval == 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 0);
      else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, interval);
    }

  function _glfwOpenWindow(width, height, redbits, greenbits, bluebits, alphabits, depthbits, stencilbits, mode) {
      GLFW.hints[0x00021001] = redbits;     // GLFW_RED_BITS
      GLFW.hints[0x00021002] = greenbits;   // GLFW_GREEN_BITS
      GLFW.hints[0x00021003] = bluebits;    // GLFW_BLUE_BITS
      GLFW.hints[0x00021004] = alphabits;   // GLFW_ALPHA_BITS
      GLFW.hints[0x00021005] = depthbits;   // GLFW_DEPTH_BITS
      GLFW.hints[0x00021006] = stencilbits; // GLFW_STENCIL_BITS
      GLFW.createWindow(width, height, "GLFW2 Window", 0, 0);
      return 1; // GL_TRUE
    }

  function _glfwCloseWindow() {
      GLFW.destroyWindow(GLFW.active.id);
    }

  function _glfwOpenWindowHint(target, hint) {
      target = GLFW.GLFW2ParamToGLFW3Param(target);
      GLFW.hints[target] = hint;
    }

  function _glfwGetWindowSize(width, height) {
      GLFW.getWindowSize(GLFW.active.id, width, height);
    }

  function _glfwSetWindowSize(width, height) {
      GLFW.setWindowSize(GLFW.active.id, width, height);
    }

  function _glfwGetWindowPos(x, y) {
      GLFW.getWindowPos(GLFW.active.id, x, y);
    }

  function _glfwSetWindowPos(x, y) {
      GLFW.setWindowPos(GLFW.active.id, x, y);
    }

  function _glfwSetWindowTitle(title) {
      GLFW.setWindowTitle(GLFW.active.id, title);
    }

  function _glfwIconifyWindow() {
      GLFW.iconifyWindow(GLFW.active.id);
    }

  function _glfwRestoreWindow() {
      GLFW.restoreWindow(GLFW.active.id);
    }

  function _glfwSwapBuffers() {
      GLFW.swapBuffers(GLFW.active.id);
    }

  function _glfwGetWindowParam(param) {
      param = GLFW.GLFW2ParamToGLFW3Param(param);
      return GLFW.hints[param];
    }

  function _glfwSetWindowSizeCallback(cbfun) {
      GLFW.setWindowSizeCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetWindowCloseCallback(cbfun) {
      GLFW.setWindowCloseCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetWindowRefreshCallback(cbfun) {
      GLFW.setWindowRefreshCallback(GLFW.active.id, cbfun);
    }

  function _glfwGetKey(key) {
      return GLFW.getKey(GLFW.active.id, key);
    }

  function _glfwGetMouseButton(button) {
      return GLFW.getMouseButton(GLFW.active.id, button);
    }

  function _glfwGetMousePos(x, y) {
      GLFW.getMousePos(GLFW.active.id, x, y);
    }

  function _glfwSetMousePos(x, y) {
      GLFW.setCursorPos(GLFW.active.id, x, y);
    }

  function _glfwGetMouseWheel() {
      return 0;
    }

  function _glfwSetMouseWheel(pos) {
    }

  function _glfwSetKeyCallback(cbfun) {
      GLFW.setKeyCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetCharCallback(cbfun) {
      GLFW.setCharCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetMouseButtonCallback(cbfun) {
      GLFW.setMouseButtonCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetMousePosCallback(cbfun) {
      GLFW.setCursorPosCallback(GLFW.active.id, cbfun);
    }

  function _glfwSetMouseWheelCallback(cbfun) {
      GLFW.setScrollCallback(GLFW.active.id, cbfun);
    }

  function _glfwGetDesktopMode(mode) {
      throw "glfwGetDesktopMode is not implemented.";
    }

  function _glfwSleep(time) {
      _sleep(time);
    }

  function _glfwEnable(target) {
      target = GLFW.GLFW2ParamToGLFW3Param(target);
      GLFW.hints[target] = false;
    }

  function _glfwDisable(target) {
      target = GLFW.GLFW2ParamToGLFW3Param(target);
      GLFW.hints[target] = true;
    }

  function _glfwGetGLVersion(major, minor, rev) {
      setValue(major, 0, 'i32');
      setValue(minor, 0, 'i32');
      setValue(rev, 1, 'i32');
    }

  function _glfwCreateThread(fun, arg) {
      var str = 'v';
      for (var i in arg) {
        str += 'i';
      }
      dynCall(str, fun, arg);
      // One single thread
      return 0;
    }

  function _glfwDestroyThread(ID) {}

  function _glfwWaitThread(ID, waitmode) {}

  function _glfwGetThreadID() {
      // One single thread
      return 0;
    }

  function _glfwCreateMutex() { throw "glfwCreateMutex is not implemented."; }

  function _glfwDestroyMutex(mutex) { throw "glfwDestroyMutex is not implemented."; }

  function _glfwLockMutex(mutex) { throw "glfwLockMutex is not implemented."; }

  function _glfwUnlockMutex(mutex) { throw "glfwUnlockMutex is not implemented."; }

  function _glfwCreateCond() { throw "glfwCreateCond is not implemented."; }

  function _glfwDestroyCond(cond) { throw "glfwDestroyCond is not implemented."; }

  function _glfwWaitCond(cond, mutex, timeout) { throw "glfwWaitCond is not implemented."; }

  function _glfwSignalCond(cond) { throw "glfwSignalCond is not implemented."; }

  function _glfwBroadcastCond(cond) { throw "glfwBroadcastCond is not implemented."; }

  function _glfwGetNumberOfProcessors() {
      // Threads are disabled anyway…
      return 1;
    }

  function _glfwReadImage(name, img, flags) { throw "glfwReadImage is not implemented."; }

  function _glfwReadMemoryImage(data, size, img, flags) { throw "glfwReadMemoryImage is not implemented."; }

  function _glfwFreeImage(img) { throw "glfwFreeImage is not implemented."; }

  function _glfwLoadTexture2D(name, flags) { throw "glfwLoadTexture2D is not implemented."; }

  function _glfwLoadMemoryTexture2D(data, size, flags) { throw "glfwLoadMemoryTexture2D is not implemented."; }

  function _glfwLoadTextureImage2D(img, flags) { throw "glfwLoadTextureImage2D is not implemented."; }

  function _uuid_clear(uu) {
      // void uuid_clear(uuid_t uu);
      _memset(uu, 0, 16);
    }

  function _uuid_compare(uu1, uu2) {
      // int uuid_compare(const uuid_t uu1, const uuid_t uu2);
      return _memcmp(uu1, uu2, 16);
    }

  function _uuid_copy(dst, src) {
      // void uuid_copy(uuid_t dst, const uuid_t src);
      _memcpy(dst, src, 16);
    }

  function _uuid_generate(out) {
      // void uuid_generate(uuid_t out);
      var uuid = null;
  
      if (ENVIRONMENT_IS_NODE) {
        // If Node.js try to use crypto.randomBytes
        try {
          var rb = require('crypto')['randomBytes'];
          uuid = rb(16);
        } catch(e) {}
      } else if (ENVIRONMENT_IS_WEB &&
                 typeof(window.crypto) !== 'undefined' &&
                 typeof(window.crypto.getRandomValues) !== 'undefined') {
        // If crypto.getRandomValues is available try to use it.
        uuid = new Uint8Array(16);
        window.crypto.getRandomValues(uuid);
      }
  
      // Fall back to Math.random if a higher quality random number generator is not available.
      if (!uuid) {
        uuid = new Array(16);
        var d = new Date().getTime();
        for (var i = 0; i < 16; i++) {
          var r = ((d + Math.random() * 256) % 256)|0;
          d = (d / 256)|0;
          uuid[i] = r;
        }
      }
  
      uuid[6] = (uuid[6] & 0x0F) | 0x40;
      uuid[8] = (uuid[8] & 0x7F) | 0x80;
      writeArrayToMemory(uuid, out);
    }

  function _uuid_is_null(uu) {
      // int uuid_is_null(const uuid_t uu);
      for (var i = 0; i < 4; i++, uu = (uu+4)|0) {
        var val = HEAP32[((uu)>>2)];
        if (val) {
          return 0;
        }
      }
      return 1;
    }

  function _uuid_parse(inp, uu) {
      // int uuid_parse(const char *in, uuid_t uu);
      var inp = Pointer_stringify(inp);
      if (inp.length === 36) {
        var i = 0;
        var uuid = new Array(16);
        inp.toLowerCase().replace(/[0-9a-f]{2}/g, function(byte) {
          if (i < 16) {
            uuid[i++] = parseInt(byte, 16);
          }
        });
  
        if (i < 16) {
          return -1;
        } else {
          writeArrayToMemory(uuid, uu);
          return 0;
        }
      } else {
        return -1;
      }
    }

  function _uuid_unparse(uu, out, upper) {
      // void uuid_unparse(const uuid_t uu, char *out);
      var i = 0;
      var uuid = 'xxxx-xx-xx-xx-xxxxxx'.replace(/[x]/g, function(c) {
        var r = upper ? (HEAPU8[(((uu)+(i))>>0)]).toString(16).toUpperCase() :
                        (HEAPU8[(((uu)+(i))>>0)]).toString(16);
        r = (r.length === 1) ? '0' + r : r; // Zero pad single digit hex values
        i++;
        return r;
      });
      stringToUTF8(uuid, out, 37); // Always fixed 36 bytes of ASCII characters and a trailing \0.
    }

  function _uuid_unparse_lower(uu, out) {
      // void uuid_unparse_lower(const uuid_t uu, char *out);
      _uuid_unparse(uu, out);
    }

  function _uuid_unparse_upper(uu, out) {
      // void uuid_unparse_upper(const uuid_t uu, char *out);
      _uuid_unparse(uu, out, true);
    }

  function _uuid_type(uu) {
      // int uuid_type(const uuid_t uu);
      return 4;
    }

  function _uuid_variant(uu) {
      // int uuid_variant(const uuid_t uu);
      return 1;
    }

  var GLEW={isLinaroFork:1,extensions:null,error:{0:null,1:null,2:null,3:null,4:null,5:null,6:null,7:null,8:null},version:{1:null,2:null,3:null,4:null},errorStringConstantFromCode:function (error) {
        if (GLEW.isLinaroFork) {
          switch (error) {
            case 4:return "OpenGL ES lib expected, found OpenGL lib"; // GLEW_ERROR_NOT_GLES_VERSION
            case 5:return "OpenGL lib expected, found OpenGL ES lib"; // GLEW_ERROR_GLES_VERSION
            case 6:return "Missing EGL version"; // GLEW_ERROR_NO_EGL_VERSION
            case 7:return "EGL 1.1 and up are supported"; // GLEW_ERROR_EGL_VERSION_10_ONLY
            default:break;
          }
        }
  
        switch (error) {
          case 0:return "No error"; // GLEW_OK || GLEW_NO_ERROR
          case 1:return "Missing GL version"; // GLEW_ERROR_NO_GL_VERSION
          case 2:return "GL 1.1 and up are supported"; // GLEW_ERROR_GL_VERSION_10_ONLY
          case 3:return "GLX 1.2 and up are supported"; // GLEW_ERROR_GLX_VERSION_11_ONLY
          default:return null;
        }
      },errorString:function (error) {
        if (!GLEW.error[error]) {
          var string = GLEW.errorStringConstantFromCode(error);
          if (!string) {
            string = "Unknown error";
            error = 8; // prevent array from growing more than this
          }
          GLEW.error[error] = allocate(intArrayFromString(string), 'i8', ALLOC_NORMAL);
        }
        return GLEW.error[error];
      },versionStringConstantFromCode:function (name) {
        switch (name) {
          case 1:return "1.10.0"; // GLEW_VERSION
          case 2:return "1"; // GLEW_VERSION_MAJOR
          case 3:return "10"; // GLEW_VERSION_MINOR
          case 4:return "0"; // GLEW_VERSION_MICRO
          default:return null;
        }
      },versionString:function (name) {
        if (!GLEW.version[name]) {
          var string = GLEW.versionStringConstantFromCode(name);
          if (!string)
            return 0;
          GLEW.version[name] = allocate(intArrayFromString(string), 'i8', ALLOC_NORMAL);
        }
        return GLEW.version[name];
      },extensionIsSupported:function (name) {
        if (!GLEW.extensions) {
          GLEW.extensions = Pointer_stringify(_glGetString(0x1F03)).split(' ');
        }
  
        if (GLEW.extensions.indexOf(name) != -1)
          return 1;
  
        // extensions from GLEmulations do not come unprefixed
        // so, try with prefix
        return (GLEW.extensions.indexOf("GL_" + name) != -1);
      }};

  function _glewInit() { return 0; }

  function _glewIsSupported(name) {
      var exts = Pointer_stringify(name).split(' ');
      for (var i in exts) {
        if (!GLEW.extensionIsSupported(exts[i]))
          return 0;
      }
      return 1;
    }

  function _glewGetExtension(name) {
      return GLEW.extensionIsSupported(Pointer_stringify(name));
    }

  function _glewGetErrorString(error) {
      return GLEW.errorString(error);
    }

  function _glewGetString(name) {
      return GLEW.versionString(name);
    }

  var IDBStore={indexedDB:function () {
      if (typeof indexedDB !== 'undefined') return indexedDB;
      var ret = null;
      if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      assert(ret, 'IDBStore used, but indexedDB not supported');
      return ret;
    },DB_VERSION:22,DB_STORE_NAME:"FILE_DATA",dbs:{},blobs:[0],getDB:function (name, callback) {
      // check the cache first
      var db = IDBStore.dbs[name];
      if (db) {
        return callback(null, db);
      }
      var req;
      try {
        req = IDBStore.indexedDB().open(name, IDBStore.DB_VERSION);
      } catch (e) {
        return callback(e);
      }
      req.onupgradeneeded = function(e) {
        var db = e.target.result;
        var transaction = e.target.transaction;
        var fileStore;
        if (db.objectStoreNames.contains(IDBStore.DB_STORE_NAME)) {
          fileStore = transaction.objectStore(IDBStore.DB_STORE_NAME);
        } else {
          fileStore = db.createObjectStore(IDBStore.DB_STORE_NAME);
        }
      };
      req.onsuccess = function() {
        db = req.result;
        // add to the cache
        IDBStore.dbs[name] = db;
        callback(null, db);
      };
      req.onerror = function(e) {
        callback(this.error);
        e.preventDefault();
      };
    },getStore:function (dbName, type, callback) {
      IDBStore.getDB(dbName, function(error, db) {
        if (error) return callback(error);
        var transaction = db.transaction([IDBStore.DB_STORE_NAME], type);
        transaction.onerror = function(e) {
          callback(this.error || 'unknown error');
          e.preventDefault();
        };
        var store = transaction.objectStore(IDBStore.DB_STORE_NAME);
        callback(null, store);
      });
    },getFile:function (dbName, id, callback) {
      IDBStore.getStore(dbName, 'readonly', function(err, store) {
        if (err) return callback(err);
        var req = store.get(id);
        req.onsuccess = function(event) {
          var result = event.target.result;
          if (!result) {
            return callback('file ' + id + ' not found');
          } else {
            return callback(null, result);
          }
        };
        req.onerror = function(error) {
          callback(error);
        };
      });
    },setFile:function (dbName, id, data, callback) {
      IDBStore.getStore(dbName, 'readwrite', function(err, store) {
        if (err) return callback(err);
        var req = store.put(data, id);
        req.onsuccess = function(event) {
          callback();
        };
        req.onerror = function(error) {
          callback(error);
        };
      });
    },deleteFile:function (dbName, id, callback) {
      IDBStore.getStore(dbName, 'readwrite', function(err, store) {
        if (err) return callback(err);
        var req = store.delete(id);
        req.onsuccess = function(event) {
          callback();
        };
        req.onerror = function(error) {
          callback(error);
        };
      });
    },existsFile:function (dbName, id, callback) {
      IDBStore.getStore(dbName, 'readonly', function(err, store) {
        if (err) return callback(err);
        var req = store.count(id);
        req.onsuccess = function(event) {
          callback(null, event.target.result > 0);
        };
        req.onerror = function(error) {
          callback(error);
        };
      });
    }};

  function _emscripten_idb_async_load(db, id, arg, onload, onerror) {
      IDBStore.getFile(Pointer_stringify(db), Pointer_stringify(id), function(error, byteArray) {
        if (error) {
          if (onerror) Module['dynCall_vi'](onerror, arg);
          return;
        }
        var buffer = _malloc(byteArray.length);
        HEAPU8.set(byteArray, buffer);
        Module['dynCall_viii'](onload, arg, buffer, byteArray.length);
        _free(buffer);
      });
    }

  function _emscripten_idb_async_store(db, id, ptr, num, arg, onstore, onerror) {
      // note that we copy the data here, as these are async operatins - changes to HEAPU8 meanwhile should not affect us!
      IDBStore.setFile(Pointer_stringify(db), Pointer_stringify(id), new Uint8Array(HEAPU8.subarray(ptr, ptr+num)), function(error) {
        if (error) {
          if (onerror) Module['dynCall_vi'](onerror, arg);
          return;
        }
        if (onstore) Module['dynCall_vi'](onstore, arg);
      });
    }

  function _emscripten_idb_async_delete(db, id, arg, ondelete, onerror) {
      IDBStore.deleteFile(Pointer_stringify(db), Pointer_stringify(id), function(error) {
        if (error) {
          if (onerror) Module['dynCall_vi'](onerror, arg);
          return;
        }
        if (ondelete) Module['dynCall_vi'](ondelete, arg);
      });
    }

  function _emscripten_idb_async_exists(db, id, arg, oncheck, onerror) {
      IDBStore.existsFile(Pointer_stringify(db), Pointer_stringify(id), function(error, exists) {
        if (error) {
          if (onerror) Module['dynCall_vi'](onerror, arg);
          return;
        }
        if (oncheck) Module['dynCall_vii'](oncheck, arg, exists);
      });
    }

  function _emscripten_idb_load() {
      throw 'Please compile your program with async support in order to use synchronous operations like emscripten_idb_load, etc.';
    }

  function _emscripten_idb_store() {
      throw 'Please compile your program with async support in order to use synchronous operations like emscripten_idb_store, etc.';
    }

  function _emscripten_idb_delete() {
      throw 'Please compile your program with async support in order to use synchronous operations like emscripten_idb_delete, etc.';
    }

  function _emscripten_idb_exists() {
      throw 'Please compile your program with async support in order to use synchronous operations like emscripten_idb_exists, etc.';
    }

  function _emscripten_sleep() {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_sleep';
    }

  function _emscripten_coroutine_create() {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_coroutine_create';
    }

  function _emscripten_coroutine_next() {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_coroutine_next';
    }

  function _emscripten_yield() {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_yield';
    }

  function _emscripten_wget(url, file) {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_wget';
    }

  function _emscripten_wget_data(url, file) {
      throw 'Please compile your program with async support in order to use asynchronous operations like emscripten_wget_data';
    }

  var WebVR={EYE_LEFT:0,EYE_RIGHT:1,POSE_POSITION:1,POSE_LINEAR_VELOCITY:2,POSE_LINEAR_ACCELERATION:4,POSE_ORIENTATION:8,POSE_ANGULAR_VELOCITY:16,POSE_ANGULAR_ACCELERATION:32,initialized:false,ready:false,version:[-1,-1],displays:[],displayNames:[],init:function (callback) {
        if (WebVR.initialized) return;
  
        WebVR.initialized = true;
  
        if (!navigator.getVRDisplays) {
          /* WebVR 1.1 required, but not supported. */
          WebVR.ready = true;
          WebVR.displays = [];
          return 0;
        }
  
        WebVR.version = [1, 1];
  
        navigator.getVRDisplays().then(function(displays) {
          WebVR.ready = true;
          WebVR.displays = displays;
          WebVR.displayNames = new Array(displays.length);
          callback();
        });
  
        return 1;
      },deinit:function () {
        WebVR.displayNames.forEach(function(name) {
          _free(name);
        });
        return 1
      },dereferenceDisplayHandle:function (displayHandle) {
        /* Display handles start as 1 as 0 will be interpreted as false or null-handle
         * on errors */
        if (displayHandle < 1 || displayHandle > WebVR.displays.length) {
          console.log("library_vr dereferenceDisplayHandle invalid display handle at: " + stackTrace());
          return null;
        }
  
        return WebVR.displays[displayHandle-1];
      }};

  function _emscripten_vr_init(func, userData) {
      return WebVR.init(function() {
        Runtime.dynCall('vi', func, [userData]);
      });
    }

  function _emscripten_vr_deinit() {
      return WebVR.deinit();
    }

  function _emscripten_vr_version_major() {
      return WebVR.version[0];
    }

  function _emscripten_vr_version_minor() {
      return WebVR.version[1];
    }

  function _emscripten_vr_ready() {
      return WebVR.ready ? 1 : 0;
    }

  function _emscripten_vr_count_displays() {
      return WebVR.displays.length;
    }

  function _emscripten_vr_get_display_handle(displayIndex) {
      if (displayIndex < 0 || displayIndex >= WebVR.displays.length) {
        return -1;
      }
  
      /* As displayHandle == 0 will be interpreted as NULL handle for errors,
       * the handle is index + 1. */
      return displayIndex + 1;
    }

  function _emscripten_vr_get_display_name(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      var name = WebVR.displayNames[displayHandle-1];
      if (name) {
        return name;
      }
  
      var buffer, displayName;
      displayName = display ? display.displayName : "";
      var len = lengthBytesUTF8(displayName);
      buffer = _malloc(len + 1);
      stringToUTF8(displayName, buffer, len + 1);
  
      WebVR.displayNames[displayHandle-1] = buffer;
  
      return buffer;
    }

  function _emscripten_vr_get_display_capabilities(displayHandle, capsPtr) {
      if (!capsPtr) return 0;
  
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      var caps = display.capabilities;
  
      HEAP32[((capsPtr)>>2)]=caps.hasPosition ? 1 : 0;
      HEAP32[(((capsPtr)+(4))>>2)]=caps.hasExternalDisplay ? 1 : 0;
      HEAP32[(((capsPtr)+(8))>>2)]=caps.canPresent ? 1 : 0;
  
      (tempI64 = [caps.maxLayers>>>0,(tempDouble=caps.maxLayers,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((capsPtr)+(12))>>2)]=tempI64[0],HEAP32[(((capsPtr)+(16))>>2)]=tempI64[1]);
  
      return 1;
    }

  function _emscripten_vr_get_eye_parameters(displayHandle, whichEye, eyeParamsPtr) {
      if (!eyeParamsPtr) return 0;
  
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      var params = display.getEyeParameters(whichEye == WebVR.EYE_LEFT ? "left" : "right");
  
      HEAPF32[((eyeParamsPtr)>>2)]=params.offset[0];
      HEAPF32[(((eyeParamsPtr)+(4))>>2)]=params.offset[1];
      HEAPF32[(((eyeParamsPtr)+(8))>>2)]=params.offset[2];
  
      (tempI64 = [params.renderWidth>>>0,(tempDouble=params.renderWidth,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((eyeParamsPtr)+(12))>>2)]=tempI64[0],HEAP32[(((eyeParamsPtr)+(16))>>2)]=tempI64[1]);
      (tempI64 = [params.renderHeight>>>0,(tempDouble=params.renderHeight,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((eyeParamsPtr)+(16))>>2)]=tempI64[0],HEAP32[(((eyeParamsPtr)+(20))>>2)]=tempI64[1]);
  
      return 1;
    }

  function _emscripten_vr_display_connected(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display || !display.isConnected) return 0;
      return 1;
    }

  function _emscripten_vr_display_presenting(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display || !display.isPresenting) return 0;
      return 1;
    }

  function _emscripten_vr_set_display_render_loop(displayHandle, func, arg) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      assert(!display.mainLoop || !display.mainLoop.scheduler, "emscripten_vr_set_device_main_loop: there can only be one render loop function per VRDisplay: call emscripten_vr_cancel_render_loop to cancel the previous one before setting a new one with different parameters.");
  
      var displayIterationFunc;
      if (typeof arg !== 'undefined') {
        displayIterationFunc = function() {
          dynCall('vi', func, [arg]);
        };
      } else {
        displayIterationFunc = function() {
          dynCall('v', func);
        };
      }
  
      display.mainLoop = {
        running: !display.mainLoop ? false : display.mainLoop.running,
        scheduler: function() {
          display.requestAnimationFrame(display.mainLoop.runner);
        },
        runner: function() {
          if (ABORT) return;
  
          /* Prevent scheduler being called twice when loop is changed */
          display.mainLoop.running = true;
  
  
          try {
            displayIterationFunc();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) err('exception thrown in render loop of VR display ' + displayHandle.toString() + ': ' + [e, e.stack]);
              throw e;
            }
          }
  
          checkStackCookie();
  
          if (!display.mainLoop.scheduler) {
            display.mainLoop.running = false;
          } else {
            display.mainLoop.scheduler();
          }
        },
        pause: function() {
          display.mainLoop.scheduler = null;
        }
      };
  
      if (!display.mainLoop.running) {
        display.mainLoop.scheduler();
      } // otherwise called by display.mainLoop.runner()
      return 1;
    }

  function _emscripten_vr_set_display_render_loop_arg(displayHandle, func, arg) {
      return _emscripten_vr_set_display_render_loop(displayHandle, func, arg);
    }

  function _emscripten_vr_cancel_display_render_loop(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display || !display.mainLoop) return 0;
  
      display.mainLoop.pause();
      return 1;
    }

  function _emscripten_vr_request_present(displayHandle, layerInitPtr, layerCount, func, userData) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      layerInit = new Array(layerCount);
      for (var i = 0; i < layerCount; ++i) {
        sourceStrPtr = HEAP32[((layerInitPtr)>>2)];
  
        var source = null;
        if (sourceStrPtr == 0) {
          source = Module['canvas'];
        } else {
          sourceStr = UTF8ToString(sourceStrPtr);
  
          if (sourceStr && sourceStr.length > 0) {
            source = document.getElementById(sourceStr);
          }
  
          if (!source) {
            return 0;
          }
        }
  
        leftBounds = new Float32Array(4);
        rightBounds = new Float32Array(4);
        var ptr = layerInitPtr;
        for (var j = 0; j < 4; ++j) {
          leftBounds[j] = HEAPF32[(((layerInitPtr)+(4+ 4*j))>>2)];
          rightBounds[j] = HEAPF32[(((layerInitPtr)+(20+ 4*j))>>2)];
          ptr += 4;
        }
  
        layerInit[i] = {
          source: source,
          leftBounds: leftBounds,
          rightBounds: rightBounds
        };
        layerInitPtr += 36;
      }
  
      display.requestPresent(layerInit).then(function() {
        if (!func) return;
        dynCall('vi', func, [userData]);
      });
  
      return 1;
    }

  function _emscripten_vr_exit_present(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display) return 0;
  
      display.exitPresent();
      return 1;
    }

  function _emscripten_vr_get_frame_data(displayHandle, frameDataPtr) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display || !display.mainLoop || !frameDataPtr) return 0;
  
      if (!display.frameData) {
        display.frameData = new VRFrameData();
      }
      display.getFrameData(display.frameData);
  
      /* Pose */
  
      /* Used to expose to C which attributes are valid (!== null) */
      var poseFlags = 0;
  
      HEAPF64[((frameDataPtr)>>3)]=display.frameData.timestamp;
  
      if (display.frameData.pose.position !== null) {
        HEAPF32[(((frameDataPtr)+(264))>>2)]=display.frameData.pose.position[0];
        HEAPF32[(((frameDataPtr)+(268))>>2)]=display.frameData.pose.position[1];
        HEAPF32[(((frameDataPtr)+(272))>>2)]=display.frameData.pose.position[2];
  
        poseFlags |= WebVR.POSE_POSITION;
      }
  
      if (display.frameData.pose.linearVelocity !== null) {
        HEAPF32[(((frameDataPtr)+(276))>>2)]=display.frameData.pose.linearVelocity[0];
        HEAPF32[(((frameDataPtr)+(280))>>2)]=display.frameData.pose.linearVelocity[1];
        HEAPF32[(((frameDataPtr)+(284))>>2)]=display.frameData.pose.linearVelocity[2];
  
        poseFlags |= WebVR.POSE_LINEAR_VELOCITY;
      }
  
      if (display.frameData.pose.linearAcceleration !== null) {
        HEAPF32[(((frameDataPtr)+(288))>>2)]=display.frameData.pose.linearAcceleration[0];
        HEAPF32[(((frameDataPtr)+(292))>>2)]=display.frameData.pose.linearAcceleration[1];
        HEAPF32[(((frameDataPtr)+(296))>>2)]=display.frameData.pose.linearAcceleration[2];
  
        poseFlags |= WebVR.POSE_LINEAR_ACCELERATION;
      }
  
      if (display.frameData.pose.orientation !== null) {
        HEAPF32[(((frameDataPtr)+(300))>>2)]=display.frameData.pose.orientation[0];
        HEAPF32[(((frameDataPtr)+(304))>>2)]=display.frameData.pose.orientation[1];
        HEAPF32[(((frameDataPtr)+(308))>>2)]=display.frameData.pose.orientation[2];
        HEAPF32[(((frameDataPtr)+(312))>>2)]=display.frameData.pose.orientation[3];
  
          poseFlags |= WebVR.POSE_ORIENTATION;
      }
  
      if (display.frameData.pose.angularVelocity !== null) {
        HEAPF32[(((frameDataPtr)+(316))>>2)]=display.frameData.pose.angularVelocity[0];
        HEAPF32[(((frameDataPtr)+(320))>>2)]=display.frameData.pose.angularVelocity[1];
        HEAPF32[(((frameDataPtr)+(324))>>2)]=display.frameData.pose.angularVelocity[2];
  
        poseFlags |= WebVR.POSE_ANGULAR_VELOCITY;
      }
  
      if (display.frameData.pose.angularAcceleration !== null) {
        HEAPF32[(((frameDataPtr)+(328))>>2)]=display.frameData.pose.angularAcceleration[0];
        HEAPF32[(((frameDataPtr)+(332))>>2)]=display.frameData.pose.angularAcceleration[1];
        HEAPF32[(((frameDataPtr)+(336))>>2)]=display.frameData.pose.angularAcceleration[0];
  
        poseFlags |= WebVR.POSE_ANGULAR_ACCELERATION;
      }
  
      HEAP32[(((frameDataPtr)+(340))>>2)]=poseFlags;
  
      /* Matrices */
  
      for (var i = 0; i < 16; ++i) {
        HEAPF32[(((frameDataPtr)+(8 + i*4))>>2)]=display.frameData.leftProjectionMatrix[i];
      }
  
      for (var i = 0; i < 16; ++i) {
        HEAPF32[(((frameDataPtr)+(72 + i*4))>>2)]=display.frameData.leftViewMatrix[i];
      }
  
      for (var i = 0; i < 16; ++i) {
        HEAPF32[(((frameDataPtr)+(136 + i*4))>>2)]=display.frameData.rightProjectionMatrix[i];
      }
  
      for (var i = 0; i < 16; ++i) {
        HEAPF32[(((frameDataPtr)+(200 + i*4))>>2)]=display.frameData.rightViewMatrix[i];
      }
  
      return 1;
    }

  function _emscripten_vr_submit_frame(displayHandle) {
      var display = WebVR.dereferenceDisplayHandle(displayHandle);
      if (!display || !display.mainLoop) return 0;
  
      display.submitFrame();
  
      return 1;
    }

  function _emscripten_has_threading_support() {
      return 0;
    }

  function _emscripten_num_logical_cores() {
      return 1;
    }

  function _emscripten_force_num_logical_cores(cores) {
      // Ignored, no threading available.
    }

  function _emscripten_is_main_runtime_thread() {
      return 1;
    }

  function _emscripten_is_main_browser_thread() {
      return !ENVIRONMENT_IS_WORKER;
    }

  function _emscripten_main_thread_process_queued_calls() {
      // We will never have any queued calls to process, so no-op.
    }

  function _pthread_barrier_init() {}

  function _pthread_barrier_wait() {}

  function _pthread_barrier_destroy() {}

  function _pthread_mutex_init() {}

  function _pthread_mutex_destroy() {}

  function _pthread_mutexattr_init() {}

  function _pthread_mutexattr_setschedparam() {}

  function _pthread_mutexattr_setprotocol() {}

  function _pthread_mutexattr_settype() {}

  function _pthread_mutexattr_destroy() {}

   

   

   

  function _pthread_mutexattr_setpshared(attr, pshared) {
      // XXX implement if/when getpshared is required
      return 0;
    }

  function _pthread_cond_init() { return 0; }

  function _pthread_cond_destroy() { return 0; }

  function _pthread_cond_wait() { return 0; }

  function _pthread_cond_timedwait() { return 0; }

  function _pthread_cond_signal() { return 0; }

  function _pthread_condattr_init() { return 0; }

  function _pthread_condattr_destroy() { return 0; }

  function _pthread_condattr_setclock() { return 0; }

  function _pthread_condattr_setpshared() { return 0; }

  function _pthread_condattr_getclock() { return 0; }

  function _pthread_condattr_getpshared() { return 0; }

   

  function _pthread_attr_init(attr) {
      /* int pthread_attr_init(pthread_attr_t *attr); */
      //FIXME: should allocate a pthread_attr_t
      return 0;
    }

  function _pthread_getattr_np(thread, attr) {
      /* int pthread_getattr_np(pthread_t thread, pthread_attr_t *attr); */
      //FIXME: should fill in attributes of the given thread in pthread_attr_t
      return 0;
    }

  function _pthread_attr_destroy(attr) {
      /* int pthread_attr_destroy(pthread_attr_t *attr); */
      //FIXME: should destroy the pthread_attr_t struct
      return 0;
    }

  function _pthread_attr_getstack(attr, stackaddr, stacksize) {
      /* int pthread_attr_getstack(const pthread_attr_t *restrict attr,
         void **restrict stackaddr, size_t *restrict stacksize); */
      /*FIXME: assumes that there is only one thread, and that attr is the
        current thread*/
      HEAP32[((stackaddr)>>2)]=STACK_BASE;
      HEAP32[((stacksize)>>2)]=TOTAL_STACK;
      return 0;
    }


  function _pthread_once(ptr, func) {
      if (!_pthread_once.seen) _pthread_once.seen = {};
      if (ptr in _pthread_once.seen) return;
      Module['dynCall_v'](func);
      _pthread_once.seen[ptr] = 1;
    }

  var PTHREAD_SPECIFIC={};

  var PTHREAD_SPECIFIC_NEXT_KEY=1;

  function _pthread_key_create(key, destructor) {
      if (key == 0) {
        return ERRNO_CODES.EINVAL;
      }
      HEAP32[((key)>>2)]=PTHREAD_SPECIFIC_NEXT_KEY;
      // values start at 0
      PTHREAD_SPECIFIC[PTHREAD_SPECIFIC_NEXT_KEY] = 0;
      PTHREAD_SPECIFIC_NEXT_KEY++;
      return 0;
    }

  function _pthread_getspecific(key) {
      return PTHREAD_SPECIFIC[key] || 0;
    }

  function _pthread_setspecific(key, value) {
      if (!(key in PTHREAD_SPECIFIC)) {
        return ERRNO_CODES.EINVAL;
      }
      PTHREAD_SPECIFIC[key] = value;
      return 0;
    }

  function _pthread_key_delete(key) {
      if (key in PTHREAD_SPECIFIC) {
        delete PTHREAD_SPECIFIC[key];
        return 0;
      }
      return ERRNO_CODES.EINVAL;
    }



  function __pthread_cleanup_push() {
  return _pthread_cleanup_push.apply(null, arguments)
  }

  function __pthread_cleanup_pop() {
  return _pthread_cleanup_pop.apply(null, arguments)
  }


  function _pthread_rwlock_init() { return 0; }

  function _pthread_rwlock_destroy() { return 0; }

  function _pthread_rwlock_rdlock() { return 0; }

  function _pthread_rwlock_tryrdlock() { return 0; }

  function _pthread_rwlock_timedrdlock() { return 0; }

  function _pthread_rwlock_wrlock() { return 0; }

  function _pthread_rwlock_trywrlock() { return 0; }

  function _pthread_rwlock_timedwrlock() { return 0; }

  function _pthread_rwlock_unlock() { return 0; }

  function _pthread_rwlockattr_init() { return 0; }

  function _pthread_rwlockattr_destroy() { return 0; }

  function _pthread_rwlockattr_setpshared() { return 0; }

  function _pthread_rwlockattr_getpshared() { return 0; }

  function _pthread_spin_init() { return 0; }

  function _pthread_spin_destroy() { return 0; }

  function _pthread_spin_lock() { return 0; }

  function _pthread_spin_trylock() { return 0; }

  function _pthread_spin_unlock() { return 0; }

  function _pthread_attr_setdetachstate() {}

  function _pthread_attr_setschedparam() {}

  function _pthread_attr_setstacksize() {}

  function _pthread_create() {
      return 11;
    }

  function _pthread_cancel() {}

  function _pthread_exit(status) {
      _exit(status);
    }

  function _pthread_equal(x, y) { return x == y }

  function _pthread_join() {}

  function _pthread_detach() {}

  function _sem_init() {}

  function _sem_post() {}

  function _sem_wait() {}

  function _sem_trywait() {}

  function _sem_destroy() {}

  function _emscripten_main_browser_thread_id() { return _pthread_self(); }



  function _llvm_memory_barrier(){}

  function _llvm_atomic_load_add_i32_p0i32(ptr, delta) {
      var ret = HEAP32[((ptr)>>2)];
      HEAP32[((ptr)>>2)]=ret+delta;
      return ret;
    }

  function ___atomic_is_lock_free(size, ptr) {
      return size <= 4 && (size & (size-1)) == 0 && (ptr&(size-1)) == 0;
    }

  function ___atomic_load_8(ptr, memmodel) {
      return ((setTempRet0(HEAP32[(((ptr)+(4))>>2)]),HEAP32[((ptr)>>2)])|0);
    }

  function ___atomic_store_8(ptr, vall, valh, memmodel) {
      HEAP32[((ptr)>>2)]=vall;
      HEAP32[(((ptr)+(4))>>2)]=valh;
    }

  function ___atomic_exchange_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=vall;
      HEAP32[(((ptr)+(4))>>2)]=valh;
      return ((setTempRet0(h),l)|0);
    }

  function ___atomic_compare_exchange_8(ptr, expected, desiredl, desiredh, weak, success_memmodel, failure_memmodel) {
      var pl = HEAP32[((ptr)>>2)];
      var ph = HEAP32[(((ptr)+(4))>>2)];
      var el = HEAP32[((expected)>>2)];
      var eh = HEAP32[(((expected)+(4))>>2)];
      if (pl === el && ph === eh) {
        HEAP32[((ptr)>>2)]=desiredl;
        HEAP32[(((ptr)+(4))>>2)]=desiredh;
        return 1;
      } else {
        HEAP32[((expected)>>2)]=pl;
        HEAP32[(((expected)+(4))>>2)]=ph;
        return 0;
      }
    }

  function ___atomic_fetch_add_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=_i64Add(l, h, vall, valh);
      HEAP32[(((ptr)+(4))>>2)]=getTempRet0();
      return ((setTempRet0(h),l)|0);
    }

  function ___atomic_fetch_sub_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=_i64Subtract(l, h, vall, valh);
      HEAP32[(((ptr)+(4))>>2)]=getTempRet0();
      return ((setTempRet0(h),l)|0);
    }

  function ___atomic_fetch_and_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=l&vall;
      HEAP32[(((ptr)+(4))>>2)]=h&valh;
      return ((setTempRet0(h),l)|0);
    }

  function ___atomic_fetch_or_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=l|vall;
      HEAP32[(((ptr)+(4))>>2)]=h|valh;
      return ((setTempRet0(h),l)|0);
    }

  function ___atomic_fetch_xor_8(ptr, vall, valh, memmodel) {
      var l = HEAP32[((ptr)>>2)];
      var h = HEAP32[(((ptr)+(4))>>2)];
      HEAP32[((ptr)>>2)]=l^vall;
      HEAP32[(((ptr)+(4))>>2)]=h^valh;
      return ((setTempRet0(h),l)|0);
    }

  function _emscripten_atomic_add_u32() {
  return _llvm_atomic_load_add_i32_p0i32.apply(null, arguments)
  }

  function _emscripten_atomic_load_u64() {
  return ___atomic_load_8.apply(null, arguments)
  }

  function _emscripten_atomic_store_u64() {
  return ___atomic_store_8.apply(null, arguments)
  }

  function _emscripten_atomic_cas_u64() {
  return ___atomic_compare_exchange_8.apply(null, arguments)
  }

  function _emscripten_atomic_exchange_u64() {
  return ___atomic_exchange_8.apply(null, arguments)
  }

  function __emscripten_atomic_fetch_and_add_u64() {
  return ___atomic_fetch_add_8.apply(null, arguments)
  }

  function __emscripten_atomic_fetch_and_sub_u64() {
  return ___atomic_fetch_sub_8.apply(null, arguments)
  }

  function __emscripten_atomic_fetch_and_and_u64() {
  return ___atomic_fetch_and_8.apply(null, arguments)
  }

  function __emscripten_atomic_fetch_and_or_u64() {
  return ___atomic_fetch_or_8.apply(null, arguments)
  }

  function __emscripten_atomic_fetch_and_xor_u64() {
  return ___atomic_fetch_xor_8.apply(null, arguments)
  }

if (ENVIRONMENT_IS_NODE) {
    _emscripten_get_now = function _emscripten_get_now_actual() {
      var t = process['hrtime']();
      return t[0] * 1e3 + t[1] / 1e6;
    };
  } else if (typeof dateNow !== 'undefined') {
    _emscripten_get_now = dateNow;
  } else if (typeof self === 'object' && self['performance'] && typeof self['performance']['now'] === 'function') {
    _emscripten_get_now = function() { return self['performance']['now'](); };
  } else if (typeof performance === 'object' && typeof performance['now'] === 'function') {
    _emscripten_get_now = function() { return performance['now'](); };
  } else {
    _emscripten_get_now = Date.now;
  };
FS.staticInit();__ATINIT__.unshift(function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() });__ATMAIN__.push(function() { FS.ignorePermissions = false });__ATEXIT__.push(function() { FS.quit() });;
__ATINIT__.unshift(function() { TTY.init() });__ATEXIT__.push(function() { TTY.shutdown() });;
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); var NODEJS_PATH = require("path"); NODEFS.staticInit(); };
__ATINIT__.push(function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); });;
__ATINIT__.push(function() { PIPEFS.root = FS.mount(PIPEFS, {}, null); });;
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas, vrDevice) { err("Module.requestFullScreen is deprecated. Please call Module.requestFullscreen instead."); Module["requestFullScreen"] = Module["requestFullscreen"]; Browser.requestFullScreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestFullscreen"] = function Module_requestFullscreen(lockPointer, resizeCanvas, vrDevice) { Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
  Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) { return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes) };
JSEvents.staticInit();;
var GLctx; GL.init();
DYNAMICTOP_PTR = staticAlloc(4);

STACK_BASE = STACKTOP = alignMemory(STATICTOP);

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = alignMemory(STACK_MAX);

HEAP32[DYNAMICTOP_PTR>>2] = DYNAMIC_BASE;

staticSealed = true; // seal the static portion of memory

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

var ASSERTIONS = true;

// Copyright 2017 The Emscripten Authors.  All rights reserved.
// Emscripten is available under two separate licenses, the MIT license and the
// University of Illinois/NCSA Open Source License.  Both these licenses can be
// found in the LICENSE file.

/** @type {function(string, boolean=, number=)} */
function intArrayFromString(stringy, dontAddNull, length) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      if (ASSERTIONS) {
        assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      }
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}



function nullFunc_ii(x) { err("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iii(x) { err("Invalid function pointer called with signature 'iii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiii(x) { err("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiii(x) { err("Invalid function pointer called with signature 'iiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiiii(x) { err("Invalid function pointer called with signature 'iiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_v(x) { err("Invalid function pointer called with signature 'v'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vi(x) { err("Invalid function pointer called with signature 'vi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info.");abort(x) }
var gb = GLOBAL_BASE, fb = 0;

function invoke_ii(index,a1) {
  var sp = stackSave();
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  var sp = stackSave();
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  var sp = stackSave();
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  var sp = stackSave();
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  var sp = stackSave();
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  var sp = stackSave();
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  var sp = stackSave();
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    stackRestore(sp);
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function ftCall_ii(x, a0) {
  if (x < 0 || x >= FUNCTION_TABLE_ii.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_ii[x](a0);
}

function ftCall_iii(x, a0, a1) {
  if (x < 0 || x >= FUNCTION_TABLE_iii.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'iii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_iii[x](a0, a1);
}

function ftCall_iiii(x, a0, a1, a2) {
  if (x < 0 || x >= FUNCTION_TABLE_iiii.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_iiii[x](a0, a1, a2);
}

function ftCall_iiiii(x, a0, a1, a2, a3) {
  if (x < 0 || x >= FUNCTION_TABLE_iiiii.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'iiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_iiiii[x](a0, a1, a2, a3);
}

function ftCall_iiiiii(x, a0, a1, a2, a3, a4) {
  if (x < 0 || x >= FUNCTION_TABLE_iiiiii.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'iiiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_iiiiii[x](a0, a1, a2, a3, a4);
}

function ftCall_v(x) {
  if (x < 0 || x >= FUNCTION_TABLE_v.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'v'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_v[x]();
}

function ftCall_vi(x, a0) {
  if (x < 0 || x >= FUNCTION_TABLE_vi.length) { err("Function table mask error (out of range)"); err("Invalid function pointer called with signature 'vi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  err("Build with ASSERTIONS=2 for more info."); ; abort(x) }
  return FUNCTION_TABLE_vi[x](a0);
}


var dynCall_ii = ftCall_ii;


var dynCall_iii = ftCall_iii;


var dynCall_iiii = ftCall_iiii;


var dynCall_iiiii = ftCall_iiiii;


var dynCall_iiiiii = ftCall_iiiiii;


var dynCall_v = ftCall_v;


var dynCall_vi = ftCall_vi;


Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };

Module.asmLibraryArg = { "abort": abort, "assert": assert, "enlargeMemory": enlargeMemory, "getTotalMemory": getTotalMemory, "abortOnCannotGrowMemory": abortOnCannotGrowMemory, "abortStackOverflow": abortStackOverflow, "nullFunc_ii": nullFunc_ii, "nullFunc_iii": nullFunc_iii, "nullFunc_iiii": nullFunc_iiii, "nullFunc_iiiii": nullFunc_iiiii, "nullFunc_iiiiii": nullFunc_iiiiii, "nullFunc_v": nullFunc_v, "nullFunc_vi": nullFunc_vi, "setTempRet0": setTempRet0, "getTempRet0": getTempRet0, "invoke_ii": invoke_ii, "invoke_iii": invoke_iii, "invoke_iiii": invoke_iiii, "invoke_iiiii": invoke_iiiii, "invoke_iiiiii": invoke_iiiiii, "invoke_v": invoke_v, "invoke_vi": invoke_vi, "ftCall_ii": ftCall_ii, "ftCall_iii": ftCall_iii, "ftCall_iiii": ftCall_iiii, "ftCall_iiiii": ftCall_iiiii, "ftCall_iiiiii": ftCall_iiiiii, "ftCall_v": ftCall_v, "ftCall_vi": ftCall_vi, "_IMG_Init": _IMG_Init, "_IMG_Load": _IMG_Load, "_IMG_Load_RW": _IMG_Load_RW, "_IMG_Quit": _IMG_Quit, "_Mix_AllocateChannels": _Mix_AllocateChannels, "_Mix_ChannelFinished": _Mix_ChannelFinished, "_Mix_CloseAudio": _Mix_CloseAudio, "_Mix_FadeInChannelTimed": _Mix_FadeInChannelTimed, "_Mix_FadeInMusicPos": _Mix_FadeInMusicPos, "_Mix_FadeOutChannel": _Mix_FadeOutChannel, "_Mix_FadeOutMusic": _Mix_FadeOutMusic, "_Mix_FadingChannel": _Mix_FadingChannel, "_Mix_FreeChunk": _Mix_FreeChunk, "_Mix_FreeMusic": _Mix_FreeMusic, "_Mix_HaltChannel": _Mix_HaltChannel, "_Mix_HaltMusic": _Mix_HaltMusic, "_Mix_HookMusicFinished": _Mix_HookMusicFinished, "_Mix_Init": _Mix_Init, "_Mix_Linked_Version": _Mix_Linked_Version, "_Mix_LoadMUS": _Mix_LoadMUS, "_Mix_LoadMUS_RW": _Mix_LoadMUS_RW, "_Mix_LoadWAV": _Mix_LoadWAV, "_Mix_LoadWAV_RW": _Mix_LoadWAV_RW, "_Mix_OpenAudio": _Mix_OpenAudio, "_Mix_Pause": _Mix_Pause, "_Mix_PauseMusic": _Mix_PauseMusic, "_Mix_Paused": _Mix_Paused, "_Mix_PausedMusic": _Mix_PausedMusic, "_Mix_PlayChannel": _Mix_PlayChannel, "_Mix_PlayChannelTimed": _Mix_PlayChannelTimed, "_Mix_PlayMusic": _Mix_PlayMusic, "_Mix_Playing": _Mix_Playing, "_Mix_PlayingMusic": _Mix_PlayingMusic, "_Mix_QuerySpec": _Mix_QuerySpec, "_Mix_QuickLoad_RAW": _Mix_QuickLoad_RAW, "_Mix_Quit": _Mix_Quit, "_Mix_ReserveChannels": _Mix_ReserveChannels, "_Mix_Resume": _Mix_Resume, "_Mix_ResumeMusic": _Mix_ResumeMusic, "_Mix_SetPanning": _Mix_SetPanning, "_Mix_SetPosition": _Mix_SetPosition, "_Mix_SetPostMix": _Mix_SetPostMix, "_Mix_Volume": _Mix_Volume, "_Mix_VolumeChunk": _Mix_VolumeChunk, "_Mix_VolumeMusic": _Mix_VolumeMusic, "_SDL_AddTimer": _SDL_AddTimer, "_SDL_AllocRW": _SDL_AllocRW, "_SDL_AudioDriverName": _SDL_AudioDriverName, "_SDL_AudioQuit": _SDL_AudioQuit, "_SDL_BlitScaled": _SDL_BlitScaled, "_SDL_BlitSurface": _SDL_BlitSurface, "_SDL_ClearError": _SDL_ClearError, "_SDL_CloseAudio": _SDL_CloseAudio, "_SDL_CondBroadcast": _SDL_CondBroadcast, "_SDL_CondSignal": _SDL_CondSignal, "_SDL_CondWait": _SDL_CondWait, "_SDL_CondWaitTimeout": _SDL_CondWaitTimeout, "_SDL_ConvertSurface": _SDL_ConvertSurface, "_SDL_CreateCond": _SDL_CreateCond, "_SDL_CreateMutex": _SDL_CreateMutex, "_SDL_CreateRGBSurface": _SDL_CreateRGBSurface, "_SDL_CreateRGBSurfaceFrom": _SDL_CreateRGBSurfaceFrom, "_SDL_CreateThread": _SDL_CreateThread, "_SDL_Delay": _SDL_Delay, "_SDL_DestroyCond": _SDL_DestroyCond, "_SDL_DestroyMutex": _SDL_DestroyMutex, "_SDL_DestroyRenderer": _SDL_DestroyRenderer, "_SDL_DestroyWindow": _SDL_DestroyWindow, "_SDL_DisplayFormatAlpha": _SDL_DisplayFormatAlpha, "_SDL_EnableKeyRepeat": _SDL_EnableKeyRepeat, "_SDL_EnableUNICODE": _SDL_EnableUNICODE, "_SDL_FillRect": _SDL_FillRect, "_SDL_Flip": _SDL_Flip, "_SDL_FreeRW": _SDL_FreeRW, "_SDL_FreeSurface": _SDL_FreeSurface, "_SDL_GL_DeleteContext": _SDL_GL_DeleteContext, "_SDL_GL_ExtensionSupported": _SDL_GL_ExtensionSupported, "_SDL_GL_GetAttribute": _SDL_GL_GetAttribute, "_SDL_GL_GetProcAddress": _SDL_GL_GetProcAddress, "_SDL_GL_GetSwapInterval": _SDL_GL_GetSwapInterval, "_SDL_GL_MakeCurrent": _SDL_GL_MakeCurrent, "_SDL_GL_SetAttribute": _SDL_GL_SetAttribute, "_SDL_GL_SetSwapInterval": _SDL_GL_SetSwapInterval, "_SDL_GL_SwapBuffers": _SDL_GL_SwapBuffers, "_SDL_GL_SwapWindow": _SDL_GL_SwapWindow, "_SDL_GetAppState": _SDL_GetAppState, "_SDL_GetAudioDriver": _SDL_GetAudioDriver, "_SDL_GetClipRect": _SDL_GetClipRect, "_SDL_GetCurrentAudioDriver": _SDL_GetCurrentAudioDriver, "_SDL_GetError": _SDL_GetError, "_SDL_GetKeyName": _SDL_GetKeyName, "_SDL_GetKeyState": _SDL_GetKeyState, "_SDL_GetKeyboardState": _SDL_GetKeyboardState, "_SDL_GetModState": _SDL_GetModState, "_SDL_GetMouseState": _SDL_GetMouseState, "_SDL_GetNumAudioDrivers": _SDL_GetNumAudioDrivers, "_SDL_GetRGB": _SDL_GetRGB, "_SDL_GetRGBA": _SDL_GetRGBA, "_SDL_GetThreadID": _SDL_GetThreadID, "_SDL_GetTicks": _SDL_GetTicks, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "_SDL_GetVideoSurface": _SDL_GetVideoSurface, "_SDL_GetWindowFlags": _SDL_GetWindowFlags, "_SDL_GetWindowSize": _SDL_GetWindowSize, "_SDL_Has3DNow": _SDL_Has3DNow, "_SDL_Has3DNowExt": _SDL_Has3DNowExt, "_SDL_HasAltiVec": _SDL_HasAltiVec, "_SDL_HasMMX": _SDL_HasMMX, "_SDL_HasMMXExt": _SDL_HasMMXExt, "_SDL_HasRDTSC": _SDL_HasRDTSC, "_SDL_HasSSE": _SDL_HasSSE, "_SDL_HasSSE2": _SDL_HasSSE2, "_SDL_Init": _SDL_Init, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_SDL_JoystickClose": _SDL_JoystickClose, "_SDL_JoystickEventState": _SDL_JoystickEventState, "_SDL_JoystickGetAxis": _SDL_JoystickGetAxis, "_SDL_JoystickGetBall": _SDL_JoystickGetBall, "_SDL_JoystickGetButton": _SDL_JoystickGetButton, "_SDL_JoystickGetHat": _SDL_JoystickGetHat, "_SDL_JoystickIndex": _SDL_JoystickIndex, "_SDL_JoystickName": _SDL_JoystickName, "_SDL_JoystickNumAxes": _SDL_JoystickNumAxes, "_SDL_JoystickNumBalls": _SDL_JoystickNumBalls, "_SDL_JoystickNumButtons": _SDL_JoystickNumButtons, "_SDL_JoystickNumHats": _SDL_JoystickNumHats, "_SDL_JoystickOpen": _SDL_JoystickOpen, "_SDL_JoystickOpened": _SDL_JoystickOpened, "_SDL_JoystickUpdate": _SDL_JoystickUpdate, "_SDL_Linked_Version": _SDL_Linked_Version, "_SDL_ListModes": _SDL_ListModes, "_SDL_LoadBMP": _SDL_LoadBMP, "_SDL_LoadBMP_RW": _SDL_LoadBMP_RW, "_SDL_LockAudio": _SDL_LockAudio, "_SDL_LockMutex": _SDL_LockMutex, "_SDL_LockSurface": _SDL_LockSurface, "_SDL_LogSetOutputFunction": _SDL_LogSetOutputFunction, "_SDL_LowerBlit": _SDL_LowerBlit, "_SDL_LowerBlitScaled": _SDL_LowerBlitScaled, "_SDL_MapRGB": _SDL_MapRGB, "_SDL_MapRGBA": _SDL_MapRGBA, "_SDL_NumJoysticks": _SDL_NumJoysticks, "_SDL_OpenAudio": _SDL_OpenAudio, "_SDL_PauseAudio": _SDL_PauseAudio, "_SDL_PeepEvents": _SDL_PeepEvents, "_SDL_PollEvent": _SDL_PollEvent, "_SDL_PumpEvents": _SDL_PumpEvents, "_SDL_PushEvent": _SDL_PushEvent, "_SDL_Quit": _SDL_Quit, "_SDL_QuitSubSystem": _SDL_QuitSubSystem, "_SDL_RWFromConstMem": _SDL_RWFromConstMem, "_SDL_RWFromFile": _SDL_RWFromFile, "_SDL_RWFromMem": _SDL_RWFromMem, "_SDL_RemoveTimer": _SDL_RemoveTimer, "_SDL_SaveBMP_RW": _SDL_SaveBMP_RW, "_SDL_SetAlpha": _SDL_SetAlpha, "_SDL_SetClipRect": _SDL_SetClipRect, "_SDL_SetColorKey": _SDL_SetColorKey, "_SDL_SetColors": _SDL_SetColors, "_SDL_SetError": _SDL_SetError, "_SDL_SetGamma": _SDL_SetGamma, "_SDL_SetGammaRamp": _SDL_SetGammaRamp, "_SDL_SetPalette": _SDL_SetPalette, "_SDL_SetVideoMode": _SDL_SetVideoMode, "_SDL_SetWindowFullscreen": _SDL_SetWindowFullscreen, "_SDL_SetWindowTitle": _SDL_SetWindowTitle, "_SDL_ShowCursor": _SDL_ShowCursor, "_SDL_StartTextInput": _SDL_StartTextInput, "_SDL_StopTextInput": _SDL_StopTextInput, "_SDL_ThreadID": _SDL_ThreadID, "_SDL_UnlockAudio": _SDL_UnlockAudio, "_SDL_UnlockMutex": _SDL_UnlockMutex, "_SDL_UnlockSurface": _SDL_UnlockSurface, "_SDL_UpdateRect": _SDL_UpdateRect, "_SDL_UpdateRects": _SDL_UpdateRects, "_SDL_UpperBlit": _SDL_UpperBlit, "_SDL_UpperBlitScaled": _SDL_UpperBlitScaled, "_SDL_VideoDriverName": _SDL_VideoDriverName, "_SDL_VideoModeOK": _SDL_VideoModeOK, "_SDL_VideoQuit": _SDL_VideoQuit, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "_SDL_WM_IconifyWindow": _SDL_WM_IconifyWindow, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_SDL_WM_SetIcon": _SDL_WM_SetIcon, "_SDL_WM_ToggleFullScreen": _SDL_WM_ToggleFullScreen, "_SDL_WaitThread": _SDL_WaitThread, "_SDL_WarpMouse": _SDL_WarpMouse, "_SDL_WasInit": _SDL_WasInit, "_SDL_free": _SDL_free, "_SDL_getenv": _SDL_getenv, "_SDL_malloc": _SDL_malloc, "_SDL_mutexP": _SDL_mutexP, "_SDL_mutexV": _SDL_mutexV, "_SDL_putenv": _SDL_putenv, "_TTF_CloseFont": _TTF_CloseFont, "_TTF_FontAscent": _TTF_FontAscent, "_TTF_FontDescent": _TTF_FontDescent, "_TTF_FontHeight": _TTF_FontHeight, "_TTF_FontLineSkip": _TTF_FontLineSkip, "_TTF_GlyphMetrics": _TTF_GlyphMetrics, "_TTF_Init": _TTF_Init, "_TTF_OpenFont": _TTF_OpenFont, "_TTF_Quit": _TTF_Quit, "_TTF_RenderText_Blended": _TTF_RenderText_Blended, "_TTF_RenderText_Shaded": _TTF_RenderText_Shaded, "_TTF_RenderText_Solid": _TTF_RenderText_Solid, "_TTF_RenderUTF8_Solid": _TTF_RenderUTF8_Solid, "_TTF_SizeText": _TTF_SizeText, "_TTF_SizeUTF8": _TTF_SizeUTF8, "_XChangeWindowAttributes": _XChangeWindowAttributes, "_XCreateWindow": _XCreateWindow, "_XInternAtom": _XInternAtom, "_XMapWindow": _XMapWindow, "_XOpenDisplay": _XOpenDisplay, "_XPending": _XPending, "_XSendEvent": _XSendEvent, "_XSetWMHints": _XSetWMHints, "_XStoreName": _XStoreName, "__Exit": __Exit, "__Unwind_Backtrace": __Unwind_Backtrace, "__Unwind_DeleteException": __Unwind_DeleteException, "__Unwind_FindEnclosingFunction": __Unwind_FindEnclosingFunction, "__Unwind_GetIPInfo": __Unwind_GetIPInfo, "__Unwind_RaiseException": __Unwind_RaiseException, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "__ZSt9terminatev": __ZSt9terminatev, "___assert_fail": ___assert_fail, "___assert_func": ___assert_func, "___atomic_compare_exchange_8": ___atomic_compare_exchange_8, "___atomic_exchange_8": ___atomic_exchange_8, "___atomic_fetch_add_8": ___atomic_fetch_add_8, "___atomic_fetch_and_8": ___atomic_fetch_and_8, "___atomic_fetch_or_8": ___atomic_fetch_or_8, "___atomic_fetch_sub_8": ___atomic_fetch_sub_8, "___atomic_fetch_xor_8": ___atomic_fetch_xor_8, "___atomic_is_lock_free": ___atomic_is_lock_free, "___atomic_load_8": ___atomic_load_8, "___atomic_store_8": ___atomic_store_8, "___buildEnvironment": ___buildEnvironment, "___builtin_prefetch": ___builtin_prefetch, "___clock_gettime": ___clock_gettime, "___cxa_allocate_exception": ___cxa_allocate_exception, "___cxa_atexit": ___cxa_atexit, "___cxa_begin_catch": ___cxa_begin_catch, "___cxa_call_unexpected": ___cxa_call_unexpected, "___cxa_current_primary_exception": ___cxa_current_primary_exception, "___cxa_decrement_exception_refcount": ___cxa_decrement_exception_refcount, "___cxa_end_catch": ___cxa_end_catch, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "___cxa_free_exception": ___cxa_free_exception, "___cxa_get_exception_ptr": ___cxa_get_exception_ptr, "___cxa_increment_exception_refcount": ___cxa_increment_exception_refcount, "___cxa_pure_virtual": ___cxa_pure_virtual, "___cxa_rethrow": ___cxa_rethrow, "___cxa_rethrow_primary_exception": ___cxa_rethrow_primary_exception, "___cxa_thread_atexit": ___cxa_thread_atexit, "___cxa_thread_atexit_impl": ___cxa_thread_atexit_impl, "___cxa_throw": ___cxa_throw, "___cxa_uncaught_exception": ___cxa_uncaught_exception, "___execvpe": ___execvpe, "___gcc_personality_v0": ___gcc_personality_v0, "___gxx_personality_v0": ___gxx_personality_v0, "___libc_current_sigrtmax": ___libc_current_sigrtmax, "___libc_current_sigrtmin": ___libc_current_sigrtmin, "___lock": ___lock, "___map_file": ___map_file, "___resumeException": ___resumeException, "___setErrNo": ___setErrNo, "___set_network_callback": ___set_network_callback, "___syscall1": ___syscall1, "___syscall10": ___syscall10, "___syscall102": ___syscall102, "___syscall104": ___syscall104, "___syscall114": ___syscall114, "___syscall118": ___syscall118, "___syscall12": ___syscall12, "___syscall121": ___syscall121, "___syscall122": ___syscall122, "___syscall125": ___syscall125, "___syscall132": ___syscall132, "___syscall133": ___syscall133, "___syscall14": ___syscall14, "___syscall140": ___syscall140, "___syscall142": ___syscall142, "___syscall144": ___syscall144, "___syscall145": ___syscall145, "___syscall146": ___syscall146, "___syscall147": ___syscall147, "___syscall148": ___syscall148, "___syscall15": ___syscall15, "___syscall150": ___syscall150, "___syscall151": ___syscall151, "___syscall152": ___syscall152, "___syscall153": ___syscall153, "___syscall163": ___syscall163, "___syscall168": ___syscall168, "___syscall178": ___syscall178, "___syscall180": ___syscall180, "___syscall181": ___syscall181, "___syscall183": ___syscall183, "___syscall191": ___syscall191, "___syscall192": ___syscall192, "___syscall193": ___syscall193, "___syscall194": ___syscall194, "___syscall195": ___syscall195, "___syscall196": ___syscall196, "___syscall197": ___syscall197, "___syscall198": ___syscall198, "___syscall199": ___syscall199, "___syscall20": ___syscall20, "___syscall200": ___syscall200, "___syscall201": ___syscall201, "___syscall202": ___syscall202, "___syscall203": ___syscall203, "___syscall204": ___syscall204, "___syscall205": ___syscall205, "___syscall207": ___syscall207, "___syscall208": ___syscall208, "___syscall209": ___syscall209, "___syscall210": ___syscall210, "___syscall211": ___syscall211, "___syscall212": ___syscall212, "___syscall213": ___syscall213, "___syscall214": ___syscall214, "___syscall218": ___syscall218, "___syscall219": ___syscall219, "___syscall220": ___syscall220, "___syscall221": ___syscall221, "___syscall265": ___syscall265, "___syscall268": ___syscall268, "___syscall269": ___syscall269, "___syscall272": ___syscall272, "___syscall29": ___syscall29, "___syscall295": ___syscall295, "___syscall296": ___syscall296, "___syscall297": ___syscall297, "___syscall298": ___syscall298, "___syscall299": ___syscall299, "___syscall3": ___syscall3, "___syscall300": ___syscall300, "___syscall301": ___syscall301, "___syscall302": ___syscall302, "___syscall303": ___syscall303, "___syscall304": ___syscall304, "___syscall305": ___syscall305, "___syscall306": ___syscall306, "___syscall307": ___syscall307, "___syscall308": ___syscall308, "___syscall320": ___syscall320, "___syscall324": ___syscall324, "___syscall33": ___syscall33, "___syscall330": ___syscall330, "___syscall331": ___syscall331, "___syscall333": ___syscall333, "___syscall334": ___syscall334, "___syscall337": ___syscall337, "___syscall34": ___syscall34, "___syscall340": ___syscall340, "___syscall345": ___syscall345, "___syscall36": ___syscall36, "___syscall38": ___syscall38, "___syscall39": ___syscall39, "___syscall4": ___syscall4, "___syscall40": ___syscall40, "___syscall41": ___syscall41, "___syscall42": ___syscall42, "___syscall5": ___syscall5, "___syscall51": ___syscall51, "___syscall54": ___syscall54, "___syscall57": ___syscall57, "___syscall6": ___syscall6, "___syscall60": ___syscall60, "___syscall63": ___syscall63, "___syscall64": ___syscall64, "___syscall65": ___syscall65, "___syscall66": ___syscall66, "___syscall75": ___syscall75, "___syscall77": ___syscall77, "___syscall83": ___syscall83, "___syscall85": ___syscall85, "___syscall9": ___syscall9, "___syscall91": ___syscall91, "___syscall94": ___syscall94, "___syscall96": ___syscall96, "___syscall97": ___syscall97, "___ubsan_handle_add_overflow": ___ubsan_handle_add_overflow, "___ubsan_handle_float_cast_overflow": ___ubsan_handle_float_cast_overflow, "___ubsan_handle_pointer_overflow": ___ubsan_handle_pointer_overflow, "___ubsan_handle_type_mismatch_v1": ___ubsan_handle_type_mismatch_v1, "___unlock": ___unlock, "___wait": ___wait, "__addDays": __addDays, "__arraySum": __arraySum, "__emscripten_atomic_fetch_and_add_u64": __emscripten_atomic_fetch_and_add_u64, "__emscripten_atomic_fetch_and_and_u64": __emscripten_atomic_fetch_and_and_u64, "__emscripten_atomic_fetch_and_or_u64": __emscripten_atomic_fetch_and_or_u64, "__emscripten_atomic_fetch_and_sub_u64": __emscripten_atomic_fetch_and_sub_u64, "__emscripten_atomic_fetch_and_xor_u64": __emscripten_atomic_fetch_and_xor_u64, "__emscripten_do_request_fullscreen": __emscripten_do_request_fullscreen, "__emscripten_push_main_loop_blocker": __emscripten_push_main_loop_blocker, "__emscripten_push_uncounted_main_loop_blocker": __emscripten_push_uncounted_main_loop_blocker, "__emscripten_sample_gamepad_data": __emscripten_sample_gamepad_data, "__emscripten_traverse_stack": __emscripten_traverse_stack, "__exit": __exit, "__formatString": __formatString, "__get_canvas_element_size": __get_canvas_element_size, "__hideEverythingExceptGivenElement": __hideEverythingExceptGivenElement, "__inet_ntop4_raw": __inet_ntop4_raw, "__inet_ntop6_raw": __inet_ntop6_raw, "__inet_pton4_raw": __inet_pton4_raw, "__inet_pton6": __inet_pton6, "__inet_pton6_raw": __inet_pton6_raw, "__isLeapYear": __isLeapYear, "__pthread_cleanup_pop": __pthread_cleanup_pop, "__pthread_cleanup_push": __pthread_cleanup_push, "__read_sockaddr": __read_sockaddr, "__reallyNegative": __reallyNegative, "__registerRestoreOldStyle": __registerRestoreOldStyle, "__restoreHiddenElements": __restoreHiddenElements, "__setLetterbox": __setLetterbox, "__set_canvas_element_size": __set_canvas_element_size, "__softFullscreenResizeWebGLRenderTarget": __softFullscreenResizeWebGLRenderTarget, "__write_sockaddr": __write_sockaddr, "_abort": _abort, "_abs": _abs, "_acos": _acos, "_acosf": _acosf, "_acosl": _acosl, "_alBuffer3f": _alBuffer3f, "_alBuffer3i": _alBuffer3i, "_alBufferData": _alBufferData, "_alBufferf": _alBufferf, "_alBufferfv": _alBufferfv, "_alBufferi": _alBufferi, "_alBufferiv": _alBufferiv, "_alDeleteBuffers": _alDeleteBuffers, "_alDeleteSources": _alDeleteSources, "_alDisable": _alDisable, "_alDistanceModel": _alDistanceModel, "_alDopplerFactor": _alDopplerFactor, "_alDopplerVelocity": _alDopplerVelocity, "_alEnable": _alEnable, "_alGenBuffers": _alGenBuffers, "_alGenSources": _alGenSources, "_alGetBoolean": _alGetBoolean, "_alGetBooleanv": _alGetBooleanv, "_alGetBuffer3f": _alGetBuffer3f, "_alGetBuffer3i": _alGetBuffer3i, "_alGetBufferf": _alGetBufferf, "_alGetBufferfv": _alGetBufferfv, "_alGetBufferi": _alGetBufferi, "_alGetBufferiv": _alGetBufferiv, "_alGetDouble": _alGetDouble, "_alGetDoublev": _alGetDoublev, "_alGetEnumValue": _alGetEnumValue, "_alGetError": _alGetError, "_alGetFloat": _alGetFloat, "_alGetFloatv": _alGetFloatv, "_alGetInteger": _alGetInteger, "_alGetIntegerv": _alGetIntegerv, "_alGetListener3f": _alGetListener3f, "_alGetListener3i": _alGetListener3i, "_alGetListenerf": _alGetListenerf, "_alGetListenerfv": _alGetListenerfv, "_alGetListeneri": _alGetListeneri, "_alGetListeneriv": _alGetListeneriv, "_alGetProcAddress": _alGetProcAddress, "_alGetSource3f": _alGetSource3f, "_alGetSource3i": _alGetSource3i, "_alGetSourcef": _alGetSourcef, "_alGetSourcefv": _alGetSourcefv, "_alGetSourcei": _alGetSourcei, "_alGetSourceiv": _alGetSourceiv, "_alGetString": _alGetString, "_alIsBuffer": _alIsBuffer, "_alIsEnabled": _alIsEnabled, "_alIsExtensionPresent": _alIsExtensionPresent, "_alIsSource": _alIsSource, "_alListener3f": _alListener3f, "_alListener3i": _alListener3i, "_alListenerf": _alListenerf, "_alListenerfv": _alListenerfv, "_alListeneri": _alListeneri, "_alListeneriv": _alListeneriv, "_alSource3f": _alSource3f, "_alSource3i": _alSource3i, "_alSourcePause": _alSourcePause, "_alSourcePausev": _alSourcePausev, "_alSourcePlay": _alSourcePlay, "_alSourcePlayv": _alSourcePlayv, "_alSourceQueueBuffers": _alSourceQueueBuffers, "_alSourceRewind": _alSourceRewind, "_alSourceRewindv": _alSourceRewindv, "_alSourceStop": _alSourceStop, "_alSourceStopv": _alSourceStopv, "_alSourceUnqueueBuffers": _alSourceUnqueueBuffers, "_alSourcef": _alSourcef, "_alSourcefv": _alSourcefv, "_alSourcei": _alSourcei, "_alSourceiv": _alSourceiv, "_alSpeedOfSound": _alSpeedOfSound, "_alarm": _alarm, "_alcCaptureCloseDevice": _alcCaptureCloseDevice, "_alcCaptureOpenDevice": _alcCaptureOpenDevice, "_alcCaptureSamples": _alcCaptureSamples, "_alcCaptureStart": _alcCaptureStart, "_alcCaptureStop": _alcCaptureStop, "_alcCloseDevice": _alcCloseDevice, "_alcCreateContext": _alcCreateContext, "_alcDestroyContext": _alcDestroyContext, "_alcGetContextsDevice": _alcGetContextsDevice, "_alcGetCurrentContext": _alcGetCurrentContext, "_alcGetEnumValue": _alcGetEnumValue, "_alcGetError": _alcGetError, "_alcGetIntegerv": _alcGetIntegerv, "_alcGetProcAddress": _alcGetProcAddress, "_alcGetString": _alcGetString, "_alcIsExtensionPresent": _alcIsExtensionPresent, "_alcMakeContextCurrent": _alcMakeContextCurrent, "_alcOpenDevice": _alcOpenDevice, "_alcProcessContext": _alcProcessContext, "_alcSuspendContext": _alcSuspendContext, "_arc4random": _arc4random, "_asctime": _asctime, "_asctime_r": _asctime_r, "_asin": _asin, "_asinf": _asinf, "_asinl": _asinl, "_atan": _atan, "_atan2": _atan2, "_atan2f": _atan2f, "_atan2l": _atan2l, "_atanf": _atanf, "_atanl": _atanl, "_atexit": _atexit, "_boxColor": _boxColor, "_boxRGBA": _boxRGBA, "_ceil": _ceil, "_ceilf": _ceilf, "_ceill": _ceill, "_chroot": _chroot, "_clearenv": _clearenv, "_clock": _clock, "_clock_getcpuclockid": _clock_getcpuclockid, "_clock_getres": _clock_getres, "_clock_gettime": _clock_gettime, "_clock_settime": _clock_settime, "_confstr": _confstr, "_cos": _cos, "_cosf": _cosf, "_cosl": _cosl, "_ctime": _ctime, "_ctime_r": _ctime_r, "_difftime": _difftime, "_dladdr": _dladdr, "_dlclose": _dlclose, "_dlerror": _dlerror, "_dlopen": _dlopen, "_dlsym": _dlsym, "_dysize": _dysize, "_eglBindAPI": _eglBindAPI, "_eglChooseConfig": _eglChooseConfig, "_eglCreateContext": _eglCreateContext, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_eglDestroyContext": _eglDestroyContext, "_eglDestroySurface": _eglDestroySurface, "_eglGetConfigAttrib": _eglGetConfigAttrib, "_eglGetConfigs": _eglGetConfigs, "_eglGetCurrentContext": _eglGetCurrentContext, "_eglGetCurrentDisplay": _eglGetCurrentDisplay, "_eglGetCurrentSurface": _eglGetCurrentSurface, "_eglGetDisplay": _eglGetDisplay, "_eglGetError": _eglGetError, "_eglGetProcAddress": _eglGetProcAddress, "_eglInitialize": _eglInitialize, "_eglMakeCurrent": _eglMakeCurrent, "_eglQueryAPI": _eglQueryAPI, "_eglQueryContext": _eglQueryContext, "_eglQueryString": _eglQueryString, "_eglQuerySurface": _eglQuerySurface, "_eglReleaseThread": _eglReleaseThread, "_eglSwapBuffers": _eglSwapBuffers, "_eglSwapInterval": _eglSwapInterval, "_eglTerminate": _eglTerminate, "_eglWaitClient": _eglWaitClient, "_eglWaitGL": _eglWaitGL, "_eglWaitNative": _eglWaitNative, "_ellipseColor": _ellipseColor, "_ellipseRGBA": _ellipseRGBA, "_emscripten_SDL_SetEventHandler": _emscripten_SDL_SetEventHandler, "_emscripten_alcDevicePauseSOFT": _emscripten_alcDevicePauseSOFT, "_emscripten_alcDeviceResumeSOFT": _emscripten_alcDeviceResumeSOFT, "_emscripten_alcGetStringiSOFT": _emscripten_alcGetStringiSOFT, "_emscripten_alcResetDeviceSOFT": _emscripten_alcResetDeviceSOFT, "_emscripten_async_call": _emscripten_async_call, "_emscripten_async_load_script": _emscripten_async_load_script, "_emscripten_async_run_script": _emscripten_async_run_script, "_emscripten_async_wget": _emscripten_async_wget, "_emscripten_async_wget2": _emscripten_async_wget2, "_emscripten_async_wget2_abort": _emscripten_async_wget2_abort, "_emscripten_async_wget2_data": _emscripten_async_wget2_data, "_emscripten_async_wget_data": _emscripten_async_wget_data, "_emscripten_atomic_add_u32": _emscripten_atomic_add_u32, "_emscripten_atomic_cas_u64": _emscripten_atomic_cas_u64, "_emscripten_atomic_exchange_u64": _emscripten_atomic_exchange_u64, "_emscripten_atomic_load_u64": _emscripten_atomic_load_u64, "_emscripten_atomic_store_u64": _emscripten_atomic_store_u64, "_emscripten_autodebug_double": _emscripten_autodebug_double, "_emscripten_autodebug_float": _emscripten_autodebug_float, "_emscripten_autodebug_i16": _emscripten_autodebug_i16, "_emscripten_autodebug_i32": _emscripten_autodebug_i32, "_emscripten_autodebug_i64": _emscripten_autodebug_i64, "_emscripten_autodebug_i8": _emscripten_autodebug_i8, "_emscripten_call_worker": _emscripten_call_worker, "_emscripten_cancel_main_loop": _emscripten_cancel_main_loop, "_emscripten_coroutine_create": _emscripten_coroutine_create, "_emscripten_coroutine_next": _emscripten_coroutine_next, "_emscripten_create_worker": _emscripten_create_worker, "_emscripten_debugger": _emscripten_debugger, "_emscripten_destroy_worker": _emscripten_destroy_worker, "_emscripten_enter_soft_fullscreen": _emscripten_enter_soft_fullscreen, "_emscripten_exit_fullscreen": _emscripten_exit_fullscreen, "_emscripten_exit_pointerlock": _emscripten_exit_pointerlock, "_emscripten_exit_soft_fullscreen": _emscripten_exit_soft_fullscreen, "_emscripten_exit_with_live_runtime": _emscripten_exit_with_live_runtime, "_emscripten_force_exit": _emscripten_force_exit, "_emscripten_force_num_logical_cores": _emscripten_force_num_logical_cores, "_emscripten_get_battery_status": _emscripten_get_battery_status, "_emscripten_get_callstack": _emscripten_get_callstack, "_emscripten_get_callstack_js": _emscripten_get_callstack_js, "_emscripten_get_canvas_element_size": _emscripten_get_canvas_element_size, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_emscripten_get_compiler_setting": _emscripten_get_compiler_setting, "_emscripten_get_device_pixel_ratio": _emscripten_get_device_pixel_ratio, "_emscripten_get_devicemotion_status": _emscripten_get_devicemotion_status, "_emscripten_get_deviceorientation_status": _emscripten_get_deviceorientation_status, "_emscripten_get_element_css_size": _emscripten_get_element_css_size, "_emscripten_get_fullscreen_status": _emscripten_get_fullscreen_status, "_emscripten_get_gamepad_status": _emscripten_get_gamepad_status, "_emscripten_get_main_loop_timing": _emscripten_get_main_loop_timing, "_emscripten_get_mouse_status": _emscripten_get_mouse_status, "_emscripten_get_now": _emscripten_get_now, "_emscripten_get_now_is_monotonic": _emscripten_get_now_is_monotonic, "_emscripten_get_now_res": _emscripten_get_now_res, "_emscripten_get_num_gamepads": _emscripten_get_num_gamepads, "_emscripten_get_orientation_status": _emscripten_get_orientation_status, "_emscripten_get_pointerlock_status": _emscripten_get_pointerlock_status, "_emscripten_get_preloaded_image_data": _emscripten_get_preloaded_image_data, "_emscripten_get_preloaded_image_data_from_FILE": _emscripten_get_preloaded_image_data_from_FILE, "_emscripten_get_visibility_status": _emscripten_get_visibility_status, "_emscripten_get_worker_queue_size": _emscripten_get_worker_queue_size, "_emscripten_glActiveTexture": _emscripten_glActiveTexture, "_emscripten_glAttachShader": _emscripten_glAttachShader, "_emscripten_glBegin": _emscripten_glBegin, "_emscripten_glBeginQueryEXT": _emscripten_glBeginQueryEXT, "_emscripten_glBindAttribLocation": _emscripten_glBindAttribLocation, "_emscripten_glBindBuffer": _emscripten_glBindBuffer, "_emscripten_glBindFramebuffer": _emscripten_glBindFramebuffer, "_emscripten_glBindRenderbuffer": _emscripten_glBindRenderbuffer, "_emscripten_glBindTexture": _emscripten_glBindTexture, "_emscripten_glBindVertexArray": _emscripten_glBindVertexArray, "_emscripten_glBindVertexArrayOES": _emscripten_glBindVertexArrayOES, "_emscripten_glBlendColor": _emscripten_glBlendColor, "_emscripten_glBlendEquation": _emscripten_glBlendEquation, "_emscripten_glBlendEquationSeparate": _emscripten_glBlendEquationSeparate, "_emscripten_glBlendFunc": _emscripten_glBlendFunc, "_emscripten_glBlendFuncSeparate": _emscripten_glBlendFuncSeparate, "_emscripten_glBufferData": _emscripten_glBufferData, "_emscripten_glBufferSubData": _emscripten_glBufferSubData, "_emscripten_glCheckFramebufferStatus": _emscripten_glCheckFramebufferStatus, "_emscripten_glClear": _emscripten_glClear, "_emscripten_glClearColor": _emscripten_glClearColor, "_emscripten_glClearDepth": _emscripten_glClearDepth, "_emscripten_glClearDepthf": _emscripten_glClearDepthf, "_emscripten_glClearStencil": _emscripten_glClearStencil, "_emscripten_glColorMask": _emscripten_glColorMask, "_emscripten_glCompileShader": _emscripten_glCompileShader, "_emscripten_glCompressedTexImage2D": _emscripten_glCompressedTexImage2D, "_emscripten_glCompressedTexSubImage2D": _emscripten_glCompressedTexSubImage2D, "_emscripten_glCopyTexImage2D": _emscripten_glCopyTexImage2D, "_emscripten_glCopyTexSubImage2D": _emscripten_glCopyTexSubImage2D, "_emscripten_glCreateProgram": _emscripten_glCreateProgram, "_emscripten_glCreateShader": _emscripten_glCreateShader, "_emscripten_glCullFace": _emscripten_glCullFace, "_emscripten_glDeleteBuffers": _emscripten_glDeleteBuffers, "_emscripten_glDeleteFramebuffers": _emscripten_glDeleteFramebuffers, "_emscripten_glDeleteProgram": _emscripten_glDeleteProgram, "_emscripten_glDeleteQueriesEXT": _emscripten_glDeleteQueriesEXT, "_emscripten_glDeleteRenderbuffers": _emscripten_glDeleteRenderbuffers, "_emscripten_glDeleteShader": _emscripten_glDeleteShader, "_emscripten_glDeleteTextures": _emscripten_glDeleteTextures, "_emscripten_glDeleteVertexArrays": _emscripten_glDeleteVertexArrays, "_emscripten_glDeleteVertexArraysOES": _emscripten_glDeleteVertexArraysOES, "_emscripten_glDepthFunc": _emscripten_glDepthFunc, "_emscripten_glDepthMask": _emscripten_glDepthMask, "_emscripten_glDepthRange": _emscripten_glDepthRange, "_emscripten_glDepthRangef": _emscripten_glDepthRangef, "_emscripten_glDetachShader": _emscripten_glDetachShader, "_emscripten_glDisable": _emscripten_glDisable, "_emscripten_glDisableVertexAttribArray": _emscripten_glDisableVertexAttribArray, "_emscripten_glDrawArrays": _emscripten_glDrawArrays, "_emscripten_glDrawArraysInstanced": _emscripten_glDrawArraysInstanced, "_emscripten_glDrawArraysInstancedANGLE": _emscripten_glDrawArraysInstancedANGLE, "_emscripten_glDrawArraysInstancedARB": _emscripten_glDrawArraysInstancedARB, "_emscripten_glDrawArraysInstancedEXT": _emscripten_glDrawArraysInstancedEXT, "_emscripten_glDrawArraysInstancedNV": _emscripten_glDrawArraysInstancedNV, "_emscripten_glDrawBuffers": _emscripten_glDrawBuffers, "_emscripten_glDrawBuffersEXT": _emscripten_glDrawBuffersEXT, "_emscripten_glDrawBuffersWEBGL": _emscripten_glDrawBuffersWEBGL, "_emscripten_glDrawElements": _emscripten_glDrawElements, "_emscripten_glDrawElementsInstanced": _emscripten_glDrawElementsInstanced, "_emscripten_glDrawElementsInstancedANGLE": _emscripten_glDrawElementsInstancedANGLE, "_emscripten_glDrawElementsInstancedARB": _emscripten_glDrawElementsInstancedARB, "_emscripten_glDrawElementsInstancedEXT": _emscripten_glDrawElementsInstancedEXT, "_emscripten_glDrawElementsInstancedNV": _emscripten_glDrawElementsInstancedNV, "_emscripten_glEnable": _emscripten_glEnable, "_emscripten_glEnableVertexAttribArray": _emscripten_glEnableVertexAttribArray, "_emscripten_glEndQueryEXT": _emscripten_glEndQueryEXT, "_emscripten_glFinish": _emscripten_glFinish, "_emscripten_glFlush": _emscripten_glFlush, "_emscripten_glFramebufferRenderbuffer": _emscripten_glFramebufferRenderbuffer, "_emscripten_glFramebufferTexture2D": _emscripten_glFramebufferTexture2D, "_emscripten_glFrontFace": _emscripten_glFrontFace, "_emscripten_glGenBuffers": _emscripten_glGenBuffers, "_emscripten_glGenFramebuffers": _emscripten_glGenFramebuffers, "_emscripten_glGenQueriesEXT": _emscripten_glGenQueriesEXT, "_emscripten_glGenRenderbuffers": _emscripten_glGenRenderbuffers, "_emscripten_glGenTextures": _emscripten_glGenTextures, "_emscripten_glGenVertexArrays": _emscripten_glGenVertexArrays, "_emscripten_glGenVertexArraysOES": _emscripten_glGenVertexArraysOES, "_emscripten_glGenerateMipmap": _emscripten_glGenerateMipmap, "_emscripten_glGetActiveAttrib": _emscripten_glGetActiveAttrib, "_emscripten_glGetActiveUniform": _emscripten_glGetActiveUniform, "_emscripten_glGetAttachedShaders": _emscripten_glGetAttachedShaders, "_emscripten_glGetAttribLocation": _emscripten_glGetAttribLocation, "_emscripten_glGetBooleanv": _emscripten_glGetBooleanv, "_emscripten_glGetBufferParameteriv": _emscripten_glGetBufferParameteriv, "_emscripten_glGetError": _emscripten_glGetError, "_emscripten_glGetFloatv": _emscripten_glGetFloatv, "_emscripten_glGetFramebufferAttachmentParameteriv": _emscripten_glGetFramebufferAttachmentParameteriv, "_emscripten_glGetIntegerv": _emscripten_glGetIntegerv, "_emscripten_glGetProgramInfoLog": _emscripten_glGetProgramInfoLog, "_emscripten_glGetProgramiv": _emscripten_glGetProgramiv, "_emscripten_glGetQueryObjecti64vEXT": _emscripten_glGetQueryObjecti64vEXT, "_emscripten_glGetQueryObjectivEXT": _emscripten_glGetQueryObjectivEXT, "_emscripten_glGetQueryObjectui64vEXT": _emscripten_glGetQueryObjectui64vEXT, "_emscripten_glGetQueryObjectuivEXT": _emscripten_glGetQueryObjectuivEXT, "_emscripten_glGetQueryivEXT": _emscripten_glGetQueryivEXT, "_emscripten_glGetRenderbufferParameteriv": _emscripten_glGetRenderbufferParameteriv, "_emscripten_glGetShaderInfoLog": _emscripten_glGetShaderInfoLog, "_emscripten_glGetShaderPrecisionFormat": _emscripten_glGetShaderPrecisionFormat, "_emscripten_glGetShaderSource": _emscripten_glGetShaderSource, "_emscripten_glGetShaderiv": _emscripten_glGetShaderiv, "_emscripten_glGetString": _emscripten_glGetString, "_emscripten_glGetTexParameterfv": _emscripten_glGetTexParameterfv, "_emscripten_glGetTexParameteriv": _emscripten_glGetTexParameteriv, "_emscripten_glGetUniformLocation": _emscripten_glGetUniformLocation, "_emscripten_glGetUniformfv": _emscripten_glGetUniformfv, "_emscripten_glGetUniformiv": _emscripten_glGetUniformiv, "_emscripten_glGetVertexAttribPointerv": _emscripten_glGetVertexAttribPointerv, "_emscripten_glGetVertexAttribfv": _emscripten_glGetVertexAttribfv, "_emscripten_glGetVertexAttribiv": _emscripten_glGetVertexAttribiv, "_emscripten_glHint": _emscripten_glHint, "_emscripten_glIsBuffer": _emscripten_glIsBuffer, "_emscripten_glIsEnabled": _emscripten_glIsEnabled, "_emscripten_glIsFramebuffer": _emscripten_glIsFramebuffer, "_emscripten_glIsProgram": _emscripten_glIsProgram, "_emscripten_glIsQueryEXT": _emscripten_glIsQueryEXT, "_emscripten_glIsRenderbuffer": _emscripten_glIsRenderbuffer, "_emscripten_glIsShader": _emscripten_glIsShader, "_emscripten_glIsTexture": _emscripten_glIsTexture, "_emscripten_glIsVertexArray": _emscripten_glIsVertexArray, "_emscripten_glIsVertexArrayOES": _emscripten_glIsVertexArrayOES, "_emscripten_glLineWidth": _emscripten_glLineWidth, "_emscripten_glLinkProgram": _emscripten_glLinkProgram, "_emscripten_glLoadIdentity": _emscripten_glLoadIdentity, "_emscripten_glMatrixMode": _emscripten_glMatrixMode, "_emscripten_glPixelStorei": _emscripten_glPixelStorei, "_emscripten_glPolygonOffset": _emscripten_glPolygonOffset, "_emscripten_glQueryCounterEXT": _emscripten_glQueryCounterEXT, "_emscripten_glReadPixels": _emscripten_glReadPixels, "_emscripten_glReleaseShaderCompiler": _emscripten_glReleaseShaderCompiler, "_emscripten_glRenderbufferStorage": _emscripten_glRenderbufferStorage, "_emscripten_glSampleCoverage": _emscripten_glSampleCoverage, "_emscripten_glScissor": _emscripten_glScissor, "_emscripten_glShaderBinary": _emscripten_glShaderBinary, "_emscripten_glShaderSource": _emscripten_glShaderSource, "_emscripten_glStencilFunc": _emscripten_glStencilFunc, "_emscripten_glStencilFuncSeparate": _emscripten_glStencilFuncSeparate, "_emscripten_glStencilMask": _emscripten_glStencilMask, "_emscripten_glStencilMaskSeparate": _emscripten_glStencilMaskSeparate, "_emscripten_glStencilOp": _emscripten_glStencilOp, "_emscripten_glStencilOpSeparate": _emscripten_glStencilOpSeparate, "_emscripten_glTexImage2D": _emscripten_glTexImage2D, "_emscripten_glTexParameterf": _emscripten_glTexParameterf, "_emscripten_glTexParameterfv": _emscripten_glTexParameterfv, "_emscripten_glTexParameteri": _emscripten_glTexParameteri, "_emscripten_glTexParameteriv": _emscripten_glTexParameteriv, "_emscripten_glTexSubImage2D": _emscripten_glTexSubImage2D, "_emscripten_glUniform1f": _emscripten_glUniform1f, "_emscripten_glUniform1fv": _emscripten_glUniform1fv, "_emscripten_glUniform1i": _emscripten_glUniform1i, "_emscripten_glUniform1iv": _emscripten_glUniform1iv, "_emscripten_glUniform2f": _emscripten_glUniform2f, "_emscripten_glUniform2fv": _emscripten_glUniform2fv, "_emscripten_glUniform2i": _emscripten_glUniform2i, "_emscripten_glUniform2iv": _emscripten_glUniform2iv, "_emscripten_glUniform3f": _emscripten_glUniform3f, "_emscripten_glUniform3fv": _emscripten_glUniform3fv, "_emscripten_glUniform3i": _emscripten_glUniform3i, "_emscripten_glUniform3iv": _emscripten_glUniform3iv, "_emscripten_glUniform4f": _emscripten_glUniform4f, "_emscripten_glUniform4fv": _emscripten_glUniform4fv, "_emscripten_glUniform4i": _emscripten_glUniform4i, "_emscripten_glUniform4iv": _emscripten_glUniform4iv, "_emscripten_glUniformMatrix2fv": _emscripten_glUniformMatrix2fv, "_emscripten_glUniformMatrix3fv": _emscripten_glUniformMatrix3fv, "_emscripten_glUniformMatrix4fv": _emscripten_glUniformMatrix4fv, "_emscripten_glUseProgram": _emscripten_glUseProgram, "_emscripten_glValidateProgram": _emscripten_glValidateProgram, "_emscripten_glVertexAttrib1f": _emscripten_glVertexAttrib1f, "_emscripten_glVertexAttrib1fv": _emscripten_glVertexAttrib1fv, "_emscripten_glVertexAttrib2f": _emscripten_glVertexAttrib2f, "_emscripten_glVertexAttrib2fv": _emscripten_glVertexAttrib2fv, "_emscripten_glVertexAttrib3f": _emscripten_glVertexAttrib3f, "_emscripten_glVertexAttrib3fv": _emscripten_glVertexAttrib3fv, "_emscripten_glVertexAttrib4f": _emscripten_glVertexAttrib4f, "_emscripten_glVertexAttrib4fv": _emscripten_glVertexAttrib4fv, "_emscripten_glVertexAttribDivisor": _emscripten_glVertexAttribDivisor, "_emscripten_glVertexAttribDivisorANGLE": _emscripten_glVertexAttribDivisorANGLE, "_emscripten_glVertexAttribDivisorARB": _emscripten_glVertexAttribDivisorARB, "_emscripten_glVertexAttribDivisorEXT": _emscripten_glVertexAttribDivisorEXT, "_emscripten_glVertexAttribDivisorNV": _emscripten_glVertexAttribDivisorNV, "_emscripten_glVertexAttribPointer": _emscripten_glVertexAttribPointer, "_emscripten_glVertexPointer": _emscripten_glVertexPointer, "_emscripten_glViewport": _emscripten_glViewport, "_emscripten_gluLookAt": _emscripten_gluLookAt, "_emscripten_gluOrtho2D": _emscripten_gluOrtho2D, "_emscripten_gluPerspective": _emscripten_gluPerspective, "_emscripten_gluProject": _emscripten_gluProject, "_emscripten_gluUnProject": _emscripten_gluUnProject, "_emscripten_has_threading_support": _emscripten_has_threading_support, "_emscripten_hide_mouse": _emscripten_hide_mouse, "_emscripten_html5_remove_all_event_listeners": _emscripten_html5_remove_all_event_listeners, "_emscripten_idb_async_delete": _emscripten_idb_async_delete, "_emscripten_idb_async_exists": _emscripten_idb_async_exists, "_emscripten_idb_async_load": _emscripten_idb_async_load, "_emscripten_idb_async_store": _emscripten_idb_async_store, "_emscripten_idb_delete": _emscripten_idb_delete, "_emscripten_idb_exists": _emscripten_idb_exists, "_emscripten_idb_load": _emscripten_idb_load, "_emscripten_idb_store": _emscripten_idb_store, "_emscripten_is_main_browser_thread": _emscripten_is_main_browser_thread, "_emscripten_is_main_runtime_thread": _emscripten_is_main_runtime_thread, "_emscripten_is_webgl_context_lost": _emscripten_is_webgl_context_lost, "_emscripten_lock_orientation": _emscripten_lock_orientation, "_emscripten_log": _emscripten_log, "_emscripten_log_js": _emscripten_log_js, "_emscripten_longjmp": _emscripten_longjmp, "_emscripten_main_browser_thread_id": _emscripten_main_browser_thread_id, "_emscripten_main_thread_process_queued_calls": _emscripten_main_thread_process_queued_calls, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_emscripten_num_logical_cores": _emscripten_num_logical_cores, "_emscripten_pause_main_loop": _emscripten_pause_main_loop, "_emscripten_print_double": _emscripten_print_double, "_emscripten_random": _emscripten_random, "_emscripten_request_fullscreen": _emscripten_request_fullscreen, "_emscripten_request_fullscreen_strategy": _emscripten_request_fullscreen_strategy, "_emscripten_request_pointerlock": _emscripten_request_pointerlock, "_emscripten_resume_main_loop": _emscripten_resume_main_loop, "_emscripten_run_preload_plugins": _emscripten_run_preload_plugins, "_emscripten_run_preload_plugins_data": _emscripten_run_preload_plugins_data, "_emscripten_run_script": _emscripten_run_script, "_emscripten_run_script_int": _emscripten_run_script_int, "_emscripten_run_script_string": _emscripten_run_script_string, "_emscripten_set_batterychargingchange_callback_on_thread": _emscripten_set_batterychargingchange_callback_on_thread, "_emscripten_set_batterylevelchange_callback_on_thread": _emscripten_set_batterylevelchange_callback_on_thread, "_emscripten_set_beforeunload_callback_on_thread": _emscripten_set_beforeunload_callback_on_thread, "_emscripten_set_blur_callback_on_thread": _emscripten_set_blur_callback_on_thread, "_emscripten_set_canvas_element_size": _emscripten_set_canvas_element_size, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_emscripten_set_click_callback_on_thread": _emscripten_set_click_callback_on_thread, "_emscripten_set_dblclick_callback_on_thread": _emscripten_set_dblclick_callback_on_thread, "_emscripten_set_devicemotion_callback_on_thread": _emscripten_set_devicemotion_callback_on_thread, "_emscripten_set_deviceorientation_callback_on_thread": _emscripten_set_deviceorientation_callback_on_thread, "_emscripten_set_element_css_size": _emscripten_set_element_css_size, "_emscripten_set_focus_callback_on_thread": _emscripten_set_focus_callback_on_thread, "_emscripten_set_focusin_callback_on_thread": _emscripten_set_focusin_callback_on_thread, "_emscripten_set_focusout_callback_on_thread": _emscripten_set_focusout_callback_on_thread, "_emscripten_set_fullscreenchange_callback_on_thread": _emscripten_set_fullscreenchange_callback_on_thread, "_emscripten_set_gamepadconnected_callback_on_thread": _emscripten_set_gamepadconnected_callback_on_thread, "_emscripten_set_gamepaddisconnected_callback_on_thread": _emscripten_set_gamepaddisconnected_callback_on_thread, "_emscripten_set_keydown_callback_on_thread": _emscripten_set_keydown_callback_on_thread, "_emscripten_set_keypress_callback_on_thread": _emscripten_set_keypress_callback_on_thread, "_emscripten_set_keyup_callback_on_thread": _emscripten_set_keyup_callback_on_thread, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_emscripten_set_main_loop_arg": _emscripten_set_main_loop_arg, "_emscripten_set_main_loop_expected_blockers": _emscripten_set_main_loop_expected_blockers, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "_emscripten_set_mousedown_callback_on_thread": _emscripten_set_mousedown_callback_on_thread, "_emscripten_set_mouseenter_callback_on_thread": _emscripten_set_mouseenter_callback_on_thread, "_emscripten_set_mouseleave_callback_on_thread": _emscripten_set_mouseleave_callback_on_thread, "_emscripten_set_mousemove_callback_on_thread": _emscripten_set_mousemove_callback_on_thread, "_emscripten_set_mouseout_callback_on_thread": _emscripten_set_mouseout_callback_on_thread, "_emscripten_set_mouseover_callback_on_thread": _emscripten_set_mouseover_callback_on_thread, "_emscripten_set_mouseup_callback_on_thread": _emscripten_set_mouseup_callback_on_thread, "_emscripten_set_orientationchange_callback_on_thread": _emscripten_set_orientationchange_callback_on_thread, "_emscripten_set_pointerlockchange_callback_on_thread": _emscripten_set_pointerlockchange_callback_on_thread, "_emscripten_set_pointerlockerror_callback_on_thread": _emscripten_set_pointerlockerror_callback_on_thread, "_emscripten_set_resize_callback_on_thread": _emscripten_set_resize_callback_on_thread, "_emscripten_set_scroll_callback_on_thread": _emscripten_set_scroll_callback_on_thread, "_emscripten_set_socket_close_callback": _emscripten_set_socket_close_callback, "_emscripten_set_socket_connection_callback": _emscripten_set_socket_connection_callback, "_emscripten_set_socket_error_callback": _emscripten_set_socket_error_callback, "_emscripten_set_socket_listen_callback": _emscripten_set_socket_listen_callback, "_emscripten_set_socket_message_callback": _emscripten_set_socket_message_callback, "_emscripten_set_socket_open_callback": _emscripten_set_socket_open_callback, "_emscripten_set_touchcancel_callback_on_thread": _emscripten_set_touchcancel_callback_on_thread, "_emscripten_set_touchend_callback_on_thread": _emscripten_set_touchend_callback_on_thread, "_emscripten_set_touchmove_callback_on_thread": _emscripten_set_touchmove_callback_on_thread, "_emscripten_set_touchstart_callback_on_thread": _emscripten_set_touchstart_callback_on_thread, "_emscripten_set_visibilitychange_callback_on_thread": _emscripten_set_visibilitychange_callback_on_thread, "_emscripten_set_webglcontextlost_callback_on_thread": _emscripten_set_webglcontextlost_callback_on_thread, "_emscripten_set_webglcontextrestored_callback_on_thread": _emscripten_set_webglcontextrestored_callback_on_thread, "_emscripten_set_wheel_callback_on_thread": _emscripten_set_wheel_callback_on_thread, "_emscripten_sleep": _emscripten_sleep, "_emscripten_supports_offscreencanvas": _emscripten_supports_offscreencanvas, "_emscripten_unlock_orientation": _emscripten_unlock_orientation, "_emscripten_vibrate": _emscripten_vibrate, "_emscripten_vibrate_pattern": _emscripten_vibrate_pattern, "_emscripten_vr_cancel_display_render_loop": _emscripten_vr_cancel_display_render_loop, "_emscripten_vr_count_displays": _emscripten_vr_count_displays, "_emscripten_vr_deinit": _emscripten_vr_deinit, "_emscripten_vr_display_connected": _emscripten_vr_display_connected, "_emscripten_vr_display_presenting": _emscripten_vr_display_presenting, "_emscripten_vr_exit_present": _emscripten_vr_exit_present, "_emscripten_vr_get_display_capabilities": _emscripten_vr_get_display_capabilities, "_emscripten_vr_get_display_handle": _emscripten_vr_get_display_handle, "_emscripten_vr_get_display_name": _emscripten_vr_get_display_name, "_emscripten_vr_get_eye_parameters": _emscripten_vr_get_eye_parameters, "_emscripten_vr_get_frame_data": _emscripten_vr_get_frame_data, "_emscripten_vr_init": _emscripten_vr_init, "_emscripten_vr_ready": _emscripten_vr_ready, "_emscripten_vr_request_present": _emscripten_vr_request_present, "_emscripten_vr_set_display_render_loop": _emscripten_vr_set_display_render_loop, "_emscripten_vr_set_display_render_loop_arg": _emscripten_vr_set_display_render_loop_arg, "_emscripten_vr_submit_frame": _emscripten_vr_submit_frame, "_emscripten_vr_version_major": _emscripten_vr_version_major, "_emscripten_vr_version_minor": _emscripten_vr_version_minor, "_emscripten_webgl_commit_frame": _emscripten_webgl_commit_frame, "_emscripten_webgl_create_context": _emscripten_webgl_create_context, "_emscripten_webgl_destroy_context": _emscripten_webgl_destroy_context, "_emscripten_webgl_destroy_context_calling_thread": _emscripten_webgl_destroy_context_calling_thread, "_emscripten_webgl_do_commit_frame": _emscripten_webgl_do_commit_frame, "_emscripten_webgl_do_create_context": _emscripten_webgl_do_create_context, "_emscripten_webgl_do_get_current_context": _emscripten_webgl_do_get_current_context, "_emscripten_webgl_enable_extension": _emscripten_webgl_enable_extension, "_emscripten_webgl_enable_extension_calling_thread": _emscripten_webgl_enable_extension_calling_thread, "_emscripten_webgl_get_current_context": _emscripten_webgl_get_current_context, "_emscripten_webgl_get_drawing_buffer_size": _emscripten_webgl_get_drawing_buffer_size, "_emscripten_webgl_get_drawing_buffer_size_calling_thread": _emscripten_webgl_get_drawing_buffer_size_calling_thread, "_emscripten_webgl_init_context_attributes": _emscripten_webgl_init_context_attributes, "_emscripten_webgl_make_context_current": _emscripten_webgl_make_context_current, "_emscripten_wget": _emscripten_wget, "_emscripten_wget_data": _emscripten_wget_data, "_emscripten_worker_respond": _emscripten_worker_respond, "_emscripten_worker_respond_provisionally": _emscripten_worker_respond_provisionally, "_emscripten_yield": _emscripten_yield, "_endprotoent": _endprotoent, "_endpwent": _endpwent, "_execl": _execl, "_execle": _execle, "_execlp": _execlp, "_execv": _execv, "_execve": _execve, "_execvp": _execvp, "_exit": _exit, "_exp": _exp, "_expf": _expf, "_expl": _expl, "_fabs": _fabs, "_fabsf": _fabsf, "_fabsl": _fabsl, "_fexecve": _fexecve, "_filledEllipseColor": _filledEllipseColor, "_filledEllipseRGBA": _filledEllipseRGBA, "_flock": _flock, "_floor": _floor, "_floorf": _floorf, "_floorl": _floorl, "_fork": _fork, "_fpathconf": _fpathconf, "_ftime": _ftime, "_gai_strerror": _gai_strerror, "_getaddrinfo": _getaddrinfo, "_getdate": _getdate, "_getenv": _getenv, "_gethostbyaddr": _gethostbyaddr, "_gethostbyname": _gethostbyname, "_gethostbyname_r": _gethostbyname_r, "_getitimer": _getitimer, "_getloadavg": _getloadavg, "_getnameinfo": _getnameinfo, "_getpagesize": _getpagesize, "_getprotobyname": _getprotobyname, "_getprotobynumber": _getprotobynumber, "_getprotoent": _getprotoent, "_getpwent": _getpwent, "_getpwnam": _getpwnam, "_getpwuid": _getpwuid, "_gettimeofday": _gettimeofday, "_glActiveTexture": _glActiveTexture, "_glAttachShader": _glAttachShader, "_glBegin": _glBegin, "_glBeginQueryEXT": _glBeginQueryEXT, "_glBindAttribLocation": _glBindAttribLocation, "_glBindBuffer": _glBindBuffer, "_glBindFramebuffer": _glBindFramebuffer, "_glBindRenderbuffer": _glBindRenderbuffer, "_glBindTexture": _glBindTexture, "_glBindVertexArray": _glBindVertexArray, "_glBindVertexArrayOES": _glBindVertexArrayOES, "_glBlendColor": _glBlendColor, "_glBlendEquation": _glBlendEquation, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_glBlendFunc": _glBlendFunc, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_glBufferData": _glBufferData, "_glBufferSubData": _glBufferSubData, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "_glClear": _glClear, "_glClearColor": _glClearColor, "_glClearDepth": _glClearDepth, "_glClearDepthf": _glClearDepthf, "_glClearStencil": _glClearStencil, "_glColorMask": _glColorMask, "_glCompileShader": _glCompileShader, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_glCopyTexImage2D": _glCopyTexImage2D, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_glCreateProgram": _glCreateProgram, "_glCreateShader": _glCreateShader, "_glCullFace": _glCullFace, "_glDeleteBuffers": _glDeleteBuffers, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_glDeleteProgram": _glDeleteProgram, "_glDeleteQueriesEXT": _glDeleteQueriesEXT, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glDeleteShader": _glDeleteShader, "_glDeleteTextures": _glDeleteTextures, "_glDeleteVertexArrays": _glDeleteVertexArrays, "_glDeleteVertexArraysOES": _glDeleteVertexArraysOES, "_glDepthFunc": _glDepthFunc, "_glDepthMask": _glDepthMask, "_glDepthRange": _glDepthRange, "_glDepthRangef": _glDepthRangef, "_glDetachShader": _glDetachShader, "_glDisable": _glDisable, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glDrawArrays": _glDrawArrays, "_glDrawArraysInstanced": _glDrawArraysInstanced, "_glDrawArraysInstancedANGLE": _glDrawArraysInstancedANGLE, "_glDrawArraysInstancedARB": _glDrawArraysInstancedARB, "_glDrawArraysInstancedEXT": _glDrawArraysInstancedEXT, "_glDrawArraysInstancedNV": _glDrawArraysInstancedNV, "_glDrawBuffers": _glDrawBuffers, "_glDrawBuffersEXT": _glDrawBuffersEXT, "_glDrawBuffersWEBGL": _glDrawBuffersWEBGL, "_glDrawElements": _glDrawElements, "_glDrawElementsInstanced": _glDrawElementsInstanced, "_glDrawElementsInstancedANGLE": _glDrawElementsInstancedANGLE, "_glDrawElementsInstancedARB": _glDrawElementsInstancedARB, "_glDrawElementsInstancedEXT": _glDrawElementsInstancedEXT, "_glDrawElementsInstancedNV": _glDrawElementsInstancedNV, "_glEnable": _glEnable, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_glEndQueryEXT": _glEndQueryEXT, "_glFinish": _glFinish, "_glFlush": _glFlush, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glFrontFace": _glFrontFace, "_glGenBuffers": _glGenBuffers, "_glGenFramebuffers": _glGenFramebuffers, "_glGenQueriesEXT": _glGenQueriesEXT, "_glGenRenderbuffers": _glGenRenderbuffers, "_glGenTextures": _glGenTextures, "_glGenVertexArrays": _glGenVertexArrays, "_glGenVertexArraysOES": _glGenVertexArraysOES, "_glGenerateMipmap": _glGenerateMipmap, "_glGetActiveAttrib": _glGetActiveAttrib, "_glGetActiveUniform": _glGetActiveUniform, "_glGetAttachedShaders": _glGetAttachedShaders, "_glGetAttribLocation": _glGetAttribLocation, "_glGetBooleanv": _glGetBooleanv, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glGetError": _glGetError, "_glGetFloatv": _glGetFloatv, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glGetIntegerv": _glGetIntegerv, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glGetProgramiv": _glGetProgramiv, "_glGetQueryObjecti64vEXT": _glGetQueryObjecti64vEXT, "_glGetQueryObjectivEXT": _glGetQueryObjectivEXT, "_glGetQueryObjectui64vEXT": _glGetQueryObjectui64vEXT, "_glGetQueryObjectuivEXT": _glGetQueryObjectuivEXT, "_glGetQueryivEXT": _glGetQueryivEXT, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glGetShaderSource": _glGetShaderSource, "_glGetShaderiv": _glGetShaderiv, "_glGetString": _glGetString, "_glGetTexParameterfv": _glGetTexParameterfv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glGetUniformLocation": _glGetUniformLocation, "_glGetUniformfv": _glGetUniformfv, "_glGetUniformiv": _glGetUniformiv, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glHint": _glHint, "_glIsBuffer": _glIsBuffer, "_glIsEnabled": _glIsEnabled, "_glIsFramebuffer": _glIsFramebuffer, "_glIsProgram": _glIsProgram, "_glIsQueryEXT": _glIsQueryEXT, "_glIsRenderbuffer": _glIsRenderbuffer, "_glIsShader": _glIsShader, "_glIsTexture": _glIsTexture, "_glIsVertexArray": _glIsVertexArray, "_glIsVertexArrayOES": _glIsVertexArrayOES, "_glLineWidth": _glLineWidth, "_glLinkProgram": _glLinkProgram, "_glLoadIdentity": _glLoadIdentity, "_glMatrixMode": _glMatrixMode, "_glPixelStorei": _glPixelStorei, "_glPolygonOffset": _glPolygonOffset, "_glQueryCounterEXT": _glQueryCounterEXT, "_glReadPixels": _glReadPixels, "_glReleaseShaderCompiler": _glReleaseShaderCompiler, "_glRenderbufferStorage": _glRenderbufferStorage, "_glSampleCoverage": _glSampleCoverage, "_glScissor": _glScissor, "_glShaderBinary": _glShaderBinary, "_glShaderSource": _glShaderSource, "_glStencilFunc": _glStencilFunc, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_glStencilMask": _glStencilMask, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glStencilOp": _glStencilOp, "_glStencilOpSeparate": _glStencilOpSeparate, "_glTexImage2D": _glTexImage2D, "_glTexParameterf": _glTexParameterf, "_glTexParameterfv": _glTexParameterfv, "_glTexParameteri": _glTexParameteri, "_glTexParameteriv": _glTexParameteriv, "_glTexSubImage2D": _glTexSubImage2D, "_glUniform1f": _glUniform1f, "_glUniform1fv": _glUniform1fv, "_glUniform1i": _glUniform1i, "_glUniform1iv": _glUniform1iv, "_glUniform2f": _glUniform2f, "_glUniform2fv": _glUniform2fv, "_glUniform2i": _glUniform2i, "_glUniform2iv": _glUniform2iv, "_glUniform3f": _glUniform3f, "_glUniform3fv": _glUniform3fv, "_glUniform3i": _glUniform3i, "_glUniform3iv": _glUniform3iv, "_glUniform4f": _glUniform4f, "_glUniform4fv": _glUniform4fv, "_glUniform4i": _glUniform4i, "_glUniform4iv": _glUniform4iv, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glUseProgram": _glUseProgram, "_glValidateProgram": _glValidateProgram, "_glVertexAttrib1f": _glVertexAttrib1f, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glVertexAttrib2f": _glVertexAttrib2f, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_glVertexAttrib3f": _glVertexAttrib3f, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glVertexAttrib4f": _glVertexAttrib4f, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glVertexAttribDivisor": _glVertexAttribDivisor, "_glVertexAttribDivisorANGLE": _glVertexAttribDivisorANGLE, "_glVertexAttribDivisorARB": _glVertexAttribDivisorARB, "_glVertexAttribDivisorEXT": _glVertexAttribDivisorEXT, "_glVertexAttribDivisorNV": _glVertexAttribDivisorNV, "_glVertexAttribPointer": _glVertexAttribPointer, "_glVertexPointer": _glVertexPointer, "_glViewport": _glViewport, "_glewGetErrorString": _glewGetErrorString, "_glewGetExtension": _glewGetExtension, "_glewGetString": _glewGetString, "_glewInit": _glewInit, "_glewIsSupported": _glewIsSupported, "_glfwBroadcastCond": _glfwBroadcastCond, "_glfwCloseWindow": _glfwCloseWindow, "_glfwCreateCond": _glfwCreateCond, "_glfwCreateMutex": _glfwCreateMutex, "_glfwCreateThread": _glfwCreateThread, "_glfwDestroyCond": _glfwDestroyCond, "_glfwDestroyMutex": _glfwDestroyMutex, "_glfwDestroyThread": _glfwDestroyThread, "_glfwDisable": _glfwDisable, "_glfwEnable": _glfwEnable, "_glfwExtensionSupported": _glfwExtensionSupported, "_glfwFreeImage": _glfwFreeImage, "_glfwGetDesktopMode": _glfwGetDesktopMode, "_glfwGetGLVersion": _glfwGetGLVersion, "_glfwGetKey": _glfwGetKey, "_glfwGetMouseButton": _glfwGetMouseButton, "_glfwGetMousePos": _glfwGetMousePos, "_glfwGetMouseWheel": _glfwGetMouseWheel, "_glfwGetNumberOfProcessors": _glfwGetNumberOfProcessors, "_glfwGetProcAddress": _glfwGetProcAddress, "_glfwGetThreadID": _glfwGetThreadID, "_glfwGetTime": _glfwGetTime, "_glfwGetVersion": _glfwGetVersion, "_glfwGetWindowParam": _glfwGetWindowParam, "_glfwGetWindowPos": _glfwGetWindowPos, "_glfwGetWindowSize": _glfwGetWindowSize, "_glfwIconifyWindow": _glfwIconifyWindow, "_glfwInit": _glfwInit, "_glfwLoadMemoryTexture2D": _glfwLoadMemoryTexture2D, "_glfwLoadTexture2D": _glfwLoadTexture2D, "_glfwLoadTextureImage2D": _glfwLoadTextureImage2D, "_glfwLockMutex": _glfwLockMutex, "_glfwOpenWindow": _glfwOpenWindow, "_glfwOpenWindowHint": _glfwOpenWindowHint, "_glfwPollEvents": _glfwPollEvents, "_glfwReadImage": _glfwReadImage, "_glfwReadMemoryImage": _glfwReadMemoryImage, "_glfwRestoreWindow": _glfwRestoreWindow, "_glfwSetCharCallback": _glfwSetCharCallback, "_glfwSetKeyCallback": _glfwSetKeyCallback, "_glfwSetMouseButtonCallback": _glfwSetMouseButtonCallback, "_glfwSetMousePos": _glfwSetMousePos, "_glfwSetMousePosCallback": _glfwSetMousePosCallback, "_glfwSetMouseWheel": _glfwSetMouseWheel, "_glfwSetMouseWheelCallback": _glfwSetMouseWheelCallback, "_glfwSetTime": _glfwSetTime, "_glfwSetWindowCloseCallback": _glfwSetWindowCloseCallback, "_glfwSetWindowPos": _glfwSetWindowPos, "_glfwSetWindowRefreshCallback": _glfwSetWindowRefreshCallback, "_glfwSetWindowSize": _glfwSetWindowSize, "_glfwSetWindowSizeCallback": _glfwSetWindowSizeCallback, "_glfwSetWindowTitle": _glfwSetWindowTitle, "_glfwSignalCond": _glfwSignalCond, "_glfwSleep": _glfwSleep, "_glfwSwapBuffers": _glfwSwapBuffers, "_glfwSwapInterval": _glfwSwapInterval, "_glfwTerminate": _glfwTerminate, "_glfwUnlockMutex": _glfwUnlockMutex, "_glfwWaitCond": _glfwWaitCond, "_glfwWaitEvents": _glfwWaitEvents, "_glfwWaitThread": _glfwWaitThread, "_gluLookAt": _gluLookAt, "_gluOrtho2D": _gluOrtho2D, "_gluPerspective": _gluPerspective, "_gluProject": _gluProject, "_gluUnProject": _gluUnProject, "_glutCreateWindow": _glutCreateWindow, "_glutDestroyWindow": _glutDestroyWindow, "_glutDisplayFunc": _glutDisplayFunc, "_glutFullScreen": _glutFullScreen, "_glutGet": _glutGet, "_glutGetModifiers": _glutGetModifiers, "_glutIdleFunc": _glutIdleFunc, "_glutInit": _glutInit, "_glutInitDisplayMode": _glutInitDisplayMode, "_glutInitWindowPosition": _glutInitWindowPosition, "_glutInitWindowSize": _glutInitWindowSize, "_glutKeyboardFunc": _glutKeyboardFunc, "_glutKeyboardUpFunc": _glutKeyboardUpFunc, "_glutMainLoop": _glutMainLoop, "_glutMotionFunc": _glutMotionFunc, "_glutMouseFunc": _glutMouseFunc, "_glutPassiveMotionFunc": _glutPassiveMotionFunc, "_glutPositionWindow": _glutPositionWindow, "_glutPostRedisplay": _glutPostRedisplay, "_glutReshapeFunc": _glutReshapeFunc, "_glutReshapeWindow": _glutReshapeWindow, "_glutSetCursor": _glutSetCursor, "_glutSpecialFunc": _glutSpecialFunc, "_glutSpecialUpFunc": _glutSpecialUpFunc, "_glutSwapBuffers": _glutSwapBuffers, "_glutTimerFunc": _glutTimerFunc, "_gmtime": _gmtime, "_gmtime_r": _gmtime_r, "_gnu_dev_major": _gnu_dev_major, "_gnu_dev_makedev": _gnu_dev_makedev, "_gnu_dev_minor": _gnu_dev_minor, "_inet_addr": _inet_addr, "_kfunc1": _kfunc1, "_kill": _kill, "_killpg": _killpg, "_lineColor": _lineColor, "_lineRGBA": _lineRGBA, "_llvm_atomic_load_add_i32_p0i32": _llvm_atomic_load_add_i32_p0i32, "_llvm_bswap_i64": _llvm_bswap_i64, "_llvm_ceil_f32": _llvm_ceil_f32, "_llvm_ceil_f64": _llvm_ceil_f64, "_llvm_copysign_f32": _llvm_copysign_f32, "_llvm_copysign_f64": _llvm_copysign_f64, "_llvm_cos_f32": _llvm_cos_f32, "_llvm_cos_f64": _llvm_cos_f64, "_llvm_cttz_i64": _llvm_cttz_i64, "_llvm_eh_exception": _llvm_eh_exception, "_llvm_eh_selector": _llvm_eh_selector, "_llvm_eh_typeid_for": _llvm_eh_typeid_for, "_llvm_exp2_f32": _llvm_exp2_f32, "_llvm_exp2_f64": _llvm_exp2_f64, "_llvm_exp_f32": _llvm_exp_f32, "_llvm_exp_f64": _llvm_exp_f64, "_llvm_fabs_f32": _llvm_fabs_f32, "_llvm_fabs_f64": _llvm_fabs_f64, "_llvm_floor_f32": _llvm_floor_f32, "_llvm_floor_f64": _llvm_floor_f64, "_llvm_flt_rounds": _llvm_flt_rounds, "_llvm_log10_f32": _llvm_log10_f32, "_llvm_log10_f64": _llvm_log10_f64, "_llvm_log2_f32": _llvm_log2_f32, "_llvm_log2_f64": _llvm_log2_f64, "_llvm_log_f32": _llvm_log_f32, "_llvm_log_f64": _llvm_log_f64, "_llvm_memory_barrier": _llvm_memory_barrier, "_llvm_mono_load_i16_p0i16": _llvm_mono_load_i16_p0i16, "_llvm_mono_load_i32_p0i32": _llvm_mono_load_i32_p0i32, "_llvm_mono_load_i8_p0i8": _llvm_mono_load_i8_p0i8, "_llvm_mono_store_i16_p0i16": _llvm_mono_store_i16_p0i16, "_llvm_mono_store_i32_p0i32": _llvm_mono_store_i32_p0i32, "_llvm_mono_store_i8_p0i8": _llvm_mono_store_i8_p0i8, "_llvm_objectsize_i32": _llvm_objectsize_i32, "_llvm_pow_f32": _llvm_pow_f32, "_llvm_pow_f64": _llvm_pow_f64, "_llvm_powi_f32": _llvm_powi_f32, "_llvm_powi_f64": _llvm_powi_f64, "_llvm_prefetch": _llvm_prefetch, "_llvm_sin_f32": _llvm_sin_f32, "_llvm_sin_f64": _llvm_sin_f64, "_llvm_sqrt_f32": _llvm_sqrt_f32, "_llvm_sqrt_f64": _llvm_sqrt_f64, "_llvm_stackrestore": _llvm_stackrestore, "_llvm_stacksave": _llvm_stacksave, "_llvm_trap": _llvm_trap, "_llvm_trunc_f32": _llvm_trunc_f32, "_llvm_trunc_f64": _llvm_trunc_f64, "_llvm_va_copy": _llvm_va_copy, "_llvm_va_end": _llvm_va_end, "_localtime": _localtime, "_localtime_r": _localtime_r, "_log": _log, "_logf": _logf, "_logl": _logl, "_longjmp": _longjmp, "_major": _major, "_makedev": _makedev, "_minor": _minor, "_mktime": _mktime, "_nanosleep": _nanosleep, "_pathconf": _pathconf, "_pixelRGBA": _pixelRGBA, "_posix_spawn": _posix_spawn, "_posix_spawnp": _posix_spawnp, "_pow": _pow, "_powf": _powf, "_powl": _powl, "_pthread_attr_destroy": _pthread_attr_destroy, "_pthread_attr_getstack": _pthread_attr_getstack, "_pthread_attr_init": _pthread_attr_init, "_pthread_attr_setdetachstate": _pthread_attr_setdetachstate, "_pthread_attr_setschedparam": _pthread_attr_setschedparam, "_pthread_attr_setstacksize": _pthread_attr_setstacksize, "_pthread_barrier_destroy": _pthread_barrier_destroy, "_pthread_barrier_init": _pthread_barrier_init, "_pthread_barrier_wait": _pthread_barrier_wait, "_pthread_cancel": _pthread_cancel, "_pthread_cleanup_pop": _pthread_cleanup_pop, "_pthread_cleanup_push": _pthread_cleanup_push, "_pthread_cond_destroy": _pthread_cond_destroy, "_pthread_cond_init": _pthread_cond_init, "_pthread_cond_signal": _pthread_cond_signal, "_pthread_cond_timedwait": _pthread_cond_timedwait, "_pthread_cond_wait": _pthread_cond_wait, "_pthread_condattr_destroy": _pthread_condattr_destroy, "_pthread_condattr_getclock": _pthread_condattr_getclock, "_pthread_condattr_getpshared": _pthread_condattr_getpshared, "_pthread_condattr_init": _pthread_condattr_init, "_pthread_condattr_setclock": _pthread_condattr_setclock, "_pthread_condattr_setpshared": _pthread_condattr_setpshared, "_pthread_create": _pthread_create, "_pthread_detach": _pthread_detach, "_pthread_equal": _pthread_equal, "_pthread_exit": _pthread_exit, "_pthread_getattr_np": _pthread_getattr_np, "_pthread_getspecific": _pthread_getspecific, "_pthread_join": _pthread_join, "_pthread_key_create": _pthread_key_create, "_pthread_key_delete": _pthread_key_delete, "_pthread_mutex_destroy": _pthread_mutex_destroy, "_pthread_mutex_init": _pthread_mutex_init, "_pthread_mutexattr_destroy": _pthread_mutexattr_destroy, "_pthread_mutexattr_init": _pthread_mutexattr_init, "_pthread_mutexattr_setprotocol": _pthread_mutexattr_setprotocol, "_pthread_mutexattr_setpshared": _pthread_mutexattr_setpshared, "_pthread_mutexattr_setschedparam": _pthread_mutexattr_setschedparam, "_pthread_mutexattr_settype": _pthread_mutexattr_settype, "_pthread_once": _pthread_once, "_pthread_rwlock_destroy": _pthread_rwlock_destroy, "_pthread_rwlock_init": _pthread_rwlock_init, "_pthread_rwlock_rdlock": _pthread_rwlock_rdlock, "_pthread_rwlock_timedrdlock": _pthread_rwlock_timedrdlock, "_pthread_rwlock_timedwrlock": _pthread_rwlock_timedwrlock, "_pthread_rwlock_tryrdlock": _pthread_rwlock_tryrdlock, "_pthread_rwlock_trywrlock": _pthread_rwlock_trywrlock, "_pthread_rwlock_unlock": _pthread_rwlock_unlock, "_pthread_rwlock_wrlock": _pthread_rwlock_wrlock, "_pthread_rwlockattr_destroy": _pthread_rwlockattr_destroy, "_pthread_rwlockattr_getpshared": _pthread_rwlockattr_getpshared, "_pthread_rwlockattr_init": _pthread_rwlockattr_init, "_pthread_rwlockattr_setpshared": _pthread_rwlockattr_setpshared, "_pthread_setcancelstate": _pthread_setcancelstate, "_pthread_setspecific": _pthread_setspecific, "_pthread_sigmask": _pthread_sigmask, "_pthread_spin_destroy": _pthread_spin_destroy, "_pthread_spin_init": _pthread_spin_init, "_pthread_spin_lock": _pthread_spin_lock, "_pthread_spin_trylock": _pthread_spin_trylock, "_pthread_spin_unlock": _pthread_spin_unlock, "_putenv": _putenv, "_raise": _raise, "_rectangleColor": _rectangleColor, "_rectangleRGBA": _rectangleRGBA, "_rotozoomSurface": _rotozoomSurface, "_sched_yield": _sched_yield, "_sem_destroy": _sem_destroy, "_sem_init": _sem_init, "_sem_post": _sem_post, "_sem_trywait": _sem_trywait, "_sem_wait": _sem_wait, "_setenv": _setenv, "_setgroups": _setgroups, "_setitimer": _setitimer, "_setprotoent": _setprotoent, "_setpwent": _setpwent, "_sigaction": _sigaction, "_sigaddset": _sigaddset, "_sigdelset": _sigdelset, "_sigemptyset": _sigemptyset, "_sigfillset": _sigfillset, "_siginterrupt": _siginterrupt, "_sigismember": _sigismember, "_siglongjmp": _siglongjmp, "_signal": _signal, "_sigpending": _sigpending, "_sigprocmask": _sigprocmask, "_sin": _sin, "_sinf": _sinf, "_sinl": _sinl, "_sqrt": _sqrt, "_sqrtf": _sqrtf, "_sqrtl": _sqrtl, "_stime": _stime, "_strftime": _strftime, "_strftime_l": _strftime_l, "_strptime": _strptime, "_strptime_l": _strptime_l, "_sysconf": _sysconf, "_system": _system, "_tan": _tan, "_tanf": _tanf, "_tanl": _tanl, "_terminate": _terminate, "_time": _time, "_timegm": _timegm, "_timelocal": _timelocal, "_times": _times, "_timespec_get": _timespec_get, "_tzset": _tzset, "_unsetenv": _unsetenv, "_usleep": _usleep, "_utime": _utime, "_utimes": _utimes, "_uuid_clear": _uuid_clear, "_uuid_compare": _uuid_compare, "_uuid_copy": _uuid_copy, "_uuid_generate": _uuid_generate, "_uuid_is_null": _uuid_is_null, "_uuid_parse": _uuid_parse, "_uuid_type": _uuid_type, "_uuid_unparse": _uuid_unparse, "_uuid_unparse_lower": _uuid_unparse_lower, "_uuid_unparse_upper": _uuid_unparse_upper, "_uuid_variant": _uuid_variant, "_vfork": _vfork, "_wait": _wait, "_wait3": _wait3, "_wait4": _wait4, "_waitid": _waitid, "_waitpid": _waitpid, "_zoomSurface": _zoomSurface, "emscriptenWebGLComputeImageSize": emscriptenWebGLComputeImageSize, "emscriptenWebGLGet": emscriptenWebGLGet, "emscriptenWebGLGetTexPixelData": emscriptenWebGLGetTexPixelData, "emscriptenWebGLGetUniform": emscriptenWebGLGetUniform, "emscriptenWebGLGetVertexAttrib": emscriptenWebGLGetVertexAttrib, "DYNAMICTOP_PTR": DYNAMICTOP_PTR, "tempDoublePtr": tempDoublePtr, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "gb": gb, "fb": fb };
// EMSCRIPTEN_START_ASM
var asm = (/** @suppress {uselessCode} */ function(global, env, buffer) {
'almost asm';


  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);

  var DYNAMICTOP_PTR=env.DYNAMICTOP_PTR|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var gb=env.gb|0;
  var fb=env.fb|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntS = 0, tempValue = 0, tempDouble = 0.0;

  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_max=global.Math.max;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var enlargeMemory=env.enlargeMemory;
  var getTotalMemory=env.getTotalMemory;
  var abortOnCannotGrowMemory=env.abortOnCannotGrowMemory;
  var abortStackOverflow=env.abortStackOverflow;
  var nullFunc_ii=env.nullFunc_ii;
  var nullFunc_iii=env.nullFunc_iii;
  var nullFunc_iiii=env.nullFunc_iiii;
  var nullFunc_iiiii=env.nullFunc_iiiii;
  var nullFunc_iiiiii=env.nullFunc_iiiiii;
  var nullFunc_v=env.nullFunc_v;
  var nullFunc_vi=env.nullFunc_vi;
  var setTempRet0=env.setTempRet0;
  var getTempRet0=env.getTempRet0;
  var invoke_ii=env.invoke_ii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_v=env.invoke_v;
  var invoke_vi=env.invoke_vi;
  var ftCall_ii=env.ftCall_ii;
  var ftCall_iii=env.ftCall_iii;
  var ftCall_iiii=env.ftCall_iiii;
  var ftCall_iiiii=env.ftCall_iiiii;
  var ftCall_iiiiii=env.ftCall_iiiiii;
  var ftCall_v=env.ftCall_v;
  var ftCall_vi=env.ftCall_vi;
  var _IMG_Init=env._IMG_Init;
  var _IMG_Load=env._IMG_Load;
  var _IMG_Load_RW=env._IMG_Load_RW;
  var _IMG_Quit=env._IMG_Quit;
  var _Mix_AllocateChannels=env._Mix_AllocateChannels;
  var _Mix_ChannelFinished=env._Mix_ChannelFinished;
  var _Mix_CloseAudio=env._Mix_CloseAudio;
  var _Mix_FadeInChannelTimed=env._Mix_FadeInChannelTimed;
  var _Mix_FadeInMusicPos=env._Mix_FadeInMusicPos;
  var _Mix_FadeOutChannel=env._Mix_FadeOutChannel;
  var _Mix_FadeOutMusic=env._Mix_FadeOutMusic;
  var _Mix_FadingChannel=env._Mix_FadingChannel;
  var _Mix_FreeChunk=env._Mix_FreeChunk;
  var _Mix_FreeMusic=env._Mix_FreeMusic;
  var _Mix_HaltChannel=env._Mix_HaltChannel;
  var _Mix_HaltMusic=env._Mix_HaltMusic;
  var _Mix_HookMusicFinished=env._Mix_HookMusicFinished;
  var _Mix_Init=env._Mix_Init;
  var _Mix_Linked_Version=env._Mix_Linked_Version;
  var _Mix_LoadMUS=env._Mix_LoadMUS;
  var _Mix_LoadMUS_RW=env._Mix_LoadMUS_RW;
  var _Mix_LoadWAV=env._Mix_LoadWAV;
  var _Mix_LoadWAV_RW=env._Mix_LoadWAV_RW;
  var _Mix_OpenAudio=env._Mix_OpenAudio;
  var _Mix_Pause=env._Mix_Pause;
  var _Mix_PauseMusic=env._Mix_PauseMusic;
  var _Mix_Paused=env._Mix_Paused;
  var _Mix_PausedMusic=env._Mix_PausedMusic;
  var _Mix_PlayChannel=env._Mix_PlayChannel;
  var _Mix_PlayChannelTimed=env._Mix_PlayChannelTimed;
  var _Mix_PlayMusic=env._Mix_PlayMusic;
  var _Mix_Playing=env._Mix_Playing;
  var _Mix_PlayingMusic=env._Mix_PlayingMusic;
  var _Mix_QuerySpec=env._Mix_QuerySpec;
  var _Mix_QuickLoad_RAW=env._Mix_QuickLoad_RAW;
  var _Mix_Quit=env._Mix_Quit;
  var _Mix_ReserveChannels=env._Mix_ReserveChannels;
  var _Mix_Resume=env._Mix_Resume;
  var _Mix_ResumeMusic=env._Mix_ResumeMusic;
  var _Mix_SetPanning=env._Mix_SetPanning;
  var _Mix_SetPosition=env._Mix_SetPosition;
  var _Mix_SetPostMix=env._Mix_SetPostMix;
  var _Mix_Volume=env._Mix_Volume;
  var _Mix_VolumeChunk=env._Mix_VolumeChunk;
  var _Mix_VolumeMusic=env._Mix_VolumeMusic;
  var _SDL_AddTimer=env._SDL_AddTimer;
  var _SDL_AllocRW=env._SDL_AllocRW;
  var _SDL_AudioDriverName=env._SDL_AudioDriverName;
  var _SDL_AudioQuit=env._SDL_AudioQuit;
  var _SDL_BlitScaled=env._SDL_BlitScaled;
  var _SDL_BlitSurface=env._SDL_BlitSurface;
  var _SDL_ClearError=env._SDL_ClearError;
  var _SDL_CloseAudio=env._SDL_CloseAudio;
  var _SDL_CondBroadcast=env._SDL_CondBroadcast;
  var _SDL_CondSignal=env._SDL_CondSignal;
  var _SDL_CondWait=env._SDL_CondWait;
  var _SDL_CondWaitTimeout=env._SDL_CondWaitTimeout;
  var _SDL_ConvertSurface=env._SDL_ConvertSurface;
  var _SDL_CreateCond=env._SDL_CreateCond;
  var _SDL_CreateMutex=env._SDL_CreateMutex;
  var _SDL_CreateRGBSurface=env._SDL_CreateRGBSurface;
  var _SDL_CreateRGBSurfaceFrom=env._SDL_CreateRGBSurfaceFrom;
  var _SDL_CreateThread=env._SDL_CreateThread;
  var _SDL_Delay=env._SDL_Delay;
  var _SDL_DestroyCond=env._SDL_DestroyCond;
  var _SDL_DestroyMutex=env._SDL_DestroyMutex;
  var _SDL_DestroyRenderer=env._SDL_DestroyRenderer;
  var _SDL_DestroyWindow=env._SDL_DestroyWindow;
  var _SDL_DisplayFormatAlpha=env._SDL_DisplayFormatAlpha;
  var _SDL_EnableKeyRepeat=env._SDL_EnableKeyRepeat;
  var _SDL_EnableUNICODE=env._SDL_EnableUNICODE;
  var _SDL_FillRect=env._SDL_FillRect;
  var _SDL_Flip=env._SDL_Flip;
  var _SDL_FreeRW=env._SDL_FreeRW;
  var _SDL_FreeSurface=env._SDL_FreeSurface;
  var _SDL_GL_DeleteContext=env._SDL_GL_DeleteContext;
  var _SDL_GL_ExtensionSupported=env._SDL_GL_ExtensionSupported;
  var _SDL_GL_GetAttribute=env._SDL_GL_GetAttribute;
  var _SDL_GL_GetProcAddress=env._SDL_GL_GetProcAddress;
  var _SDL_GL_GetSwapInterval=env._SDL_GL_GetSwapInterval;
  var _SDL_GL_MakeCurrent=env._SDL_GL_MakeCurrent;
  var _SDL_GL_SetAttribute=env._SDL_GL_SetAttribute;
  var _SDL_GL_SetSwapInterval=env._SDL_GL_SetSwapInterval;
  var _SDL_GL_SwapBuffers=env._SDL_GL_SwapBuffers;
  var _SDL_GL_SwapWindow=env._SDL_GL_SwapWindow;
  var _SDL_GetAppState=env._SDL_GetAppState;
  var _SDL_GetAudioDriver=env._SDL_GetAudioDriver;
  var _SDL_GetClipRect=env._SDL_GetClipRect;
  var _SDL_GetCurrentAudioDriver=env._SDL_GetCurrentAudioDriver;
  var _SDL_GetError=env._SDL_GetError;
  var _SDL_GetKeyName=env._SDL_GetKeyName;
  var _SDL_GetKeyState=env._SDL_GetKeyState;
  var _SDL_GetKeyboardState=env._SDL_GetKeyboardState;
  var _SDL_GetModState=env._SDL_GetModState;
  var _SDL_GetMouseState=env._SDL_GetMouseState;
  var _SDL_GetNumAudioDrivers=env._SDL_GetNumAudioDrivers;
  var _SDL_GetRGB=env._SDL_GetRGB;
  var _SDL_GetRGBA=env._SDL_GetRGBA;
  var _SDL_GetThreadID=env._SDL_GetThreadID;
  var _SDL_GetTicks=env._SDL_GetTicks;
  var _SDL_GetVideoInfo=env._SDL_GetVideoInfo;
  var _SDL_GetVideoSurface=env._SDL_GetVideoSurface;
  var _SDL_GetWindowFlags=env._SDL_GetWindowFlags;
  var _SDL_GetWindowSize=env._SDL_GetWindowSize;
  var _SDL_Has3DNow=env._SDL_Has3DNow;
  var _SDL_Has3DNowExt=env._SDL_Has3DNowExt;
  var _SDL_HasAltiVec=env._SDL_HasAltiVec;
  var _SDL_HasMMX=env._SDL_HasMMX;
  var _SDL_HasMMXExt=env._SDL_HasMMXExt;
  var _SDL_HasRDTSC=env._SDL_HasRDTSC;
  var _SDL_HasSSE=env._SDL_HasSSE;
  var _SDL_HasSSE2=env._SDL_HasSSE2;
  var _SDL_Init=env._SDL_Init;
  var _SDL_InitSubSystem=env._SDL_InitSubSystem;
  var _SDL_JoystickClose=env._SDL_JoystickClose;
  var _SDL_JoystickEventState=env._SDL_JoystickEventState;
  var _SDL_JoystickGetAxis=env._SDL_JoystickGetAxis;
  var _SDL_JoystickGetBall=env._SDL_JoystickGetBall;
  var _SDL_JoystickGetButton=env._SDL_JoystickGetButton;
  var _SDL_JoystickGetHat=env._SDL_JoystickGetHat;
  var _SDL_JoystickIndex=env._SDL_JoystickIndex;
  var _SDL_JoystickName=env._SDL_JoystickName;
  var _SDL_JoystickNumAxes=env._SDL_JoystickNumAxes;
  var _SDL_JoystickNumBalls=env._SDL_JoystickNumBalls;
  var _SDL_JoystickNumButtons=env._SDL_JoystickNumButtons;
  var _SDL_JoystickNumHats=env._SDL_JoystickNumHats;
  var _SDL_JoystickOpen=env._SDL_JoystickOpen;
  var _SDL_JoystickOpened=env._SDL_JoystickOpened;
  var _SDL_JoystickUpdate=env._SDL_JoystickUpdate;
  var _SDL_Linked_Version=env._SDL_Linked_Version;
  var _SDL_ListModes=env._SDL_ListModes;
  var _SDL_LoadBMP=env._SDL_LoadBMP;
  var _SDL_LoadBMP_RW=env._SDL_LoadBMP_RW;
  var _SDL_LockAudio=env._SDL_LockAudio;
  var _SDL_LockMutex=env._SDL_LockMutex;
  var _SDL_LockSurface=env._SDL_LockSurface;
  var _SDL_LogSetOutputFunction=env._SDL_LogSetOutputFunction;
  var _SDL_LowerBlit=env._SDL_LowerBlit;
  var _SDL_LowerBlitScaled=env._SDL_LowerBlitScaled;
  var _SDL_MapRGB=env._SDL_MapRGB;
  var _SDL_MapRGBA=env._SDL_MapRGBA;
  var _SDL_NumJoysticks=env._SDL_NumJoysticks;
  var _SDL_OpenAudio=env._SDL_OpenAudio;
  var _SDL_PauseAudio=env._SDL_PauseAudio;
  var _SDL_PeepEvents=env._SDL_PeepEvents;
  var _SDL_PollEvent=env._SDL_PollEvent;
  var _SDL_PumpEvents=env._SDL_PumpEvents;
  var _SDL_PushEvent=env._SDL_PushEvent;
  var _SDL_Quit=env._SDL_Quit;
  var _SDL_QuitSubSystem=env._SDL_QuitSubSystem;
  var _SDL_RWFromConstMem=env._SDL_RWFromConstMem;
  var _SDL_RWFromFile=env._SDL_RWFromFile;
  var _SDL_RWFromMem=env._SDL_RWFromMem;
  var _SDL_RemoveTimer=env._SDL_RemoveTimer;
  var _SDL_SaveBMP_RW=env._SDL_SaveBMP_RW;
  var _SDL_SetAlpha=env._SDL_SetAlpha;
  var _SDL_SetClipRect=env._SDL_SetClipRect;
  var _SDL_SetColorKey=env._SDL_SetColorKey;
  var _SDL_SetColors=env._SDL_SetColors;
  var _SDL_SetError=env._SDL_SetError;
  var _SDL_SetGamma=env._SDL_SetGamma;
  var _SDL_SetGammaRamp=env._SDL_SetGammaRamp;
  var _SDL_SetPalette=env._SDL_SetPalette;
  var _SDL_SetVideoMode=env._SDL_SetVideoMode;
  var _SDL_SetWindowFullscreen=env._SDL_SetWindowFullscreen;
  var _SDL_SetWindowTitle=env._SDL_SetWindowTitle;
  var _SDL_ShowCursor=env._SDL_ShowCursor;
  var _SDL_StartTextInput=env._SDL_StartTextInput;
  var _SDL_StopTextInput=env._SDL_StopTextInput;
  var _SDL_ThreadID=env._SDL_ThreadID;
  var _SDL_UnlockAudio=env._SDL_UnlockAudio;
  var _SDL_UnlockMutex=env._SDL_UnlockMutex;
  var _SDL_UnlockSurface=env._SDL_UnlockSurface;
  var _SDL_UpdateRect=env._SDL_UpdateRect;
  var _SDL_UpdateRects=env._SDL_UpdateRects;
  var _SDL_UpperBlit=env._SDL_UpperBlit;
  var _SDL_UpperBlitScaled=env._SDL_UpperBlitScaled;
  var _SDL_VideoDriverName=env._SDL_VideoDriverName;
  var _SDL_VideoModeOK=env._SDL_VideoModeOK;
  var _SDL_VideoQuit=env._SDL_VideoQuit;
  var _SDL_WM_GrabInput=env._SDL_WM_GrabInput;
  var _SDL_WM_IconifyWindow=env._SDL_WM_IconifyWindow;
  var _SDL_WM_SetCaption=env._SDL_WM_SetCaption;
  var _SDL_WM_SetIcon=env._SDL_WM_SetIcon;
  var _SDL_WM_ToggleFullScreen=env._SDL_WM_ToggleFullScreen;
  var _SDL_WaitThread=env._SDL_WaitThread;
  var _SDL_WarpMouse=env._SDL_WarpMouse;
  var _SDL_WasInit=env._SDL_WasInit;
  var _SDL_free=env._SDL_free;
  var _SDL_getenv=env._SDL_getenv;
  var _SDL_malloc=env._SDL_malloc;
  var _SDL_mutexP=env._SDL_mutexP;
  var _SDL_mutexV=env._SDL_mutexV;
  var _SDL_putenv=env._SDL_putenv;
  var _TTF_CloseFont=env._TTF_CloseFont;
  var _TTF_FontAscent=env._TTF_FontAscent;
  var _TTF_FontDescent=env._TTF_FontDescent;
  var _TTF_FontHeight=env._TTF_FontHeight;
  var _TTF_FontLineSkip=env._TTF_FontLineSkip;
  var _TTF_GlyphMetrics=env._TTF_GlyphMetrics;
  var _TTF_Init=env._TTF_Init;
  var _TTF_OpenFont=env._TTF_OpenFont;
  var _TTF_Quit=env._TTF_Quit;
  var _TTF_RenderText_Blended=env._TTF_RenderText_Blended;
  var _TTF_RenderText_Shaded=env._TTF_RenderText_Shaded;
  var _TTF_RenderText_Solid=env._TTF_RenderText_Solid;
  var _TTF_RenderUTF8_Solid=env._TTF_RenderUTF8_Solid;
  var _TTF_SizeText=env._TTF_SizeText;
  var _TTF_SizeUTF8=env._TTF_SizeUTF8;
  var _XChangeWindowAttributes=env._XChangeWindowAttributes;
  var _XCreateWindow=env._XCreateWindow;
  var _XInternAtom=env._XInternAtom;
  var _XMapWindow=env._XMapWindow;
  var _XOpenDisplay=env._XOpenDisplay;
  var _XPending=env._XPending;
  var _XSendEvent=env._XSendEvent;
  var _XSetWMHints=env._XSetWMHints;
  var _XStoreName=env._XStoreName;
  var __Exit=env.__Exit;
  var __Unwind_Backtrace=env.__Unwind_Backtrace;
  var __Unwind_DeleteException=env.__Unwind_DeleteException;
  var __Unwind_FindEnclosingFunction=env.__Unwind_FindEnclosingFunction;
  var __Unwind_GetIPInfo=env.__Unwind_GetIPInfo;
  var __Unwind_RaiseException=env.__Unwind_RaiseException;
  var __ZSt18uncaught_exceptionv=env.__ZSt18uncaught_exceptionv;
  var __ZSt9terminatev=env.__ZSt9terminatev;
  var ___assert_fail=env.___assert_fail;
  var ___assert_func=env.___assert_func;
  var ___atomic_compare_exchange_8=env.___atomic_compare_exchange_8;
  var ___atomic_exchange_8=env.___atomic_exchange_8;
  var ___atomic_fetch_add_8=env.___atomic_fetch_add_8;
  var ___atomic_fetch_and_8=env.___atomic_fetch_and_8;
  var ___atomic_fetch_or_8=env.___atomic_fetch_or_8;
  var ___atomic_fetch_sub_8=env.___atomic_fetch_sub_8;
  var ___atomic_fetch_xor_8=env.___atomic_fetch_xor_8;
  var ___atomic_is_lock_free=env.___atomic_is_lock_free;
  var ___atomic_load_8=env.___atomic_load_8;
  var ___atomic_store_8=env.___atomic_store_8;
  var ___buildEnvironment=env.___buildEnvironment;
  var ___builtin_prefetch=env.___builtin_prefetch;
  var ___clock_gettime=env.___clock_gettime;
  var ___cxa_allocate_exception=env.___cxa_allocate_exception;
  var ___cxa_atexit=env.___cxa_atexit;
  var ___cxa_begin_catch=env.___cxa_begin_catch;
  var ___cxa_call_unexpected=env.___cxa_call_unexpected;
  var ___cxa_current_primary_exception=env.___cxa_current_primary_exception;
  var ___cxa_decrement_exception_refcount=env.___cxa_decrement_exception_refcount;
  var ___cxa_end_catch=env.___cxa_end_catch;
  var ___cxa_find_matching_catch=env.___cxa_find_matching_catch;
  var ___cxa_free_exception=env.___cxa_free_exception;
  var ___cxa_get_exception_ptr=env.___cxa_get_exception_ptr;
  var ___cxa_increment_exception_refcount=env.___cxa_increment_exception_refcount;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var ___cxa_rethrow=env.___cxa_rethrow;
  var ___cxa_rethrow_primary_exception=env.___cxa_rethrow_primary_exception;
  var ___cxa_thread_atexit=env.___cxa_thread_atexit;
  var ___cxa_thread_atexit_impl=env.___cxa_thread_atexit_impl;
  var ___cxa_throw=env.___cxa_throw;
  var ___cxa_uncaught_exception=env.___cxa_uncaught_exception;
  var ___execvpe=env.___execvpe;
  var ___gcc_personality_v0=env.___gcc_personality_v0;
  var ___gxx_personality_v0=env.___gxx_personality_v0;
  var ___libc_current_sigrtmax=env.___libc_current_sigrtmax;
  var ___libc_current_sigrtmin=env.___libc_current_sigrtmin;
  var ___lock=env.___lock;
  var ___map_file=env.___map_file;
  var ___resumeException=env.___resumeException;
  var ___setErrNo=env.___setErrNo;
  var ___set_network_callback=env.___set_network_callback;
  var ___syscall1=env.___syscall1;
  var ___syscall10=env.___syscall10;
  var ___syscall102=env.___syscall102;
  var ___syscall104=env.___syscall104;
  var ___syscall114=env.___syscall114;
  var ___syscall118=env.___syscall118;
  var ___syscall12=env.___syscall12;
  var ___syscall121=env.___syscall121;
  var ___syscall122=env.___syscall122;
  var ___syscall125=env.___syscall125;
  var ___syscall132=env.___syscall132;
  var ___syscall133=env.___syscall133;
  var ___syscall14=env.___syscall14;
  var ___syscall140=env.___syscall140;
  var ___syscall142=env.___syscall142;
  var ___syscall144=env.___syscall144;
  var ___syscall145=env.___syscall145;
  var ___syscall146=env.___syscall146;
  var ___syscall147=env.___syscall147;
  var ___syscall148=env.___syscall148;
  var ___syscall15=env.___syscall15;
  var ___syscall150=env.___syscall150;
  var ___syscall151=env.___syscall151;
  var ___syscall152=env.___syscall152;
  var ___syscall153=env.___syscall153;
  var ___syscall163=env.___syscall163;
  var ___syscall168=env.___syscall168;
  var ___syscall178=env.___syscall178;
  var ___syscall180=env.___syscall180;
  var ___syscall181=env.___syscall181;
  var ___syscall183=env.___syscall183;
  var ___syscall191=env.___syscall191;
  var ___syscall192=env.___syscall192;
  var ___syscall193=env.___syscall193;
  var ___syscall194=env.___syscall194;
  var ___syscall195=env.___syscall195;
  var ___syscall196=env.___syscall196;
  var ___syscall197=env.___syscall197;
  var ___syscall198=env.___syscall198;
  var ___syscall199=env.___syscall199;
  var ___syscall20=env.___syscall20;
  var ___syscall200=env.___syscall200;
  var ___syscall201=env.___syscall201;
  var ___syscall202=env.___syscall202;
  var ___syscall203=env.___syscall203;
  var ___syscall204=env.___syscall204;
  var ___syscall205=env.___syscall205;
  var ___syscall207=env.___syscall207;
  var ___syscall208=env.___syscall208;
  var ___syscall209=env.___syscall209;
  var ___syscall210=env.___syscall210;
  var ___syscall211=env.___syscall211;
  var ___syscall212=env.___syscall212;
  var ___syscall213=env.___syscall213;
  var ___syscall214=env.___syscall214;
  var ___syscall218=env.___syscall218;
  var ___syscall219=env.___syscall219;
  var ___syscall220=env.___syscall220;
  var ___syscall221=env.___syscall221;
  var ___syscall265=env.___syscall265;
  var ___syscall268=env.___syscall268;
  var ___syscall269=env.___syscall269;
  var ___syscall272=env.___syscall272;
  var ___syscall29=env.___syscall29;
  var ___syscall295=env.___syscall295;
  var ___syscall296=env.___syscall296;
  var ___syscall297=env.___syscall297;
  var ___syscall298=env.___syscall298;
  var ___syscall299=env.___syscall299;
  var ___syscall3=env.___syscall3;
  var ___syscall300=env.___syscall300;
  var ___syscall301=env.___syscall301;
  var ___syscall302=env.___syscall302;
  var ___syscall303=env.___syscall303;
  var ___syscall304=env.___syscall304;
  var ___syscall305=env.___syscall305;
  var ___syscall306=env.___syscall306;
  var ___syscall307=env.___syscall307;
  var ___syscall308=env.___syscall308;
  var ___syscall320=env.___syscall320;
  var ___syscall324=env.___syscall324;
  var ___syscall33=env.___syscall33;
  var ___syscall330=env.___syscall330;
  var ___syscall331=env.___syscall331;
  var ___syscall333=env.___syscall333;
  var ___syscall334=env.___syscall334;
  var ___syscall337=env.___syscall337;
  var ___syscall34=env.___syscall34;
  var ___syscall340=env.___syscall340;
  var ___syscall345=env.___syscall345;
  var ___syscall36=env.___syscall36;
  var ___syscall38=env.___syscall38;
  var ___syscall39=env.___syscall39;
  var ___syscall4=env.___syscall4;
  var ___syscall40=env.___syscall40;
  var ___syscall41=env.___syscall41;
  var ___syscall42=env.___syscall42;
  var ___syscall5=env.___syscall5;
  var ___syscall51=env.___syscall51;
  var ___syscall54=env.___syscall54;
  var ___syscall57=env.___syscall57;
  var ___syscall6=env.___syscall6;
  var ___syscall60=env.___syscall60;
  var ___syscall63=env.___syscall63;
  var ___syscall64=env.___syscall64;
  var ___syscall65=env.___syscall65;
  var ___syscall66=env.___syscall66;
  var ___syscall75=env.___syscall75;
  var ___syscall77=env.___syscall77;
  var ___syscall83=env.___syscall83;
  var ___syscall85=env.___syscall85;
  var ___syscall9=env.___syscall9;
  var ___syscall91=env.___syscall91;
  var ___syscall94=env.___syscall94;
  var ___syscall96=env.___syscall96;
  var ___syscall97=env.___syscall97;
  var ___ubsan_handle_add_overflow=env.___ubsan_handle_add_overflow;
  var ___ubsan_handle_float_cast_overflow=env.___ubsan_handle_float_cast_overflow;
  var ___ubsan_handle_pointer_overflow=env.___ubsan_handle_pointer_overflow;
  var ___ubsan_handle_type_mismatch_v1=env.___ubsan_handle_type_mismatch_v1;
  var ___unlock=env.___unlock;
  var ___wait=env.___wait;
  var __addDays=env.__addDays;
  var __arraySum=env.__arraySum;
  var __emscripten_atomic_fetch_and_add_u64=env.__emscripten_atomic_fetch_and_add_u64;
  var __emscripten_atomic_fetch_and_and_u64=env.__emscripten_atomic_fetch_and_and_u64;
  var __emscripten_atomic_fetch_and_or_u64=env.__emscripten_atomic_fetch_and_or_u64;
  var __emscripten_atomic_fetch_and_sub_u64=env.__emscripten_atomic_fetch_and_sub_u64;
  var __emscripten_atomic_fetch_and_xor_u64=env.__emscripten_atomic_fetch_and_xor_u64;
  var __emscripten_do_request_fullscreen=env.__emscripten_do_request_fullscreen;
  var __emscripten_push_main_loop_blocker=env.__emscripten_push_main_loop_blocker;
  var __emscripten_push_uncounted_main_loop_blocker=env.__emscripten_push_uncounted_main_loop_blocker;
  var __emscripten_sample_gamepad_data=env.__emscripten_sample_gamepad_data;
  var __emscripten_traverse_stack=env.__emscripten_traverse_stack;
  var __exit=env.__exit;
  var __formatString=env.__formatString;
  var __get_canvas_element_size=env.__get_canvas_element_size;
  var __hideEverythingExceptGivenElement=env.__hideEverythingExceptGivenElement;
  var __inet_ntop4_raw=env.__inet_ntop4_raw;
  var __inet_ntop6_raw=env.__inet_ntop6_raw;
  var __inet_pton4_raw=env.__inet_pton4_raw;
  var __inet_pton6=env.__inet_pton6;
  var __inet_pton6_raw=env.__inet_pton6_raw;
  var __isLeapYear=env.__isLeapYear;
  var __pthread_cleanup_pop=env.__pthread_cleanup_pop;
  var __pthread_cleanup_push=env.__pthread_cleanup_push;
  var __read_sockaddr=env.__read_sockaddr;
  var __reallyNegative=env.__reallyNegative;
  var __registerRestoreOldStyle=env.__registerRestoreOldStyle;
  var __restoreHiddenElements=env.__restoreHiddenElements;
  var __setLetterbox=env.__setLetterbox;
  var __set_canvas_element_size=env.__set_canvas_element_size;
  var __softFullscreenResizeWebGLRenderTarget=env.__softFullscreenResizeWebGLRenderTarget;
  var __write_sockaddr=env.__write_sockaddr;
  var _abort=env._abort;
  var _abs=env._abs;
  var _acos=env._acos;
  var _acosf=env._acosf;
  var _acosl=env._acosl;
  var _alBuffer3f=env._alBuffer3f;
  var _alBuffer3i=env._alBuffer3i;
  var _alBufferData=env._alBufferData;
  var _alBufferf=env._alBufferf;
  var _alBufferfv=env._alBufferfv;
  var _alBufferi=env._alBufferi;
  var _alBufferiv=env._alBufferiv;
  var _alDeleteBuffers=env._alDeleteBuffers;
  var _alDeleteSources=env._alDeleteSources;
  var _alDisable=env._alDisable;
  var _alDistanceModel=env._alDistanceModel;
  var _alDopplerFactor=env._alDopplerFactor;
  var _alDopplerVelocity=env._alDopplerVelocity;
  var _alEnable=env._alEnable;
  var _alGenBuffers=env._alGenBuffers;
  var _alGenSources=env._alGenSources;
  var _alGetBoolean=env._alGetBoolean;
  var _alGetBooleanv=env._alGetBooleanv;
  var _alGetBuffer3f=env._alGetBuffer3f;
  var _alGetBuffer3i=env._alGetBuffer3i;
  var _alGetBufferf=env._alGetBufferf;
  var _alGetBufferfv=env._alGetBufferfv;
  var _alGetBufferi=env._alGetBufferi;
  var _alGetBufferiv=env._alGetBufferiv;
  var _alGetDouble=env._alGetDouble;
  var _alGetDoublev=env._alGetDoublev;
  var _alGetEnumValue=env._alGetEnumValue;
  var _alGetError=env._alGetError;
  var _alGetFloat=env._alGetFloat;
  var _alGetFloatv=env._alGetFloatv;
  var _alGetInteger=env._alGetInteger;
  var _alGetIntegerv=env._alGetIntegerv;
  var _alGetListener3f=env._alGetListener3f;
  var _alGetListener3i=env._alGetListener3i;
  var _alGetListenerf=env._alGetListenerf;
  var _alGetListenerfv=env._alGetListenerfv;
  var _alGetListeneri=env._alGetListeneri;
  var _alGetListeneriv=env._alGetListeneriv;
  var _alGetProcAddress=env._alGetProcAddress;
  var _alGetSource3f=env._alGetSource3f;
  var _alGetSource3i=env._alGetSource3i;
  var _alGetSourcef=env._alGetSourcef;
  var _alGetSourcefv=env._alGetSourcefv;
  var _alGetSourcei=env._alGetSourcei;
  var _alGetSourceiv=env._alGetSourceiv;
  var _alGetString=env._alGetString;
  var _alIsBuffer=env._alIsBuffer;
  var _alIsEnabled=env._alIsEnabled;
  var _alIsExtensionPresent=env._alIsExtensionPresent;
  var _alIsSource=env._alIsSource;
  var _alListener3f=env._alListener3f;
  var _alListener3i=env._alListener3i;
  var _alListenerf=env._alListenerf;
  var _alListenerfv=env._alListenerfv;
  var _alListeneri=env._alListeneri;
  var _alListeneriv=env._alListeneriv;
  var _alSource3f=env._alSource3f;
  var _alSource3i=env._alSource3i;
  var _alSourcePause=env._alSourcePause;
  var _alSourcePausev=env._alSourcePausev;
  var _alSourcePlay=env._alSourcePlay;
  var _alSourcePlayv=env._alSourcePlayv;
  var _alSourceQueueBuffers=env._alSourceQueueBuffers;
  var _alSourceRewind=env._alSourceRewind;
  var _alSourceRewindv=env._alSourceRewindv;
  var _alSourceStop=env._alSourceStop;
  var _alSourceStopv=env._alSourceStopv;
  var _alSourceUnqueueBuffers=env._alSourceUnqueueBuffers;
  var _alSourcef=env._alSourcef;
  var _alSourcefv=env._alSourcefv;
  var _alSourcei=env._alSourcei;
  var _alSourceiv=env._alSourceiv;
  var _alSpeedOfSound=env._alSpeedOfSound;
  var _alarm=env._alarm;
  var _alcCaptureCloseDevice=env._alcCaptureCloseDevice;
  var _alcCaptureOpenDevice=env._alcCaptureOpenDevice;
  var _alcCaptureSamples=env._alcCaptureSamples;
  var _alcCaptureStart=env._alcCaptureStart;
  var _alcCaptureStop=env._alcCaptureStop;
  var _alcCloseDevice=env._alcCloseDevice;
  var _alcCreateContext=env._alcCreateContext;
  var _alcDestroyContext=env._alcDestroyContext;
  var _alcGetContextsDevice=env._alcGetContextsDevice;
  var _alcGetCurrentContext=env._alcGetCurrentContext;
  var _alcGetEnumValue=env._alcGetEnumValue;
  var _alcGetError=env._alcGetError;
  var _alcGetIntegerv=env._alcGetIntegerv;
  var _alcGetProcAddress=env._alcGetProcAddress;
  var _alcGetString=env._alcGetString;
  var _alcIsExtensionPresent=env._alcIsExtensionPresent;
  var _alcMakeContextCurrent=env._alcMakeContextCurrent;
  var _alcOpenDevice=env._alcOpenDevice;
  var _alcProcessContext=env._alcProcessContext;
  var _alcSuspendContext=env._alcSuspendContext;
  var _arc4random=env._arc4random;
  var _asctime=env._asctime;
  var _asctime_r=env._asctime_r;
  var _asin=env._asin;
  var _asinf=env._asinf;
  var _asinl=env._asinl;
  var _atan=env._atan;
  var _atan2=env._atan2;
  var _atan2f=env._atan2f;
  var _atan2l=env._atan2l;
  var _atanf=env._atanf;
  var _atanl=env._atanl;
  var _atexit=env._atexit;
  var _boxColor=env._boxColor;
  var _boxRGBA=env._boxRGBA;
  var _ceil=env._ceil;
  var _ceilf=env._ceilf;
  var _ceill=env._ceill;
  var _chroot=env._chroot;
  var _clearenv=env._clearenv;
  var _clock=env._clock;
  var _clock_getcpuclockid=env._clock_getcpuclockid;
  var _clock_getres=env._clock_getres;
  var _clock_gettime=env._clock_gettime;
  var _clock_settime=env._clock_settime;
  var _confstr=env._confstr;
  var _cos=env._cos;
  var _cosf=env._cosf;
  var _cosl=env._cosl;
  var _ctime=env._ctime;
  var _ctime_r=env._ctime_r;
  var _difftime=env._difftime;
  var _dladdr=env._dladdr;
  var _dlclose=env._dlclose;
  var _dlerror=env._dlerror;
  var _dlopen=env._dlopen;
  var _dlsym=env._dlsym;
  var _dysize=env._dysize;
  var _eglBindAPI=env._eglBindAPI;
  var _eglChooseConfig=env._eglChooseConfig;
  var _eglCreateContext=env._eglCreateContext;
  var _eglCreateWindowSurface=env._eglCreateWindowSurface;
  var _eglDestroyContext=env._eglDestroyContext;
  var _eglDestroySurface=env._eglDestroySurface;
  var _eglGetConfigAttrib=env._eglGetConfigAttrib;
  var _eglGetConfigs=env._eglGetConfigs;
  var _eglGetCurrentContext=env._eglGetCurrentContext;
  var _eglGetCurrentDisplay=env._eglGetCurrentDisplay;
  var _eglGetCurrentSurface=env._eglGetCurrentSurface;
  var _eglGetDisplay=env._eglGetDisplay;
  var _eglGetError=env._eglGetError;
  var _eglGetProcAddress=env._eglGetProcAddress;
  var _eglInitialize=env._eglInitialize;
  var _eglMakeCurrent=env._eglMakeCurrent;
  var _eglQueryAPI=env._eglQueryAPI;
  var _eglQueryContext=env._eglQueryContext;
  var _eglQueryString=env._eglQueryString;
  var _eglQuerySurface=env._eglQuerySurface;
  var _eglReleaseThread=env._eglReleaseThread;
  var _eglSwapBuffers=env._eglSwapBuffers;
  var _eglSwapInterval=env._eglSwapInterval;
  var _eglTerminate=env._eglTerminate;
  var _eglWaitClient=env._eglWaitClient;
  var _eglWaitGL=env._eglWaitGL;
  var _eglWaitNative=env._eglWaitNative;
  var _ellipseColor=env._ellipseColor;
  var _ellipseRGBA=env._ellipseRGBA;
  var _emscripten_SDL_SetEventHandler=env._emscripten_SDL_SetEventHandler;
  var _emscripten_alcDevicePauseSOFT=env._emscripten_alcDevicePauseSOFT;
  var _emscripten_alcDeviceResumeSOFT=env._emscripten_alcDeviceResumeSOFT;
  var _emscripten_alcGetStringiSOFT=env._emscripten_alcGetStringiSOFT;
  var _emscripten_alcResetDeviceSOFT=env._emscripten_alcResetDeviceSOFT;
  var _emscripten_async_call=env._emscripten_async_call;
  var _emscripten_async_load_script=env._emscripten_async_load_script;
  var _emscripten_async_run_script=env._emscripten_async_run_script;
  var _emscripten_async_wget=env._emscripten_async_wget;
  var _emscripten_async_wget2=env._emscripten_async_wget2;
  var _emscripten_async_wget2_abort=env._emscripten_async_wget2_abort;
  var _emscripten_async_wget2_data=env._emscripten_async_wget2_data;
  var _emscripten_async_wget_data=env._emscripten_async_wget_data;
  var _emscripten_atomic_add_u32=env._emscripten_atomic_add_u32;
  var _emscripten_atomic_cas_u64=env._emscripten_atomic_cas_u64;
  var _emscripten_atomic_exchange_u64=env._emscripten_atomic_exchange_u64;
  var _emscripten_atomic_load_u64=env._emscripten_atomic_load_u64;
  var _emscripten_atomic_store_u64=env._emscripten_atomic_store_u64;
  var _emscripten_autodebug_double=env._emscripten_autodebug_double;
  var _emscripten_autodebug_float=env._emscripten_autodebug_float;
  var _emscripten_autodebug_i16=env._emscripten_autodebug_i16;
  var _emscripten_autodebug_i32=env._emscripten_autodebug_i32;
  var _emscripten_autodebug_i64=env._emscripten_autodebug_i64;
  var _emscripten_autodebug_i8=env._emscripten_autodebug_i8;
  var _emscripten_call_worker=env._emscripten_call_worker;
  var _emscripten_cancel_main_loop=env._emscripten_cancel_main_loop;
  var _emscripten_coroutine_create=env._emscripten_coroutine_create;
  var _emscripten_coroutine_next=env._emscripten_coroutine_next;
  var _emscripten_create_worker=env._emscripten_create_worker;
  var _emscripten_debugger=env._emscripten_debugger;
  var _emscripten_destroy_worker=env._emscripten_destroy_worker;
  var _emscripten_enter_soft_fullscreen=env._emscripten_enter_soft_fullscreen;
  var _emscripten_exit_fullscreen=env._emscripten_exit_fullscreen;
  var _emscripten_exit_pointerlock=env._emscripten_exit_pointerlock;
  var _emscripten_exit_soft_fullscreen=env._emscripten_exit_soft_fullscreen;
  var _emscripten_exit_with_live_runtime=env._emscripten_exit_with_live_runtime;
  var _emscripten_force_exit=env._emscripten_force_exit;
  var _emscripten_force_num_logical_cores=env._emscripten_force_num_logical_cores;
  var _emscripten_get_battery_status=env._emscripten_get_battery_status;
  var _emscripten_get_callstack=env._emscripten_get_callstack;
  var _emscripten_get_callstack_js=env._emscripten_get_callstack_js;
  var _emscripten_get_canvas_element_size=env._emscripten_get_canvas_element_size;
  var _emscripten_get_canvas_size=env._emscripten_get_canvas_size;
  var _emscripten_get_compiler_setting=env._emscripten_get_compiler_setting;
  var _emscripten_get_device_pixel_ratio=env._emscripten_get_device_pixel_ratio;
  var _emscripten_get_devicemotion_status=env._emscripten_get_devicemotion_status;
  var _emscripten_get_deviceorientation_status=env._emscripten_get_deviceorientation_status;
  var _emscripten_get_element_css_size=env._emscripten_get_element_css_size;
  var _emscripten_get_fullscreen_status=env._emscripten_get_fullscreen_status;
  var _emscripten_get_gamepad_status=env._emscripten_get_gamepad_status;
  var _emscripten_get_main_loop_timing=env._emscripten_get_main_loop_timing;
  var _emscripten_get_mouse_status=env._emscripten_get_mouse_status;
  var _emscripten_get_now=env._emscripten_get_now;
  var _emscripten_get_now_is_monotonic=env._emscripten_get_now_is_monotonic;
  var _emscripten_get_now_res=env._emscripten_get_now_res;
  var _emscripten_get_num_gamepads=env._emscripten_get_num_gamepads;
  var _emscripten_get_orientation_status=env._emscripten_get_orientation_status;
  var _emscripten_get_pointerlock_status=env._emscripten_get_pointerlock_status;
  var _emscripten_get_preloaded_image_data=env._emscripten_get_preloaded_image_data;
  var _emscripten_get_preloaded_image_data_from_FILE=env._emscripten_get_preloaded_image_data_from_FILE;
  var _emscripten_get_visibility_status=env._emscripten_get_visibility_status;
  var _emscripten_get_worker_queue_size=env._emscripten_get_worker_queue_size;
  var _emscripten_glActiveTexture=env._emscripten_glActiveTexture;
  var _emscripten_glAttachShader=env._emscripten_glAttachShader;
  var _emscripten_glBegin=env._emscripten_glBegin;
  var _emscripten_glBeginQueryEXT=env._emscripten_glBeginQueryEXT;
  var _emscripten_glBindAttribLocation=env._emscripten_glBindAttribLocation;
  var _emscripten_glBindBuffer=env._emscripten_glBindBuffer;
  var _emscripten_glBindFramebuffer=env._emscripten_glBindFramebuffer;
  var _emscripten_glBindRenderbuffer=env._emscripten_glBindRenderbuffer;
  var _emscripten_glBindTexture=env._emscripten_glBindTexture;
  var _emscripten_glBindVertexArray=env._emscripten_glBindVertexArray;
  var _emscripten_glBindVertexArrayOES=env._emscripten_glBindVertexArrayOES;
  var _emscripten_glBlendColor=env._emscripten_glBlendColor;
  var _emscripten_glBlendEquation=env._emscripten_glBlendEquation;
  var _emscripten_glBlendEquationSeparate=env._emscripten_glBlendEquationSeparate;
  var _emscripten_glBlendFunc=env._emscripten_glBlendFunc;
  var _emscripten_glBlendFuncSeparate=env._emscripten_glBlendFuncSeparate;
  var _emscripten_glBufferData=env._emscripten_glBufferData;
  var _emscripten_glBufferSubData=env._emscripten_glBufferSubData;
  var _emscripten_glCheckFramebufferStatus=env._emscripten_glCheckFramebufferStatus;
  var _emscripten_glClear=env._emscripten_glClear;
  var _emscripten_glClearColor=env._emscripten_glClearColor;
  var _emscripten_glClearDepth=env._emscripten_glClearDepth;
  var _emscripten_glClearDepthf=env._emscripten_glClearDepthf;
  var _emscripten_glClearStencil=env._emscripten_glClearStencil;
  var _emscripten_glColorMask=env._emscripten_glColorMask;
  var _emscripten_glCompileShader=env._emscripten_glCompileShader;
  var _emscripten_glCompressedTexImage2D=env._emscripten_glCompressedTexImage2D;
  var _emscripten_glCompressedTexSubImage2D=env._emscripten_glCompressedTexSubImage2D;
  var _emscripten_glCopyTexImage2D=env._emscripten_glCopyTexImage2D;
  var _emscripten_glCopyTexSubImage2D=env._emscripten_glCopyTexSubImage2D;
  var _emscripten_glCreateProgram=env._emscripten_glCreateProgram;
  var _emscripten_glCreateShader=env._emscripten_glCreateShader;
  var _emscripten_glCullFace=env._emscripten_glCullFace;
  var _emscripten_glDeleteBuffers=env._emscripten_glDeleteBuffers;
  var _emscripten_glDeleteFramebuffers=env._emscripten_glDeleteFramebuffers;
  var _emscripten_glDeleteProgram=env._emscripten_glDeleteProgram;
  var _emscripten_glDeleteQueriesEXT=env._emscripten_glDeleteQueriesEXT;
  var _emscripten_glDeleteRenderbuffers=env._emscripten_glDeleteRenderbuffers;
  var _emscripten_glDeleteShader=env._emscripten_glDeleteShader;
  var _emscripten_glDeleteTextures=env._emscripten_glDeleteTextures;
  var _emscripten_glDeleteVertexArrays=env._emscripten_glDeleteVertexArrays;
  var _emscripten_glDeleteVertexArraysOES=env._emscripten_glDeleteVertexArraysOES;
  var _emscripten_glDepthFunc=env._emscripten_glDepthFunc;
  var _emscripten_glDepthMask=env._emscripten_glDepthMask;
  var _emscripten_glDepthRange=env._emscripten_glDepthRange;
  var _emscripten_glDepthRangef=env._emscripten_glDepthRangef;
  var _emscripten_glDetachShader=env._emscripten_glDetachShader;
  var _emscripten_glDisable=env._emscripten_glDisable;
  var _emscripten_glDisableVertexAttribArray=env._emscripten_glDisableVertexAttribArray;
  var _emscripten_glDrawArrays=env._emscripten_glDrawArrays;
  var _emscripten_glDrawArraysInstanced=env._emscripten_glDrawArraysInstanced;
  var _emscripten_glDrawArraysInstancedANGLE=env._emscripten_glDrawArraysInstancedANGLE;
  var _emscripten_glDrawArraysInstancedARB=env._emscripten_glDrawArraysInstancedARB;
  var _emscripten_glDrawArraysInstancedEXT=env._emscripten_glDrawArraysInstancedEXT;
  var _emscripten_glDrawArraysInstancedNV=env._emscripten_glDrawArraysInstancedNV;
  var _emscripten_glDrawBuffers=env._emscripten_glDrawBuffers;
  var _emscripten_glDrawBuffersEXT=env._emscripten_glDrawBuffersEXT;
  var _emscripten_glDrawBuffersWEBGL=env._emscripten_glDrawBuffersWEBGL;
  var _emscripten_glDrawElements=env._emscripten_glDrawElements;
  var _emscripten_glDrawElementsInstanced=env._emscripten_glDrawElementsInstanced;
  var _emscripten_glDrawElementsInstancedANGLE=env._emscripten_glDrawElementsInstancedANGLE;
  var _emscripten_glDrawElementsInstancedARB=env._emscripten_glDrawElementsInstancedARB;
  var _emscripten_glDrawElementsInstancedEXT=env._emscripten_glDrawElementsInstancedEXT;
  var _emscripten_glDrawElementsInstancedNV=env._emscripten_glDrawElementsInstancedNV;
  var _emscripten_glEnable=env._emscripten_glEnable;
  var _emscripten_glEnableVertexAttribArray=env._emscripten_glEnableVertexAttribArray;
  var _emscripten_glEndQueryEXT=env._emscripten_glEndQueryEXT;
  var _emscripten_glFinish=env._emscripten_glFinish;
  var _emscripten_glFlush=env._emscripten_glFlush;
  var _emscripten_glFramebufferRenderbuffer=env._emscripten_glFramebufferRenderbuffer;
  var _emscripten_glFramebufferTexture2D=env._emscripten_glFramebufferTexture2D;
  var _emscripten_glFrontFace=env._emscripten_glFrontFace;
  var _emscripten_glGenBuffers=env._emscripten_glGenBuffers;
  var _emscripten_glGenFramebuffers=env._emscripten_glGenFramebuffers;
  var _emscripten_glGenQueriesEXT=env._emscripten_glGenQueriesEXT;
  var _emscripten_glGenRenderbuffers=env._emscripten_glGenRenderbuffers;
  var _emscripten_glGenTextures=env._emscripten_glGenTextures;
  var _emscripten_glGenVertexArrays=env._emscripten_glGenVertexArrays;
  var _emscripten_glGenVertexArraysOES=env._emscripten_glGenVertexArraysOES;
  var _emscripten_glGenerateMipmap=env._emscripten_glGenerateMipmap;
  var _emscripten_glGetActiveAttrib=env._emscripten_glGetActiveAttrib;
  var _emscripten_glGetActiveUniform=env._emscripten_glGetActiveUniform;
  var _emscripten_glGetAttachedShaders=env._emscripten_glGetAttachedShaders;
  var _emscripten_glGetAttribLocation=env._emscripten_glGetAttribLocation;
  var _emscripten_glGetBooleanv=env._emscripten_glGetBooleanv;
  var _emscripten_glGetBufferParameteriv=env._emscripten_glGetBufferParameteriv;
  var _emscripten_glGetError=env._emscripten_glGetError;
  var _emscripten_glGetFloatv=env._emscripten_glGetFloatv;
  var _emscripten_glGetFramebufferAttachmentParameteriv=env._emscripten_glGetFramebufferAttachmentParameteriv;
  var _emscripten_glGetIntegerv=env._emscripten_glGetIntegerv;
  var _emscripten_glGetProgramInfoLog=env._emscripten_glGetProgramInfoLog;
  var _emscripten_glGetProgramiv=env._emscripten_glGetProgramiv;
  var _emscripten_glGetQueryObjecti64vEXT=env._emscripten_glGetQueryObjecti64vEXT;
  var _emscripten_glGetQueryObjectivEXT=env._emscripten_glGetQueryObjectivEXT;
  var _emscripten_glGetQueryObjectui64vEXT=env._emscripten_glGetQueryObjectui64vEXT;
  var _emscripten_glGetQueryObjectuivEXT=env._emscripten_glGetQueryObjectuivEXT;
  var _emscripten_glGetQueryivEXT=env._emscripten_glGetQueryivEXT;
  var _emscripten_glGetRenderbufferParameteriv=env._emscripten_glGetRenderbufferParameteriv;
  var _emscripten_glGetShaderInfoLog=env._emscripten_glGetShaderInfoLog;
  var _emscripten_glGetShaderPrecisionFormat=env._emscripten_glGetShaderPrecisionFormat;
  var _emscripten_glGetShaderSource=env._emscripten_glGetShaderSource;
  var _emscripten_glGetShaderiv=env._emscripten_glGetShaderiv;
  var _emscripten_glGetString=env._emscripten_glGetString;
  var _emscripten_glGetTexParameterfv=env._emscripten_glGetTexParameterfv;
  var _emscripten_glGetTexParameteriv=env._emscripten_glGetTexParameteriv;
  var _emscripten_glGetUniformLocation=env._emscripten_glGetUniformLocation;
  var _emscripten_glGetUniformfv=env._emscripten_glGetUniformfv;
  var _emscripten_glGetUniformiv=env._emscripten_glGetUniformiv;
  var _emscripten_glGetVertexAttribPointerv=env._emscripten_glGetVertexAttribPointerv;
  var _emscripten_glGetVertexAttribfv=env._emscripten_glGetVertexAttribfv;
  var _emscripten_glGetVertexAttribiv=env._emscripten_glGetVertexAttribiv;
  var _emscripten_glHint=env._emscripten_glHint;
  var _emscripten_glIsBuffer=env._emscripten_glIsBuffer;
  var _emscripten_glIsEnabled=env._emscripten_glIsEnabled;
  var _emscripten_glIsFramebuffer=env._emscripten_glIsFramebuffer;
  var _emscripten_glIsProgram=env._emscripten_glIsProgram;
  var _emscripten_glIsQueryEXT=env._emscripten_glIsQueryEXT;
  var _emscripten_glIsRenderbuffer=env._emscripten_glIsRenderbuffer;
  var _emscripten_glIsShader=env._emscripten_glIsShader;
  var _emscripten_glIsTexture=env._emscripten_glIsTexture;
  var _emscripten_glIsVertexArray=env._emscripten_glIsVertexArray;
  var _emscripten_glIsVertexArrayOES=env._emscripten_glIsVertexArrayOES;
  var _emscripten_glLineWidth=env._emscripten_glLineWidth;
  var _emscripten_glLinkProgram=env._emscripten_glLinkProgram;
  var _emscripten_glLoadIdentity=env._emscripten_glLoadIdentity;
  var _emscripten_glMatrixMode=env._emscripten_glMatrixMode;
  var _emscripten_glPixelStorei=env._emscripten_glPixelStorei;
  var _emscripten_glPolygonOffset=env._emscripten_glPolygonOffset;
  var _emscripten_glQueryCounterEXT=env._emscripten_glQueryCounterEXT;
  var _emscripten_glReadPixels=env._emscripten_glReadPixels;
  var _emscripten_glReleaseShaderCompiler=env._emscripten_glReleaseShaderCompiler;
  var _emscripten_glRenderbufferStorage=env._emscripten_glRenderbufferStorage;
  var _emscripten_glSampleCoverage=env._emscripten_glSampleCoverage;
  var _emscripten_glScissor=env._emscripten_glScissor;
  var _emscripten_glShaderBinary=env._emscripten_glShaderBinary;
  var _emscripten_glShaderSource=env._emscripten_glShaderSource;
  var _emscripten_glStencilFunc=env._emscripten_glStencilFunc;
  var _emscripten_glStencilFuncSeparate=env._emscripten_glStencilFuncSeparate;
  var _emscripten_glStencilMask=env._emscripten_glStencilMask;
  var _emscripten_glStencilMaskSeparate=env._emscripten_glStencilMaskSeparate;
  var _emscripten_glStencilOp=env._emscripten_glStencilOp;
  var _emscripten_glStencilOpSeparate=env._emscripten_glStencilOpSeparate;
  var _emscripten_glTexImage2D=env._emscripten_glTexImage2D;
  var _emscripten_glTexParameterf=env._emscripten_glTexParameterf;
  var _emscripten_glTexParameterfv=env._emscripten_glTexParameterfv;
  var _emscripten_glTexParameteri=env._emscripten_glTexParameteri;
  var _emscripten_glTexParameteriv=env._emscripten_glTexParameteriv;
  var _emscripten_glTexSubImage2D=env._emscripten_glTexSubImage2D;
  var _emscripten_glUniform1f=env._emscripten_glUniform1f;
  var _emscripten_glUniform1fv=env._emscripten_glUniform1fv;
  var _emscripten_glUniform1i=env._emscripten_glUniform1i;
  var _emscripten_glUniform1iv=env._emscripten_glUniform1iv;
  var _emscripten_glUniform2f=env._emscripten_glUniform2f;
  var _emscripten_glUniform2fv=env._emscripten_glUniform2fv;
  var _emscripten_glUniform2i=env._emscripten_glUniform2i;
  var _emscripten_glUniform2iv=env._emscripten_glUniform2iv;
  var _emscripten_glUniform3f=env._emscripten_glUniform3f;
  var _emscripten_glUniform3fv=env._emscripten_glUniform3fv;
  var _emscripten_glUniform3i=env._emscripten_glUniform3i;
  var _emscripten_glUniform3iv=env._emscripten_glUniform3iv;
  var _emscripten_glUniform4f=env._emscripten_glUniform4f;
  var _emscripten_glUniform4fv=env._emscripten_glUniform4fv;
  var _emscripten_glUniform4i=env._emscripten_glUniform4i;
  var _emscripten_glUniform4iv=env._emscripten_glUniform4iv;
  var _emscripten_glUniformMatrix2fv=env._emscripten_glUniformMatrix2fv;
  var _emscripten_glUniformMatrix3fv=env._emscripten_glUniformMatrix3fv;
  var _emscripten_glUniformMatrix4fv=env._emscripten_glUniformMatrix4fv;
  var _emscripten_glUseProgram=env._emscripten_glUseProgram;
  var _emscripten_glValidateProgram=env._emscripten_glValidateProgram;
  var _emscripten_glVertexAttrib1f=env._emscripten_glVertexAttrib1f;
  var _emscripten_glVertexAttrib1fv=env._emscripten_glVertexAttrib1fv;
  var _emscripten_glVertexAttrib2f=env._emscripten_glVertexAttrib2f;
  var _emscripten_glVertexAttrib2fv=env._emscripten_glVertexAttrib2fv;
  var _emscripten_glVertexAttrib3f=env._emscripten_glVertexAttrib3f;
  var _emscripten_glVertexAttrib3fv=env._emscripten_glVertexAttrib3fv;
  var _emscripten_glVertexAttrib4f=env._emscripten_glVertexAttrib4f;
  var _emscripten_glVertexAttrib4fv=env._emscripten_glVertexAttrib4fv;
  var _emscripten_glVertexAttribDivisor=env._emscripten_glVertexAttribDivisor;
  var _emscripten_glVertexAttribDivisorANGLE=env._emscripten_glVertexAttribDivisorANGLE;
  var _emscripten_glVertexAttribDivisorARB=env._emscripten_glVertexAttribDivisorARB;
  var _emscripten_glVertexAttribDivisorEXT=env._emscripten_glVertexAttribDivisorEXT;
  var _emscripten_glVertexAttribDivisorNV=env._emscripten_glVertexAttribDivisorNV;
  var _emscripten_glVertexAttribPointer=env._emscripten_glVertexAttribPointer;
  var _emscripten_glVertexPointer=env._emscripten_glVertexPointer;
  var _emscripten_glViewport=env._emscripten_glViewport;
  var _emscripten_gluLookAt=env._emscripten_gluLookAt;
  var _emscripten_gluOrtho2D=env._emscripten_gluOrtho2D;
  var _emscripten_gluPerspective=env._emscripten_gluPerspective;
  var _emscripten_gluProject=env._emscripten_gluProject;
  var _emscripten_gluUnProject=env._emscripten_gluUnProject;
  var _emscripten_has_threading_support=env._emscripten_has_threading_support;
  var _emscripten_hide_mouse=env._emscripten_hide_mouse;
  var _emscripten_html5_remove_all_event_listeners=env._emscripten_html5_remove_all_event_listeners;
  var _emscripten_idb_async_delete=env._emscripten_idb_async_delete;
  var _emscripten_idb_async_exists=env._emscripten_idb_async_exists;
  var _emscripten_idb_async_load=env._emscripten_idb_async_load;
  var _emscripten_idb_async_store=env._emscripten_idb_async_store;
  var _emscripten_idb_delete=env._emscripten_idb_delete;
  var _emscripten_idb_exists=env._emscripten_idb_exists;
  var _emscripten_idb_load=env._emscripten_idb_load;
  var _emscripten_idb_store=env._emscripten_idb_store;
  var _emscripten_is_main_browser_thread=env._emscripten_is_main_browser_thread;
  var _emscripten_is_main_runtime_thread=env._emscripten_is_main_runtime_thread;
  var _emscripten_is_webgl_context_lost=env._emscripten_is_webgl_context_lost;
  var _emscripten_lock_orientation=env._emscripten_lock_orientation;
  var _emscripten_log=env._emscripten_log;
  var _emscripten_log_js=env._emscripten_log_js;
  var _emscripten_longjmp=env._emscripten_longjmp;
  var _emscripten_main_browser_thread_id=env._emscripten_main_browser_thread_id;
  var _emscripten_main_thread_process_queued_calls=env._emscripten_main_thread_process_queued_calls;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _emscripten_num_logical_cores=env._emscripten_num_logical_cores;
  var _emscripten_pause_main_loop=env._emscripten_pause_main_loop;
  var _emscripten_print_double=env._emscripten_print_double;
  var _emscripten_random=env._emscripten_random;
  var _emscripten_request_fullscreen=env._emscripten_request_fullscreen;
  var _emscripten_request_fullscreen_strategy=env._emscripten_request_fullscreen_strategy;
  var _emscripten_request_pointerlock=env._emscripten_request_pointerlock;
  var _emscripten_resume_main_loop=env._emscripten_resume_main_loop;
  var _emscripten_run_preload_plugins=env._emscripten_run_preload_plugins;
  var _emscripten_run_preload_plugins_data=env._emscripten_run_preload_plugins_data;
  var _emscripten_run_script=env._emscripten_run_script;
  var _emscripten_run_script_int=env._emscripten_run_script_int;
  var _emscripten_run_script_string=env._emscripten_run_script_string;
  var _emscripten_set_batterychargingchange_callback_on_thread=env._emscripten_set_batterychargingchange_callback_on_thread;
  var _emscripten_set_batterylevelchange_callback_on_thread=env._emscripten_set_batterylevelchange_callback_on_thread;
  var _emscripten_set_beforeunload_callback_on_thread=env._emscripten_set_beforeunload_callback_on_thread;
  var _emscripten_set_blur_callback_on_thread=env._emscripten_set_blur_callback_on_thread;
  var _emscripten_set_canvas_element_size=env._emscripten_set_canvas_element_size;
  var _emscripten_set_canvas_size=env._emscripten_set_canvas_size;
  var _emscripten_set_click_callback_on_thread=env._emscripten_set_click_callback_on_thread;
  var _emscripten_set_dblclick_callback_on_thread=env._emscripten_set_dblclick_callback_on_thread;
  var _emscripten_set_devicemotion_callback_on_thread=env._emscripten_set_devicemotion_callback_on_thread;
  var _emscripten_set_deviceorientation_callback_on_thread=env._emscripten_set_deviceorientation_callback_on_thread;
  var _emscripten_set_element_css_size=env._emscripten_set_element_css_size;
  var _emscripten_set_focus_callback_on_thread=env._emscripten_set_focus_callback_on_thread;
  var _emscripten_set_focusin_callback_on_thread=env._emscripten_set_focusin_callback_on_thread;
  var _emscripten_set_focusout_callback_on_thread=env._emscripten_set_focusout_callback_on_thread;
  var _emscripten_set_fullscreenchange_callback_on_thread=env._emscripten_set_fullscreenchange_callback_on_thread;
  var _emscripten_set_gamepadconnected_callback_on_thread=env._emscripten_set_gamepadconnected_callback_on_thread;
  var _emscripten_set_gamepaddisconnected_callback_on_thread=env._emscripten_set_gamepaddisconnected_callback_on_thread;
  var _emscripten_set_keydown_callback_on_thread=env._emscripten_set_keydown_callback_on_thread;
  var _emscripten_set_keypress_callback_on_thread=env._emscripten_set_keypress_callback_on_thread;
  var _emscripten_set_keyup_callback_on_thread=env._emscripten_set_keyup_callback_on_thread;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var _emscripten_set_main_loop_arg=env._emscripten_set_main_loop_arg;
  var _emscripten_set_main_loop_expected_blockers=env._emscripten_set_main_loop_expected_blockers;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var _emscripten_set_mousedown_callback_on_thread=env._emscripten_set_mousedown_callback_on_thread;
  var _emscripten_set_mouseenter_callback_on_thread=env._emscripten_set_mouseenter_callback_on_thread;
  var _emscripten_set_mouseleave_callback_on_thread=env._emscripten_set_mouseleave_callback_on_thread;
  var _emscripten_set_mousemove_callback_on_thread=env._emscripten_set_mousemove_callback_on_thread;
  var _emscripten_set_mouseout_callback_on_thread=env._emscripten_set_mouseout_callback_on_thread;
  var _emscripten_set_mouseover_callback_on_thread=env._emscripten_set_mouseover_callback_on_thread;
  var _emscripten_set_mouseup_callback_on_thread=env._emscripten_set_mouseup_callback_on_thread;
  var _emscripten_set_orientationchange_callback_on_thread=env._emscripten_set_orientationchange_callback_on_thread;
  var _emscripten_set_pointerlockchange_callback_on_thread=env._emscripten_set_pointerlockchange_callback_on_thread;
  var _emscripten_set_pointerlockerror_callback_on_thread=env._emscripten_set_pointerlockerror_callback_on_thread;
  var _emscripten_set_resize_callback_on_thread=env._emscripten_set_resize_callback_on_thread;
  var _emscripten_set_scroll_callback_on_thread=env._emscripten_set_scroll_callback_on_thread;
  var _emscripten_set_socket_close_callback=env._emscripten_set_socket_close_callback;
  var _emscripten_set_socket_connection_callback=env._emscripten_set_socket_connection_callback;
  var _emscripten_set_socket_error_callback=env._emscripten_set_socket_error_callback;
  var _emscripten_set_socket_listen_callback=env._emscripten_set_socket_listen_callback;
  var _emscripten_set_socket_message_callback=env._emscripten_set_socket_message_callback;
  var _emscripten_set_socket_open_callback=env._emscripten_set_socket_open_callback;
  var _emscripten_set_touchcancel_callback_on_thread=env._emscripten_set_touchcancel_callback_on_thread;
  var _emscripten_set_touchend_callback_on_thread=env._emscripten_set_touchend_callback_on_thread;
  var _emscripten_set_touchmove_callback_on_thread=env._emscripten_set_touchmove_callback_on_thread;
  var _emscripten_set_touchstart_callback_on_thread=env._emscripten_set_touchstart_callback_on_thread;
  var _emscripten_set_visibilitychange_callback_on_thread=env._emscripten_set_visibilitychange_callback_on_thread;
  var _emscripten_set_webglcontextlost_callback_on_thread=env._emscripten_set_webglcontextlost_callback_on_thread;
  var _emscripten_set_webglcontextrestored_callback_on_thread=env._emscripten_set_webglcontextrestored_callback_on_thread;
  var _emscripten_set_wheel_callback_on_thread=env._emscripten_set_wheel_callback_on_thread;
  var _emscripten_sleep=env._emscripten_sleep;
  var _emscripten_supports_offscreencanvas=env._emscripten_supports_offscreencanvas;
  var _emscripten_unlock_orientation=env._emscripten_unlock_orientation;
  var _emscripten_vibrate=env._emscripten_vibrate;
  var _emscripten_vibrate_pattern=env._emscripten_vibrate_pattern;
  var _emscripten_vr_cancel_display_render_loop=env._emscripten_vr_cancel_display_render_loop;
  var _emscripten_vr_count_displays=env._emscripten_vr_count_displays;
  var _emscripten_vr_deinit=env._emscripten_vr_deinit;
  var _emscripten_vr_display_connected=env._emscripten_vr_display_connected;
  var _emscripten_vr_display_presenting=env._emscripten_vr_display_presenting;
  var _emscripten_vr_exit_present=env._emscripten_vr_exit_present;
  var _emscripten_vr_get_display_capabilities=env._emscripten_vr_get_display_capabilities;
  var _emscripten_vr_get_display_handle=env._emscripten_vr_get_display_handle;
  var _emscripten_vr_get_display_name=env._emscripten_vr_get_display_name;
  var _emscripten_vr_get_eye_parameters=env._emscripten_vr_get_eye_parameters;
  var _emscripten_vr_get_frame_data=env._emscripten_vr_get_frame_data;
  var _emscripten_vr_init=env._emscripten_vr_init;
  var _emscripten_vr_ready=env._emscripten_vr_ready;
  var _emscripten_vr_request_present=env._emscripten_vr_request_present;
  var _emscripten_vr_set_display_render_loop=env._emscripten_vr_set_display_render_loop;
  var _emscripten_vr_set_display_render_loop_arg=env._emscripten_vr_set_display_render_loop_arg;
  var _emscripten_vr_submit_frame=env._emscripten_vr_submit_frame;
  var _emscripten_vr_version_major=env._emscripten_vr_version_major;
  var _emscripten_vr_version_minor=env._emscripten_vr_version_minor;
  var _emscripten_webgl_commit_frame=env._emscripten_webgl_commit_frame;
  var _emscripten_webgl_create_context=env._emscripten_webgl_create_context;
  var _emscripten_webgl_destroy_context=env._emscripten_webgl_destroy_context;
  var _emscripten_webgl_destroy_context_calling_thread=env._emscripten_webgl_destroy_context_calling_thread;
  var _emscripten_webgl_do_commit_frame=env._emscripten_webgl_do_commit_frame;
  var _emscripten_webgl_do_create_context=env._emscripten_webgl_do_create_context;
  var _emscripten_webgl_do_get_current_context=env._emscripten_webgl_do_get_current_context;
  var _emscripten_webgl_enable_extension=env._emscripten_webgl_enable_extension;
  var _emscripten_webgl_enable_extension_calling_thread=env._emscripten_webgl_enable_extension_calling_thread;
  var _emscripten_webgl_get_current_context=env._emscripten_webgl_get_current_context;
  var _emscripten_webgl_get_drawing_buffer_size=env._emscripten_webgl_get_drawing_buffer_size;
  var _emscripten_webgl_get_drawing_buffer_size_calling_thread=env._emscripten_webgl_get_drawing_buffer_size_calling_thread;
  var _emscripten_webgl_init_context_attributes=env._emscripten_webgl_init_context_attributes;
  var _emscripten_webgl_make_context_current=env._emscripten_webgl_make_context_current;
  var _emscripten_wget=env._emscripten_wget;
  var _emscripten_wget_data=env._emscripten_wget_data;
  var _emscripten_worker_respond=env._emscripten_worker_respond;
  var _emscripten_worker_respond_provisionally=env._emscripten_worker_respond_provisionally;
  var _emscripten_yield=env._emscripten_yield;
  var _endprotoent=env._endprotoent;
  var _endpwent=env._endpwent;
  var _execl=env._execl;
  var _execle=env._execle;
  var _execlp=env._execlp;
  var _execv=env._execv;
  var _execve=env._execve;
  var _execvp=env._execvp;
  var _exit=env._exit;
  var _exp=env._exp;
  var _expf=env._expf;
  var _expl=env._expl;
  var _fabs=env._fabs;
  var _fabsf=env._fabsf;
  var _fabsl=env._fabsl;
  var _fexecve=env._fexecve;
  var _filledEllipseColor=env._filledEllipseColor;
  var _filledEllipseRGBA=env._filledEllipseRGBA;
  var _flock=env._flock;
  var _floor=env._floor;
  var _floorf=env._floorf;
  var _floorl=env._floorl;
  var _fork=env._fork;
  var _fpathconf=env._fpathconf;
  var _ftime=env._ftime;
  var _gai_strerror=env._gai_strerror;
  var _getaddrinfo=env._getaddrinfo;
  var _getdate=env._getdate;
  var _getenv=env._getenv;
  var _gethostbyaddr=env._gethostbyaddr;
  var _gethostbyname=env._gethostbyname;
  var _gethostbyname_r=env._gethostbyname_r;
  var _getitimer=env._getitimer;
  var _getloadavg=env._getloadavg;
  var _getnameinfo=env._getnameinfo;
  var _getpagesize=env._getpagesize;
  var _getprotobyname=env._getprotobyname;
  var _getprotobynumber=env._getprotobynumber;
  var _getprotoent=env._getprotoent;
  var _getpwent=env._getpwent;
  var _getpwnam=env._getpwnam;
  var _getpwuid=env._getpwuid;
  var _gettimeofday=env._gettimeofday;
  var _glActiveTexture=env._glActiveTexture;
  var _glAttachShader=env._glAttachShader;
  var _glBegin=env._glBegin;
  var _glBeginQueryEXT=env._glBeginQueryEXT;
  var _glBindAttribLocation=env._glBindAttribLocation;
  var _glBindBuffer=env._glBindBuffer;
  var _glBindFramebuffer=env._glBindFramebuffer;
  var _glBindRenderbuffer=env._glBindRenderbuffer;
  var _glBindTexture=env._glBindTexture;
  var _glBindVertexArray=env._glBindVertexArray;
  var _glBindVertexArrayOES=env._glBindVertexArrayOES;
  var _glBlendColor=env._glBlendColor;
  var _glBlendEquation=env._glBlendEquation;
  var _glBlendEquationSeparate=env._glBlendEquationSeparate;
  var _glBlendFunc=env._glBlendFunc;
  var _glBlendFuncSeparate=env._glBlendFuncSeparate;
  var _glBufferData=env._glBufferData;
  var _glBufferSubData=env._glBufferSubData;
  var _glCheckFramebufferStatus=env._glCheckFramebufferStatus;
  var _glClear=env._glClear;
  var _glClearColor=env._glClearColor;
  var _glClearDepth=env._glClearDepth;
  var _glClearDepthf=env._glClearDepthf;
  var _glClearStencil=env._glClearStencil;
  var _glColorMask=env._glColorMask;
  var _glCompileShader=env._glCompileShader;
  var _glCompressedTexImage2D=env._glCompressedTexImage2D;
  var _glCompressedTexSubImage2D=env._glCompressedTexSubImage2D;
  var _glCopyTexImage2D=env._glCopyTexImage2D;
  var _glCopyTexSubImage2D=env._glCopyTexSubImage2D;
  var _glCreateProgram=env._glCreateProgram;
  var _glCreateShader=env._glCreateShader;
  var _glCullFace=env._glCullFace;
  var _glDeleteBuffers=env._glDeleteBuffers;
  var _glDeleteFramebuffers=env._glDeleteFramebuffers;
  var _glDeleteProgram=env._glDeleteProgram;
  var _glDeleteQueriesEXT=env._glDeleteQueriesEXT;
  var _glDeleteRenderbuffers=env._glDeleteRenderbuffers;
  var _glDeleteShader=env._glDeleteShader;
  var _glDeleteTextures=env._glDeleteTextures;
  var _glDeleteVertexArrays=env._glDeleteVertexArrays;
  var _glDeleteVertexArraysOES=env._glDeleteVertexArraysOES;
  var _glDepthFunc=env._glDepthFunc;
  var _glDepthMask=env._glDepthMask;
  var _glDepthRange=env._glDepthRange;
  var _glDepthRangef=env._glDepthRangef;
  var _glDetachShader=env._glDetachShader;
  var _glDisable=env._glDisable;
  var _glDisableVertexAttribArray=env._glDisableVertexAttribArray;
  var _glDrawArrays=env._glDrawArrays;
  var _glDrawArraysInstanced=env._glDrawArraysInstanced;
  var _glDrawArraysInstancedANGLE=env._glDrawArraysInstancedANGLE;
  var _glDrawArraysInstancedARB=env._glDrawArraysInstancedARB;
  var _glDrawArraysInstancedEXT=env._glDrawArraysInstancedEXT;
  var _glDrawArraysInstancedNV=env._glDrawArraysInstancedNV;
  var _glDrawBuffers=env._glDrawBuffers;
  var _glDrawBuffersEXT=env._glDrawBuffersEXT;
  var _glDrawBuffersWEBGL=env._glDrawBuffersWEBGL;
  var _glDrawElements=env._glDrawElements;
  var _glDrawElementsInstanced=env._glDrawElementsInstanced;
  var _glDrawElementsInstancedANGLE=env._glDrawElementsInstancedANGLE;
  var _glDrawElementsInstancedARB=env._glDrawElementsInstancedARB;
  var _glDrawElementsInstancedEXT=env._glDrawElementsInstancedEXT;
  var _glDrawElementsInstancedNV=env._glDrawElementsInstancedNV;
  var _glEnable=env._glEnable;
  var _glEnableVertexAttribArray=env._glEnableVertexAttribArray;
  var _glEndQueryEXT=env._glEndQueryEXT;
  var _glFinish=env._glFinish;
  var _glFlush=env._glFlush;
  var _glFramebufferRenderbuffer=env._glFramebufferRenderbuffer;
  var _glFramebufferTexture2D=env._glFramebufferTexture2D;
  var _glFrontFace=env._glFrontFace;
  var _glGenBuffers=env._glGenBuffers;
  var _glGenFramebuffers=env._glGenFramebuffers;
  var _glGenQueriesEXT=env._glGenQueriesEXT;
  var _glGenRenderbuffers=env._glGenRenderbuffers;
  var _glGenTextures=env._glGenTextures;
  var _glGenVertexArrays=env._glGenVertexArrays;
  var _glGenVertexArraysOES=env._glGenVertexArraysOES;
  var _glGenerateMipmap=env._glGenerateMipmap;
  var _glGetActiveAttrib=env._glGetActiveAttrib;
  var _glGetActiveUniform=env._glGetActiveUniform;
  var _glGetAttachedShaders=env._glGetAttachedShaders;
  var _glGetAttribLocation=env._glGetAttribLocation;
  var _glGetBooleanv=env._glGetBooleanv;
  var _glGetBufferParameteriv=env._glGetBufferParameteriv;
  var _glGetError=env._glGetError;
  var _glGetFloatv=env._glGetFloatv;
  var _glGetFramebufferAttachmentParameteriv=env._glGetFramebufferAttachmentParameteriv;
  var _glGetIntegerv=env._glGetIntegerv;
  var _glGetProgramInfoLog=env._glGetProgramInfoLog;
  var _glGetProgramiv=env._glGetProgramiv;
  var _glGetQueryObjecti64vEXT=env._glGetQueryObjecti64vEXT;
  var _glGetQueryObjectivEXT=env._glGetQueryObjectivEXT;
  var _glGetQueryObjectui64vEXT=env._glGetQueryObjectui64vEXT;
  var _glGetQueryObjectuivEXT=env._glGetQueryObjectuivEXT;
  var _glGetQueryivEXT=env._glGetQueryivEXT;
  var _glGetRenderbufferParameteriv=env._glGetRenderbufferParameteriv;
  var _glGetShaderInfoLog=env._glGetShaderInfoLog;
  var _glGetShaderPrecisionFormat=env._glGetShaderPrecisionFormat;
  var _glGetShaderSource=env._glGetShaderSource;
  var _glGetShaderiv=env._glGetShaderiv;
  var _glGetString=env._glGetString;
  var _glGetTexParameterfv=env._glGetTexParameterfv;
  var _glGetTexParameteriv=env._glGetTexParameteriv;
  var _glGetUniformLocation=env._glGetUniformLocation;
  var _glGetUniformfv=env._glGetUniformfv;
  var _glGetUniformiv=env._glGetUniformiv;
  var _glGetVertexAttribPointerv=env._glGetVertexAttribPointerv;
  var _glGetVertexAttribfv=env._glGetVertexAttribfv;
  var _glGetVertexAttribiv=env._glGetVertexAttribiv;
  var _glHint=env._glHint;
  var _glIsBuffer=env._glIsBuffer;
  var _glIsEnabled=env._glIsEnabled;
  var _glIsFramebuffer=env._glIsFramebuffer;
  var _glIsProgram=env._glIsProgram;
  var _glIsQueryEXT=env._glIsQueryEXT;
  var _glIsRenderbuffer=env._glIsRenderbuffer;
  var _glIsShader=env._glIsShader;
  var _glIsTexture=env._glIsTexture;
  var _glIsVertexArray=env._glIsVertexArray;
  var _glIsVertexArrayOES=env._glIsVertexArrayOES;
  var _glLineWidth=env._glLineWidth;
  var _glLinkProgram=env._glLinkProgram;
  var _glLoadIdentity=env._glLoadIdentity;
  var _glMatrixMode=env._glMatrixMode;
  var _glPixelStorei=env._glPixelStorei;
  var _glPolygonOffset=env._glPolygonOffset;
  var _glQueryCounterEXT=env._glQueryCounterEXT;
  var _glReadPixels=env._glReadPixels;
  var _glReleaseShaderCompiler=env._glReleaseShaderCompiler;
  var _glRenderbufferStorage=env._glRenderbufferStorage;
  var _glSampleCoverage=env._glSampleCoverage;
  var _glScissor=env._glScissor;
  var _glShaderBinary=env._glShaderBinary;
  var _glShaderSource=env._glShaderSource;
  var _glStencilFunc=env._glStencilFunc;
  var _glStencilFuncSeparate=env._glStencilFuncSeparate;
  var _glStencilMask=env._glStencilMask;
  var _glStencilMaskSeparate=env._glStencilMaskSeparate;
  var _glStencilOp=env._glStencilOp;
  var _glStencilOpSeparate=env._glStencilOpSeparate;
  var _glTexImage2D=env._glTexImage2D;
  var _glTexParameterf=env._glTexParameterf;
  var _glTexParameterfv=env._glTexParameterfv;
  var _glTexParameteri=env._glTexParameteri;
  var _glTexParameteriv=env._glTexParameteriv;
  var _glTexSubImage2D=env._glTexSubImage2D;
  var _glUniform1f=env._glUniform1f;
  var _glUniform1fv=env._glUniform1fv;
  var _glUniform1i=env._glUniform1i;
  var _glUniform1iv=env._glUniform1iv;
  var _glUniform2f=env._glUniform2f;
  var _glUniform2fv=env._glUniform2fv;
  var _glUniform2i=env._glUniform2i;
  var _glUniform2iv=env._glUniform2iv;
  var _glUniform3f=env._glUniform3f;
  var _glUniform3fv=env._glUniform3fv;
  var _glUniform3i=env._glUniform3i;
  var _glUniform3iv=env._glUniform3iv;
  var _glUniform4f=env._glUniform4f;
  var _glUniform4fv=env._glUniform4fv;
  var _glUniform4i=env._glUniform4i;
  var _glUniform4iv=env._glUniform4iv;
  var _glUniformMatrix2fv=env._glUniformMatrix2fv;
  var _glUniformMatrix3fv=env._glUniformMatrix3fv;
  var _glUniformMatrix4fv=env._glUniformMatrix4fv;
  var _glUseProgram=env._glUseProgram;
  var _glValidateProgram=env._glValidateProgram;
  var _glVertexAttrib1f=env._glVertexAttrib1f;
  var _glVertexAttrib1fv=env._glVertexAttrib1fv;
  var _glVertexAttrib2f=env._glVertexAttrib2f;
  var _glVertexAttrib2fv=env._glVertexAttrib2fv;
  var _glVertexAttrib3f=env._glVertexAttrib3f;
  var _glVertexAttrib3fv=env._glVertexAttrib3fv;
  var _glVertexAttrib4f=env._glVertexAttrib4f;
  var _glVertexAttrib4fv=env._glVertexAttrib4fv;
  var _glVertexAttribDivisor=env._glVertexAttribDivisor;
  var _glVertexAttribDivisorANGLE=env._glVertexAttribDivisorANGLE;
  var _glVertexAttribDivisorARB=env._glVertexAttribDivisorARB;
  var _glVertexAttribDivisorEXT=env._glVertexAttribDivisorEXT;
  var _glVertexAttribDivisorNV=env._glVertexAttribDivisorNV;
  var _glVertexAttribPointer=env._glVertexAttribPointer;
  var _glVertexPointer=env._glVertexPointer;
  var _glViewport=env._glViewport;
  var _glewGetErrorString=env._glewGetErrorString;
  var _glewGetExtension=env._glewGetExtension;
  var _glewGetString=env._glewGetString;
  var _glewInit=env._glewInit;
  var _glewIsSupported=env._glewIsSupported;
  var _glfwBroadcastCond=env._glfwBroadcastCond;
  var _glfwCloseWindow=env._glfwCloseWindow;
  var _glfwCreateCond=env._glfwCreateCond;
  var _glfwCreateMutex=env._glfwCreateMutex;
  var _glfwCreateThread=env._glfwCreateThread;
  var _glfwDestroyCond=env._glfwDestroyCond;
  var _glfwDestroyMutex=env._glfwDestroyMutex;
  var _glfwDestroyThread=env._glfwDestroyThread;
  var _glfwDisable=env._glfwDisable;
  var _glfwEnable=env._glfwEnable;
  var _glfwExtensionSupported=env._glfwExtensionSupported;
  var _glfwFreeImage=env._glfwFreeImage;
  var _glfwGetDesktopMode=env._glfwGetDesktopMode;
  var _glfwGetGLVersion=env._glfwGetGLVersion;
  var _glfwGetKey=env._glfwGetKey;
  var _glfwGetMouseButton=env._glfwGetMouseButton;
  var _glfwGetMousePos=env._glfwGetMousePos;
  var _glfwGetMouseWheel=env._glfwGetMouseWheel;
  var _glfwGetNumberOfProcessors=env._glfwGetNumberOfProcessors;
  var _glfwGetProcAddress=env._glfwGetProcAddress;
  var _glfwGetThreadID=env._glfwGetThreadID;
  var _glfwGetTime=env._glfwGetTime;
  var _glfwGetVersion=env._glfwGetVersion;
  var _glfwGetWindowParam=env._glfwGetWindowParam;
  var _glfwGetWindowPos=env._glfwGetWindowPos;
  var _glfwGetWindowSize=env._glfwGetWindowSize;
  var _glfwIconifyWindow=env._glfwIconifyWindow;
  var _glfwInit=env._glfwInit;
  var _glfwLoadMemoryTexture2D=env._glfwLoadMemoryTexture2D;
  var _glfwLoadTexture2D=env._glfwLoadTexture2D;
  var _glfwLoadTextureImage2D=env._glfwLoadTextureImage2D;
  var _glfwLockMutex=env._glfwLockMutex;
  var _glfwOpenWindow=env._glfwOpenWindow;
  var _glfwOpenWindowHint=env._glfwOpenWindowHint;
  var _glfwPollEvents=env._glfwPollEvents;
  var _glfwReadImage=env._glfwReadImage;
  var _glfwReadMemoryImage=env._glfwReadMemoryImage;
  var _glfwRestoreWindow=env._glfwRestoreWindow;
  var _glfwSetCharCallback=env._glfwSetCharCallback;
  var _glfwSetKeyCallback=env._glfwSetKeyCallback;
  var _glfwSetMouseButtonCallback=env._glfwSetMouseButtonCallback;
  var _glfwSetMousePos=env._glfwSetMousePos;
  var _glfwSetMousePosCallback=env._glfwSetMousePosCallback;
  var _glfwSetMouseWheel=env._glfwSetMouseWheel;
  var _glfwSetMouseWheelCallback=env._glfwSetMouseWheelCallback;
  var _glfwSetTime=env._glfwSetTime;
  var _glfwSetWindowCloseCallback=env._glfwSetWindowCloseCallback;
  var _glfwSetWindowPos=env._glfwSetWindowPos;
  var _glfwSetWindowRefreshCallback=env._glfwSetWindowRefreshCallback;
  var _glfwSetWindowSize=env._glfwSetWindowSize;
  var _glfwSetWindowSizeCallback=env._glfwSetWindowSizeCallback;
  var _glfwSetWindowTitle=env._glfwSetWindowTitle;
  var _glfwSignalCond=env._glfwSignalCond;
  var _glfwSleep=env._glfwSleep;
  var _glfwSwapBuffers=env._glfwSwapBuffers;
  var _glfwSwapInterval=env._glfwSwapInterval;
  var _glfwTerminate=env._glfwTerminate;
  var _glfwUnlockMutex=env._glfwUnlockMutex;
  var _glfwWaitCond=env._glfwWaitCond;
  var _glfwWaitEvents=env._glfwWaitEvents;
  var _glfwWaitThread=env._glfwWaitThread;
  var _gluLookAt=env._gluLookAt;
  var _gluOrtho2D=env._gluOrtho2D;
  var _gluPerspective=env._gluPerspective;
  var _gluProject=env._gluProject;
  var _gluUnProject=env._gluUnProject;
  var _glutCreateWindow=env._glutCreateWindow;
  var _glutDestroyWindow=env._glutDestroyWindow;
  var _glutDisplayFunc=env._glutDisplayFunc;
  var _glutFullScreen=env._glutFullScreen;
  var _glutGet=env._glutGet;
  var _glutGetModifiers=env._glutGetModifiers;
  var _glutIdleFunc=env._glutIdleFunc;
  var _glutInit=env._glutInit;
  var _glutInitDisplayMode=env._glutInitDisplayMode;
  var _glutInitWindowPosition=env._glutInitWindowPosition;
  var _glutInitWindowSize=env._glutInitWindowSize;
  var _glutKeyboardFunc=env._glutKeyboardFunc;
  var _glutKeyboardUpFunc=env._glutKeyboardUpFunc;
  var _glutMainLoop=env._glutMainLoop;
  var _glutMotionFunc=env._glutMotionFunc;
  var _glutMouseFunc=env._glutMouseFunc;
  var _glutPassiveMotionFunc=env._glutPassiveMotionFunc;
  var _glutPositionWindow=env._glutPositionWindow;
  var _glutPostRedisplay=env._glutPostRedisplay;
  var _glutReshapeFunc=env._glutReshapeFunc;
  var _glutReshapeWindow=env._glutReshapeWindow;
  var _glutSetCursor=env._glutSetCursor;
  var _glutSpecialFunc=env._glutSpecialFunc;
  var _glutSpecialUpFunc=env._glutSpecialUpFunc;
  var _glutSwapBuffers=env._glutSwapBuffers;
  var _glutTimerFunc=env._glutTimerFunc;
  var _gmtime=env._gmtime;
  var _gmtime_r=env._gmtime_r;
  var _gnu_dev_major=env._gnu_dev_major;
  var _gnu_dev_makedev=env._gnu_dev_makedev;
  var _gnu_dev_minor=env._gnu_dev_minor;
  var _inet_addr=env._inet_addr;
  var _kfunc1=env._kfunc1;
  var _kill=env._kill;
  var _killpg=env._killpg;
  var _lineColor=env._lineColor;
  var _lineRGBA=env._lineRGBA;
  var _llvm_atomic_load_add_i32_p0i32=env._llvm_atomic_load_add_i32_p0i32;
  var _llvm_bswap_i64=env._llvm_bswap_i64;
  var _llvm_ceil_f32=env._llvm_ceil_f32;
  var _llvm_ceil_f64=env._llvm_ceil_f64;
  var _llvm_copysign_f32=env._llvm_copysign_f32;
  var _llvm_copysign_f64=env._llvm_copysign_f64;
  var _llvm_cos_f32=env._llvm_cos_f32;
  var _llvm_cos_f64=env._llvm_cos_f64;
  var _llvm_cttz_i64=env._llvm_cttz_i64;
  var _llvm_eh_exception=env._llvm_eh_exception;
  var _llvm_eh_selector=env._llvm_eh_selector;
  var _llvm_eh_typeid_for=env._llvm_eh_typeid_for;
  var _llvm_exp2_f32=env._llvm_exp2_f32;
  var _llvm_exp2_f64=env._llvm_exp2_f64;
  var _llvm_exp_f32=env._llvm_exp_f32;
  var _llvm_exp_f64=env._llvm_exp_f64;
  var _llvm_fabs_f32=env._llvm_fabs_f32;
  var _llvm_fabs_f64=env._llvm_fabs_f64;
  var _llvm_floor_f32=env._llvm_floor_f32;
  var _llvm_floor_f64=env._llvm_floor_f64;
  var _llvm_flt_rounds=env._llvm_flt_rounds;
  var _llvm_log10_f32=env._llvm_log10_f32;
  var _llvm_log10_f64=env._llvm_log10_f64;
  var _llvm_log2_f32=env._llvm_log2_f32;
  var _llvm_log2_f64=env._llvm_log2_f64;
  var _llvm_log_f32=env._llvm_log_f32;
  var _llvm_log_f64=env._llvm_log_f64;
  var _llvm_memory_barrier=env._llvm_memory_barrier;
  var _llvm_mono_load_i16_p0i16=env._llvm_mono_load_i16_p0i16;
  var _llvm_mono_load_i32_p0i32=env._llvm_mono_load_i32_p0i32;
  var _llvm_mono_load_i8_p0i8=env._llvm_mono_load_i8_p0i8;
  var _llvm_mono_store_i16_p0i16=env._llvm_mono_store_i16_p0i16;
  var _llvm_mono_store_i32_p0i32=env._llvm_mono_store_i32_p0i32;
  var _llvm_mono_store_i8_p0i8=env._llvm_mono_store_i8_p0i8;
  var _llvm_objectsize_i32=env._llvm_objectsize_i32;
  var _llvm_pow_f32=env._llvm_pow_f32;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _llvm_powi_f32=env._llvm_powi_f32;
  var _llvm_powi_f64=env._llvm_powi_f64;
  var _llvm_prefetch=env._llvm_prefetch;
  var _llvm_sin_f32=env._llvm_sin_f32;
  var _llvm_sin_f64=env._llvm_sin_f64;
  var _llvm_sqrt_f32=env._llvm_sqrt_f32;
  var _llvm_sqrt_f64=env._llvm_sqrt_f64;
  var _llvm_stackrestore=env._llvm_stackrestore;
  var _llvm_stacksave=env._llvm_stacksave;
  var _llvm_trap=env._llvm_trap;
  var _llvm_trunc_f32=env._llvm_trunc_f32;
  var _llvm_trunc_f64=env._llvm_trunc_f64;
  var _llvm_va_copy=env._llvm_va_copy;
  var _llvm_va_end=env._llvm_va_end;
  var _localtime=env._localtime;
  var _localtime_r=env._localtime_r;
  var _log=env._log;
  var _logf=env._logf;
  var _logl=env._logl;
  var _longjmp=env._longjmp;
  var _major=env._major;
  var _makedev=env._makedev;
  var _minor=env._minor;
  var _mktime=env._mktime;
  var _nanosleep=env._nanosleep;
  var _pathconf=env._pathconf;
  var _pixelRGBA=env._pixelRGBA;
  var _posix_spawn=env._posix_spawn;
  var _posix_spawnp=env._posix_spawnp;
  var _pow=env._pow;
  var _powf=env._powf;
  var _powl=env._powl;
  var _pthread_attr_destroy=env._pthread_attr_destroy;
  var _pthread_attr_getstack=env._pthread_attr_getstack;
  var _pthread_attr_init=env._pthread_attr_init;
  var _pthread_attr_setdetachstate=env._pthread_attr_setdetachstate;
  var _pthread_attr_setschedparam=env._pthread_attr_setschedparam;
  var _pthread_attr_setstacksize=env._pthread_attr_setstacksize;
  var _pthread_barrier_destroy=env._pthread_barrier_destroy;
  var _pthread_barrier_init=env._pthread_barrier_init;
  var _pthread_barrier_wait=env._pthread_barrier_wait;
  var _pthread_cancel=env._pthread_cancel;
  var _pthread_cleanup_pop=env._pthread_cleanup_pop;
  var _pthread_cleanup_push=env._pthread_cleanup_push;
  var _pthread_cond_destroy=env._pthread_cond_destroy;
  var _pthread_cond_init=env._pthread_cond_init;
  var _pthread_cond_signal=env._pthread_cond_signal;
  var _pthread_cond_timedwait=env._pthread_cond_timedwait;
  var _pthread_cond_wait=env._pthread_cond_wait;
  var _pthread_condattr_destroy=env._pthread_condattr_destroy;
  var _pthread_condattr_getclock=env._pthread_condattr_getclock;
  var _pthread_condattr_getpshared=env._pthread_condattr_getpshared;
  var _pthread_condattr_init=env._pthread_condattr_init;
  var _pthread_condattr_setclock=env._pthread_condattr_setclock;
  var _pthread_condattr_setpshared=env._pthread_condattr_setpshared;
  var _pthread_create=env._pthread_create;
  var _pthread_detach=env._pthread_detach;
  var _pthread_equal=env._pthread_equal;
  var _pthread_exit=env._pthread_exit;
  var _pthread_getattr_np=env._pthread_getattr_np;
  var _pthread_getspecific=env._pthread_getspecific;
  var _pthread_join=env._pthread_join;
  var _pthread_key_create=env._pthread_key_create;
  var _pthread_key_delete=env._pthread_key_delete;
  var _pthread_mutex_destroy=env._pthread_mutex_destroy;
  var _pthread_mutex_init=env._pthread_mutex_init;
  var _pthread_mutexattr_destroy=env._pthread_mutexattr_destroy;
  var _pthread_mutexattr_init=env._pthread_mutexattr_init;
  var _pthread_mutexattr_setprotocol=env._pthread_mutexattr_setprotocol;
  var _pthread_mutexattr_setpshared=env._pthread_mutexattr_setpshared;
  var _pthread_mutexattr_setschedparam=env._pthread_mutexattr_setschedparam;
  var _pthread_mutexattr_settype=env._pthread_mutexattr_settype;
  var _pthread_once=env._pthread_once;
  var _pthread_rwlock_destroy=env._pthread_rwlock_destroy;
  var _pthread_rwlock_init=env._pthread_rwlock_init;
  var _pthread_rwlock_rdlock=env._pthread_rwlock_rdlock;
  var _pthread_rwlock_timedrdlock=env._pthread_rwlock_timedrdlock;
  var _pthread_rwlock_timedwrlock=env._pthread_rwlock_timedwrlock;
  var _pthread_rwlock_tryrdlock=env._pthread_rwlock_tryrdlock;
  var _pthread_rwlock_trywrlock=env._pthread_rwlock_trywrlock;
  var _pthread_rwlock_unlock=env._pthread_rwlock_unlock;
  var _pthread_rwlock_wrlock=env._pthread_rwlock_wrlock;
  var _pthread_rwlockattr_destroy=env._pthread_rwlockattr_destroy;
  var _pthread_rwlockattr_getpshared=env._pthread_rwlockattr_getpshared;
  var _pthread_rwlockattr_init=env._pthread_rwlockattr_init;
  var _pthread_rwlockattr_setpshared=env._pthread_rwlockattr_setpshared;
  var _pthread_setcancelstate=env._pthread_setcancelstate;
  var _pthread_setspecific=env._pthread_setspecific;
  var _pthread_sigmask=env._pthread_sigmask;
  var _pthread_spin_destroy=env._pthread_spin_destroy;
  var _pthread_spin_init=env._pthread_spin_init;
  var _pthread_spin_lock=env._pthread_spin_lock;
  var _pthread_spin_trylock=env._pthread_spin_trylock;
  var _pthread_spin_unlock=env._pthread_spin_unlock;
  var _putenv=env._putenv;
  var _raise=env._raise;
  var _rectangleColor=env._rectangleColor;
  var _rectangleRGBA=env._rectangleRGBA;
  var _rotozoomSurface=env._rotozoomSurface;
  var _sched_yield=env._sched_yield;
  var _sem_destroy=env._sem_destroy;
  var _sem_init=env._sem_init;
  var _sem_post=env._sem_post;
  var _sem_trywait=env._sem_trywait;
  var _sem_wait=env._sem_wait;
  var _setenv=env._setenv;
  var _setgroups=env._setgroups;
  var _setitimer=env._setitimer;
  var _setprotoent=env._setprotoent;
  var _setpwent=env._setpwent;
  var _sigaction=env._sigaction;
  var _sigaddset=env._sigaddset;
  var _sigdelset=env._sigdelset;
  var _sigemptyset=env._sigemptyset;
  var _sigfillset=env._sigfillset;
  var _siginterrupt=env._siginterrupt;
  var _sigismember=env._sigismember;
  var _siglongjmp=env._siglongjmp;
  var _signal=env._signal;
  var _sigpending=env._sigpending;
  var _sigprocmask=env._sigprocmask;
  var _sin=env._sin;
  var _sinf=env._sinf;
  var _sinl=env._sinl;
  var _sqrt=env._sqrt;
  var _sqrtf=env._sqrtf;
  var _sqrtl=env._sqrtl;
  var _stime=env._stime;
  var _strftime=env._strftime;
  var _strftime_l=env._strftime_l;
  var _strptime=env._strptime;
  var _strptime_l=env._strptime_l;
  var _sysconf=env._sysconf;
  var _system=env._system;
  var _tan=env._tan;
  var _tanf=env._tanf;
  var _tanl=env._tanl;
  var _terminate=env._terminate;
  var _time=env._time;
  var _timegm=env._timegm;
  var _timelocal=env._timelocal;
  var _times=env._times;
  var _timespec_get=env._timespec_get;
  var _tzset=env._tzset;
  var _unsetenv=env._unsetenv;
  var _usleep=env._usleep;
  var _utime=env._utime;
  var _utimes=env._utimes;
  var _uuid_clear=env._uuid_clear;
  var _uuid_compare=env._uuid_compare;
  var _uuid_copy=env._uuid_copy;
  var _uuid_generate=env._uuid_generate;
  var _uuid_is_null=env._uuid_is_null;
  var _uuid_parse=env._uuid_parse;
  var _uuid_type=env._uuid_type;
  var _uuid_unparse=env._uuid_unparse;
  var _uuid_unparse_lower=env._uuid_unparse_lower;
  var _uuid_unparse_upper=env._uuid_unparse_upper;
  var _uuid_variant=env._uuid_variant;
  var _vfork=env._vfork;
  var _wait=env._wait;
  var _wait3=env._wait3;
  var _wait4=env._wait4;
  var _waitid=env._waitid;
  var _waitpid=env._waitpid;
  var _zoomSurface=env._zoomSurface;
  var emscriptenWebGLComputeImageSize=env.emscriptenWebGLComputeImageSize;
  var emscriptenWebGLGet=env.emscriptenWebGLGet;
  var emscriptenWebGLGetTexPixelData=env.emscriptenWebGLGetTexPixelData;
  var emscriptenWebGLGetUniform=env.emscriptenWebGLGetUniform;
  var emscriptenWebGLGetVertexAttrib=env.emscriptenWebGLGetVertexAttrib;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS

function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
  STACKTOP = (STACKTOP + 15)&-16;
    if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(size|0);

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}
function establishStackSpace(stackBase, stackMax) {
  stackBase = stackBase|0;
  stackMax = stackMax|0;
  STACKTOP = stackBase;
  STACK_MAX = stackMax;
}
function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}

function _main() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = 0;
 (_printf((gb + (166382) | 0),$vararg_buffer)|0);
 $2 = (_kfunc1()|0);
 $1 = $2;
 $3 = $1;
 HEAP32[$vararg_buffer1>>2] = $3;
 (_printf((gb + (166389) | 0),$vararg_buffer1)|0);
 STACKTOP = sp;return 0;
}
function _malloc($0) {
 $0 = $0|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i20$i = 0, $$0169$i = 0, $$0170$i = 0, $$0171$i = 0, $$0192 = 0, $$0194 = 0, $$02014$i$i = 0, $$0202$lcssa$i$i = 0, $$02023$i$i = 0, $$0206$i$i = 0, $$0207$i$i = 0, $$024372$i = 0, $$0259$i$i = 0, $$02604$i$i = 0, $$0261$lcssa$i$i = 0, $$02613$i$i = 0;
 var $$0267$i$i = 0, $$0268$i$i = 0, $$0318$i = 0, $$032012$i = 0, $$0321$lcssa$i = 0, $$032111$i = 0, $$0323$i = 0, $$0329$i = 0, $$0335$i = 0, $$0336$i = 0, $$0338$i = 0, $$0339$i = 0, $$0344$i = 0, $$1174$i = 0, $$1174$i$be = 0, $$1174$i$ph = 0, $$1176$i = 0, $$1176$i$be = 0, $$1176$i$ph = 0, $$124471$i = 0;
 var $$1263$i$i = 0, $$1263$i$i$be = 0, $$1263$i$i$ph = 0, $$1265$i$i = 0, $$1265$i$i$be = 0, $$1265$i$i$ph = 0, $$1319$i = 0, $$1324$i = 0, $$1340$i = 0, $$1346$i = 0, $$1346$i$be = 0, $$1346$i$ph = 0, $$1350$i = 0, $$1350$i$be = 0, $$1350$i$ph = 0, $$2234243136$i = 0, $$2247$ph$i = 0, $$2253$ph$i = 0, $$2331$i = 0, $$3$i = 0;
 var $$3$i$i = 0, $$3$i198 = 0, $$3$i198211 = 0, $$3326$i = 0, $$3348$i = 0, $$4$lcssa$i = 0, $$415$i = 0, $$415$i$ph = 0, $$4236$i = 0, $$4327$lcssa$i = 0, $$432714$i = 0, $$432714$i$ph = 0, $$4333$i = 0, $$533413$i = 0, $$533413$i$ph = 0, $$723947$i = 0, $$748$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0;
 var $$pre$i16$i = 0, $$pre$i195 = 0, $$pre$i204 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i17$iZ2D = 0, $$pre$phi$i205Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phiZ2D = 0, $$sink = 0, $$sink320 = 0, $$sink321 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0;
 var $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0;
 var $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0;
 var $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0;
 var $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0;
 var $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0;
 var $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0;
 var $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0;
 var $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0;
 var $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0;
 var $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0;
 var $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $99 = 0, $cond$i = 0, $cond$i$i = 0, $cond$i203 = 0, $not$$i = 0, $or$cond$i = 0, $or$cond$i199 = 0, $or$cond1$i = 0, $or$cond1$i197 = 0, $or$cond11$i = 0, $or$cond2$i = 0;
 var $or$cond5$i = 0, $or$cond50$i = 0, $or$cond51$i = 0, $or$cond6$i = 0, $or$cond7$i = 0, $or$cond8$i = 0, $or$cond8$not$i = 0, $spec$select$i = 0, $spec$select$i201 = 0, $spec$select1$i = 0, $spec$select2$i = 0, $spec$select4$i = 0, $spec$select49$i = 0, $spec$select9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = ($0>>>0)<(245);
 do {
  if ($2) {
   $3 = ($0>>>0)<(11);
   $4 = (($0) + 11)|0;
   $5 = $4 & -8;
   $6 = $3 ? 16 : $5;
   $7 = $6 >>> 3;
   $8 = HEAP32[(gb + (170632) | 0)>>2]|0;
   $9 = $8 >>> $7;
   $10 = $9 & 3;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = $9 & 1;
    $13 = $12 ^ 1;
    $14 = (($13) + ($7))|0;
    $15 = $14 << 1;
    $16 = ((((gb + (170632) | 0)) + 40|0) + ($15<<2)|0);
    $17 = ((($16)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($16|0);
    if ($21) {
     $22 = 1 << $14;
     $23 = $22 ^ -1;
     $24 = $8 & $23;
     HEAP32[(gb + (170632) | 0)>>2] = $24;
    } else {
     $25 = ((($20)) + 12|0);
     HEAP32[$25>>2] = $16;
     HEAP32[$17>>2] = $20;
    }
    $26 = $14 << 3;
    $27 = $26 | 3;
    $28 = ((($18)) + 4|0);
    HEAP32[$28>>2] = $27;
    $29 = (($18) + ($26)|0);
    $30 = ((($29)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = $31 | 1;
    HEAP32[$30>>2] = $32;
    $$0 = $19;
    STACKTOP = sp;return ($$0|0);
   }
   $33 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
   $34 = ($6>>>0)>($33>>>0);
   if ($34) {
    $35 = ($9|0)==(0);
    if (!($35)) {
     $36 = $9 << $7;
     $37 = 2 << $7;
     $38 = (0 - ($37))|0;
     $39 = $37 | $38;
     $40 = $36 & $39;
     $41 = (0 - ($40))|0;
     $42 = $40 & $41;
     $43 = (($42) + -1)|0;
     $44 = $43 >>> 12;
     $45 = $44 & 16;
     $46 = $43 >>> $45;
     $47 = $46 >>> 5;
     $48 = $47 & 8;
     $49 = $48 | $45;
     $50 = $46 >>> $48;
     $51 = $50 >>> 2;
     $52 = $51 & 4;
     $53 = $49 | $52;
     $54 = $50 >>> $52;
     $55 = $54 >>> 1;
     $56 = $55 & 2;
     $57 = $53 | $56;
     $58 = $54 >>> $56;
     $59 = $58 >>> 1;
     $60 = $59 & 1;
     $61 = $57 | $60;
     $62 = $58 >>> $60;
     $63 = (($61) + ($62))|0;
     $64 = $63 << 1;
     $65 = ((((gb + (170632) | 0)) + 40|0) + ($64<<2)|0);
     $66 = ((($65)) + 8|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ((($67)) + 8|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($69|0)==($65|0);
     if ($70) {
      $71 = 1 << $63;
      $72 = $71 ^ -1;
      $73 = $8 & $72;
      HEAP32[(gb + (170632) | 0)>>2] = $73;
      $90 = $73;
     } else {
      $74 = ((($69)) + 12|0);
      HEAP32[$74>>2] = $65;
      HEAP32[$66>>2] = $69;
      $90 = $8;
     }
     $75 = $63 << 3;
     $76 = (($75) - ($6))|0;
     $77 = $6 | 3;
     $78 = ((($67)) + 4|0);
     HEAP32[$78>>2] = $77;
     $79 = (($67) + ($6)|0);
     $80 = $76 | 1;
     $81 = ((($79)) + 4|0);
     HEAP32[$81>>2] = $80;
     $82 = (($67) + ($75)|0);
     HEAP32[$82>>2] = $76;
     $83 = ($33|0)==(0);
     if (!($83)) {
      $84 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
      $85 = $33 >>> 3;
      $86 = $85 << 1;
      $87 = ((((gb + (170632) | 0)) + 40|0) + ($86<<2)|0);
      $88 = 1 << $85;
      $89 = $90 & $88;
      $91 = ($89|0)==(0);
      if ($91) {
       $92 = $90 | $88;
       HEAP32[(gb + (170632) | 0)>>2] = $92;
       $$pre = ((($87)) + 8|0);
       $$0194 = $87;$$pre$phiZ2D = $$pre;
      } else {
       $93 = ((($87)) + 8|0);
       $94 = HEAP32[$93>>2]|0;
       $$0194 = $94;$$pre$phiZ2D = $93;
      }
      HEAP32[$$pre$phiZ2D>>2] = $84;
      $95 = ((($$0194)) + 12|0);
      HEAP32[$95>>2] = $84;
      $96 = ((($84)) + 8|0);
      HEAP32[$96>>2] = $$0194;
      $97 = ((($84)) + 12|0);
      HEAP32[$97>>2] = $87;
     }
     HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $76;
     HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $79;
     $$0 = $68;
     STACKTOP = sp;return ($$0|0);
    }
    $98 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
    $99 = ($98|0)==(0);
    if ($99) {
     $$0192 = $6;
    } else {
     $100 = (0 - ($98))|0;
     $101 = $98 & $100;
     $102 = (($101) + -1)|0;
     $103 = $102 >>> 12;
     $104 = $103 & 16;
     $105 = $102 >>> $104;
     $106 = $105 >>> 5;
     $107 = $106 & 8;
     $108 = $107 | $104;
     $109 = $105 >>> $107;
     $110 = $109 >>> 2;
     $111 = $110 & 4;
     $112 = $108 | $111;
     $113 = $109 >>> $111;
     $114 = $113 >>> 1;
     $115 = $114 & 2;
     $116 = $112 | $115;
     $117 = $113 >>> $115;
     $118 = $117 >>> 1;
     $119 = $118 & 1;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = (($120) + ($121))|0;
     $123 = ((((gb + (170632) | 0)) + 304|0) + ($122<<2)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ((($124)) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = $126 & -8;
     $128 = (($127) - ($6))|0;
     $$0169$i = $124;$$0170$i = $124;$$0171$i = $128;
     while(1) {
      $129 = ((($$0169$i)) + 16|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($130|0)==(0|0);
      if ($131) {
       $132 = ((($$0169$i)) + 20|0);
       $133 = HEAP32[$132>>2]|0;
       $134 = ($133|0)==(0|0);
       if ($134) {
        break;
       } else {
        $136 = $133;
       }
      } else {
       $136 = $130;
      }
      $135 = ((($136)) + 4|0);
      $137 = HEAP32[$135>>2]|0;
      $138 = $137 & -8;
      $139 = (($138) - ($6))|0;
      $140 = ($139>>>0)<($$0171$i>>>0);
      $spec$select$i = $140 ? $139 : $$0171$i;
      $spec$select1$i = $140 ? $136 : $$0170$i;
      $$0169$i = $136;$$0170$i = $spec$select1$i;$$0171$i = $spec$select$i;
     }
     $141 = (($$0170$i) + ($6)|0);
     $142 = ($141>>>0)>($$0170$i>>>0);
     if ($142) {
      $143 = ((($$0170$i)) + 24|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ((($$0170$i)) + 12|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($146|0)==($$0170$i|0);
      do {
       if ($147) {
        $152 = ((($$0170$i)) + 20|0);
        $153 = HEAP32[$152>>2]|0;
        $154 = ($153|0)==(0|0);
        if ($154) {
         $155 = ((($$0170$i)) + 16|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = ($156|0)==(0|0);
         if ($157) {
          $$3$i = 0;
          break;
         } else {
          $$1174$i$ph = $156;$$1176$i$ph = $155;
         }
        } else {
         $$1174$i$ph = $153;$$1176$i$ph = $152;
        }
        $$1174$i = $$1174$i$ph;$$1176$i = $$1176$i$ph;
        while(1) {
         $158 = ((($$1174$i)) + 20|0);
         $159 = HEAP32[$158>>2]|0;
         $160 = ($159|0)==(0|0);
         if ($160) {
          $161 = ((($$1174$i)) + 16|0);
          $162 = HEAP32[$161>>2]|0;
          $163 = ($162|0)==(0|0);
          if ($163) {
           break;
          } else {
           $$1174$i$be = $162;$$1176$i$be = $161;
          }
         } else {
          $$1174$i$be = $159;$$1176$i$be = $158;
         }
         $$1174$i = $$1174$i$be;$$1176$i = $$1176$i$be;
        }
        HEAP32[$$1176$i>>2] = 0;
        $$3$i = $$1174$i;
       } else {
        $148 = ((($$0170$i)) + 8|0);
        $149 = HEAP32[$148>>2]|0;
        $150 = ((($149)) + 12|0);
        HEAP32[$150>>2] = $146;
        $151 = ((($146)) + 8|0);
        HEAP32[$151>>2] = $149;
        $$3$i = $146;
       }
      } while(0);
      $164 = ($144|0)==(0|0);
      do {
       if (!($164)) {
        $165 = ((($$0170$i)) + 28|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ((((gb + (170632) | 0)) + 304|0) + ($166<<2)|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = ($$0170$i|0)==($168|0);
        if ($169) {
         HEAP32[$167>>2] = $$3$i;
         $cond$i = ($$3$i|0)==(0|0);
         if ($cond$i) {
          $170 = 1 << $166;
          $171 = $170 ^ -1;
          $172 = $98 & $171;
          HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $172;
          break;
         }
        } else {
         $173 = ((($144)) + 16|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = ($174|0)==($$0170$i|0);
         $176 = ((($144)) + 20|0);
         $$sink = $175 ? $173 : $176;
         HEAP32[$$sink>>2] = $$3$i;
         $177 = ($$3$i|0)==(0|0);
         if ($177) {
          break;
         }
        }
        $178 = ((($$3$i)) + 24|0);
        HEAP32[$178>>2] = $144;
        $179 = ((($$0170$i)) + 16|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = ($180|0)==(0|0);
        if (!($181)) {
         $182 = ((($$3$i)) + 16|0);
         HEAP32[$182>>2] = $180;
         $183 = ((($180)) + 24|0);
         HEAP32[$183>>2] = $$3$i;
        }
        $184 = ((($$0170$i)) + 20|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = ($185|0)==(0|0);
        if (!($186)) {
         $187 = ((($$3$i)) + 20|0);
         HEAP32[$187>>2] = $185;
         $188 = ((($185)) + 24|0);
         HEAP32[$188>>2] = $$3$i;
        }
       }
      } while(0);
      $189 = ($$0171$i>>>0)<(16);
      if ($189) {
       $190 = (($$0171$i) + ($6))|0;
       $191 = $190 | 3;
       $192 = ((($$0170$i)) + 4|0);
       HEAP32[$192>>2] = $191;
       $193 = (($$0170$i) + ($190)|0);
       $194 = ((($193)) + 4|0);
       $195 = HEAP32[$194>>2]|0;
       $196 = $195 | 1;
       HEAP32[$194>>2] = $196;
      } else {
       $197 = $6 | 3;
       $198 = ((($$0170$i)) + 4|0);
       HEAP32[$198>>2] = $197;
       $199 = $$0171$i | 1;
       $200 = ((($141)) + 4|0);
       HEAP32[$200>>2] = $199;
       $201 = (($141) + ($$0171$i)|0);
       HEAP32[$201>>2] = $$0171$i;
       $202 = ($33|0)==(0);
       if (!($202)) {
        $203 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
        $204 = $33 >>> 3;
        $205 = $204 << 1;
        $206 = ((((gb + (170632) | 0)) + 40|0) + ($205<<2)|0);
        $207 = 1 << $204;
        $208 = $207 & $8;
        $209 = ($208|0)==(0);
        if ($209) {
         $210 = $207 | $8;
         HEAP32[(gb + (170632) | 0)>>2] = $210;
         $$pre$i = ((($206)) + 8|0);
         $$0$i = $206;$$pre$phi$iZ2D = $$pre$i;
        } else {
         $211 = ((($206)) + 8|0);
         $212 = HEAP32[$211>>2]|0;
         $$0$i = $212;$$pre$phi$iZ2D = $211;
        }
        HEAP32[$$pre$phi$iZ2D>>2] = $203;
        $213 = ((($$0$i)) + 12|0);
        HEAP32[$213>>2] = $203;
        $214 = ((($203)) + 8|0);
        HEAP32[$214>>2] = $$0$i;
        $215 = ((($203)) + 12|0);
        HEAP32[$215>>2] = $206;
       }
       HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $$0171$i;
       HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $141;
      }
      $216 = ((($$0170$i)) + 8|0);
      $$0 = $216;
      STACKTOP = sp;return ($$0|0);
     } else {
      $$0192 = $6;
     }
    }
   } else {
    $$0192 = $6;
   }
  } else {
   $217 = ($0>>>0)>(4294967231);
   if ($217) {
    $$0192 = -1;
   } else {
    $218 = (($0) + 11)|0;
    $219 = $218 & -8;
    $220 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
    $221 = ($220|0)==(0);
    if ($221) {
     $$0192 = $219;
    } else {
     $222 = (0 - ($219))|0;
     $223 = $218 >>> 8;
     $224 = ($223|0)==(0);
     if ($224) {
      $$0335$i = 0;
     } else {
      $225 = ($219>>>0)>(16777215);
      if ($225) {
       $$0335$i = 31;
      } else {
       $226 = (($223) + 1048320)|0;
       $227 = $226 >>> 16;
       $228 = $227 & 8;
       $229 = $223 << $228;
       $230 = (($229) + 520192)|0;
       $231 = $230 >>> 16;
       $232 = $231 & 4;
       $233 = $232 | $228;
       $234 = $229 << $232;
       $235 = (($234) + 245760)|0;
       $236 = $235 >>> 16;
       $237 = $236 & 2;
       $238 = $233 | $237;
       $239 = (14 - ($238))|0;
       $240 = $234 << $237;
       $241 = $240 >>> 15;
       $242 = (($239) + ($241))|0;
       $243 = $242 << 1;
       $244 = (($242) + 7)|0;
       $245 = $219 >>> $244;
       $246 = $245 & 1;
       $247 = $246 | $243;
       $$0335$i = $247;
      }
     }
     $248 = ((((gb + (170632) | 0)) + 304|0) + ($$0335$i<<2)|0);
     $249 = HEAP32[$248>>2]|0;
     $250 = ($249|0)==(0|0);
     L79: do {
      if ($250) {
       $$2331$i = 0;$$3$i198 = 0;$$3326$i = $222;
       label = 61;
      } else {
       $251 = ($$0335$i|0)==(31);
       $252 = $$0335$i >>> 1;
       $253 = (25 - ($252))|0;
       $254 = $251 ? 0 : $253;
       $255 = $219 << $254;
       $$0318$i = 0;$$0323$i = $222;$$0329$i = $249;$$0336$i = $255;$$0339$i = 0;
       while(1) {
        $256 = ((($$0329$i)) + 4|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = $257 & -8;
        $259 = (($258) - ($219))|0;
        $260 = ($259>>>0)<($$0323$i>>>0);
        if ($260) {
         $261 = ($259|0)==(0);
         if ($261) {
          $$415$i$ph = $$0329$i;$$432714$i$ph = 0;$$533413$i$ph = $$0329$i;
          label = 65;
          break L79;
         } else {
          $$1319$i = $$0329$i;$$1324$i = $259;
         }
        } else {
         $$1319$i = $$0318$i;$$1324$i = $$0323$i;
        }
        $262 = ((($$0329$i)) + 20|0);
        $263 = HEAP32[$262>>2]|0;
        $264 = $$0336$i >>> 31;
        $265 = (((($$0329$i)) + 16|0) + ($264<<2)|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = ($263|0)==(0|0);
        $268 = ($263|0)==($266|0);
        $or$cond1$i197 = $267 | $268;
        $$1340$i = $or$cond1$i197 ? $$0339$i : $263;
        $269 = ($266|0)==(0|0);
        $spec$select4$i = $$0336$i << 1;
        if ($269) {
         $$2331$i = $$1340$i;$$3$i198 = $$1319$i;$$3326$i = $$1324$i;
         label = 61;
         break;
        } else {
         $$0318$i = $$1319$i;$$0323$i = $$1324$i;$$0329$i = $266;$$0336$i = $spec$select4$i;$$0339$i = $$1340$i;
        }
       }
      }
     } while(0);
     if ((label|0) == 61) {
      $270 = ($$2331$i|0)==(0|0);
      $271 = ($$3$i198|0)==(0|0);
      $or$cond$i199 = $270 & $271;
      if ($or$cond$i199) {
       $272 = 2 << $$0335$i;
       $273 = (0 - ($272))|0;
       $274 = $272 | $273;
       $275 = $274 & $220;
       $276 = ($275|0)==(0);
       if ($276) {
        $$0192 = $219;
        break;
       }
       $277 = (0 - ($275))|0;
       $278 = $275 & $277;
       $279 = (($278) + -1)|0;
       $280 = $279 >>> 12;
       $281 = $280 & 16;
       $282 = $279 >>> $281;
       $283 = $282 >>> 5;
       $284 = $283 & 8;
       $285 = $284 | $281;
       $286 = $282 >>> $284;
       $287 = $286 >>> 2;
       $288 = $287 & 4;
       $289 = $285 | $288;
       $290 = $286 >>> $288;
       $291 = $290 >>> 1;
       $292 = $291 & 2;
       $293 = $289 | $292;
       $294 = $290 >>> $292;
       $295 = $294 >>> 1;
       $296 = $295 & 1;
       $297 = $293 | $296;
       $298 = $294 >>> $296;
       $299 = (($297) + ($298))|0;
       $300 = ((((gb + (170632) | 0)) + 304|0) + ($299<<2)|0);
       $301 = HEAP32[$300>>2]|0;
       $$3$i198211 = 0;$$4333$i = $301;
      } else {
       $$3$i198211 = $$3$i198;$$4333$i = $$2331$i;
      }
      $302 = ($$4333$i|0)==(0|0);
      if ($302) {
       $$4$lcssa$i = $$3$i198211;$$4327$lcssa$i = $$3326$i;
      } else {
       $$415$i$ph = $$3$i198211;$$432714$i$ph = $$3326$i;$$533413$i$ph = $$4333$i;
       label = 65;
      }
     }
     if ((label|0) == 65) {
      $$415$i = $$415$i$ph;$$432714$i = $$432714$i$ph;$$533413$i = $$533413$i$ph;
      while(1) {
       $303 = ((($$533413$i)) + 4|0);
       $304 = HEAP32[$303>>2]|0;
       $305 = $304 & -8;
       $306 = (($305) - ($219))|0;
       $307 = ($306>>>0)<($$432714$i>>>0);
       $spec$select$i201 = $307 ? $306 : $$432714$i;
       $spec$select2$i = $307 ? $$533413$i : $$415$i;
       $308 = ((($$533413$i)) + 16|0);
       $309 = HEAP32[$308>>2]|0;
       $310 = ($309|0)==(0|0);
       if ($310) {
        $311 = ((($$533413$i)) + 20|0);
        $312 = HEAP32[$311>>2]|0;
        $314 = $312;
       } else {
        $314 = $309;
       }
       $313 = ($314|0)==(0|0);
       if ($313) {
        $$4$lcssa$i = $spec$select2$i;$$4327$lcssa$i = $spec$select$i201;
        break;
       } else {
        $$415$i = $spec$select2$i;$$432714$i = $spec$select$i201;$$533413$i = $314;
       }
      }
     }
     $315 = ($$4$lcssa$i|0)==(0|0);
     if ($315) {
      $$0192 = $219;
     } else {
      $316 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
      $317 = (($316) - ($219))|0;
      $318 = ($$4327$lcssa$i>>>0)<($317>>>0);
      if ($318) {
       $319 = (($$4$lcssa$i) + ($219)|0);
       $320 = ($319>>>0)>($$4$lcssa$i>>>0);
       if ($320) {
        $321 = ((($$4$lcssa$i)) + 24|0);
        $322 = HEAP32[$321>>2]|0;
        $323 = ((($$4$lcssa$i)) + 12|0);
        $324 = HEAP32[$323>>2]|0;
        $325 = ($324|0)==($$4$lcssa$i|0);
        do {
         if ($325) {
          $330 = ((($$4$lcssa$i)) + 20|0);
          $331 = HEAP32[$330>>2]|0;
          $332 = ($331|0)==(0|0);
          if ($332) {
           $333 = ((($$4$lcssa$i)) + 16|0);
           $334 = HEAP32[$333>>2]|0;
           $335 = ($334|0)==(0|0);
           if ($335) {
            $$3348$i = 0;
            break;
           } else {
            $$1346$i$ph = $334;$$1350$i$ph = $333;
           }
          } else {
           $$1346$i$ph = $331;$$1350$i$ph = $330;
          }
          $$1346$i = $$1346$i$ph;$$1350$i = $$1350$i$ph;
          while(1) {
           $336 = ((($$1346$i)) + 20|0);
           $337 = HEAP32[$336>>2]|0;
           $338 = ($337|0)==(0|0);
           if ($338) {
            $339 = ((($$1346$i)) + 16|0);
            $340 = HEAP32[$339>>2]|0;
            $341 = ($340|0)==(0|0);
            if ($341) {
             break;
            } else {
             $$1346$i$be = $340;$$1350$i$be = $339;
            }
           } else {
            $$1346$i$be = $337;$$1350$i$be = $336;
           }
           $$1346$i = $$1346$i$be;$$1350$i = $$1350$i$be;
          }
          HEAP32[$$1350$i>>2] = 0;
          $$3348$i = $$1346$i;
         } else {
          $326 = ((($$4$lcssa$i)) + 8|0);
          $327 = HEAP32[$326>>2]|0;
          $328 = ((($327)) + 12|0);
          HEAP32[$328>>2] = $324;
          $329 = ((($324)) + 8|0);
          HEAP32[$329>>2] = $327;
          $$3348$i = $324;
         }
        } while(0);
        $342 = ($322|0)==(0|0);
        do {
         if ($342) {
          $425 = $220;
         } else {
          $343 = ((($$4$lcssa$i)) + 28|0);
          $344 = HEAP32[$343>>2]|0;
          $345 = ((((gb + (170632) | 0)) + 304|0) + ($344<<2)|0);
          $346 = HEAP32[$345>>2]|0;
          $347 = ($$4$lcssa$i|0)==($346|0);
          if ($347) {
           HEAP32[$345>>2] = $$3348$i;
           $cond$i203 = ($$3348$i|0)==(0|0);
           if ($cond$i203) {
            $348 = 1 << $344;
            $349 = $348 ^ -1;
            $350 = $220 & $349;
            HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $350;
            $425 = $350;
            break;
           }
          } else {
           $351 = ((($322)) + 16|0);
           $352 = HEAP32[$351>>2]|0;
           $353 = ($352|0)==($$4$lcssa$i|0);
           $354 = ((($322)) + 20|0);
           $$sink320 = $353 ? $351 : $354;
           HEAP32[$$sink320>>2] = $$3348$i;
           $355 = ($$3348$i|0)==(0|0);
           if ($355) {
            $425 = $220;
            break;
           }
          }
          $356 = ((($$3348$i)) + 24|0);
          HEAP32[$356>>2] = $322;
          $357 = ((($$4$lcssa$i)) + 16|0);
          $358 = HEAP32[$357>>2]|0;
          $359 = ($358|0)==(0|0);
          if (!($359)) {
           $360 = ((($$3348$i)) + 16|0);
           HEAP32[$360>>2] = $358;
           $361 = ((($358)) + 24|0);
           HEAP32[$361>>2] = $$3348$i;
          }
          $362 = ((($$4$lcssa$i)) + 20|0);
          $363 = HEAP32[$362>>2]|0;
          $364 = ($363|0)==(0|0);
          if ($364) {
           $425 = $220;
          } else {
           $365 = ((($$3348$i)) + 20|0);
           HEAP32[$365>>2] = $363;
           $366 = ((($363)) + 24|0);
           HEAP32[$366>>2] = $$3348$i;
           $425 = $220;
          }
         }
        } while(0);
        $367 = ($$4327$lcssa$i>>>0)<(16);
        L128: do {
         if ($367) {
          $368 = (($$4327$lcssa$i) + ($219))|0;
          $369 = $368 | 3;
          $370 = ((($$4$lcssa$i)) + 4|0);
          HEAP32[$370>>2] = $369;
          $371 = (($$4$lcssa$i) + ($368)|0);
          $372 = ((($371)) + 4|0);
          $373 = HEAP32[$372>>2]|0;
          $374 = $373 | 1;
          HEAP32[$372>>2] = $374;
         } else {
          $375 = $219 | 3;
          $376 = ((($$4$lcssa$i)) + 4|0);
          HEAP32[$376>>2] = $375;
          $377 = $$4327$lcssa$i | 1;
          $378 = ((($319)) + 4|0);
          HEAP32[$378>>2] = $377;
          $379 = (($319) + ($$4327$lcssa$i)|0);
          HEAP32[$379>>2] = $$4327$lcssa$i;
          $380 = $$4327$lcssa$i >>> 3;
          $381 = ($$4327$lcssa$i>>>0)<(256);
          if ($381) {
           $382 = $380 << 1;
           $383 = ((((gb + (170632) | 0)) + 40|0) + ($382<<2)|0);
           $384 = HEAP32[(gb + (170632) | 0)>>2]|0;
           $385 = 1 << $380;
           $386 = $384 & $385;
           $387 = ($386|0)==(0);
           if ($387) {
            $388 = $384 | $385;
            HEAP32[(gb + (170632) | 0)>>2] = $388;
            $$pre$i204 = ((($383)) + 8|0);
            $$0344$i = $383;$$pre$phi$i205Z2D = $$pre$i204;
           } else {
            $389 = ((($383)) + 8|0);
            $390 = HEAP32[$389>>2]|0;
            $$0344$i = $390;$$pre$phi$i205Z2D = $389;
           }
           HEAP32[$$pre$phi$i205Z2D>>2] = $319;
           $391 = ((($$0344$i)) + 12|0);
           HEAP32[$391>>2] = $319;
           $392 = ((($319)) + 8|0);
           HEAP32[$392>>2] = $$0344$i;
           $393 = ((($319)) + 12|0);
           HEAP32[$393>>2] = $383;
           break;
          }
          $394 = $$4327$lcssa$i >>> 8;
          $395 = ($394|0)==(0);
          if ($395) {
           $$0338$i = 0;
          } else {
           $396 = ($$4327$lcssa$i>>>0)>(16777215);
           if ($396) {
            $$0338$i = 31;
           } else {
            $397 = (($394) + 1048320)|0;
            $398 = $397 >>> 16;
            $399 = $398 & 8;
            $400 = $394 << $399;
            $401 = (($400) + 520192)|0;
            $402 = $401 >>> 16;
            $403 = $402 & 4;
            $404 = $403 | $399;
            $405 = $400 << $403;
            $406 = (($405) + 245760)|0;
            $407 = $406 >>> 16;
            $408 = $407 & 2;
            $409 = $404 | $408;
            $410 = (14 - ($409))|0;
            $411 = $405 << $408;
            $412 = $411 >>> 15;
            $413 = (($410) + ($412))|0;
            $414 = $413 << 1;
            $415 = (($413) + 7)|0;
            $416 = $$4327$lcssa$i >>> $415;
            $417 = $416 & 1;
            $418 = $417 | $414;
            $$0338$i = $418;
           }
          }
          $419 = ((((gb + (170632) | 0)) + 304|0) + ($$0338$i<<2)|0);
          $420 = ((($319)) + 28|0);
          HEAP32[$420>>2] = $$0338$i;
          $421 = ((($319)) + 16|0);
          $422 = ((($421)) + 4|0);
          HEAP32[$422>>2] = 0;
          HEAP32[$421>>2] = 0;
          $423 = 1 << $$0338$i;
          $424 = $425 & $423;
          $426 = ($424|0)==(0);
          if ($426) {
           $427 = $425 | $423;
           HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $427;
           HEAP32[$419>>2] = $319;
           $428 = ((($319)) + 24|0);
           HEAP32[$428>>2] = $419;
           $429 = ((($319)) + 12|0);
           HEAP32[$429>>2] = $319;
           $430 = ((($319)) + 8|0);
           HEAP32[$430>>2] = $319;
           break;
          }
          $431 = HEAP32[$419>>2]|0;
          $432 = ((($431)) + 4|0);
          $433 = HEAP32[$432>>2]|0;
          $434 = $433 & -8;
          $435 = ($434|0)==($$4327$lcssa$i|0);
          L145: do {
           if ($435) {
            $$0321$lcssa$i = $431;
           } else {
            $436 = ($$0338$i|0)==(31);
            $437 = $$0338$i >>> 1;
            $438 = (25 - ($437))|0;
            $439 = $436 ? 0 : $438;
            $440 = $$4327$lcssa$i << $439;
            $$032012$i = $440;$$032111$i = $431;
            while(1) {
             $447 = $$032012$i >>> 31;
             $448 = (((($$032111$i)) + 16|0) + ($447<<2)|0);
             $443 = HEAP32[$448>>2]|0;
             $449 = ($443|0)==(0|0);
             if ($449) {
              break;
             }
             $441 = $$032012$i << 1;
             $442 = ((($443)) + 4|0);
             $444 = HEAP32[$442>>2]|0;
             $445 = $444 & -8;
             $446 = ($445|0)==($$4327$lcssa$i|0);
             if ($446) {
              $$0321$lcssa$i = $443;
              break L145;
             } else {
              $$032012$i = $441;$$032111$i = $443;
             }
            }
            HEAP32[$448>>2] = $319;
            $450 = ((($319)) + 24|0);
            HEAP32[$450>>2] = $$032111$i;
            $451 = ((($319)) + 12|0);
            HEAP32[$451>>2] = $319;
            $452 = ((($319)) + 8|0);
            HEAP32[$452>>2] = $319;
            break L128;
           }
          } while(0);
          $453 = ((($$0321$lcssa$i)) + 8|0);
          $454 = HEAP32[$453>>2]|0;
          $455 = ((($454)) + 12|0);
          HEAP32[$455>>2] = $319;
          HEAP32[$453>>2] = $319;
          $456 = ((($319)) + 8|0);
          HEAP32[$456>>2] = $454;
          $457 = ((($319)) + 12|0);
          HEAP32[$457>>2] = $$0321$lcssa$i;
          $458 = ((($319)) + 24|0);
          HEAP32[$458>>2] = 0;
         }
        } while(0);
        $459 = ((($$4$lcssa$i)) + 8|0);
        $$0 = $459;
        STACKTOP = sp;return ($$0|0);
       } else {
        $$0192 = $219;
       }
      } else {
       $$0192 = $219;
      }
     }
    }
   }
  }
 } while(0);
 $460 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
 $461 = ($460>>>0)<($$0192>>>0);
 if (!($461)) {
  $462 = (($460) - ($$0192))|0;
  $463 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
  $464 = ($462>>>0)>(15);
  if ($464) {
   $465 = (($463) + ($$0192)|0);
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $465;
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $462;
   $466 = $462 | 1;
   $467 = ((($465)) + 4|0);
   HEAP32[$467>>2] = $466;
   $468 = (($463) + ($460)|0);
   HEAP32[$468>>2] = $462;
   $469 = $$0192 | 3;
   $470 = ((($463)) + 4|0);
   HEAP32[$470>>2] = $469;
  } else {
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = 0;
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = 0;
   $471 = $460 | 3;
   $472 = ((($463)) + 4|0);
   HEAP32[$472>>2] = $471;
   $473 = (($463) + ($460)|0);
   $474 = ((($473)) + 4|0);
   $475 = HEAP32[$474>>2]|0;
   $476 = $475 | 1;
   HEAP32[$474>>2] = $476;
  }
  $477 = ((($463)) + 8|0);
  $$0 = $477;
  STACKTOP = sp;return ($$0|0);
 }
 $478 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
 $479 = ($478>>>0)>($$0192>>>0);
 if ($479) {
  $480 = (($478) - ($$0192))|0;
  HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $480;
  $481 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
  $482 = (($481) + ($$0192)|0);
  HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $482;
  $483 = $480 | 1;
  $484 = ((($482)) + 4|0);
  HEAP32[$484>>2] = $483;
  $485 = $$0192 | 3;
  $486 = ((($481)) + 4|0);
  HEAP32[$486>>2] = $485;
  $487 = ((($481)) + 8|0);
  $$0 = $487;
  STACKTOP = sp;return ($$0|0);
 }
 $488 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $489 = ($488|0)==(0);
 if ($489) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $490 = $1;
  $491 = $490 & -16;
  $492 = $491 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $492;
  $496 = 4096;
 } else {
  $$pre$i195 = HEAP32[((((gb + (171104) | 0)) + 8|0))>>2]|0;
  $496 = $$pre$i195;
 }
 $493 = (($$0192) + 48)|0;
 $494 = (($$0192) + 47)|0;
 $495 = (($496) + ($494))|0;
 $497 = (0 - ($496))|0;
 $498 = $495 & $497;
 $499 = ($498>>>0)>($$0192>>>0);
 if (!($499)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $500 = HEAP32[((((gb + (170632) | 0)) + 440|0))>>2]|0;
 $501 = ($500|0)==(0);
 if (!($501)) {
  $502 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
  $503 = (($502) + ($498))|0;
  $504 = ($503>>>0)<=($502>>>0);
  $505 = ($503>>>0)>($500>>>0);
  $or$cond1$i = $504 | $505;
  if ($or$cond1$i) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $506 = HEAP32[((((gb + (170632) | 0)) + 444|0))>>2]|0;
 $507 = $506 & 4;
 $508 = ($507|0)==(0);
 L178: do {
  if ($508) {
   $509 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
   $510 = ($509|0)==(0|0);
   L180: do {
    if ($510) {
     label = 128;
    } else {
     $$0$i20$i = ((((gb + (170632) | 0)) + 448|0));
     while(1) {
      $511 = HEAP32[$$0$i20$i>>2]|0;
      $512 = ($511>>>0)>($509>>>0);
      if (!($512)) {
       $513 = ((($$0$i20$i)) + 4|0);
       $514 = HEAP32[$513>>2]|0;
       $515 = (($511) + ($514)|0);
       $516 = ($515>>>0)>($509>>>0);
       if ($516) {
        break;
       }
      }
      $517 = ((($$0$i20$i)) + 8|0);
      $518 = HEAP32[$517>>2]|0;
      $519 = ($518|0)==(0|0);
      if ($519) {
       label = 128;
       break L180;
      } else {
       $$0$i20$i = $518;
      }
     }
     $542 = (($495) - ($478))|0;
     $543 = $542 & $497;
     $544 = ($543>>>0)<(2147483647);
     if ($544) {
      $545 = ((($$0$i20$i)) + 4|0);
      $546 = (_sbrk(($543|0))|0);
      $547 = HEAP32[$$0$i20$i>>2]|0;
      $548 = HEAP32[$545>>2]|0;
      $549 = (($547) + ($548)|0);
      $550 = ($546|0)==($549|0);
      if ($550) {
       $551 = ($546|0)==((-1)|0);
       if ($551) {
        $$2234243136$i = $543;
       } else {
        $$723947$i = $543;$$748$i = $546;
        label = 145;
        break L178;
       }
      } else {
       $$2247$ph$i = $546;$$2253$ph$i = $543;
       label = 136;
      }
     } else {
      $$2234243136$i = 0;
     }
    }
   } while(0);
   do {
    if ((label|0) == 128) {
     $520 = (_sbrk(0)|0);
     $521 = ($520|0)==((-1)|0);
     if ($521) {
      $$2234243136$i = 0;
     } else {
      $522 = $520;
      $523 = HEAP32[((((gb + (171104) | 0)) + 4|0))>>2]|0;
      $524 = (($523) + -1)|0;
      $525 = $524 & $522;
      $526 = ($525|0)==(0);
      $527 = (($524) + ($522))|0;
      $528 = (0 - ($523))|0;
      $529 = $527 & $528;
      $530 = (($529) - ($522))|0;
      $531 = $526 ? 0 : $530;
      $spec$select49$i = (($531) + ($498))|0;
      $532 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
      $533 = (($spec$select49$i) + ($532))|0;
      $534 = ($spec$select49$i>>>0)>($$0192>>>0);
      $535 = ($spec$select49$i>>>0)<(2147483647);
      $or$cond$i = $534 & $535;
      if ($or$cond$i) {
       $536 = HEAP32[((((gb + (170632) | 0)) + 440|0))>>2]|0;
       $537 = ($536|0)==(0);
       if (!($537)) {
        $538 = ($533>>>0)<=($532>>>0);
        $539 = ($533>>>0)>($536>>>0);
        $or$cond2$i = $538 | $539;
        if ($or$cond2$i) {
         $$2234243136$i = 0;
         break;
        }
       }
       $540 = (_sbrk(($spec$select49$i|0))|0);
       $541 = ($540|0)==($520|0);
       if ($541) {
        $$723947$i = $spec$select49$i;$$748$i = $520;
        label = 145;
        break L178;
       } else {
        $$2247$ph$i = $540;$$2253$ph$i = $spec$select49$i;
        label = 136;
       }
      } else {
       $$2234243136$i = 0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 136) {
     $552 = (0 - ($$2253$ph$i))|0;
     $553 = ($$2247$ph$i|0)!=((-1)|0);
     $554 = ($$2253$ph$i>>>0)<(2147483647);
     $or$cond7$i = $554 & $553;
     $555 = ($493>>>0)>($$2253$ph$i>>>0);
     $or$cond6$i = $555 & $or$cond7$i;
     if (!($or$cond6$i)) {
      $565 = ($$2247$ph$i|0)==((-1)|0);
      if ($565) {
       $$2234243136$i = 0;
       break;
      } else {
       $$723947$i = $$2253$ph$i;$$748$i = $$2247$ph$i;
       label = 145;
       break L178;
      }
     }
     $556 = HEAP32[((((gb + (171104) | 0)) + 8|0))>>2]|0;
     $557 = (($494) - ($$2253$ph$i))|0;
     $558 = (($557) + ($556))|0;
     $559 = (0 - ($556))|0;
     $560 = $558 & $559;
     $561 = ($560>>>0)<(2147483647);
     if (!($561)) {
      $$723947$i = $$2253$ph$i;$$748$i = $$2247$ph$i;
      label = 145;
      break L178;
     }
     $562 = (_sbrk(($560|0))|0);
     $563 = ($562|0)==((-1)|0);
     if ($563) {
      (_sbrk(($552|0))|0);
      $$2234243136$i = 0;
      break;
     } else {
      $564 = (($560) + ($$2253$ph$i))|0;
      $$723947$i = $564;$$748$i = $$2247$ph$i;
      label = 145;
      break L178;
     }
    }
   } while(0);
   $566 = HEAP32[((((gb + (170632) | 0)) + 444|0))>>2]|0;
   $567 = $566 | 4;
   HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = $567;
   $$4236$i = $$2234243136$i;
   label = 143;
  } else {
   $$4236$i = 0;
   label = 143;
  }
 } while(0);
 if ((label|0) == 143) {
  $568 = ($498>>>0)<(2147483647);
  if ($568) {
   $569 = (_sbrk(($498|0))|0);
   $570 = (_sbrk(0)|0);
   $571 = ($569|0)!=((-1)|0);
   $572 = ($570|0)!=((-1)|0);
   $or$cond5$i = $571 & $572;
   $573 = ($569>>>0)<($570>>>0);
   $or$cond8$i = $573 & $or$cond5$i;
   $574 = $570;
   $575 = $569;
   $576 = (($574) - ($575))|0;
   $577 = (($$0192) + 40)|0;
   $578 = ($576>>>0)>($577>>>0);
   $spec$select9$i = $578 ? $576 : $$4236$i;
   $or$cond8$not$i = $or$cond8$i ^ 1;
   $579 = ($569|0)==((-1)|0);
   $not$$i = $578 ^ 1;
   $580 = $579 | $not$$i;
   $or$cond50$i = $580 | $or$cond8$not$i;
   if (!($or$cond50$i)) {
    $$723947$i = $spec$select9$i;$$748$i = $569;
    label = 145;
   }
  }
 }
 if ((label|0) == 145) {
  $581 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
  $582 = (($581) + ($$723947$i))|0;
  HEAP32[((((gb + (170632) | 0)) + 432|0))>>2] = $582;
  $583 = HEAP32[((((gb + (170632) | 0)) + 436|0))>>2]|0;
  $584 = ($582>>>0)>($583>>>0);
  if ($584) {
   HEAP32[((((gb + (170632) | 0)) + 436|0))>>2] = $582;
  }
  $585 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
  $586 = ($585|0)==(0|0);
  L215: do {
   if ($586) {
    $587 = HEAP32[((((gb + (170632) | 0)) + 16|0))>>2]|0;
    $588 = ($587|0)==(0|0);
    $589 = ($$748$i>>>0)<($587>>>0);
    $or$cond11$i = $588 | $589;
    if ($or$cond11$i) {
     HEAP32[((((gb + (170632) | 0)) + 16|0))>>2] = $$748$i;
    }
    HEAP32[((((gb + (170632) | 0)) + 448|0))>>2] = $$748$i;
    HEAP32[((((gb + (170632) | 0)) + 452|0))>>2] = $$723947$i;
    HEAP32[((((gb + (170632) | 0)) + 460|0))>>2] = 0;
    $590 = HEAP32[(gb + (171104) | 0)>>2]|0;
    HEAP32[((((gb + (170632) | 0)) + 36|0))>>2] = $590;
    HEAP32[((((gb + (170632) | 0)) + 32|0))>>2] = -1;
    HEAP32[((((gb + (170632) | 0)) + 52|0))>>2] = ((((gb + (170632) | 0)) + 40|0));
    HEAP32[((((gb + (170632) | 0)) + 48|0))>>2] = ((((gb + (170632) | 0)) + 40|0));
    HEAP32[((((gb + (170632) | 0)) + 60|0))>>2] = ((((gb + (170632) | 0)) + 48|0));
    HEAP32[((((gb + (170632) | 0)) + 56|0))>>2] = ((((gb + (170632) | 0)) + 48|0));
    HEAP32[((((gb + (170632) | 0)) + 68|0))>>2] = ((((gb + (170632) | 0)) + 56|0));
    HEAP32[((((gb + (170632) | 0)) + 64|0))>>2] = ((((gb + (170632) | 0)) + 56|0));
    HEAP32[((((gb + (170632) | 0)) + 76|0))>>2] = ((((gb + (170632) | 0)) + 64|0));
    HEAP32[((((gb + (170632) | 0)) + 72|0))>>2] = ((((gb + (170632) | 0)) + 64|0));
    HEAP32[((((gb + (170632) | 0)) + 84|0))>>2] = ((((gb + (170632) | 0)) + 72|0));
    HEAP32[((((gb + (170632) | 0)) + 80|0))>>2] = ((((gb + (170632) | 0)) + 72|0));
    HEAP32[((((gb + (170632) | 0)) + 92|0))>>2] = ((((gb + (170632) | 0)) + 80|0));
    HEAP32[((((gb + (170632) | 0)) + 88|0))>>2] = ((((gb + (170632) | 0)) + 80|0));
    HEAP32[((((gb + (170632) | 0)) + 100|0))>>2] = ((((gb + (170632) | 0)) + 88|0));
    HEAP32[((((gb + (170632) | 0)) + 96|0))>>2] = ((((gb + (170632) | 0)) + 88|0));
    HEAP32[((((gb + (170632) | 0)) + 108|0))>>2] = ((((gb + (170632) | 0)) + 96|0));
    HEAP32[((((gb + (170632) | 0)) + 104|0))>>2] = ((((gb + (170632) | 0)) + 96|0));
    HEAP32[((((gb + (170632) | 0)) + 116|0))>>2] = ((((gb + (170632) | 0)) + 104|0));
    HEAP32[((((gb + (170632) | 0)) + 112|0))>>2] = ((((gb + (170632) | 0)) + 104|0));
    HEAP32[((((gb + (170632) | 0)) + 124|0))>>2] = ((((gb + (170632) | 0)) + 112|0));
    HEAP32[((((gb + (170632) | 0)) + 120|0))>>2] = ((((gb + (170632) | 0)) + 112|0));
    HEAP32[((((gb + (170632) | 0)) + 132|0))>>2] = ((((gb + (170632) | 0)) + 120|0));
    HEAP32[((((gb + (170632) | 0)) + 128|0))>>2] = ((((gb + (170632) | 0)) + 120|0));
    HEAP32[((((gb + (170632) | 0)) + 140|0))>>2] = ((((gb + (170632) | 0)) + 128|0));
    HEAP32[((((gb + (170632) | 0)) + 136|0))>>2] = ((((gb + (170632) | 0)) + 128|0));
    HEAP32[((((gb + (170632) | 0)) + 148|0))>>2] = ((((gb + (170632) | 0)) + 136|0));
    HEAP32[((((gb + (170632) | 0)) + 144|0))>>2] = ((((gb + (170632) | 0)) + 136|0));
    HEAP32[((((gb + (170632) | 0)) + 156|0))>>2] = ((((gb + (170632) | 0)) + 144|0));
    HEAP32[((((gb + (170632) | 0)) + 152|0))>>2] = ((((gb + (170632) | 0)) + 144|0));
    HEAP32[((((gb + (170632) | 0)) + 164|0))>>2] = ((((gb + (170632) | 0)) + 152|0));
    HEAP32[((((gb + (170632) | 0)) + 160|0))>>2] = ((((gb + (170632) | 0)) + 152|0));
    HEAP32[((((gb + (170632) | 0)) + 172|0))>>2] = ((((gb + (170632) | 0)) + 160|0));
    HEAP32[((((gb + (170632) | 0)) + 168|0))>>2] = ((((gb + (170632) | 0)) + 160|0));
    HEAP32[((((gb + (170632) | 0)) + 180|0))>>2] = ((((gb + (170632) | 0)) + 168|0));
    HEAP32[((((gb + (170632) | 0)) + 176|0))>>2] = ((((gb + (170632) | 0)) + 168|0));
    HEAP32[((((gb + (170632) | 0)) + 188|0))>>2] = ((((gb + (170632) | 0)) + 176|0));
    HEAP32[((((gb + (170632) | 0)) + 184|0))>>2] = ((((gb + (170632) | 0)) + 176|0));
    HEAP32[((((gb + (170632) | 0)) + 196|0))>>2] = ((((gb + (170632) | 0)) + 184|0));
    HEAP32[((((gb + (170632) | 0)) + 192|0))>>2] = ((((gb + (170632) | 0)) + 184|0));
    HEAP32[((((gb + (170632) | 0)) + 204|0))>>2] = ((((gb + (170632) | 0)) + 192|0));
    HEAP32[((((gb + (170632) | 0)) + 200|0))>>2] = ((((gb + (170632) | 0)) + 192|0));
    HEAP32[((((gb + (170632) | 0)) + 212|0))>>2] = ((((gb + (170632) | 0)) + 200|0));
    HEAP32[((((gb + (170632) | 0)) + 208|0))>>2] = ((((gb + (170632) | 0)) + 200|0));
    HEAP32[((((gb + (170632) | 0)) + 220|0))>>2] = ((((gb + (170632) | 0)) + 208|0));
    HEAP32[((((gb + (170632) | 0)) + 216|0))>>2] = ((((gb + (170632) | 0)) + 208|0));
    HEAP32[((((gb + (170632) | 0)) + 228|0))>>2] = ((((gb + (170632) | 0)) + 216|0));
    HEAP32[((((gb + (170632) | 0)) + 224|0))>>2] = ((((gb + (170632) | 0)) + 216|0));
    HEAP32[((((gb + (170632) | 0)) + 236|0))>>2] = ((((gb + (170632) | 0)) + 224|0));
    HEAP32[((((gb + (170632) | 0)) + 232|0))>>2] = ((((gb + (170632) | 0)) + 224|0));
    HEAP32[((((gb + (170632) | 0)) + 244|0))>>2] = ((((gb + (170632) | 0)) + 232|0));
    HEAP32[((((gb + (170632) | 0)) + 240|0))>>2] = ((((gb + (170632) | 0)) + 232|0));
    HEAP32[((((gb + (170632) | 0)) + 252|0))>>2] = ((((gb + (170632) | 0)) + 240|0));
    HEAP32[((((gb + (170632) | 0)) + 248|0))>>2] = ((((gb + (170632) | 0)) + 240|0));
    HEAP32[((((gb + (170632) | 0)) + 260|0))>>2] = ((((gb + (170632) | 0)) + 248|0));
    HEAP32[((((gb + (170632) | 0)) + 256|0))>>2] = ((((gb + (170632) | 0)) + 248|0));
    HEAP32[((((gb + (170632) | 0)) + 268|0))>>2] = ((((gb + (170632) | 0)) + 256|0));
    HEAP32[((((gb + (170632) | 0)) + 264|0))>>2] = ((((gb + (170632) | 0)) + 256|0));
    HEAP32[((((gb + (170632) | 0)) + 276|0))>>2] = ((((gb + (170632) | 0)) + 264|0));
    HEAP32[((((gb + (170632) | 0)) + 272|0))>>2] = ((((gb + (170632) | 0)) + 264|0));
    HEAP32[((((gb + (170632) | 0)) + 284|0))>>2] = ((((gb + (170632) | 0)) + 272|0));
    HEAP32[((((gb + (170632) | 0)) + 280|0))>>2] = ((((gb + (170632) | 0)) + 272|0));
    HEAP32[((((gb + (170632) | 0)) + 292|0))>>2] = ((((gb + (170632) | 0)) + 280|0));
    HEAP32[((((gb + (170632) | 0)) + 288|0))>>2] = ((((gb + (170632) | 0)) + 280|0));
    HEAP32[((((gb + (170632) | 0)) + 300|0))>>2] = ((((gb + (170632) | 0)) + 288|0));
    HEAP32[((((gb + (170632) | 0)) + 296|0))>>2] = ((((gb + (170632) | 0)) + 288|0));
    $591 = (($$723947$i) + -40)|0;
    $592 = ((($$748$i)) + 8|0);
    $593 = $592;
    $594 = $593 & 7;
    $595 = ($594|0)==(0);
    $596 = (0 - ($593))|0;
    $597 = $596 & 7;
    $598 = $595 ? 0 : $597;
    $599 = (($$748$i) + ($598)|0);
    $600 = (($591) - ($598))|0;
    HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $599;
    HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $600;
    $601 = $600 | 1;
    $602 = ((($599)) + 4|0);
    HEAP32[$602>>2] = $601;
    $603 = (($$748$i) + ($591)|0);
    $604 = ((($603)) + 4|0);
    HEAP32[$604>>2] = 40;
    $605 = HEAP32[((((gb + (171104) | 0)) + 16|0))>>2]|0;
    HEAP32[((((gb + (170632) | 0)) + 28|0))>>2] = $605;
   } else {
    $$024372$i = ((((gb + (170632) | 0)) + 448|0));
    while(1) {
     $606 = HEAP32[$$024372$i>>2]|0;
     $607 = ((($$024372$i)) + 4|0);
     $608 = HEAP32[$607>>2]|0;
     $609 = (($606) + ($608)|0);
     $610 = ($$748$i|0)==($609|0);
     if ($610) {
      label = 154;
      break;
     }
     $611 = ((($$024372$i)) + 8|0);
     $612 = HEAP32[$611>>2]|0;
     $613 = ($612|0)==(0|0);
     if ($613) {
      break;
     } else {
      $$024372$i = $612;
     }
    }
    if ((label|0) == 154) {
     $614 = ((($$024372$i)) + 4|0);
     $615 = ((($$024372$i)) + 12|0);
     $616 = HEAP32[$615>>2]|0;
     $617 = $616 & 8;
     $618 = ($617|0)==(0);
     if ($618) {
      $619 = ($606>>>0)<=($585>>>0);
      $620 = ($$748$i>>>0)>($585>>>0);
      $or$cond51$i = $620 & $619;
      if ($or$cond51$i) {
       $621 = (($608) + ($$723947$i))|0;
       HEAP32[$614>>2] = $621;
       $622 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
       $623 = (($622) + ($$723947$i))|0;
       $624 = ((($585)) + 8|0);
       $625 = $624;
       $626 = $625 & 7;
       $627 = ($626|0)==(0);
       $628 = (0 - ($625))|0;
       $629 = $628 & 7;
       $630 = $627 ? 0 : $629;
       $631 = (($585) + ($630)|0);
       $632 = (($623) - ($630))|0;
       HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $631;
       HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $632;
       $633 = $632 | 1;
       $634 = ((($631)) + 4|0);
       HEAP32[$634>>2] = $633;
       $635 = (($585) + ($623)|0);
       $636 = ((($635)) + 4|0);
       HEAP32[$636>>2] = 40;
       $637 = HEAP32[((((gb + (171104) | 0)) + 16|0))>>2]|0;
       HEAP32[((((gb + (170632) | 0)) + 28|0))>>2] = $637;
       break;
      }
     }
    }
    $638 = HEAP32[((((gb + (170632) | 0)) + 16|0))>>2]|0;
    $639 = ($$748$i>>>0)<($638>>>0);
    if ($639) {
     HEAP32[((((gb + (170632) | 0)) + 16|0))>>2] = $$748$i;
    }
    $640 = (($$748$i) + ($$723947$i)|0);
    $$124471$i = ((((gb + (170632) | 0)) + 448|0));
    while(1) {
     $641 = HEAP32[$$124471$i>>2]|0;
     $642 = ($641|0)==($640|0);
     if ($642) {
      label = 162;
      break;
     }
     $643 = ((($$124471$i)) + 8|0);
     $644 = HEAP32[$643>>2]|0;
     $645 = ($644|0)==(0|0);
     if ($645) {
      break;
     } else {
      $$124471$i = $644;
     }
    }
    if ((label|0) == 162) {
     $646 = ((($$124471$i)) + 12|0);
     $647 = HEAP32[$646>>2]|0;
     $648 = $647 & 8;
     $649 = ($648|0)==(0);
     if ($649) {
      HEAP32[$$124471$i>>2] = $$748$i;
      $650 = ((($$124471$i)) + 4|0);
      $651 = HEAP32[$650>>2]|0;
      $652 = (($651) + ($$723947$i))|0;
      HEAP32[$650>>2] = $652;
      $653 = ((($$748$i)) + 8|0);
      $654 = $653;
      $655 = $654 & 7;
      $656 = ($655|0)==(0);
      $657 = (0 - ($654))|0;
      $658 = $657 & 7;
      $659 = $656 ? 0 : $658;
      $660 = (($$748$i) + ($659)|0);
      $661 = ((($640)) + 8|0);
      $662 = $661;
      $663 = $662 & 7;
      $664 = ($663|0)==(0);
      $665 = (0 - ($662))|0;
      $666 = $665 & 7;
      $667 = $664 ? 0 : $666;
      $668 = (($640) + ($667)|0);
      $669 = $668;
      $670 = $660;
      $671 = (($669) - ($670))|0;
      $672 = (($660) + ($$0192)|0);
      $673 = (($671) - ($$0192))|0;
      $674 = $$0192 | 3;
      $675 = ((($660)) + 4|0);
      HEAP32[$675>>2] = $674;
      $676 = ($585|0)==($668|0);
      L238: do {
       if ($676) {
        $677 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
        $678 = (($677) + ($673))|0;
        HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $678;
        HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $672;
        $679 = $678 | 1;
        $680 = ((($672)) + 4|0);
        HEAP32[$680>>2] = $679;
       } else {
        $681 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
        $682 = ($681|0)==($668|0);
        if ($682) {
         $683 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
         $684 = (($683) + ($673))|0;
         HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $684;
         HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $672;
         $685 = $684 | 1;
         $686 = ((($672)) + 4|0);
         HEAP32[$686>>2] = $685;
         $687 = (($672) + ($684)|0);
         HEAP32[$687>>2] = $684;
         break;
        }
        $688 = ((($668)) + 4|0);
        $689 = HEAP32[$688>>2]|0;
        $690 = $689 & 3;
        $691 = ($690|0)==(1);
        if ($691) {
         $692 = $689 & -8;
         $693 = $689 >>> 3;
         $694 = ($689>>>0)<(256);
         L246: do {
          if ($694) {
           $695 = ((($668)) + 8|0);
           $696 = HEAP32[$695>>2]|0;
           $697 = ((($668)) + 12|0);
           $698 = HEAP32[$697>>2]|0;
           $699 = ($698|0)==($696|0);
           if ($699) {
            $700 = 1 << $693;
            $701 = $700 ^ -1;
            $702 = HEAP32[(gb + (170632) | 0)>>2]|0;
            $703 = $702 & $701;
            HEAP32[(gb + (170632) | 0)>>2] = $703;
            break;
           } else {
            $704 = ((($696)) + 12|0);
            HEAP32[$704>>2] = $698;
            $705 = ((($698)) + 8|0);
            HEAP32[$705>>2] = $696;
            break;
           }
          } else {
           $706 = ((($668)) + 24|0);
           $707 = HEAP32[$706>>2]|0;
           $708 = ((($668)) + 12|0);
           $709 = HEAP32[$708>>2]|0;
           $710 = ($709|0)==($668|0);
           do {
            if ($710) {
             $715 = ((($668)) + 16|0);
             $716 = ((($715)) + 4|0);
             $717 = HEAP32[$716>>2]|0;
             $718 = ($717|0)==(0|0);
             if ($718) {
              $719 = HEAP32[$715>>2]|0;
              $720 = ($719|0)==(0|0);
              if ($720) {
               $$3$i$i = 0;
               break;
              } else {
               $$1263$i$i$ph = $719;$$1265$i$i$ph = $715;
              }
             } else {
              $$1263$i$i$ph = $717;$$1265$i$i$ph = $716;
             }
             $$1263$i$i = $$1263$i$i$ph;$$1265$i$i = $$1265$i$i$ph;
             while(1) {
              $721 = ((($$1263$i$i)) + 20|0);
              $722 = HEAP32[$721>>2]|0;
              $723 = ($722|0)==(0|0);
              if ($723) {
               $724 = ((($$1263$i$i)) + 16|0);
               $725 = HEAP32[$724>>2]|0;
               $726 = ($725|0)==(0|0);
               if ($726) {
                break;
               } else {
                $$1263$i$i$be = $725;$$1265$i$i$be = $724;
               }
              } else {
               $$1263$i$i$be = $722;$$1265$i$i$be = $721;
              }
              $$1263$i$i = $$1263$i$i$be;$$1265$i$i = $$1265$i$i$be;
             }
             HEAP32[$$1265$i$i>>2] = 0;
             $$3$i$i = $$1263$i$i;
            } else {
             $711 = ((($668)) + 8|0);
             $712 = HEAP32[$711>>2]|0;
             $713 = ((($712)) + 12|0);
             HEAP32[$713>>2] = $709;
             $714 = ((($709)) + 8|0);
             HEAP32[$714>>2] = $712;
             $$3$i$i = $709;
            }
           } while(0);
           $727 = ($707|0)==(0|0);
           if ($727) {
            break;
           }
           $728 = ((($668)) + 28|0);
           $729 = HEAP32[$728>>2]|0;
           $730 = ((((gb + (170632) | 0)) + 304|0) + ($729<<2)|0);
           $731 = HEAP32[$730>>2]|0;
           $732 = ($731|0)==($668|0);
           do {
            if ($732) {
             HEAP32[$730>>2] = $$3$i$i;
             $cond$i$i = ($$3$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $733 = 1 << $729;
             $734 = $733 ^ -1;
             $735 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
             $736 = $735 & $734;
             HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $736;
             break L246;
            } else {
             $737 = ((($707)) + 16|0);
             $738 = HEAP32[$737>>2]|0;
             $739 = ($738|0)==($668|0);
             $740 = ((($707)) + 20|0);
             $$sink321 = $739 ? $737 : $740;
             HEAP32[$$sink321>>2] = $$3$i$i;
             $741 = ($$3$i$i|0)==(0|0);
             if ($741) {
              break L246;
             }
            }
           } while(0);
           $742 = ((($$3$i$i)) + 24|0);
           HEAP32[$742>>2] = $707;
           $743 = ((($668)) + 16|0);
           $744 = HEAP32[$743>>2]|0;
           $745 = ($744|0)==(0|0);
           if (!($745)) {
            $746 = ((($$3$i$i)) + 16|0);
            HEAP32[$746>>2] = $744;
            $747 = ((($744)) + 24|0);
            HEAP32[$747>>2] = $$3$i$i;
           }
           $748 = ((($743)) + 4|0);
           $749 = HEAP32[$748>>2]|0;
           $750 = ($749|0)==(0|0);
           if ($750) {
            break;
           }
           $751 = ((($$3$i$i)) + 20|0);
           HEAP32[$751>>2] = $749;
           $752 = ((($749)) + 24|0);
           HEAP32[$752>>2] = $$3$i$i;
          }
         } while(0);
         $753 = (($668) + ($692)|0);
         $754 = (($692) + ($673))|0;
         $$0$i$i = $753;$$0259$i$i = $754;
        } else {
         $$0$i$i = $668;$$0259$i$i = $673;
        }
        $755 = ((($$0$i$i)) + 4|0);
        $756 = HEAP32[$755>>2]|0;
        $757 = $756 & -2;
        HEAP32[$755>>2] = $757;
        $758 = $$0259$i$i | 1;
        $759 = ((($672)) + 4|0);
        HEAP32[$759>>2] = $758;
        $760 = (($672) + ($$0259$i$i)|0);
        HEAP32[$760>>2] = $$0259$i$i;
        $761 = $$0259$i$i >>> 3;
        $762 = ($$0259$i$i>>>0)<(256);
        if ($762) {
         $763 = $761 << 1;
         $764 = ((((gb + (170632) | 0)) + 40|0) + ($763<<2)|0);
         $765 = HEAP32[(gb + (170632) | 0)>>2]|0;
         $766 = 1 << $761;
         $767 = $765 & $766;
         $768 = ($767|0)==(0);
         if ($768) {
          $769 = $765 | $766;
          HEAP32[(gb + (170632) | 0)>>2] = $769;
          $$pre$i16$i = ((($764)) + 8|0);
          $$0267$i$i = $764;$$pre$phi$i17$iZ2D = $$pre$i16$i;
         } else {
          $770 = ((($764)) + 8|0);
          $771 = HEAP32[$770>>2]|0;
          $$0267$i$i = $771;$$pre$phi$i17$iZ2D = $770;
         }
         HEAP32[$$pre$phi$i17$iZ2D>>2] = $672;
         $772 = ((($$0267$i$i)) + 12|0);
         HEAP32[$772>>2] = $672;
         $773 = ((($672)) + 8|0);
         HEAP32[$773>>2] = $$0267$i$i;
         $774 = ((($672)) + 12|0);
         HEAP32[$774>>2] = $764;
         break;
        }
        $775 = $$0259$i$i >>> 8;
        $776 = ($775|0)==(0);
        do {
         if ($776) {
          $$0268$i$i = 0;
         } else {
          $777 = ($$0259$i$i>>>0)>(16777215);
          if ($777) {
           $$0268$i$i = 31;
           break;
          }
          $778 = (($775) + 1048320)|0;
          $779 = $778 >>> 16;
          $780 = $779 & 8;
          $781 = $775 << $780;
          $782 = (($781) + 520192)|0;
          $783 = $782 >>> 16;
          $784 = $783 & 4;
          $785 = $784 | $780;
          $786 = $781 << $784;
          $787 = (($786) + 245760)|0;
          $788 = $787 >>> 16;
          $789 = $788 & 2;
          $790 = $785 | $789;
          $791 = (14 - ($790))|0;
          $792 = $786 << $789;
          $793 = $792 >>> 15;
          $794 = (($791) + ($793))|0;
          $795 = $794 << 1;
          $796 = (($794) + 7)|0;
          $797 = $$0259$i$i >>> $796;
          $798 = $797 & 1;
          $799 = $798 | $795;
          $$0268$i$i = $799;
         }
        } while(0);
        $800 = ((((gb + (170632) | 0)) + 304|0) + ($$0268$i$i<<2)|0);
        $801 = ((($672)) + 28|0);
        HEAP32[$801>>2] = $$0268$i$i;
        $802 = ((($672)) + 16|0);
        $803 = ((($802)) + 4|0);
        HEAP32[$803>>2] = 0;
        HEAP32[$802>>2] = 0;
        $804 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
        $805 = 1 << $$0268$i$i;
        $806 = $804 & $805;
        $807 = ($806|0)==(0);
        if ($807) {
         $808 = $804 | $805;
         HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $808;
         HEAP32[$800>>2] = $672;
         $809 = ((($672)) + 24|0);
         HEAP32[$809>>2] = $800;
         $810 = ((($672)) + 12|0);
         HEAP32[$810>>2] = $672;
         $811 = ((($672)) + 8|0);
         HEAP32[$811>>2] = $672;
         break;
        }
        $812 = HEAP32[$800>>2]|0;
        $813 = ((($812)) + 4|0);
        $814 = HEAP32[$813>>2]|0;
        $815 = $814 & -8;
        $816 = ($815|0)==($$0259$i$i|0);
        L291: do {
         if ($816) {
          $$0261$lcssa$i$i = $812;
         } else {
          $817 = ($$0268$i$i|0)==(31);
          $818 = $$0268$i$i >>> 1;
          $819 = (25 - ($818))|0;
          $820 = $817 ? 0 : $819;
          $821 = $$0259$i$i << $820;
          $$02604$i$i = $821;$$02613$i$i = $812;
          while(1) {
           $828 = $$02604$i$i >>> 31;
           $829 = (((($$02613$i$i)) + 16|0) + ($828<<2)|0);
           $824 = HEAP32[$829>>2]|0;
           $830 = ($824|0)==(0|0);
           if ($830) {
            break;
           }
           $822 = $$02604$i$i << 1;
           $823 = ((($824)) + 4|0);
           $825 = HEAP32[$823>>2]|0;
           $826 = $825 & -8;
           $827 = ($826|0)==($$0259$i$i|0);
           if ($827) {
            $$0261$lcssa$i$i = $824;
            break L291;
           } else {
            $$02604$i$i = $822;$$02613$i$i = $824;
           }
          }
          HEAP32[$829>>2] = $672;
          $831 = ((($672)) + 24|0);
          HEAP32[$831>>2] = $$02613$i$i;
          $832 = ((($672)) + 12|0);
          HEAP32[$832>>2] = $672;
          $833 = ((($672)) + 8|0);
          HEAP32[$833>>2] = $672;
          break L238;
         }
        } while(0);
        $834 = ((($$0261$lcssa$i$i)) + 8|0);
        $835 = HEAP32[$834>>2]|0;
        $836 = ((($835)) + 12|0);
        HEAP32[$836>>2] = $672;
        HEAP32[$834>>2] = $672;
        $837 = ((($672)) + 8|0);
        HEAP32[$837>>2] = $835;
        $838 = ((($672)) + 12|0);
        HEAP32[$838>>2] = $$0261$lcssa$i$i;
        $839 = ((($672)) + 24|0);
        HEAP32[$839>>2] = 0;
       }
      } while(0);
      $968 = ((($660)) + 8|0);
      $$0 = $968;
      STACKTOP = sp;return ($$0|0);
     }
    }
    $$0$i$i$i = ((((gb + (170632) | 0)) + 448|0));
    while(1) {
     $840 = HEAP32[$$0$i$i$i>>2]|0;
     $841 = ($840>>>0)>($585>>>0);
     if (!($841)) {
      $842 = ((($$0$i$i$i)) + 4|0);
      $843 = HEAP32[$842>>2]|0;
      $844 = (($840) + ($843)|0);
      $845 = ($844>>>0)>($585>>>0);
      if ($845) {
       break;
      }
     }
     $846 = ((($$0$i$i$i)) + 8|0);
     $847 = HEAP32[$846>>2]|0;
     $$0$i$i$i = $847;
    }
    $848 = ((($844)) + -47|0);
    $849 = ((($848)) + 8|0);
    $850 = $849;
    $851 = $850 & 7;
    $852 = ($851|0)==(0);
    $853 = (0 - ($850))|0;
    $854 = $853 & 7;
    $855 = $852 ? 0 : $854;
    $856 = (($848) + ($855)|0);
    $857 = ((($585)) + 16|0);
    $858 = ($856>>>0)<($857>>>0);
    $859 = $858 ? $585 : $856;
    $860 = ((($859)) + 8|0);
    $861 = ((($859)) + 24|0);
    $862 = (($$723947$i) + -40)|0;
    $863 = ((($$748$i)) + 8|0);
    $864 = $863;
    $865 = $864 & 7;
    $866 = ($865|0)==(0);
    $867 = (0 - ($864))|0;
    $868 = $867 & 7;
    $869 = $866 ? 0 : $868;
    $870 = (($$748$i) + ($869)|0);
    $871 = (($862) - ($869))|0;
    HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $870;
    HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $871;
    $872 = $871 | 1;
    $873 = ((($870)) + 4|0);
    HEAP32[$873>>2] = $872;
    $874 = (($$748$i) + ($862)|0);
    $875 = ((($874)) + 4|0);
    HEAP32[$875>>2] = 40;
    $876 = HEAP32[((((gb + (171104) | 0)) + 16|0))>>2]|0;
    HEAP32[((((gb + (170632) | 0)) + 28|0))>>2] = $876;
    $877 = ((($859)) + 4|0);
    HEAP32[$877>>2] = 27;
    ;HEAP32[$860>>2]=HEAP32[((((gb + (170632) | 0)) + 448|0))>>2]|0;HEAP32[$860+4>>2]=HEAP32[((((gb + (170632) | 0)) + 448|0))+4>>2]|0;HEAP32[$860+8>>2]=HEAP32[((((gb + (170632) | 0)) + 448|0))+8>>2]|0;HEAP32[$860+12>>2]=HEAP32[((((gb + (170632) | 0)) + 448|0))+12>>2]|0;
    HEAP32[((((gb + (170632) | 0)) + 448|0))>>2] = $$748$i;
    HEAP32[((((gb + (170632) | 0)) + 452|0))>>2] = $$723947$i;
    HEAP32[((((gb + (170632) | 0)) + 460|0))>>2] = 0;
    HEAP32[((((gb + (170632) | 0)) + 456|0))>>2] = $860;
    $879 = $861;
    while(1) {
     $878 = ((($879)) + 4|0);
     HEAP32[$878>>2] = 7;
     $880 = ((($879)) + 8|0);
     $881 = ($880>>>0)<($844>>>0);
     if ($881) {
      $879 = $878;
     } else {
      break;
     }
    }
    $882 = ($859|0)==($585|0);
    if (!($882)) {
     $883 = $859;
     $884 = $585;
     $885 = (($883) - ($884))|0;
     $886 = HEAP32[$877>>2]|0;
     $887 = $886 & -2;
     HEAP32[$877>>2] = $887;
     $888 = $885 | 1;
     $889 = ((($585)) + 4|0);
     HEAP32[$889>>2] = $888;
     HEAP32[$859>>2] = $885;
     $890 = $885 >>> 3;
     $891 = ($885>>>0)<(256);
     if ($891) {
      $892 = $890 << 1;
      $893 = ((((gb + (170632) | 0)) + 40|0) + ($892<<2)|0);
      $894 = HEAP32[(gb + (170632) | 0)>>2]|0;
      $895 = 1 << $890;
      $896 = $894 & $895;
      $897 = ($896|0)==(0);
      if ($897) {
       $898 = $894 | $895;
       HEAP32[(gb + (170632) | 0)>>2] = $898;
       $$pre$i$i = ((($893)) + 8|0);
       $$0206$i$i = $893;$$pre$phi$i$iZ2D = $$pre$i$i;
      } else {
       $899 = ((($893)) + 8|0);
       $900 = HEAP32[$899>>2]|0;
       $$0206$i$i = $900;$$pre$phi$i$iZ2D = $899;
      }
      HEAP32[$$pre$phi$i$iZ2D>>2] = $585;
      $901 = ((($$0206$i$i)) + 12|0);
      HEAP32[$901>>2] = $585;
      $902 = ((($585)) + 8|0);
      HEAP32[$902>>2] = $$0206$i$i;
      $903 = ((($585)) + 12|0);
      HEAP32[$903>>2] = $893;
      break;
     }
     $904 = $885 >>> 8;
     $905 = ($904|0)==(0);
     if ($905) {
      $$0207$i$i = 0;
     } else {
      $906 = ($885>>>0)>(16777215);
      if ($906) {
       $$0207$i$i = 31;
      } else {
       $907 = (($904) + 1048320)|0;
       $908 = $907 >>> 16;
       $909 = $908 & 8;
       $910 = $904 << $909;
       $911 = (($910) + 520192)|0;
       $912 = $911 >>> 16;
       $913 = $912 & 4;
       $914 = $913 | $909;
       $915 = $910 << $913;
       $916 = (($915) + 245760)|0;
       $917 = $916 >>> 16;
       $918 = $917 & 2;
       $919 = $914 | $918;
       $920 = (14 - ($919))|0;
       $921 = $915 << $918;
       $922 = $921 >>> 15;
       $923 = (($920) + ($922))|0;
       $924 = $923 << 1;
       $925 = (($923) + 7)|0;
       $926 = $885 >>> $925;
       $927 = $926 & 1;
       $928 = $927 | $924;
       $$0207$i$i = $928;
      }
     }
     $929 = ((((gb + (170632) | 0)) + 304|0) + ($$0207$i$i<<2)|0);
     $930 = ((($585)) + 28|0);
     HEAP32[$930>>2] = $$0207$i$i;
     $931 = ((($585)) + 20|0);
     HEAP32[$931>>2] = 0;
     HEAP32[$857>>2] = 0;
     $932 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
     $933 = 1 << $$0207$i$i;
     $934 = $932 & $933;
     $935 = ($934|0)==(0);
     if ($935) {
      $936 = $932 | $933;
      HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $936;
      HEAP32[$929>>2] = $585;
      $937 = ((($585)) + 24|0);
      HEAP32[$937>>2] = $929;
      $938 = ((($585)) + 12|0);
      HEAP32[$938>>2] = $585;
      $939 = ((($585)) + 8|0);
      HEAP32[$939>>2] = $585;
      break;
     }
     $940 = HEAP32[$929>>2]|0;
     $941 = ((($940)) + 4|0);
     $942 = HEAP32[$941>>2]|0;
     $943 = $942 & -8;
     $944 = ($943|0)==($885|0);
     L325: do {
      if ($944) {
       $$0202$lcssa$i$i = $940;
      } else {
       $945 = ($$0207$i$i|0)==(31);
       $946 = $$0207$i$i >>> 1;
       $947 = (25 - ($946))|0;
       $948 = $945 ? 0 : $947;
       $949 = $885 << $948;
       $$02014$i$i = $949;$$02023$i$i = $940;
       while(1) {
        $956 = $$02014$i$i >>> 31;
        $957 = (((($$02023$i$i)) + 16|0) + ($956<<2)|0);
        $952 = HEAP32[$957>>2]|0;
        $958 = ($952|0)==(0|0);
        if ($958) {
         break;
        }
        $950 = $$02014$i$i << 1;
        $951 = ((($952)) + 4|0);
        $953 = HEAP32[$951>>2]|0;
        $954 = $953 & -8;
        $955 = ($954|0)==($885|0);
        if ($955) {
         $$0202$lcssa$i$i = $952;
         break L325;
        } else {
         $$02014$i$i = $950;$$02023$i$i = $952;
        }
       }
       HEAP32[$957>>2] = $585;
       $959 = ((($585)) + 24|0);
       HEAP32[$959>>2] = $$02023$i$i;
       $960 = ((($585)) + 12|0);
       HEAP32[$960>>2] = $585;
       $961 = ((($585)) + 8|0);
       HEAP32[$961>>2] = $585;
       break L215;
      }
     } while(0);
     $962 = ((($$0202$lcssa$i$i)) + 8|0);
     $963 = HEAP32[$962>>2]|0;
     $964 = ((($963)) + 12|0);
     HEAP32[$964>>2] = $585;
     HEAP32[$962>>2] = $585;
     $965 = ((($585)) + 8|0);
     HEAP32[$965>>2] = $963;
     $966 = ((($585)) + 12|0);
     HEAP32[$966>>2] = $$0202$lcssa$i$i;
     $967 = ((($585)) + 24|0);
     HEAP32[$967>>2] = 0;
    }
   }
  } while(0);
  $969 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
  $970 = ($969>>>0)>($$0192>>>0);
  if ($970) {
   $971 = (($969) - ($$0192))|0;
   HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $971;
   $972 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
   $973 = (($972) + ($$0192)|0);
   HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $973;
   $974 = $971 | 1;
   $975 = ((($973)) + 4|0);
   HEAP32[$975>>2] = $974;
   $976 = $$0192 | 3;
   $977 = ((($972)) + 4|0);
   HEAP32[$977>>2] = $976;
   $978 = ((($972)) + 8|0);
   $$0 = $978;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $979 = (___errno_location()|0);
 HEAP32[$979>>2] = 12;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _free($0) {
 $0 = $0|0;
 var $$0194$i = 0, $$0194$in$i = 0, $$0346381 = 0, $$0347$lcssa = 0, $$0347380 = 0, $$0359 = 0, $$0366 = 0, $$1 = 0, $$1345 = 0, $$1350 = 0, $$1350$be = 0, $$1350$ph = 0, $$1353 = 0, $$1353$be = 0, $$1353$ph = 0, $$1361 = 0, $$1361$be = 0, $$1361$ph = 0, $$1365 = 0, $$1365$be = 0;
 var $$1365$ph = 0, $$2 = 0, $$3 = 0, $$3363 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink = 0, $$sink395 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond371 = 0, $cond372 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = ((($0)) + -8|0);
 $3 = HEAP32[((((gb + (170632) | 0)) + 16|0))>>2]|0;
 $4 = ((($0)) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & -8;
 $7 = (($2) + ($6)|0);
 $8 = $5 & 1;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $5 & 3;
   $12 = ($11|0)==(0);
   if ($12) {
    return;
   }
   $13 = (0 - ($10))|0;
   $14 = (($2) + ($13)|0);
   $15 = (($10) + ($6))|0;
   $16 = ($14>>>0)<($3>>>0);
   if ($16) {
    return;
   }
   $17 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
   $18 = ($17|0)==($14|0);
   if ($18) {
    $79 = ((($7)) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = $80 & 3;
    $82 = ($81|0)==(3);
    if (!($82)) {
     $$1 = $14;$$1345 = $15;$88 = $14;
     break;
    }
    $83 = (($14) + ($15)|0);
    $84 = ((($14)) + 4|0);
    $85 = $15 | 1;
    $86 = $80 & -2;
    HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $15;
    HEAP32[$79>>2] = $86;
    HEAP32[$84>>2] = $85;
    HEAP32[$83>>2] = $15;
    return;
   }
   $19 = $10 >>> 3;
   $20 = ($10>>>0)<(256);
   if ($20) {
    $21 = ((($14)) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($14)) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($22|0);
    if ($25) {
     $26 = 1 << $19;
     $27 = $26 ^ -1;
     $28 = HEAP32[(gb + (170632) | 0)>>2]|0;
     $29 = $28 & $27;
     HEAP32[(gb + (170632) | 0)>>2] = $29;
     $$1 = $14;$$1345 = $15;$88 = $14;
     break;
    } else {
     $30 = ((($22)) + 12|0);
     HEAP32[$30>>2] = $24;
     $31 = ((($24)) + 8|0);
     HEAP32[$31>>2] = $22;
     $$1 = $14;$$1345 = $15;$88 = $14;
     break;
    }
   }
   $32 = ((($14)) + 24|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ((($14)) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($14|0);
   do {
    if ($36) {
     $41 = ((($14)) + 16|0);
     $42 = ((($41)) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $45 = HEAP32[$41>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       $$3 = 0;
       break;
      } else {
       $$1350$ph = $45;$$1353$ph = $41;
      }
     } else {
      $$1350$ph = $43;$$1353$ph = $42;
     }
     $$1350 = $$1350$ph;$$1353 = $$1353$ph;
     while(1) {
      $47 = ((($$1350)) + 20|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==(0|0);
      if ($49) {
       $50 = ((($$1350)) + 16|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ($51|0)==(0|0);
       if ($52) {
        break;
       } else {
        $$1350$be = $51;$$1353$be = $50;
       }
      } else {
       $$1350$be = $48;$$1353$be = $47;
      }
      $$1350 = $$1350$be;$$1353 = $$1353$be;
     }
     HEAP32[$$1353>>2] = 0;
     $$3 = $$1350;
    } else {
     $37 = ((($14)) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($38)) + 12|0);
     HEAP32[$39>>2] = $35;
     $40 = ((($35)) + 8|0);
     HEAP32[$40>>2] = $38;
     $$3 = $35;
    }
   } while(0);
   $53 = ($33|0)==(0|0);
   if ($53) {
    $$1 = $14;$$1345 = $15;$88 = $14;
   } else {
    $54 = ((($14)) + 28|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ((((gb + (170632) | 0)) + 304|0) + ($55<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)==($14|0);
    if ($58) {
     HEAP32[$56>>2] = $$3;
     $cond371 = ($$3|0)==(0|0);
     if ($cond371) {
      $59 = 1 << $55;
      $60 = $59 ^ -1;
      $61 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
      $62 = $61 & $60;
      HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $62;
      $$1 = $14;$$1345 = $15;$88 = $14;
      break;
     }
    } else {
     $63 = ((($33)) + 16|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==($14|0);
     $66 = ((($33)) + 20|0);
     $$sink = $65 ? $63 : $66;
     HEAP32[$$sink>>2] = $$3;
     $67 = ($$3|0)==(0|0);
     if ($67) {
      $$1 = $14;$$1345 = $15;$88 = $14;
      break;
     }
    }
    $68 = ((($$3)) + 24|0);
    HEAP32[$68>>2] = $33;
    $69 = ((($14)) + 16|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if (!($71)) {
     $72 = ((($$3)) + 16|0);
     HEAP32[$72>>2] = $70;
     $73 = ((($70)) + 24|0);
     HEAP32[$73>>2] = $$3;
    }
    $74 = ((($69)) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     $$1 = $14;$$1345 = $15;$88 = $14;
    } else {
     $77 = ((($$3)) + 20|0);
     HEAP32[$77>>2] = $75;
     $78 = ((($75)) + 24|0);
     HEAP32[$78>>2] = $$3;
     $$1 = $14;$$1345 = $15;$88 = $14;
    }
   }
  } else {
   $$1 = $2;$$1345 = $6;$88 = $2;
  }
 } while(0);
 $87 = ($88>>>0)<($7>>>0);
 if (!($87)) {
  return;
 }
 $89 = ((($7)) + 4|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = $90 & 1;
 $92 = ($91|0)==(0);
 if ($92) {
  return;
 }
 $93 = $90 & 2;
 $94 = ($93|0)==(0);
 if ($94) {
  $95 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
  $96 = ($95|0)==($7|0);
  if ($96) {
   $97 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
   $98 = (($97) + ($$1345))|0;
   HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $98;
   HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $$1;
   $99 = $98 | 1;
   $100 = ((($$1)) + 4|0);
   HEAP32[$100>>2] = $99;
   $101 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
   $102 = ($$1|0)==($101|0);
   if (!($102)) {
    return;
   }
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = 0;
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = 0;
   return;
  }
  $103 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
  $104 = ($103|0)==($7|0);
  if ($104) {
   $105 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
   $106 = (($105) + ($$1345))|0;
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $106;
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $88;
   $107 = $106 | 1;
   $108 = ((($$1)) + 4|0);
   HEAP32[$108>>2] = $107;
   $109 = (($88) + ($106)|0);
   HEAP32[$109>>2] = $106;
   return;
  }
  $110 = $90 & -8;
  $111 = (($110) + ($$1345))|0;
  $112 = $90 >>> 3;
  $113 = ($90>>>0)<(256);
  do {
   if ($113) {
    $114 = ((($7)) + 8|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ((($7)) + 12|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==($115|0);
    if ($118) {
     $119 = 1 << $112;
     $120 = $119 ^ -1;
     $121 = HEAP32[(gb + (170632) | 0)>>2]|0;
     $122 = $121 & $120;
     HEAP32[(gb + (170632) | 0)>>2] = $122;
     break;
    } else {
     $123 = ((($115)) + 12|0);
     HEAP32[$123>>2] = $117;
     $124 = ((($117)) + 8|0);
     HEAP32[$124>>2] = $115;
     break;
    }
   } else {
    $125 = ((($7)) + 24|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((($7)) + 12|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = ($128|0)==($7|0);
    do {
     if ($129) {
      $134 = ((($7)) + 16|0);
      $135 = ((($134)) + 4|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = ($136|0)==(0|0);
      if ($137) {
       $138 = HEAP32[$134>>2]|0;
       $139 = ($138|0)==(0|0);
       if ($139) {
        $$3363 = 0;
        break;
       } else {
        $$1361$ph = $138;$$1365$ph = $134;
       }
      } else {
       $$1361$ph = $136;$$1365$ph = $135;
      }
      $$1361 = $$1361$ph;$$1365 = $$1365$ph;
      while(1) {
       $140 = ((($$1361)) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        $143 = ((($$1361)) + 16|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = ($144|0)==(0|0);
        if ($145) {
         break;
        } else {
         $$1361$be = $144;$$1365$be = $143;
        }
       } else {
        $$1361$be = $141;$$1365$be = $140;
       }
       $$1361 = $$1361$be;$$1365 = $$1365$be;
      }
      HEAP32[$$1365>>2] = 0;
      $$3363 = $$1361;
     } else {
      $130 = ((($7)) + 8|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = ((($131)) + 12|0);
      HEAP32[$132>>2] = $128;
      $133 = ((($128)) + 8|0);
      HEAP32[$133>>2] = $131;
      $$3363 = $128;
     }
    } while(0);
    $146 = ($126|0)==(0|0);
    if (!($146)) {
     $147 = ((($7)) + 28|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ((((gb + (170632) | 0)) + 304|0) + ($148<<2)|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($150|0)==($7|0);
     if ($151) {
      HEAP32[$149>>2] = $$3363;
      $cond372 = ($$3363|0)==(0|0);
      if ($cond372) {
       $152 = 1 << $148;
       $153 = $152 ^ -1;
       $154 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
       $155 = $154 & $153;
       HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $155;
       break;
      }
     } else {
      $156 = ((($126)) + 16|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = ($157|0)==($7|0);
      $159 = ((($126)) + 20|0);
      $$sink395 = $158 ? $156 : $159;
      HEAP32[$$sink395>>2] = $$3363;
      $160 = ($$3363|0)==(0|0);
      if ($160) {
       break;
      }
     }
     $161 = ((($$3363)) + 24|0);
     HEAP32[$161>>2] = $126;
     $162 = ((($7)) + 16|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = ($163|0)==(0|0);
     if (!($164)) {
      $165 = ((($$3363)) + 16|0);
      HEAP32[$165>>2] = $163;
      $166 = ((($163)) + 24|0);
      HEAP32[$166>>2] = $$3363;
     }
     $167 = ((($162)) + 4|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = ($168|0)==(0|0);
     if (!($169)) {
      $170 = ((($$3363)) + 20|0);
      HEAP32[$170>>2] = $168;
      $171 = ((($168)) + 24|0);
      HEAP32[$171>>2] = $$3363;
     }
    }
   }
  } while(0);
  $172 = $111 | 1;
  $173 = ((($$1)) + 4|0);
  HEAP32[$173>>2] = $172;
  $174 = (($88) + ($111)|0);
  HEAP32[$174>>2] = $111;
  $175 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
  $176 = ($$1|0)==($175|0);
  if ($176) {
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $111;
   return;
  } else {
   $$2 = $111;
  }
 } else {
  $177 = $90 & -2;
  HEAP32[$89>>2] = $177;
  $178 = $$1345 | 1;
  $179 = ((($$1)) + 4|0);
  HEAP32[$179>>2] = $178;
  $180 = (($88) + ($$1345)|0);
  HEAP32[$180>>2] = $$1345;
  $$2 = $$1345;
 }
 $181 = $$2 >>> 3;
 $182 = ($$2>>>0)<(256);
 if ($182) {
  $183 = $181 << 1;
  $184 = ((((gb + (170632) | 0)) + 40|0) + ($183<<2)|0);
  $185 = HEAP32[(gb + (170632) | 0)>>2]|0;
  $186 = 1 << $181;
  $187 = $185 & $186;
  $188 = ($187|0)==(0);
  if ($188) {
   $189 = $185 | $186;
   HEAP32[(gb + (170632) | 0)>>2] = $189;
   $$pre = ((($184)) + 8|0);
   $$0366 = $184;$$pre$phiZ2D = $$pre;
  } else {
   $190 = ((($184)) + 8|0);
   $191 = HEAP32[$190>>2]|0;
   $$0366 = $191;$$pre$phiZ2D = $190;
  }
  HEAP32[$$pre$phiZ2D>>2] = $$1;
  $192 = ((($$0366)) + 12|0);
  HEAP32[$192>>2] = $$1;
  $193 = ((($$1)) + 8|0);
  HEAP32[$193>>2] = $$0366;
  $194 = ((($$1)) + 12|0);
  HEAP32[$194>>2] = $184;
  return;
 }
 $195 = $$2 >>> 8;
 $196 = ($195|0)==(0);
 if ($196) {
  $$0359 = 0;
 } else {
  $197 = ($$2>>>0)>(16777215);
  if ($197) {
   $$0359 = 31;
  } else {
   $198 = (($195) + 1048320)|0;
   $199 = $198 >>> 16;
   $200 = $199 & 8;
   $201 = $195 << $200;
   $202 = (($201) + 520192)|0;
   $203 = $202 >>> 16;
   $204 = $203 & 4;
   $205 = $204 | $200;
   $206 = $201 << $204;
   $207 = (($206) + 245760)|0;
   $208 = $207 >>> 16;
   $209 = $208 & 2;
   $210 = $205 | $209;
   $211 = (14 - ($210))|0;
   $212 = $206 << $209;
   $213 = $212 >>> 15;
   $214 = (($211) + ($213))|0;
   $215 = $214 << 1;
   $216 = (($214) + 7)|0;
   $217 = $$2 >>> $216;
   $218 = $217 & 1;
   $219 = $218 | $215;
   $$0359 = $219;
  }
 }
 $220 = ((((gb + (170632) | 0)) + 304|0) + ($$0359<<2)|0);
 $221 = ((($$1)) + 28|0);
 HEAP32[$221>>2] = $$0359;
 $222 = ((($$1)) + 16|0);
 $223 = ((($$1)) + 20|0);
 HEAP32[$223>>2] = 0;
 HEAP32[$222>>2] = 0;
 $224 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
 $225 = 1 << $$0359;
 $226 = $224 & $225;
 $227 = ($226|0)==(0);
 L112: do {
  if ($227) {
   $228 = $224 | $225;
   HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $228;
   HEAP32[$220>>2] = $$1;
   $229 = ((($$1)) + 24|0);
   HEAP32[$229>>2] = $220;
   $230 = ((($$1)) + 12|0);
   HEAP32[$230>>2] = $$1;
   $231 = ((($$1)) + 8|0);
   HEAP32[$231>>2] = $$1;
  } else {
   $232 = HEAP32[$220>>2]|0;
   $233 = ((($232)) + 4|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = $234 & -8;
   $236 = ($235|0)==($$2|0);
   L115: do {
    if ($236) {
     $$0347$lcssa = $232;
    } else {
     $237 = ($$0359|0)==(31);
     $238 = $$0359 >>> 1;
     $239 = (25 - ($238))|0;
     $240 = $237 ? 0 : $239;
     $241 = $$2 << $240;
     $$0346381 = $241;$$0347380 = $232;
     while(1) {
      $248 = $$0346381 >>> 31;
      $249 = (((($$0347380)) + 16|0) + ($248<<2)|0);
      $244 = HEAP32[$249>>2]|0;
      $250 = ($244|0)==(0|0);
      if ($250) {
       break;
      }
      $242 = $$0346381 << 1;
      $243 = ((($244)) + 4|0);
      $245 = HEAP32[$243>>2]|0;
      $246 = $245 & -8;
      $247 = ($246|0)==($$2|0);
      if ($247) {
       $$0347$lcssa = $244;
       break L115;
      } else {
       $$0346381 = $242;$$0347380 = $244;
      }
     }
     HEAP32[$249>>2] = $$1;
     $251 = ((($$1)) + 24|0);
     HEAP32[$251>>2] = $$0347380;
     $252 = ((($$1)) + 12|0);
     HEAP32[$252>>2] = $$1;
     $253 = ((($$1)) + 8|0);
     HEAP32[$253>>2] = $$1;
     break L112;
    }
   } while(0);
   $254 = ((($$0347$lcssa)) + 8|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = ((($255)) + 12|0);
   HEAP32[$256>>2] = $$1;
   HEAP32[$254>>2] = $$1;
   $257 = ((($$1)) + 8|0);
   HEAP32[$257>>2] = $255;
   $258 = ((($$1)) + 12|0);
   HEAP32[$258>>2] = $$0347$lcssa;
   $259 = ((($$1)) + 24|0);
   HEAP32[$259>>2] = 0;
  }
 } while(0);
 $260 = HEAP32[((((gb + (170632) | 0)) + 32|0))>>2]|0;
 $261 = (($260) + -1)|0;
 HEAP32[((((gb + (170632) | 0)) + 32|0))>>2] = $261;
 $262 = ($261|0)==(0);
 if (!($262)) {
  return;
 }
 $$0194$in$i = ((((gb + (170632) | 0)) + 456|0));
 while(1) {
  $$0194$i = HEAP32[$$0194$in$i>>2]|0;
  $263 = ($$0194$i|0)==(0|0);
  $264 = ((($$0194$i)) + 8|0);
  if ($263) {
   break;
  } else {
   $$0194$in$i = $264;
  }
 }
 HEAP32[((((gb + (170632) | 0)) + 32|0))>>2] = -1;
 return;
}
function _calloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = Math_imul($1, $0)|0;
  $4 = $1 | $0;
  $5 = ($4>>>0)>(65535);
  if ($5) {
   $6 = (($3>>>0) / ($0>>>0))&-1;
   $7 = ($6|0)==($1|0);
   $spec$select = $7 ? $3 : -1;
   $$0 = $spec$select;
  } else {
   $$0 = $3;
  }
 }
 $8 = (_malloc($$0)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  return ($8|0);
 }
 $10 = ((($8)) + -4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 3;
 $13 = ($12|0)==(0);
 if ($13) {
  return ($8|0);
 }
 (_memset(($8|0),0,($$0|0))|0);
 return ($8|0);
}
function _realloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $3 = (_malloc($1)|0);
  $$1 = $3;
  return ($$1|0);
 }
 $4 = ($1>>>0)>(4294967231);
 if ($4) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 12;
  $$1 = 0;
  return ($$1|0);
 }
 $6 = ($1>>>0)<(11);
 $7 = (($1) + 11)|0;
 $8 = $7 & -8;
 $9 = $6 ? 16 : $8;
 $10 = ((($0)) + -8|0);
 $11 = (_try_realloc_chunk($10,$9)|0);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = ((($11)) + 8|0);
  $$1 = $13;
  return ($$1|0);
 }
 $14 = (_malloc($1)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$1 = 0;
  return ($$1|0);
 }
 $16 = ((($0)) + -4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & -8;
 $19 = $17 & 3;
 $20 = ($19|0)==(0);
 $21 = $20 ? 8 : 4;
 $22 = (($18) - ($21))|0;
 $23 = ($22>>>0)<($1>>>0);
 $24 = $23 ? $22 : $1;
 (_memcpy(($14|0),($0|0),($24|0))|0);
 _free($0);
 $$1 = $14;
 return ($$1|0);
}
function _try_realloc_chunk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1245 = 0, $$1245$be = 0, $$1245$ph = 0, $$1248 = 0, $$1248$be = 0, $$1248$ph = 0, $$2 = 0, $$3 = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $storemerge = 0, $storemerge1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & -8;
 $5 = (($0) + ($4)|0);
 $6 = $3 & 3;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ($1>>>0)<(256);
  if ($8) {
   $$2 = 0;
   return ($$2|0);
  }
  $9 = (($1) + 4)|0;
  $10 = ($4>>>0)<($9>>>0);
  if (!($10)) {
   $11 = (($4) - ($1))|0;
   $12 = HEAP32[((((gb + (171104) | 0)) + 8|0))>>2]|0;
   $13 = $12 << 1;
   $14 = ($11>>>0)>($13>>>0);
   if (!($14)) {
    $$2 = $0;
    return ($$2|0);
   }
  }
  $$2 = 0;
  return ($$2|0);
 }
 $15 = ($4>>>0)<($1>>>0);
 if (!($15)) {
  $16 = (($4) - ($1))|0;
  $17 = ($16>>>0)>(15);
  if (!($17)) {
   $$2 = $0;
   return ($$2|0);
  }
  $18 = (($0) + ($1)|0);
  $19 = $3 & 1;
  $20 = $19 | $1;
  $21 = $20 | 2;
  HEAP32[$2>>2] = $21;
  $22 = ((($18)) + 4|0);
  $23 = $16 | 3;
  HEAP32[$22>>2] = $23;
  $24 = ((($5)) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 1;
  HEAP32[$24>>2] = $26;
  _dispose_chunk($18,$16);
  $$2 = $0;
  return ($$2|0);
 }
 $27 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
 $28 = ($27|0)==($5|0);
 if ($28) {
  $29 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
  $30 = (($29) + ($4))|0;
  $31 = ($30>>>0)>($1>>>0);
  $32 = (($30) - ($1))|0;
  $33 = (($0) + ($1)|0);
  if (!($31)) {
   $$2 = 0;
   return ($$2|0);
  }
  $34 = $32 | 1;
  $35 = ((($33)) + 4|0);
  $36 = $3 & 1;
  $37 = $36 | $1;
  $38 = $37 | 2;
  HEAP32[$2>>2] = $38;
  HEAP32[$35>>2] = $34;
  HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $33;
  HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $32;
  $$2 = $0;
  return ($$2|0);
 }
 $39 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
 $40 = ($39|0)==($5|0);
 if ($40) {
  $41 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
  $42 = (($41) + ($4))|0;
  $43 = ($42>>>0)<($1>>>0);
  if ($43) {
   $$2 = 0;
   return ($$2|0);
  }
  $44 = (($42) - ($1))|0;
  $45 = ($44>>>0)>(15);
  if ($45) {
   $46 = (($0) + ($1)|0);
   $47 = (($0) + ($42)|0);
   $48 = $3 & 1;
   $49 = $48 | $1;
   $50 = $49 | 2;
   HEAP32[$2>>2] = $50;
   $51 = ((($46)) + 4|0);
   $52 = $44 | 1;
   HEAP32[$51>>2] = $52;
   HEAP32[$47>>2] = $44;
   $53 = ((($47)) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $54 & -2;
   HEAP32[$53>>2] = $55;
   $storemerge = $46;$storemerge1 = $44;
  } else {
   $56 = $3 & 1;
   $57 = $56 | $42;
   $58 = $57 | 2;
   HEAP32[$2>>2] = $58;
   $59 = (($0) + ($42)|0);
   $60 = ((($59)) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $61 | 1;
   HEAP32[$60>>2] = $62;
   $storemerge = 0;$storemerge1 = 0;
  }
  HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $storemerge1;
  HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $storemerge;
  $$2 = $0;
  return ($$2|0);
 }
 $63 = ((($5)) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $$2 = 0;
  return ($$2|0);
 }
 $67 = $64 & -8;
 $68 = (($67) + ($4))|0;
 $69 = ($68>>>0)<($1>>>0);
 if ($69) {
  $$2 = 0;
  return ($$2|0);
 }
 $70 = (($68) - ($1))|0;
 $71 = $64 >>> 3;
 $72 = ($64>>>0)<(256);
 do {
  if ($72) {
   $73 = ((($5)) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ((($5)) + 12|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==($74|0);
   if ($77) {
    $78 = 1 << $71;
    $79 = $78 ^ -1;
    $80 = HEAP32[(gb + (170632) | 0)>>2]|0;
    $81 = $80 & $79;
    HEAP32[(gb + (170632) | 0)>>2] = $81;
    break;
   } else {
    $82 = ((($74)) + 12|0);
    HEAP32[$82>>2] = $76;
    $83 = ((($76)) + 8|0);
    HEAP32[$83>>2] = $74;
    break;
   }
  } else {
   $84 = ((($5)) + 24|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($5)) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==($5|0);
   do {
    if ($88) {
     $93 = ((($5)) + 16|0);
     $94 = ((($93)) + 4|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)==(0|0);
     if ($96) {
      $97 = HEAP32[$93>>2]|0;
      $98 = ($97|0)==(0|0);
      if ($98) {
       $$3 = 0;
       break;
      } else {
       $$1245$ph = $97;$$1248$ph = $93;
      }
     } else {
      $$1245$ph = $95;$$1248$ph = $94;
     }
     $$1245 = $$1245$ph;$$1248 = $$1248$ph;
     while(1) {
      $99 = ((($$1245)) + 20|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($100|0)==(0|0);
      if ($101) {
       $102 = ((($$1245)) + 16|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = ($103|0)==(0|0);
       if ($104) {
        break;
       } else {
        $$1245$be = $103;$$1248$be = $102;
       }
      } else {
       $$1245$be = $100;$$1248$be = $99;
      }
      $$1245 = $$1245$be;$$1248 = $$1248$be;
     }
     HEAP32[$$1248>>2] = 0;
     $$3 = $$1245;
    } else {
     $89 = ((($5)) + 8|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ((($90)) + 12|0);
     HEAP32[$91>>2] = $87;
     $92 = ((($87)) + 8|0);
     HEAP32[$92>>2] = $90;
     $$3 = $87;
    }
   } while(0);
   $105 = ($85|0)==(0|0);
   if (!($105)) {
    $106 = ((($5)) + 28|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ((((gb + (170632) | 0)) + 304|0) + ($107<<2)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($109|0)==($5|0);
    if ($110) {
     HEAP32[$108>>2] = $$3;
     $cond = ($$3|0)==(0|0);
     if ($cond) {
      $111 = 1 << $107;
      $112 = $111 ^ -1;
      $113 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
      $114 = $113 & $112;
      HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $114;
      break;
     }
    } else {
     $115 = ((($85)) + 16|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==($5|0);
     $118 = ((($85)) + 20|0);
     $$sink = $117 ? $115 : $118;
     HEAP32[$$sink>>2] = $$3;
     $119 = ($$3|0)==(0|0);
     if ($119) {
      break;
     }
    }
    $120 = ((($$3)) + 24|0);
    HEAP32[$120>>2] = $85;
    $121 = ((($5)) + 16|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ($122|0)==(0|0);
    if (!($123)) {
     $124 = ((($$3)) + 16|0);
     HEAP32[$124>>2] = $122;
     $125 = ((($122)) + 24|0);
     HEAP32[$125>>2] = $$3;
    }
    $126 = ((($121)) + 4|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==(0|0);
    if (!($128)) {
     $129 = ((($$3)) + 20|0);
     HEAP32[$129>>2] = $127;
     $130 = ((($127)) + 24|0);
     HEAP32[$130>>2] = $$3;
    }
   }
  }
 } while(0);
 $131 = ($70>>>0)<(16);
 if ($131) {
  $132 = $3 & 1;
  $133 = $132 | $68;
  $134 = $133 | 2;
  HEAP32[$2>>2] = $134;
  $135 = (($0) + ($68)|0);
  $136 = ((($135)) + 4|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = $137 | 1;
  HEAP32[$136>>2] = $138;
  $$2 = $0;
  return ($$2|0);
 } else {
  $139 = (($0) + ($1)|0);
  $140 = $3 & 1;
  $141 = $140 | $1;
  $142 = $141 | 2;
  HEAP32[$2>>2] = $142;
  $143 = ((($139)) + 4|0);
  $144 = $70 | 3;
  HEAP32[$143>>2] = $144;
  $145 = (($0) + ($68)|0);
  $146 = ((($145)) + 4|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = $147 | 1;
  HEAP32[$146>>2] = $148;
  _dispose_chunk($139,$70);
  $$2 = $0;
  return ($$2|0);
 }
 return (0)|0;
}
function _dispose_chunk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$03649 = 0, $$0365$lcssa = 0, $$03658 = 0, $$0376 = 0, $$0383 = 0, $$1 = 0, $$1363 = 0, $$1371 = 0, $$1371$be = 0, $$1371$ph = 0, $$1374 = 0, $$1374$be = 0, $$1374$ph = 0, $$1378 = 0, $$1378$be = 0, $$1378$ph = 0, $$1382 = 0, $$1382$be = 0, $$1382$ph = 0, $$2 = 0;
 var $$3 = 0, $$3380 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink = 0, $$sink24 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $cond4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($0) + ($1)|0);
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = $4 & 3;
   $9 = ($8|0)==(0);
   if ($9) {
    return;
   }
   $10 = (0 - ($7))|0;
   $11 = (($0) + ($10)|0);
   $12 = (($7) + ($1))|0;
   $13 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
   $14 = ($13|0)==($11|0);
   if ($14) {
    $75 = ((($2)) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = $76 & 3;
    $78 = ($77|0)==(3);
    if (!($78)) {
     $$1 = $11;$$1363 = $12;
     break;
    }
    $79 = ((($11)) + 4|0);
    $80 = $12 | 1;
    $81 = $76 & -2;
    HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $12;
    HEAP32[$75>>2] = $81;
    HEAP32[$79>>2] = $80;
    HEAP32[$2>>2] = $12;
    return;
   }
   $15 = $7 >>> 3;
   $16 = ($7>>>0)<(256);
   if ($16) {
    $17 = ((($11)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($11)) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($18|0);
    if ($21) {
     $22 = 1 << $15;
     $23 = $22 ^ -1;
     $24 = HEAP32[(gb + (170632) | 0)>>2]|0;
     $25 = $24 & $23;
     HEAP32[(gb + (170632) | 0)>>2] = $25;
     $$1 = $11;$$1363 = $12;
     break;
    } else {
     $26 = ((($18)) + 12|0);
     HEAP32[$26>>2] = $20;
     $27 = ((($20)) + 8|0);
     HEAP32[$27>>2] = $18;
     $$1 = $11;$$1363 = $12;
     break;
    }
   }
   $28 = ((($11)) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($11)) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($11|0);
   do {
    if ($32) {
     $37 = ((($11)) + 16|0);
     $38 = ((($37)) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $41 = HEAP32[$37>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $$3 = 0;
       break;
      } else {
       $$1371$ph = $41;$$1374$ph = $37;
      }
     } else {
      $$1371$ph = $39;$$1374$ph = $38;
     }
     $$1371 = $$1371$ph;$$1374 = $$1374$ph;
     while(1) {
      $43 = ((($$1371)) + 20|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $46 = ((($$1371)) + 16|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        break;
       } else {
        $$1371$be = $47;$$1374$be = $46;
       }
      } else {
       $$1371$be = $44;$$1374$be = $43;
      }
      $$1371 = $$1371$be;$$1374 = $$1374$be;
     }
     HEAP32[$$1374>>2] = 0;
     $$3 = $$1371;
    } else {
     $33 = ((($11)) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ((($34)) + 12|0);
     HEAP32[$35>>2] = $31;
     $36 = ((($31)) + 8|0);
     HEAP32[$36>>2] = $34;
     $$3 = $31;
    }
   } while(0);
   $49 = ($29|0)==(0|0);
   if ($49) {
    $$1 = $11;$$1363 = $12;
   } else {
    $50 = ((($11)) + 28|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ((((gb + (170632) | 0)) + 304|0) + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==($11|0);
    if ($54) {
     HEAP32[$52>>2] = $$3;
     $cond = ($$3|0)==(0|0);
     if ($cond) {
      $55 = 1 << $51;
      $56 = $55 ^ -1;
      $57 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
      $58 = $57 & $56;
      HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $58;
      $$1 = $11;$$1363 = $12;
      break;
     }
    } else {
     $59 = ((($29)) + 16|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($11|0);
     $62 = ((($29)) + 20|0);
     $$sink = $61 ? $59 : $62;
     HEAP32[$$sink>>2] = $$3;
     $63 = ($$3|0)==(0|0);
     if ($63) {
      $$1 = $11;$$1363 = $12;
      break;
     }
    }
    $64 = ((($$3)) + 24|0);
    HEAP32[$64>>2] = $29;
    $65 = ((($11)) + 16|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     $68 = ((($$3)) + 16|0);
     HEAP32[$68>>2] = $66;
     $69 = ((($66)) + 24|0);
     HEAP32[$69>>2] = $$3;
    }
    $70 = ((($65)) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0|0);
    if ($72) {
     $$1 = $11;$$1363 = $12;
    } else {
     $73 = ((($$3)) + 20|0);
     HEAP32[$73>>2] = $71;
     $74 = ((($71)) + 24|0);
     HEAP32[$74>>2] = $$3;
     $$1 = $11;$$1363 = $12;
    }
   }
  } else {
   $$1 = $0;$$1363 = $1;
  }
 } while(0);
 $82 = ((($2)) + 4|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 & 2;
 $85 = ($84|0)==(0);
 if ($85) {
  $86 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
  $87 = ($86|0)==($2|0);
  if ($87) {
   $88 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
   $89 = (($88) + ($$1363))|0;
   HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $89;
   HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $$1;
   $90 = $89 | 1;
   $91 = ((($$1)) + 4|0);
   HEAP32[$91>>2] = $90;
   $92 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
   $93 = ($$1|0)==($92|0);
   if (!($93)) {
    return;
   }
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = 0;
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = 0;
   return;
  }
  $94 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
  $95 = ($94|0)==($2|0);
  if ($95) {
   $96 = HEAP32[((((gb + (170632) | 0)) + 8|0))>>2]|0;
   $97 = (($96) + ($$1363))|0;
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $97;
   HEAP32[((((gb + (170632) | 0)) + 20|0))>>2] = $$1;
   $98 = $97 | 1;
   $99 = ((($$1)) + 4|0);
   HEAP32[$99>>2] = $98;
   $100 = (($$1) + ($97)|0);
   HEAP32[$100>>2] = $97;
   return;
  }
  $101 = $83 & -8;
  $102 = (($101) + ($$1363))|0;
  $103 = $83 >>> 3;
  $104 = ($83>>>0)<(256);
  do {
   if ($104) {
    $105 = ((($2)) + 8|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ((($2)) + 12|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ($108|0)==($106|0);
    if ($109) {
     $110 = 1 << $103;
     $111 = $110 ^ -1;
     $112 = HEAP32[(gb + (170632) | 0)>>2]|0;
     $113 = $112 & $111;
     HEAP32[(gb + (170632) | 0)>>2] = $113;
     break;
    } else {
     $114 = ((($106)) + 12|0);
     HEAP32[$114>>2] = $108;
     $115 = ((($108)) + 8|0);
     HEAP32[$115>>2] = $106;
     break;
    }
   } else {
    $116 = ((($2)) + 24|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ((($2)) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($119|0)==($2|0);
    do {
     if ($120) {
      $125 = ((($2)) + 16|0);
      $126 = ((($125)) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($127|0)==(0|0);
      if ($128) {
       $129 = HEAP32[$125>>2]|0;
       $130 = ($129|0)==(0|0);
       if ($130) {
        $$3380 = 0;
        break;
       } else {
        $$1378$ph = $129;$$1382$ph = $125;
       }
      } else {
       $$1378$ph = $127;$$1382$ph = $126;
      }
      $$1378 = $$1378$ph;$$1382 = $$1382$ph;
      while(1) {
       $131 = ((($$1378)) + 20|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = ($132|0)==(0|0);
       if ($133) {
        $134 = ((($$1378)) + 16|0);
        $135 = HEAP32[$134>>2]|0;
        $136 = ($135|0)==(0|0);
        if ($136) {
         break;
        } else {
         $$1378$be = $135;$$1382$be = $134;
        }
       } else {
        $$1378$be = $132;$$1382$be = $131;
       }
       $$1378 = $$1378$be;$$1382 = $$1382$be;
      }
      HEAP32[$$1382>>2] = 0;
      $$3380 = $$1378;
     } else {
      $121 = ((($2)) + 8|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ((($122)) + 12|0);
      HEAP32[$123>>2] = $119;
      $124 = ((($119)) + 8|0);
      HEAP32[$124>>2] = $122;
      $$3380 = $119;
     }
    } while(0);
    $137 = ($117|0)==(0|0);
    if (!($137)) {
     $138 = ((($2)) + 28|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ((((gb + (170632) | 0)) + 304|0) + ($139<<2)|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ($141|0)==($2|0);
     if ($142) {
      HEAP32[$140>>2] = $$3380;
      $cond4 = ($$3380|0)==(0|0);
      if ($cond4) {
       $143 = 1 << $139;
       $144 = $143 ^ -1;
       $145 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
       $146 = $145 & $144;
       HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $146;
       break;
      }
     } else {
      $147 = ((($117)) + 16|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ($148|0)==($2|0);
      $150 = ((($117)) + 20|0);
      $$sink24 = $149 ? $147 : $150;
      HEAP32[$$sink24>>2] = $$3380;
      $151 = ($$3380|0)==(0|0);
      if ($151) {
       break;
      }
     }
     $152 = ((($$3380)) + 24|0);
     HEAP32[$152>>2] = $117;
     $153 = ((($2)) + 16|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ($154|0)==(0|0);
     if (!($155)) {
      $156 = ((($$3380)) + 16|0);
      HEAP32[$156>>2] = $154;
      $157 = ((($154)) + 24|0);
      HEAP32[$157>>2] = $$3380;
     }
     $158 = ((($153)) + 4|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159|0)==(0|0);
     if (!($160)) {
      $161 = ((($$3380)) + 20|0);
      HEAP32[$161>>2] = $159;
      $162 = ((($159)) + 24|0);
      HEAP32[$162>>2] = $$3380;
     }
    }
   }
  } while(0);
  $163 = $102 | 1;
  $164 = ((($$1)) + 4|0);
  HEAP32[$164>>2] = $163;
  $165 = (($$1) + ($102)|0);
  HEAP32[$165>>2] = $102;
  $166 = HEAP32[((((gb + (170632) | 0)) + 20|0))>>2]|0;
  $167 = ($$1|0)==($166|0);
  if ($167) {
   HEAP32[((((gb + (170632) | 0)) + 8|0))>>2] = $102;
   return;
  } else {
   $$2 = $102;
  }
 } else {
  $168 = $83 & -2;
  HEAP32[$82>>2] = $168;
  $169 = $$1363 | 1;
  $170 = ((($$1)) + 4|0);
  HEAP32[$170>>2] = $169;
  $171 = (($$1) + ($$1363)|0);
  HEAP32[$171>>2] = $$1363;
  $$2 = $$1363;
 }
 $172 = $$2 >>> 3;
 $173 = ($$2>>>0)<(256);
 if ($173) {
  $174 = $172 << 1;
  $175 = ((((gb + (170632) | 0)) + 40|0) + ($174<<2)|0);
  $176 = HEAP32[(gb + (170632) | 0)>>2]|0;
  $177 = 1 << $172;
  $178 = $176 & $177;
  $179 = ($178|0)==(0);
  if ($179) {
   $180 = $176 | $177;
   HEAP32[(gb + (170632) | 0)>>2] = $180;
   $$pre = ((($175)) + 8|0);
   $$0383 = $175;$$pre$phiZ2D = $$pre;
  } else {
   $181 = ((($175)) + 8|0);
   $182 = HEAP32[$181>>2]|0;
   $$0383 = $182;$$pre$phiZ2D = $181;
  }
  HEAP32[$$pre$phiZ2D>>2] = $$1;
  $183 = ((($$0383)) + 12|0);
  HEAP32[$183>>2] = $$1;
  $184 = ((($$1)) + 8|0);
  HEAP32[$184>>2] = $$0383;
  $185 = ((($$1)) + 12|0);
  HEAP32[$185>>2] = $175;
  return;
 }
 $186 = $$2 >>> 8;
 $187 = ($186|0)==(0);
 if ($187) {
  $$0376 = 0;
 } else {
  $188 = ($$2>>>0)>(16777215);
  if ($188) {
   $$0376 = 31;
  } else {
   $189 = (($186) + 1048320)|0;
   $190 = $189 >>> 16;
   $191 = $190 & 8;
   $192 = $186 << $191;
   $193 = (($192) + 520192)|0;
   $194 = $193 >>> 16;
   $195 = $194 & 4;
   $196 = $195 | $191;
   $197 = $192 << $195;
   $198 = (($197) + 245760)|0;
   $199 = $198 >>> 16;
   $200 = $199 & 2;
   $201 = $196 | $200;
   $202 = (14 - ($201))|0;
   $203 = $197 << $200;
   $204 = $203 >>> 15;
   $205 = (($202) + ($204))|0;
   $206 = $205 << 1;
   $207 = (($205) + 7)|0;
   $208 = $$2 >>> $207;
   $209 = $208 & 1;
   $210 = $209 | $206;
   $$0376 = $210;
  }
 }
 $211 = ((((gb + (170632) | 0)) + 304|0) + ($$0376<<2)|0);
 $212 = ((($$1)) + 28|0);
 HEAP32[$212>>2] = $$0376;
 $213 = ((($$1)) + 16|0);
 $214 = ((($$1)) + 20|0);
 HEAP32[$214>>2] = 0;
 HEAP32[$213>>2] = 0;
 $215 = HEAP32[((((gb + (170632) | 0)) + 4|0))>>2]|0;
 $216 = 1 << $$0376;
 $217 = $215 & $216;
 $218 = ($217|0)==(0);
 if ($218) {
  $219 = $215 | $216;
  HEAP32[((((gb + (170632) | 0)) + 4|0))>>2] = $219;
  HEAP32[$211>>2] = $$1;
  $220 = ((($$1)) + 24|0);
  HEAP32[$220>>2] = $211;
  $221 = ((($$1)) + 12|0);
  HEAP32[$221>>2] = $$1;
  $222 = ((($$1)) + 8|0);
  HEAP32[$222>>2] = $$1;
  return;
 }
 $223 = HEAP32[$211>>2]|0;
 $224 = ((($223)) + 4|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = $225 & -8;
 $227 = ($226|0)==($$2|0);
 L104: do {
  if ($227) {
   $$0365$lcssa = $223;
  } else {
   $228 = ($$0376|0)==(31);
   $229 = $$0376 >>> 1;
   $230 = (25 - ($229))|0;
   $231 = $228 ? 0 : $230;
   $232 = $$2 << $231;
   $$03649 = $232;$$03658 = $223;
   while(1) {
    $239 = $$03649 >>> 31;
    $240 = (((($$03658)) + 16|0) + ($239<<2)|0);
    $235 = HEAP32[$240>>2]|0;
    $241 = ($235|0)==(0|0);
    if ($241) {
     break;
    }
    $233 = $$03649 << 1;
    $234 = ((($235)) + 4|0);
    $236 = HEAP32[$234>>2]|0;
    $237 = $236 & -8;
    $238 = ($237|0)==($$2|0);
    if ($238) {
     $$0365$lcssa = $235;
     break L104;
    } else {
     $$03649 = $233;$$03658 = $235;
    }
   }
   HEAP32[$240>>2] = $$1;
   $242 = ((($$1)) + 24|0);
   HEAP32[$242>>2] = $$03658;
   $243 = ((($$1)) + 12|0);
   HEAP32[$243>>2] = $$1;
   $244 = ((($$1)) + 8|0);
   HEAP32[$244>>2] = $$1;
   return;
  }
 } while(0);
 $245 = ((($$0365$lcssa)) + 8|0);
 $246 = HEAP32[$245>>2]|0;
 $247 = ((($246)) + 12|0);
 HEAP32[$247>>2] = $$1;
 HEAP32[$245>>2] = $$1;
 $248 = ((($$1)) + 8|0);
 HEAP32[$248>>2] = $246;
 $249 = ((($$1)) + 12|0);
 HEAP32[$249>>2] = $$0365$lcssa;
 $250 = ((($$1)) + 24|0);
 HEAP32[$250>>2] = 0;
 return;
}
function _realloc_in_place($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$1 = 0;
  return ($$1|0);
 }
 $3 = ($1>>>0)>(4294967231);
 if ($3) {
  $4 = (___errno_location()|0);
  HEAP32[$4>>2] = 12;
  $$1 = 0;
  return ($$1|0);
 } else {
  $5 = ($1>>>0)<(11);
  $6 = (($1) + 11)|0;
  $7 = $6 & -8;
  $8 = $5 ? 16 : $7;
  $9 = ((($0)) + -8|0);
  $10 = (_try_realloc_chunk($9,$8)|0);
  $11 = ($10|0)==($9|0);
  $spec$select = $11 ? $0 : 0;
  $$1 = $spec$select;
  return ($$1|0);
 }
 return (0)|0;
}
function _memalign($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)<(9);
 if ($2) {
  $3 = (_malloc($1)|0);
  $$0 = $3;
  return ($$0|0);
 } else {
  $4 = (_internal_memalign($0,$1)|0);
  $$0 = $4;
  return ($$0|0);
 }
 return (0)|0;
}
function _internal_memalign($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0100 = 0, $$099 = 0, $$1 = 0, $$198 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)>(16);
 $spec$select = $2 ? $0 : 16;
 $3 = (($spec$select) + -1)|0;
 $4 = $3 & $spec$select;
 $5 = ($4|0)==(0);
 if ($5) {
  $$1 = $spec$select;
 } else {
  $$099 = 16;
  while(1) {
   $6 = ($$099>>>0)<($spec$select>>>0);
   $7 = $$099 << 1;
   if ($6) {
    $$099 = $7;
   } else {
    $$1 = $$099;
    break;
   }
  }
 }
 $8 = (-64 - ($$1))|0;
 $9 = ($8>>>0)>($1>>>0);
 if (!($9)) {
  $10 = (___errno_location()|0);
  HEAP32[$10>>2] = 12;
  $$198 = 0;
  return ($$198|0);
 }
 $11 = ($1>>>0)<(11);
 $12 = (($1) + 11)|0;
 $13 = $12 & -8;
 $14 = $11 ? 16 : $13;
 $15 = (($14) + 12)|0;
 $16 = (($15) + ($$1))|0;
 $17 = (_malloc($16)|0);
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$198 = 0;
  return ($$198|0);
 }
 $19 = ((($17)) + -8|0);
 $20 = $17;
 $21 = (($$1) + -1)|0;
 $22 = $21 & $20;
 $23 = ($22|0)==(0);
 do {
  if ($23) {
   $$0100 = $19;$72 = $19;
  } else {
   $24 = (($17) + ($$1)|0);
   $25 = ((($24)) + -1|0);
   $26 = $25;
   $27 = (0 - ($$1))|0;
   $28 = $26 & $27;
   $29 = $28;
   $30 = ((($29)) + -8|0);
   $31 = $30;
   $32 = $19;
   $33 = (($31) - ($32))|0;
   $34 = ($33>>>0)>(15);
   $35 = (($30) + ($$1)|0);
   $36 = $34 ? $30 : $35;
   $37 = $36;
   $38 = (($37) - ($32))|0;
   $39 = ((($17)) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40 & -8;
   $42 = (($41) - ($38))|0;
   $43 = $40 & 3;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = HEAP32[$19>>2]|0;
    $46 = (($45) + ($38))|0;
    HEAP32[$36>>2] = $46;
    $47 = ((($36)) + 4|0);
    HEAP32[$47>>2] = $42;
    $$0100 = $36;$72 = $36;
    break;
   } else {
    $48 = ((($36)) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = $49 & 1;
    $51 = $42 | $50;
    $52 = $51 | 2;
    HEAP32[$48>>2] = $52;
    $53 = (($36) + ($42)|0);
    $54 = ((($53)) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = $55 | 1;
    HEAP32[$54>>2] = $56;
    $57 = HEAP32[$39>>2]|0;
    $58 = $57 & 1;
    $59 = $38 | $58;
    $60 = $59 | 2;
    HEAP32[$39>>2] = $60;
    $61 = HEAP32[$48>>2]|0;
    $62 = $61 | 1;
    HEAP32[$48>>2] = $62;
    _dispose_chunk($19,$38);
    $$0100 = $36;$72 = $36;
    break;
   }
  }
 } while(0);
 $63 = ((($$0100)) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 3;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $67 = $64 & -8;
  $68 = (($14) + 16)|0;
  $69 = ($67>>>0)>($68>>>0);
  if ($69) {
   $70 = (($67) - ($14))|0;
   $71 = (($72) + ($14)|0);
   $73 = $64 & 1;
   $74 = $14 | $73;
   $75 = $74 | 2;
   HEAP32[$63>>2] = $75;
   $76 = ((($71)) + 4|0);
   $77 = $70 | 3;
   HEAP32[$76>>2] = $77;
   $78 = (($72) + ($67)|0);
   $79 = ((($78)) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = $80 | 1;
   HEAP32[$79>>2] = $81;
   _dispose_chunk($71,$70);
  }
 }
 $82 = ((($72)) + 8|0);
 $$198 = $82;
 return ($$198|0);
}
function _posix_memalign($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(8);
 do {
  if ($3) {
   $4 = (_malloc($2)|0);
   $$2 = $4;
  } else {
   $5 = $1 >>> 2;
   $6 = $1 & 3;
   $7 = ($6|0)!=(0);
   $8 = ($5|0)==(0);
   $or$cond = $7 | $8;
   if ($or$cond) {
    $$1 = 22;
    return ($$1|0);
   }
   $9 = (($5) + 1073741823)|0;
   $10 = $9 & $5;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $$1 = 22;
    return ($$1|0);
   }
   $12 = (-64 - ($1))|0;
   $13 = ($12>>>0)<($2>>>0);
   if ($13) {
    $$1 = 12;
    return ($$1|0);
   } else {
    $14 = ($1>>>0)>(16);
    $spec$select = $14 ? $1 : 16;
    $15 = (_internal_memalign($spec$select,$2)|0);
    $$2 = $15;
    break;
   }
  }
 } while(0);
 $16 = ($$2|0)==(0|0);
 if ($16) {
  $$1 = 12;
  return ($$1|0);
 }
 HEAP32[$0>>2] = $$2;
 $$1 = 0;
 return ($$1|0);
}
function _valloc($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $4 = $1;
  $5 = $4 & -16;
  $6 = $5 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $6;
  $7 = 4096;
  $8 = (_memalign($7,$0)|0);
  STACKTOP = sp;return ($8|0);
 } else {
  $$pre = HEAP32[((((gb + (171104) | 0)) + 4|0))>>2]|0;
  $7 = $$pre;
  $8 = (_memalign($7,$0)|0);
  STACKTOP = sp;return ($8|0);
 }
 return (0)|0;
}
function _pvalloc($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $4 = $1;
  $5 = $4 & -16;
  $6 = $5 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $6;
  $9 = 4096;
 } else {
  $$pre = HEAP32[((((gb + (171104) | 0)) + 4|0))>>2]|0;
  $9 = $$pre;
 }
 $7 = (($0) + -1)|0;
 $8 = (($7) + ($9))|0;
 $10 = (0 - ($9))|0;
 $11 = $8 & $10;
 $12 = (_memalign($9,$11)|0);
 STACKTOP = sp;return ($12|0);
}
function _independent_calloc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = (_ialloc($0,$3,3,$2)|0);
 STACKTOP = sp;return ($4|0);
}
function _ialloc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0846 = 0, $$086 = 0, $$0875 = 0, $$089 = 0, $$091 = 0, $$093$in$lcssa = 0, $$093$in1 = 0, $$093$in1$us = 0, $$094 = 0, $$13 = 0, $$13$us = 0, $$188 = 0, $$190 = 0, $$192$lcssa = 0, $$1922$us = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $7 = $4;
  $8 = $7 & -16;
  $9 = $8 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $9;
 }
 $10 = ($3|0)==(0|0);
 $11 = ($0|0)==(0);
 do {
  if ($10) {
   if (!($11)) {
    $13 = $0 << 2;
    $14 = ($13>>>0)<(11);
    $15 = (($13) + 11)|0;
    $16 = $15 & -8;
    $17 = $14 ? 16 : $16;
    $$089 = 0;$$094 = $17;
    break;
   }
   $12 = (_malloc(0)|0);
   $$0 = $12;
   STACKTOP = sp;return ($$0|0);
  } else {
   if ($11) {
    $$0 = $3;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$089 = $3;$$094 = 0;
   }
  }
 } while(0);
 $18 = $2 & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0846 = 0;$$0875 = 0;
  while(1) {
   $26 = (($1) + ($$0846<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27>>>0)<(11);
   $29 = (($27) + 11)|0;
   $30 = $29 & -8;
   $31 = $28 ? 16 : $30;
   $32 = (($31) + ($$0875))|0;
   $33 = (($$0846) + 1)|0;
   $34 = ($33|0)==($0|0);
   if ($34) {
    $$086 = 0;$$188 = $32;
    break;
   } else {
    $$0846 = $33;$$0875 = $32;
   }
  }
 } else {
  $20 = HEAP32[$1>>2]|0;
  $21 = ($20>>>0)<(11);
  $22 = (($20) + 11)|0;
  $23 = $22 & -8;
  $24 = $21 ? 16 : $23;
  $25 = Math_imul($24, $0)|0;
  $$086 = $24;$$188 = $25;
 }
 $35 = (($$094) + -4)|0;
 $36 = (($35) + ($$188))|0;
 $37 = (_malloc($36)|0);
 $38 = ($37|0)==(0|0);
 if ($38) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = ((($37)) + -8|0);
 $40 = ((($37)) + -4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & -8;
 $43 = $2 & 2;
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = (-4 - ($$094))|0;
  $46 = (($45) + ($42))|0;
  (_memset(($37|0),0,($46|0))|0);
 }
 $47 = ($$089|0)==(0|0);
 $48 = (($39) + ($$188)|0);
 if ($47) {
  $49 = ((($48)) + 4|0);
  $50 = (($42) - ($$188))|0;
  $51 = $50 | 3;
  $52 = ((($48)) + 8|0);
  HEAP32[$49>>2] = $51;
  $$091 = $$188;$$190 = $52;
 } else {
  $$091 = $42;$$190 = $$089;
 }
 HEAP32[$$190>>2] = $37;
 $53 = (($0) + -1)|0;
 $54 = ($53|0)==(0);
 L28: do {
  if ($54) {
   $$093$in$lcssa = $39;$$192$lcssa = $$091;
  } else {
   $55 = ($$086|0)==(0);
   if ($55) {
    $$093$in1$us = $39;$$13$us = 0;$$1922$us = $$091;
    while(1) {
     $56 = (($1) + ($$13$us<<2)|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57>>>0)<(11);
     $59 = (($57) + 11)|0;
     $60 = $59 & -8;
     $61 = $58 ? 16 : $60;
     $62 = (($$1922$us) - ($61))|0;
     $63 = $61 | 3;
     $64 = ((($$093$in1$us)) + 4|0);
     HEAP32[$64>>2] = $63;
     $65 = (($$093$in1$us) + ($61)|0);
     $66 = (($$13$us) + 1)|0;
     $67 = ((($65)) + 8|0);
     $68 = (($$190) + ($66<<2)|0);
     HEAP32[$68>>2] = $67;
     $69 = ($66|0)==($53|0);
     if ($69) {
      $$093$in$lcssa = $65;$$192$lcssa = $62;
      break L28;
     } else {
      $$093$in1$us = $65;$$13$us = $66;$$1922$us = $62;
     }
    }
   }
   $70 = (1 - ($0))|0;
   $71 = Math_imul($$086, $70)|0;
   $72 = Math_imul($$086, $53)|0;
   $73 = (($72) + -8)|0;
   $74 = $$086 | 3;
   $$093$in1 = $39;$$13 = 0;
   while(1) {
    $75 = ((($$093$in1)) + 4|0);
    HEAP32[$75>>2] = $74;
    $76 = (($$093$in1) + ($$086)|0);
    $77 = (($$13) + 1)|0;
    $78 = ((($76)) + 8|0);
    $79 = (($$190) + ($77<<2)|0);
    HEAP32[$79>>2] = $78;
    $80 = ($77|0)==($53|0);
    if ($80) {
     break;
    } else {
     $$093$in1 = $76;$$13 = $77;
    }
   }
   $81 = (($$091) + ($71))|0;
   $scevgep = (($37) + ($73)|0);
   $$093$in$lcssa = $scevgep;$$192$lcssa = $81;
  }
 } while(0);
 $82 = $$192$lcssa | 3;
 $83 = ((($$093$in$lcssa)) + 4|0);
 HEAP32[$83>>2] = $82;
 $$0 = $$190;
 STACKTOP = sp;return ($$0|0);
}
function _independent_comalloc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_ialloc($0,$1,0,$2)|0);
 return ($3|0);
}
function _bulk_free($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($0) + ($1<<2)|0);
 $3 = ($1|0)==(0);
 if ($3) {
  return 0;
 }
 $$01$i = $0;
 while(1) {
  $4 = HEAP32[$$01$i>>2]|0;
  $5 = ($4|0)==(0|0);
  do {
   if ($5) {
    $$pre$i = ((($$01$i)) + 4|0);
    $$pre$phi$iZ2D = $$pre$i;
   } else {
    $6 = ((($4)) + -8|0);
    $7 = ((($4)) + -4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = $8 & -8;
    HEAP32[$$01$i>>2] = 0;
    $10 = ((($$01$i)) + 4|0);
    $11 = (($6) + ($9)|0);
    $12 = ($10|0)==($2|0);
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = ((($11)) + 8|0);
     $15 = ($13|0)==($14|0);
     if ($15) {
      $16 = ((($11)) + 4|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = $17 & -8;
      $19 = (($18) + ($9))|0;
      $20 = $8 & 1;
      $21 = $20 | $19;
      $22 = $21 | 2;
      HEAP32[$7>>2] = $22;
      $23 = (($6) + ($19)|0);
      $24 = ((($23)) + 4|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = $25 | 1;
      HEAP32[$24>>2] = $26;
      HEAP32[$10>>2] = $4;
      $$pre$phi$iZ2D = $10;
      break;
     }
    }
    _dispose_chunk($6,$9);
    $$pre$phi$iZ2D = $10;
   }
  } while(0);
  $27 = ($$pre$phi$iZ2D|0)==($2|0);
  if ($27) {
   break;
  } else {
   $$01$i = $$pre$phi$iZ2D;
  }
 }
 return 0;
}
function _malloc_trim($0) {
 $0 = $0|0;
 var $$0$i$i = 0, $$4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $or$cond$not$i = 0, $or$cond4$i = 0, $spec$select$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $4 = $1;
  $5 = $4 & -16;
  $6 = $5 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $6;
 }
 $7 = ($0>>>0)<(4294967232);
 if (!($7)) {
  $$4$i = 0;
  STACKTOP = sp;return ($$4$i|0);
 }
 $8 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$4$i = 0;
  STACKTOP = sp;return ($$4$i|0);
 }
 $10 = (($0) + 40)|0;
 $11 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
 $12 = ($11>>>0)>($10>>>0);
 if ($12) {
  $13 = HEAP32[((((gb + (171104) | 0)) + 8|0))>>2]|0;
  $14 = (-41 - ($0))|0;
  $15 = (($14) + ($11))|0;
  $16 = (($15) + ($13))|0;
  $17 = (($16>>>0) / ($13>>>0))&-1;
  $$0$i$i = ((((gb + (170632) | 0)) + 448|0));
  while(1) {
   $18 = HEAP32[$$0$i$i>>2]|0;
   $19 = ($18>>>0)>($8>>>0);
   if (!($19)) {
    $20 = ((($$0$i$i)) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($18) + ($21)|0);
    $23 = ($22>>>0)>($8>>>0);
    if ($23) {
     break;
    }
   }
   $24 = ((($$0$i$i)) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $$0$i$i = $25;
  }
  $26 = ((($$0$i$i)) + 4|0);
  $27 = (($17) + -1)|0;
  $28 = Math_imul($27, $13)|0;
  $29 = ((($$0$i$i)) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30 & 8;
  $32 = ($31|0)==(0);
  if ($32) {
   $33 = (_sbrk(0)|0);
   $34 = HEAP32[$$0$i$i>>2]|0;
   $35 = HEAP32[$26>>2]|0;
   $36 = (($34) + ($35)|0);
   $37 = ($33|0)==($36|0);
   if ($37) {
    $38 = ($28>>>0)>(2147483646);
    $39 = (-2147483648 - ($13))|0;
    $spec$select$i = $38 ? $39 : $28;
    $40 = (0 - ($spec$select$i))|0;
    $41 = (_sbrk(($40|0))|0);
    $42 = (_sbrk(0)|0);
    $43 = ($41|0)==((-1)|0);
    $44 = ($42>>>0)>=($33>>>0);
    $45 = $33;
    $46 = $42;
    $47 = (($45) - ($46))|0;
    $or$cond$not$i = $43 | $44;
    $48 = ($47|0)==(0);
    $or$cond4$i = $or$cond$not$i | $48;
    if (!($or$cond4$i)) {
     $49 = HEAP32[$26>>2]|0;
     $50 = (($49) - ($47))|0;
     HEAP32[$26>>2] = $50;
     $51 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
     $52 = (($51) - ($47))|0;
     HEAP32[((((gb + (170632) | 0)) + 432|0))>>2] = $52;
     $53 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
     $54 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
     $55 = (($54) - ($47))|0;
     $56 = ((($53)) + 8|0);
     $57 = $56;
     $58 = $57 & 7;
     $59 = ($58|0)==(0);
     $60 = (0 - ($57))|0;
     $61 = $60 & 7;
     $62 = $59 ? 0 : $61;
     $63 = (($53) + ($62)|0);
     $64 = (($55) - ($62))|0;
     HEAP32[((((gb + (170632) | 0)) + 24|0))>>2] = $63;
     HEAP32[((((gb + (170632) | 0)) + 12|0))>>2] = $64;
     $65 = $64 | 1;
     $66 = ((($63)) + 4|0);
     HEAP32[$66>>2] = $65;
     $67 = (($53) + ($55)|0);
     $68 = ((($67)) + 4|0);
     HEAP32[$68>>2] = 40;
     $69 = HEAP32[((((gb + (171104) | 0)) + 16|0))>>2]|0;
     HEAP32[((((gb + (170632) | 0)) + 28|0))>>2] = $69;
     $$4$i = 1;
     STACKTOP = sp;return ($$4$i|0);
    }
   }
  }
 }
 $70 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
 $71 = HEAP32[((((gb + (170632) | 0)) + 28|0))>>2]|0;
 $72 = ($70>>>0)>($71>>>0);
 if (!($72)) {
  $$4$i = 0;
  STACKTOP = sp;return ($$4$i|0);
 }
 HEAP32[((((gb + (170632) | 0)) + 28|0))>>2] = -1;
 $$4$i = 0;
 STACKTOP = sp;return ($$4$i|0);
}
function _malloc_footprint() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
 return ($0|0);
}
function _malloc_max_footprint() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((((gb + (170632) | 0)) + 436|0))>>2]|0;
 return ($0|0);
}
function _malloc_footprint_limit() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((((gb + (170632) | 0)) + 440|0))>>2]|0;
 $1 = ($0|0)==(0);
 $2 = $1 ? -1 : $0;
 return ($2|0);
}
function _malloc_set_footprint_limit($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(-1);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = HEAP32[((((gb + (171104) | 0)) + 8|0))>>2]|0;
  $3 = (($0) + -1)|0;
  $4 = (($3) + ($2))|0;
  $5 = (0 - ($2))|0;
  $6 = $4 & $5;
  $$0 = $6;
 }
 HEAP32[((((gb + (170632) | 0)) + 440|0))>>2] = $$0;
 return ($$0|0);
}
function _mallinfo($0) {
 $0 = $0|0;
 var $$0$in6$i = 0, $$07020$i = 0, $$07119$i = 0, $$07218$i = 0, $$07417$i = 0, $$1$lcssa$ph$i = 0, $$15$i = 0, $$173$lcssa$ph$i = 0, $$1734$i = 0, $$175$lcssa$ph$i = 0, $$1753$i = 0, $$2$i = 0, $$276$i = 0, $$sroa$0$0$i = 0, $$sroa$10$0$$sroa_idx57$i = 0, $$sroa$10$0$i = 0, $$sroa$5$0$$sroa_idx40$i = 0, $$sroa$5$0$i = 0, $$sroa$6$0$$sroa_idx$i = 0, $$sroa$645$0$$sroa_idx46$i = 0;
 var $$sroa$645$0$i = 0, $$sroa$7$0$$sroa_idx48$i = 0, $$sroa$7$0$i = 0, $$sroa$8$0$$sroa_idx50$i = 0, $$sroa$852$0$$sroa_idx53$i = 0, $$sroa$852$0$i = 0, $$sroa$9$0$$sroa_idx55$i = 0, $$sroa$9$0$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $4 = $1;
  $5 = $4 & -16;
  $6 = $5 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $6;
 }
 $7 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $$sroa$0$0$i = 0;$$sroa$10$0$i = 0;$$sroa$5$0$i = 0;$$sroa$645$0$i = 0;$$sroa$7$0$i = 0;$$sroa$852$0$i = 0;$$sroa$9$0$i = 0;
 } else {
  $9 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
  $10 = (($9) + 40)|0;
  $$07020$i = ((((gb + (170632) | 0)) + 448|0));$$07119$i = $10;$$07218$i = $10;$$07417$i = 1;
  while(1) {
   $11 = HEAP32[$$07020$i>>2]|0;
   $12 = ((($11)) + 8|0);
   $13 = $12;
   $14 = $13 & 7;
   $15 = ($14|0)==(0);
   $16 = (0 - ($13))|0;
   $17 = $16 & 7;
   $18 = $15 ? 0 : $17;
   $19 = (($11) + ($18)|0);
   $20 = ((($$07020$i)) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($11) + ($21)|0);
   $$0$in6$i = $19;$$15$i = $$07119$i;$$1734$i = $$07218$i;$$1753$i = $$07417$i;
   while(1) {
    $23 = ($$0$in6$i>>>0)>=($22>>>0);
    $24 = ($7|0)==($$0$in6$i|0);
    $or$cond$i = $23 | $24;
    if ($or$cond$i) {
     $$1$lcssa$ph$i = $$15$i;$$173$lcssa$ph$i = $$1734$i;$$175$lcssa$ph$i = $$1753$i;
     break;
    }
    $25 = ((($$0$in6$i)) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(7);
    if ($27) {
     $$1$lcssa$ph$i = $$15$i;$$173$lcssa$ph$i = $$1734$i;$$175$lcssa$ph$i = $$1753$i;
     break;
    }
    $28 = $26 & -8;
    $29 = (($28) + ($$15$i))|0;
    $30 = $26 & 3;
    $31 = ($30|0)==(1);
    $32 = $31&1;
    $$276$i = (($$1753$i) + ($32))|0;
    $33 = $31 ? $28 : 0;
    $$2$i = (($33) + ($$1734$i))|0;
    $34 = (($$0$in6$i) + ($28)|0);
    $35 = ($34>>>0)<($11>>>0);
    if ($35) {
     $$1$lcssa$ph$i = $29;$$173$lcssa$ph$i = $$2$i;$$175$lcssa$ph$i = $$276$i;
     break;
    } else {
     $$0$in6$i = $34;$$15$i = $29;$$1734$i = $$2$i;$$1753$i = $$276$i;
    }
   }
   $36 = ((($$07020$i)) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    break;
   } else {
    $$07020$i = $37;$$07119$i = $$1$lcssa$ph$i;$$07218$i = $$173$lcssa$ph$i;$$07417$i = $$175$lcssa$ph$i;
   }
  }
  $39 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
  $40 = (($39) - ($$1$lcssa$ph$i))|0;
  $41 = HEAP32[((((gb + (170632) | 0)) + 436|0))>>2]|0;
  $42 = (($39) - ($$173$lcssa$ph$i))|0;
  $$sroa$0$0$i = $$1$lcssa$ph$i;$$sroa$10$0$i = $9;$$sroa$5$0$i = $$175$lcssa$ph$i;$$sroa$645$0$i = $40;$$sroa$7$0$i = $41;$$sroa$852$0$i = $42;$$sroa$9$0$i = $$173$lcssa$ph$i;
 }
 HEAP32[$0>>2] = $$sroa$0$0$i;
 $$sroa$5$0$$sroa_idx40$i = ((($0)) + 4|0);
 HEAP32[$$sroa$5$0$$sroa_idx40$i>>2] = $$sroa$5$0$i;
 $$sroa$6$0$$sroa_idx$i = ((($0)) + 8|0);
 $43 = $$sroa$6$0$$sroa_idx$i;
 $44 = $43;
 HEAP32[$44>>2] = 0;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $$sroa$645$0$$sroa_idx46$i = ((($0)) + 16|0);
 HEAP32[$$sroa$645$0$$sroa_idx46$i>>2] = $$sroa$645$0$i;
 $$sroa$7$0$$sroa_idx48$i = ((($0)) + 20|0);
 HEAP32[$$sroa$7$0$$sroa_idx48$i>>2] = $$sroa$7$0$i;
 $$sroa$8$0$$sroa_idx50$i = ((($0)) + 24|0);
 HEAP32[$$sroa$8$0$$sroa_idx50$i>>2] = 0;
 $$sroa$852$0$$sroa_idx53$i = ((($0)) + 28|0);
 HEAP32[$$sroa$852$0$$sroa_idx53$i>>2] = $$sroa$852$0$i;
 $$sroa$9$0$$sroa_idx55$i = ((($0)) + 32|0);
 HEAP32[$$sroa$9$0$$sroa_idx55$i>>2] = $$sroa$9$0$i;
 $$sroa$10$0$$sroa_idx57$i = ((($0)) + 36|0);
 HEAP32[$$sroa$10$0$$sroa_idx57$i>>2] = $$sroa$10$0$i;
 STACKTOP = sp;return;
}
function _malloc_stats() {
 var $$0$in4$i = 0, $$03710$i = 0, $$0389$i = 0, $$039$i = 0, $$040$i = 0, $$1$lcssa$ph$i = 0, $$13$i = 0, $$2$i = 0, $$3$i = 0, $$neg2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = sp + 20|0;
 $1 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $3 = $0;
  $4 = $3 & -16;
  $5 = $4 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $5;
 }
 $6 = HEAP32[((((gb + (170632) | 0)) + 24|0))>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$039$i = 0;$$040$i = 0;$$3$i = 0;
  $38 = HEAP32[(gb + (161300) | 0)>>2]|0;
  HEAP32[$vararg_buffer>>2] = $$040$i;
  (_fprintf($38,(gb + (166408) | 0),$vararg_buffer)|0);
  HEAP32[$vararg_buffer1>>2] = $$039$i;
  (_fprintf($38,(gb + (166434) | 0),$vararg_buffer1)|0);
  HEAP32[$vararg_buffer4>>2] = $$3$i;
  (_fprintf($38,(gb + (166460) | 0),$vararg_buffer4)|0);
  STACKTOP = sp;return;
 }
 $8 = HEAP32[((((gb + (170632) | 0)) + 436|0))>>2]|0;
 $9 = HEAP32[((((gb + (170632) | 0)) + 432|0))>>2]|0;
 $10 = HEAP32[((((gb + (170632) | 0)) + 12|0))>>2]|0;
 $$neg2$i = (($9) + -40)|0;
 $11 = (($$neg2$i) - ($10))|0;
 $$03710$i = ((((gb + (170632) | 0)) + 448|0));$$0389$i = $11;
 while(1) {
  $12 = HEAP32[$$03710$i>>2]|0;
  $13 = ((($12)) + 8|0);
  $14 = $13;
  $15 = $14 & 7;
  $16 = ($15|0)==(0);
  $17 = (0 - ($14))|0;
  $18 = $17 & 7;
  $19 = $16 ? 0 : $18;
  $20 = (($12) + ($19)|0);
  $21 = ((($$03710$i)) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($12) + ($22)|0);
  $$0$in4$i = $20;$$13$i = $$0389$i;
  while(1) {
   $24 = ($$0$in4$i>>>0)>=($23>>>0);
   $25 = ($6|0)==($$0$in4$i|0);
   $or$cond$i = $24 | $25;
   if ($or$cond$i) {
    $$1$lcssa$ph$i = $$13$i;
    break;
   }
   $26 = ((($$0$in4$i)) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(7);
   if ($28) {
    $$1$lcssa$ph$i = $$13$i;
    break;
   }
   $29 = $27 & 3;
   $30 = ($29|0)==(1);
   $31 = $27 & -8;
   $32 = $30 ? $31 : 0;
   $$2$i = (($$13$i) - ($32))|0;
   $33 = (($$0$in4$i) + ($31)|0);
   $34 = ($33>>>0)<($12>>>0);
   if ($34) {
    $$1$lcssa$ph$i = $$2$i;
    break;
   } else {
    $$0$in4$i = $33;$$13$i = $$2$i;
   }
  }
  $35 = ((($$03710$i)) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$039$i = $9;$$040$i = $8;$$3$i = $$1$lcssa$ph$i;
   break;
  } else {
   $$03710$i = $36;$$0389$i = $$1$lcssa$ph$i;
  }
 }
 $38 = HEAP32[(gb + (161300) | 0)>>2]|0;
 HEAP32[$vararg_buffer>>2] = $$040$i;
 (_fprintf($38,(gb + (166408) | 0),$vararg_buffer)|0);
 HEAP32[$vararg_buffer1>>2] = $$039$i;
 (_fprintf($38,(gb + (166434) | 0),$vararg_buffer1)|0);
 HEAP32[$vararg_buffer4>>2] = $$3$i;
 (_fprintf($38,(gb + (166460) | 0),$vararg_buffer4)|0);
 STACKTOP = sp;return;
}
function _mallopt($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = HEAP32[(gb + (171104) | 0)>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 4|0))>>2] = 4096;
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = -1;
  HEAP32[((((gb + (171104) | 0)) + 20|0))>>2] = 0;
  HEAP32[((((gb + (170632) | 0)) + 444|0))>>2] = 0;
  $5 = $2;
  $6 = $5 & -16;
  $7 = $6 ^ 1431655768;
  HEAP32[(gb + (171104) | 0)>>2] = $7;
 }
 switch ($0|0) {
 case -1:  {
  HEAP32[((((gb + (171104) | 0)) + 16|0))>>2] = $1;
  $$0$i = 1;
  break;
 }
 case -2:  {
  $8 = HEAP32[((((gb + (171104) | 0)) + 4|0))>>2]|0;
  $9 = ($8>>>0)>($1>>>0);
  if ($9) {
   $$0$i = 0;
  } else {
   $10 = (($1) + -1)|0;
   $11 = $10 & $1;
   $12 = ($11|0)==(0);
   if ($12) {
    HEAP32[((((gb + (171104) | 0)) + 8|0))>>2] = $1;
    $$0$i = 1;
   } else {
    $$0$i = 0;
   }
  }
  break;
 }
 case -3:  {
  HEAP32[((((gb + (171104) | 0)) + 12|0))>>2] = $1;
  $$0$i = 1;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 STACKTOP = sp;return ($$0$i|0);
}
function _malloc_usable_size($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return 0;
 } else {
  $2 = ((($0)) + -4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 & 3;
  $5 = ($4|0)==(1);
  $6 = $3 & -8;
  $7 = ($4|0)==(0);
  $8 = $7 ? 8 : 4;
  $9 = (($6) - ($8))|0;
  $spec$select = $5 ? 0 : $9;
  return ($spec$select|0);
 }
 return (0)|0;
}
function ___stdio_close($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (mftCall_ii((fb + (7) | 0)|0,($2|0))|0);
 HEAP32[$vararg_buffer>>2] = $3;
 $4 = (___syscall6(6,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___stdio_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04756 = 0, $$04855 = 0, $$04954 = 0, $$051 = 0, $$1 = 0, $$150 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0;
 var $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 32|0;
 $vararg_buffer = sp + 16|0;
 $3 = sp;
 $4 = ((($0)) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = ((($3)) + 4|0);
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) - ($5))|0;
 HEAP32[$6>>2] = $9;
 $10 = ((($3)) + 8|0);
 HEAP32[$10>>2] = $1;
 $11 = ((($3)) + 12|0);
 HEAP32[$11>>2] = $2;
 $12 = (($9) + ($2))|0;
 $13 = ((($0)) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $3;
 HEAP32[$vararg_buffer>>2] = $14;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $15;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 2;
 $16 = (___syscall146(146,($vararg_buffer|0))|0);
 $17 = (___syscall_ret($16)|0);
 $18 = ($12|0)==($17|0);
 L1: do {
  if ($18) {
   label = 3;
  } else {
   $$04756 = 2;$$04855 = $12;$$04954 = $3;$27 = $17;
   while(1) {
    $26 = ($27|0)<(0);
    if ($26) {
     break;
    }
    $35 = (($$04855) - ($27))|0;
    $36 = ((($$04954)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($27>>>0)>($37>>>0);
    $39 = ((($$04954)) + 8|0);
    $$150 = $38 ? $39 : $$04954;
    $40 = $38 << 31 >> 31;
    $$1 = (($$04756) + ($40))|0;
    $41 = $38 ? $37 : 0;
    $$0 = (($27) - ($41))|0;
    $42 = HEAP32[$$150>>2]|0;
    $43 = (($42) + ($$0)|0);
    HEAP32[$$150>>2] = $43;
    $44 = ((($$150)) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) - ($$0))|0;
    HEAP32[$44>>2] = $46;
    $47 = HEAP32[$13>>2]|0;
    $48 = $$150;
    HEAP32[$vararg_buffer3>>2] = $47;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $48;
    $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
    HEAP32[$vararg_ptr7>>2] = $$1;
    $49 = (___syscall146(146,($vararg_buffer3|0))|0);
    $50 = (___syscall_ret($49)|0);
    $51 = ($35|0)==($50|0);
    if ($51) {
     label = 3;
     break L1;
    } else {
     $$04756 = $$1;$$04855 = $35;$$04954 = $$150;$27 = $50;
    }
   }
   $28 = ((($0)) + 16|0);
   HEAP32[$28>>2] = 0;
   HEAP32[$4>>2] = 0;
   HEAP32[$7>>2] = 0;
   $29 = HEAP32[$0>>2]|0;
   $30 = $29 | 32;
   HEAP32[$0>>2] = $30;
   $31 = ($$04756|0)==(2);
   if ($31) {
    $$051 = 0;
   } else {
    $32 = ((($$04954)) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($2) - ($33))|0;
    $$051 = $34;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $19 = ((($0)) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($0)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + ($22)|0);
  $24 = ((($0)) + 16|0);
  HEAP32[$24>>2] = $23;
  $25 = $20;
  HEAP32[$4>>2] = $25;
  HEAP32[$7>>2] = $25;
  $$051 = $2;
 }
 STACKTOP = sp;return ($$051|0);
}
function ___stdio_seek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$pre = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 20|0;
 $4 = ((($0)) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 HEAP32[$vararg_buffer>>2] = $5;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $6;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $2;
 $7 = (___syscall140(140,($vararg_buffer|0))|0);
 $8 = (___syscall_ret($7)|0);
 $9 = ($8|0)<(0);
 if ($9) {
  HEAP32[$3>>2] = -1;
  $10 = -1;
 } else {
  $$pre = HEAP32[$3>>2]|0;
  $10 = $$pre;
 }
 STACKTOP = sp;return ($10|0);
}
function ___syscall_ret($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)>(4294963200);
 if ($1) {
  $2 = (0 - ($0))|0;
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = $2;
  $$0 = -1;
 } else {
  $$0 = $0;
 }
 return ($$0|0);
}
function ___errno_location() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (171176) | 0)|0);
}
function _dummy($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($0|0);
}
function ___stdio_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp + 16|0;
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = ((($3)) + 4|0);
 $5 = ((($0)) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)!=(0);
 $8 = $7&1;
 $9 = (($2) - ($8))|0;
 HEAP32[$4>>2] = $9;
 $10 = ((($3)) + 8|0);
 $11 = ((($0)) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = ((($3)) + 12|0);
 HEAP32[$13>>2] = $6;
 $14 = ((($0)) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $3;
 HEAP32[$vararg_buffer>>2] = $15;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $16;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 2;
 $17 = (___syscall145(145,($vararg_buffer|0))|0);
 $18 = (___syscall_ret($17)|0);
 $19 = ($18|0)<(1);
 if ($19) {
  $20 = $18 & 48;
  $21 = $20 ^ 16;
  $22 = HEAP32[$0>>2]|0;
  $23 = $22 | $21;
  HEAP32[$0>>2] = $23;
  $$0 = $18;
 } else {
  $24 = HEAP32[$4>>2]|0;
  $25 = ($18>>>0)>($24>>>0);
  if ($25) {
   $26 = (($18) - ($24))|0;
   $27 = HEAP32[$11>>2]|0;
   $28 = ((($0)) + 4|0);
   HEAP32[$28>>2] = $27;
   $$cast = $27;
   $29 = (($$cast) + ($26)|0);
   $30 = ((($0)) + 8|0);
   HEAP32[$30>>2] = $29;
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0);
   if ($32) {
    $$0 = $2;
   } else {
    $33 = ((($$cast)) + 1|0);
    HEAP32[$28>>2] = $33;
    $34 = HEAP8[$$cast>>0]|0;
    $35 = (($2) + -1)|0;
    $36 = (($1) + ($35)|0);
    HEAP8[$36>>0] = $34;
    $$0 = $2;
   }
  } else {
   $$0 = $18;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___stdout_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 16|0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = (fb + (2) | 0);
 $5 = HEAP32[$0>>2]|0;
 $6 = $5 & 64;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = ((($0)) + 60|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $3;
  HEAP32[$vararg_buffer>>2] = $9;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 21523;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $10;
  $11 = (___syscall54(54,($vararg_buffer|0))|0);
  $12 = ($11|0)==(0);
  if (!($12)) {
   $13 = ((($0)) + 75|0);
   HEAP8[$13>>0] = -1;
  }
 }
 $14 = (___stdio_write($0,$1,$2)|0);
 STACKTOP = sp;return ($14|0);
}
function ___strerror_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$012$lcssa = 0, $$01214 = 0, $$016 = 0, $$113 = 0, $$115 = 0, $$115$ph = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$016 = 0;
 while(1) {
  $2 = ((gb + (368) | 0) + ($$016)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = ($4|0)==($0|0);
  if ($5) {
   label = 4;
   break;
  }
  $6 = (($$016) + 1)|0;
  $7 = ($6|0)==(87);
  if ($7) {
   $$115$ph = 87;
   label = 5;
   break;
  } else {
   $$016 = $6;
  }
 }
 if ((label|0) == 4) {
  $8 = ($$016|0)==(0);
  if ($8) {
   $$012$lcssa = (gb + (464) | 0);
  } else {
   $$115$ph = $$016;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $$01214 = (gb + (464) | 0);$$115 = $$115$ph;
  while(1) {
   $$113 = $$01214;
   while(1) {
    $9 = HEAP8[$$113>>0]|0;
    $10 = ($9<<24>>24)==(0);
    $11 = ((($$113)) + 1|0);
    if ($10) {
     break;
    } else {
     $$113 = $11;
    }
   }
   $12 = (($$115) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    $$012$lcssa = $11;
    break;
   } else {
    $$01214 = $11;$$115 = $12;
   }
  }
 }
 $14 = ((($1)) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (___lctrans($$012$lcssa,$15)|0);
 return ($16|0);
}
function ___lctrans($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___lctrans_impl($0,$1)|0);
 return ($2|0);
}
function ___lctrans_impl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = ((($1)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (___mo_lookup($3,$5,$0)|0);
  $$0 = $6;
 }
 $7 = ($$0|0)==(0|0);
 $8 = $7 ? $0 : $$0;
 return ($8|0);
}
function ___mo_lookup($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$090 = 0, $$094 = 0, $$191 = 0, $$195 = 0, $$4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond102 = 0, $or$cond104 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 1794895138)|0;
 $5 = ((($0)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_swapc($6,$4)|0);
 $8 = ((($0)) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_swapc($9,$4)|0);
 $11 = ((($0)) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (_swapc($12,$4)|0);
 $14 = $1 >>> 2;
 $15 = ($7>>>0)<($14>>>0);
 L1: do {
  if ($15) {
   $16 = $7 << 2;
   $17 = (($1) - ($16))|0;
   $18 = ($10>>>0)<($17>>>0);
   $19 = ($13>>>0)<($17>>>0);
   $or$cond = $18 & $19;
   if ($or$cond) {
    $20 = $13 | $10;
    $21 = $20 & 3;
    $22 = ($21|0)==(0);
    if ($22) {
     $23 = $10 >>> 2;
     $24 = $13 >>> 2;
     $$090 = 0;$$094 = $7;
     while(1) {
      $25 = $$094 >>> 1;
      $26 = (($$090) + ($25))|0;
      $27 = $26 << 1;
      $28 = (($27) + ($23))|0;
      $29 = (($0) + ($28<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (_swapc($30,$4)|0);
      $32 = (($28) + 1)|0;
      $33 = (($0) + ($32<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (_swapc($34,$4)|0);
      $36 = ($35>>>0)<($1>>>0);
      $37 = (($1) - ($35))|0;
      $38 = ($31>>>0)<($37>>>0);
      $or$cond102 = $36 & $38;
      if (!($or$cond102)) {
       $$4 = 0;
       break L1;
      }
      $39 = (($35) + ($31))|0;
      $40 = (($0) + ($39)|0);
      $41 = HEAP8[$40>>0]|0;
      $42 = ($41<<24>>24)==(0);
      if (!($42)) {
       $$4 = 0;
       break L1;
      }
      $43 = (($0) + ($35)|0);
      $44 = (_strcmp($2,$43)|0);
      $45 = ($44|0)==(0);
      if ($45) {
       break;
      }
      $62 = ($$094|0)==(1);
      $63 = ($44|0)<(0);
      if ($62) {
       $$4 = 0;
       break L1;
      }
      $$191 = $63 ? $$090 : $26;
      $64 = (($$094) - ($25))|0;
      $$195 = $63 ? $25 : $64;
      $$090 = $$191;$$094 = $$195;
     }
     $46 = (($27) + ($24))|0;
     $47 = (($0) + ($46<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (_swapc($48,$4)|0);
     $50 = (($46) + 1)|0;
     $51 = (($0) + ($50<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (_swapc($52,$4)|0);
     $54 = ($53>>>0)<($1>>>0);
     $55 = (($1) - ($53))|0;
     $56 = ($49>>>0)<($55>>>0);
     $or$cond104 = $54 & $56;
     if ($or$cond104) {
      $57 = (($0) + ($53)|0);
      $58 = (($53) + ($49))|0;
      $59 = (($0) + ($58)|0);
      $60 = HEAP8[$59>>0]|0;
      $61 = ($60<<24>>24)==(0);
      $spec$select = $61 ? $57 : 0;
      $$4 = $spec$select;
     } else {
      $$4 = 0;
     }
    } else {
     $$4 = 0;
    }
   } else {
    $$4 = 0;
   }
  } else {
   $$4 = 0;
  }
 } while(0);
 return ($$4|0);
}
function _swapc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 $3 = (_llvm_bswap_i32(($0|0))|0);
 $spec$select = $2 ? $0 : $3;
 return ($spec$select|0);
}
function _strcmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$011 = 0, $$0710 = 0, $$lcssa = 0, $$lcssa8 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = HEAP8[$1>>0]|0;
 $4 = ($2<<24>>24)!=($3<<24>>24);
 $5 = ($2<<24>>24)==(0);
 $or$cond9 = $5 | $4;
 if ($or$cond9) {
  $$lcssa = $3;$$lcssa8 = $2;
 } else {
  $$011 = $1;$$0710 = $0;
  while(1) {
   $6 = ((($$0710)) + 1|0);
   $7 = ((($$011)) + 1|0);
   $8 = HEAP8[$6>>0]|0;
   $9 = HEAP8[$7>>0]|0;
   $10 = ($8<<24>>24)!=($9<<24>>24);
   $11 = ($8<<24>>24)==(0);
   $or$cond = $11 | $10;
   if ($or$cond) {
    $$lcssa = $9;$$lcssa8 = $8;
    break;
   } else {
    $$011 = $7;$$0710 = $6;
   }
  }
 }
 $12 = $$lcssa8&255;
 $13 = $$lcssa&255;
 $14 = (($12) - ($13))|0;
 return ($14|0);
}
function _strerror($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (___strerror_l($0,$3)|0);
 return ($4|0);
}
function ___pthread_self() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _pthread_self() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (161704) | 0)|0);
}
function _getpid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall20(20,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _truncate($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1 >> 31;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $4 = (___syscall193(193,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _getpgrp() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 0;
 $0 = (___syscall132(132,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _readlink($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $5 = (___syscall85(85,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _symlinkat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $2;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $4;
 $5 = (___syscall304(304,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _lchown($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall198(198,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _pipe2($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var $vararg_buffer12 = 0, $vararg_buffer17 = 0, $vararg_buffer2 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer17 = sp + 56|0;
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $3 = (_pipe($0)|0);
   $$1 = $3;
  } else {
   $4 = $0;
   HEAP32[$vararg_buffer>>2] = $4;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $1;
   $5 = (___syscall331(331,($vararg_buffer|0))|0);
   $6 = ($5|0)==(-38);
   if (!($6)) {
    $7 = (___syscall_ret($5)|0);
    $$1 = $7;
    break;
   }
   $8 = (_pipe($0)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $1 & 524288;
    $11 = ($10|0)==(0);
    if (!($11)) {
     $12 = HEAP32[$0>>2]|0;
     HEAP32[$vararg_buffer2>>2] = $12;
     $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
     HEAP32[$vararg_ptr5>>2] = 2;
     $vararg_ptr6 = ((($vararg_buffer2)) + 8|0);
     HEAP32[$vararg_ptr6>>2] = 1;
     (___syscall221(221,($vararg_buffer2|0))|0);
     $13 = ((($0)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     HEAP32[$vararg_buffer7>>2] = $14;
     $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
     HEAP32[$vararg_ptr10>>2] = 2;
     $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
     HEAP32[$vararg_ptr11>>2] = 1;
     (___syscall221(221,($vararg_buffer7|0))|0);
    }
    $15 = $1 & 2048;
    $16 = ($15|0)==(0);
    if ($16) {
     $$1 = 0;
    } else {
     $17 = HEAP32[$0>>2]|0;
     HEAP32[$vararg_buffer12>>2] = $17;
     $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
     HEAP32[$vararg_ptr15>>2] = 4;
     $vararg_ptr16 = ((($vararg_buffer12)) + 8|0);
     HEAP32[$vararg_ptr16>>2] = 2048;
     (___syscall221(221,($vararg_buffer12|0))|0);
     $18 = ((($0)) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$vararg_buffer17>>2] = $19;
     $vararg_ptr20 = ((($vararg_buffer17)) + 4|0);
     HEAP32[$vararg_ptr20>>2] = 4;
     $vararg_ptr21 = ((($vararg_buffer17)) + 8|0);
     HEAP32[$vararg_ptr21>>2] = 2048;
     (___syscall221(221,($vararg_buffer17|0))|0);
     $$1 = 0;
    }
   } else {
    $$1 = $8;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _pipe($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall42(42,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _getegid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall202(202,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _readv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall145(145,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _ualarm($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = 0;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($2)) + 12|0);
 HEAP32[$5>>2] = $0;
 (_setitimer(0,($2|0),($2|0))|0);
 $6 = HEAP32[$4>>2]|0;
 $7 = ($6*1000000)|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = (($7) + ($8))|0;
 STACKTOP = sp;return ($9|0);
}
function _getpgid($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall132(132,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _fchownat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $4;
 $6 = (___syscall298(298,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _sleep($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $0;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (_nanosleep(($1|0),($1|0))|0);
 $4 = ($3|0)==(0);
 $5 = HEAP32[$1>>2]|0;
 $$0 = $4 ? 0 : $5;
 STACKTOP = sp;return ($$0|0);
}
function _nice($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall34(34,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _setreuid($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___setxid(203,$0,$1,0)|0);
 return ($2|0);
}
function ___setxid($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 HEAP32[$4>>2] = $1;
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = $2;
 $6 = ((($4)) + 8|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($4)) + 12|0);
 HEAP32[$7>>2] = $0;
 $8 = ((($4)) + 16|0);
 HEAP32[$8>>2] = -1;
 ___synccall((fb + (8) | 0),$4);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0 = 0;
 } else {
  $11 = ($9|0)>(0);
  if ($11) {
   $12 = (___errno_location()|0);
   HEAP32[$12>>2] = $9;
   $$0 = -1;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _do_setxid($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  HEAP32[$1>>2] = 1;
 }
 return;
}
function ___synccall($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 mftCall_vi($0|0,($1|0));
 return;
}
function _preadv($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = 0;
 $5 = (___syscall333(333,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _getgid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall200(200,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _posix_close($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_close($0)|0);
 return ($2|0);
}
function _close($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $spec$store$select = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = (mftCall_ii((fb + (7) | 0)|0,($0|0))|0);
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall6(6,($vararg_buffer|0))|0);
 $3 = ($2|0)==(-4);
 $spec$store$select = $3 ? 0 : $2;
 $4 = (___syscall_ret($spec$store$select)|0);
 STACKTOP = sp;return ($4|0);
}
function _setuid($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___setxid(213,$0,0,0)|0);
 return ($1|0);
}
function _setregid($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___setxid(204,$0,$1,0)|0);
 return ($2|0);
}
function _linkat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = $1;
 $6 = $3;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $6;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $4;
 $7 = (___syscall303(303,($vararg_buffer|0))|0);
 $8 = (___syscall_ret($7)|0);
 STACKTOP = sp;return ($8|0);
}
function _unlinkat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall301(301,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _gethostname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$013 = 0, $$014 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(400|0);
 $2 = sp;
 $3 = (_uname($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = ($1>>>0)<(65);
  $spec$select = $5 ? $1 : 65;
  $6 = ($spec$select|0)==(0);
  L3: do {
   if ($6) {
    $$0$lcssa = 0;
   } else {
    $$014 = 0;
    while(1) {
     $7 = (((($2)) + 65|0) + ($$014)|0);
     $8 = HEAP8[$7>>0]|0;
     $9 = (($0) + ($$014)|0);
     HEAP8[$9>>0] = $8;
     $10 = ($8<<24>>24)==(0);
     if ($10) {
      $$0$lcssa = $$014;
      break L3;
     }
     $11 = (($$014) + 1)|0;
     $12 = ($11>>>0)<($spec$select>>>0);
     if ($12) {
      $$014 = $11;
     } else {
      $$0$lcssa = $11;
      break;
     }
    }
   }
  } while(0);
  $13 = ($$0$lcssa|0)==($spec$select|0);
  if ($13) {
   $14 = (($spec$select) + -1)|0;
   $15 = (($0) + ($14)|0);
   HEAP8[$15>>0] = 0;
   $$013 = 0;
  } else {
   $$013 = 0;
  }
 } else {
  $$013 = -1;
 }
 STACKTOP = sp;return ($$013|0);
}
function _uname($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall122(122,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _writev($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall146(146,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _getlogin() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getenv(((gb + (166486) | 0)|0))|0);
 return ($0|0);
}
function _chdir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall12(12,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _setgid($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___setxid(214,$0,0,0)|0);
 return ($1|0);
}
function _fdatasync($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall148(148,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _pread($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $3 >> 31;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = 0;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $3;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $5;
 $6 = (___syscall180(180,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _tcsetpgrp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = sp + 4|0;
 HEAP32[$2>>2] = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $3 = (_ioctl($0,21520,$vararg_buffer)|0);
 STACKTOP = sp;return ($3|0);
}
function _ioctl($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded2 = 0, $expanded4 = 0, $expanded5 = 0, $expanded6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp + 16|0;
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $arglist_current = HEAP32[$2>>2]|0;
 $3 = $arglist_current;
 $4 = ((0) + 4|0);
 $expanded2 = $4;
 $expanded = (($expanded2) - 1)|0;
 $5 = (($3) + ($expanded))|0;
 $6 = ((0) + 4|0);
 $expanded6 = $6;
 $expanded5 = (($expanded6) - 1)|0;
 $expanded4 = $expanded5 ^ -1;
 $7 = $5 & $expanded4;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $arglist_next = ((($8)) + 4|0);
 HEAP32[$2>>2] = $arglist_next;
 $10 = $9;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $10;
 $11 = (___syscall54(54,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function _setpgid($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $2 = (___syscall57(57,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _renameat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $3;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $5;
 $6 = (___syscall302(302,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _acct($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall51(51,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function ___dup3($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $3 = ($0|0)==($1|0);
 L1: do {
  if ($3) {
   $$sink = -22;
  } else {
   $4 = $2 & 524288;
   $5 = ($4|0)!=(0);
   L3: do {
    if ($5) {
     while(1) {
      HEAP32[$vararg_buffer>>2] = $0;
      $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
      HEAP32[$vararg_ptr1>>2] = $1;
      $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
      HEAP32[$vararg_ptr2>>2] = $2;
      $6 = (___syscall330(330,($vararg_buffer|0))|0);
      switch ($6|0) {
      case -38:  {
       break L3;
       break;
      }
      case -16:  {
       break;
      }
      default: {
       $$sink = $6;
       break L1;
      }
      }
     }
    }
   } while(0);
   while(1) {
    HEAP32[$vararg_buffer3>>2] = $0;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $1;
    $7 = (___syscall63(63,($vararg_buffer3|0))|0);
    $8 = ($7|0)==(-16);
    if (!($8)) {
     break;
    }
   }
   if ($5) {
    HEAP32[$vararg_buffer7>>2] = $1;
    $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
    HEAP32[$vararg_ptr10>>2] = 2;
    $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
    HEAP32[$vararg_ptr11>>2] = 1;
    (___syscall221(221,($vararg_buffer7|0))|0);
    $$sink = $7;
   } else {
    $$sink = $7;
   }
  }
 } while(0);
 $9 = (___syscall_ret($$sink)|0);
 STACKTOP = sp;return ($9|0);
}
function _ttyname_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 $4 = (_isatty($0)|0);
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $$0 = 25;
  } else {
   ___procfdname($3,$0);
   $6 = (_readlink($3,$1,$2)|0);
   $7 = ($6|0)<(0);
   if ($7) {
    $8 = (___errno_location()|0);
    $9 = HEAP32[$8>>2]|0;
    $$0 = $9;
    break;
   }
   $10 = ($6|0)==($2|0);
   if ($10) {
    $$0 = 34;
   } else {
    $11 = (($1) + ($6)|0);
    HEAP8[$11>>0] = 0;
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _isatty($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $1 = sp + 16|0;
 $2 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 21523;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $3 = (___syscall54(54,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 $5 = ($4|0)==(0);
 $6 = $5&1;
 STACKTOP = sp;return ($6|0);
}
function ___procfdname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02324 = 0, $$027 = 0, $$126 = 0, $$225 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$0; src=(gb + (166494) | 0); stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = ((($0)) + 14|0);
  HEAP8[$3>>0] = 48;
  $4 = ((($0)) + 15|0);
  HEAP8[$4>>0] = 0;
 } else {
  $$027 = $1;$$126 = 14;
  while(1) {
   $5 = (($$027>>>0) / 10)&-1;
   $6 = (($$126) + 1)|0;
   $7 = ($$027>>>0)<(10);
   if ($7) {
    break;
   } else {
    $$027 = $5;$$126 = $6;
   }
  }
  $8 = (($0) + ($6)|0);
  HEAP8[$8>>0] = 0;
  $$02324 = $1;$$225 = $6;
  while(1) {
   $9 = (($$02324>>>0) / 10)&-1;
   $10 = ($9*10)|0;
   $11 = (($$02324) - ($10))|0;
   $12 = $11 | 48;
   $13 = $12&255;
   $14 = (($$225) + -1)|0;
   $15 = (($0) + ($14)|0);
   HEAP8[$15>>0] = $13;
   $16 = ($$02324>>>0)<(10);
   if ($16) {
    break;
   } else {
    $$02324 = $9;$$225 = $14;
   }
  }
 }
 return;
}
function _ttyname($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ttyname_r($0,(gb + (169920) | 0),32)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = (gb + (169920) | 0);
 } else {
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = $1;
  $$0 = 0;
 }
 return ($$0|0);
}
function _dup($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall41(41,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _tcgetpgrp($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,21519,$vararg_buffer)|0);
 $3 = ($2|0)<(0);
 $4 = HEAP32[$1>>2]|0;
 $$0 = $3 ? -1 : $4;
 STACKTOP = sp;return ($$0|0);
}
function _pause() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall29(29,($vararg_buffer|0))|0);
 $1 = (___syscall_ret($0)|0);
 STACKTOP = sp;return ($1|0);
}
function _pwrite($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $3 >> 31;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = 0;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $3;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $5;
 $6 = (___syscall181(181,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _pwritev($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = 0;
 $5 = (___syscall334(334,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _lseek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 20|0;
 $4 = $3;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $4;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $2;
 $5 = (___syscall140(140,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 $7 = ($6|0)==(0);
 $8 = HEAP32[$3>>2]|0;
 $9 = $7 ? $8 : -1;
 STACKTOP = sp;return ($9|0);
}
function _getlogin_r($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_getlogin()|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 6;
 } else {
  $4 = (_strlen($2)|0);
  $5 = ($4>>>0)<($1>>>0);
  if ($5) {
   (_strcpy($0,$2)|0);
   $$0 = 0;
  } else {
   $$0 = 34;
  }
 }
 return ($$0|0);
}
function _strlen($0) {
 $0 = $0|0;
 var $$0 = 0, $$014 = 0, $$015$lcssa = 0, $$01518 = 0, $$1$lcssa = 0, $$pn = 0, $$pn29 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1 & 3;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$015$lcssa = $0;
   label = 5;
  } else {
   $$01518 = $0;$22 = $1;
   while(1) {
    $4 = HEAP8[$$01518>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     $$pn = $22;
     break L1;
    }
    $6 = ((($$01518)) + 1|0);
    $7 = $6;
    $8 = $7 & 3;
    $9 = ($8|0)==(0);
    if ($9) {
     $$015$lcssa = $6;
     label = 5;
     break;
    } else {
     $$01518 = $6;$22 = $7;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $$0 = $$015$lcssa;
  while(1) {
   $10 = HEAP32[$$0>>2]|0;
   $11 = (($10) + -16843009)|0;
   $12 = $10 & -2139062144;
   $13 = $12 ^ -2139062144;
   $14 = $13 & $11;
   $15 = ($14|0)==(0);
   $16 = ((($$0)) + 4|0);
   if ($15) {
    $$0 = $16;
   } else {
    break;
   }
  }
  $17 = $10&255;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$1$lcssa = $$0;
  } else {
   $$pn29 = $$0;
   while(1) {
    $19 = ((($$pn29)) + 1|0);
    $$pre = HEAP8[$19>>0]|0;
    $20 = ($$pre<<24>>24)==(0);
    if ($20) {
     $$1$lcssa = $19;
     break;
    } else {
     $$pn29 = $19;
    }
   }
  }
  $21 = $$1$lcssa;
  $$pn = $21;
 }
 $$014 = (($$pn) - ($1))|0;
 return ($$014|0);
}
function _strcpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___stpcpy($0,$1)|0);
 return ($0|0);
}
function ___stpcpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$025$lcssa = 0, $$02536 = 0, $$026$lcssa = 0, $$02642 = 0, $$027$lcssa = 0, $$02741 = 0, $$030 = 0, $$037 = 0, $$1 = 0, $$128 = 0, $$22934 = 0, $$235 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1;
 $3 = $0;
 $4 = $2 ^ $3;
 $5 = $4 & 3;
 $6 = ($5|0)==(0);
 L1: do {
  if ($6) {
   $7 = $2 & 3;
   $8 = ($7|0)==(0);
   if ($8) {
    $$026$lcssa = $1;$$027$lcssa = $0;
   } else {
    $$02642 = $1;$$02741 = $0;
    while(1) {
     $9 = HEAP8[$$02642>>0]|0;
     HEAP8[$$02741>>0] = $9;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      $$030 = $$02741;
      break L1;
     }
     $11 = ((($$02642)) + 1|0);
     $12 = ((($$02741)) + 1|0);
     $13 = $11;
     $14 = $13 & 3;
     $15 = ($14|0)==(0);
     if ($15) {
      $$026$lcssa = $11;$$027$lcssa = $12;
      break;
     } else {
      $$02642 = $11;$$02741 = $12;
     }
    }
   }
   $16 = HEAP32[$$026$lcssa>>2]|0;
   $17 = (($16) + -16843009)|0;
   $18 = $16 & -2139062144;
   $19 = $18 ^ -2139062144;
   $20 = $19 & $17;
   $21 = ($20|0)==(0);
   if ($21) {
    $$02536 = $$027$lcssa;$$037 = $$026$lcssa;$24 = $16;
    while(1) {
     $22 = ((($$037)) + 4|0);
     $23 = ((($$02536)) + 4|0);
     HEAP32[$$02536>>2] = $24;
     $25 = HEAP32[$22>>2]|0;
     $26 = (($25) + -16843009)|0;
     $27 = $25 & -2139062144;
     $28 = $27 ^ -2139062144;
     $29 = $28 & $26;
     $30 = ($29|0)==(0);
     if ($30) {
      $$02536 = $23;$$037 = $22;$24 = $25;
     } else {
      $$0$lcssa = $22;$$025$lcssa = $23;
      break;
     }
    }
   } else {
    $$0$lcssa = $$026$lcssa;$$025$lcssa = $$027$lcssa;
   }
   $$1 = $$0$lcssa;$$128 = $$025$lcssa;
   label = 10;
  } else {
   $$1 = $1;$$128 = $0;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $31 = HEAP8[$$1>>0]|0;
  HEAP8[$$128>>0] = $31;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $$030 = $$128;
  } else {
   $$22934 = $$128;$$235 = $$1;
   while(1) {
    $33 = ((($$235)) + 1|0);
    $34 = ((($$22934)) + 1|0);
    $35 = HEAP8[$33>>0]|0;
    HEAP8[$34>>0] = $35;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     $$030 = $34;
     break;
    } else {
     $$22934 = $34;$$235 = $33;
    }
   }
  }
 }
 return ($$030|0);
}
function _ftruncate($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $1 >> 31;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $2;
 $3 = (___syscall194(194,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _dup2($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 while(1) {
  HEAP32[$vararg_buffer>>2] = $0;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $1;
  $2 = (___syscall63(63,($vararg_buffer|0))|0);
  $3 = ($2|0)==(-16);
  if (!($3)) {
   break;
  }
 }
 $4 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($4|0);
}
function _getppid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall64(64,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _symlink($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall83(83,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _getcwd($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$06 = 0, $$07 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4112|0);
 $vararg_buffer = sp + 4096|0;
 $2 = sp;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $$0 = 4096;$$06 = $2;
  label = 4;
 } else {
  $4 = ($1|0)==(0);
  if ($4) {
   $5 = (___errno_location()|0);
   HEAP32[$5>>2] = 22;
   $$07 = 0;
  } else {
   $$0 = $1;$$06 = $0;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $6 = $$06;
  HEAP32[$vararg_buffer>>2] = $6;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $$0;
  $7 = (___syscall183(183,($vararg_buffer|0))|0);
  $8 = (___syscall_ret($7)|0);
  $9 = ($8|0)<(0);
  if ($9) {
   $$07 = 0;
  } else {
   $10 = ($$06|0)==($2|0);
   if ($10) {
    $11 = (mftCall_ii((fb + (9) | 0)|0,($2|0))|0);
    $$07 = $11;
   } else {
    $$07 = $$06;
   }
  }
 }
 STACKTOP = sp;return ($$07|0);
}
function ___strdup($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strlen($0)|0);
 $2 = (($1) + 1)|0;
 $3 = (_malloc($2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
 } else {
  $5 = (_memcpy(($3|0),($0|0),($2|0))|0);
  $$0 = $5;
 }
 return ($$0|0);
}
function _write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall4(4,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _geteuid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall201(201,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _access($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall33(33,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _setegid($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___setxid(210,-1,$0,-1)|0);
 return ($1|0);
}
function _rmdir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall40(40,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _getgroups($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $2;
 $3 = (___syscall205(205,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _setresuid($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___setxid(208,$0,$1,$2)|0);
 return ($3|0);
}
function _read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall3(3,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _setpgrp() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_setpgid(0,0)|0);
 return ($0|0);
}
function _fsync($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall118(118,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _setsid() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall66(66,($vararg_buffer|0))|0);
 $1 = (___syscall_ret($0)|0);
 STACKTOP = sp;return ($1|0);
}
function _fchown($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer7 = sp + 56|0;
 $vararg_buffer3 = sp + 48|0;
 $vararg_buffer = sp + 32|0;
 $3 = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall207(207,($vararg_buffer|0))|0);
 $5 = ($4|0)==(-9);
 if ($5) {
  HEAP32[$vararg_buffer3>>2] = $0;
  $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
  HEAP32[$vararg_ptr6>>2] = 1;
  $6 = (___syscall221(221,($vararg_buffer3|0))|0);
  $7 = ($6|0)<(0);
  if ($7) {
   label = 3;
  } else {
   ___procfdname($3,$0);
   $9 = $3;
   HEAP32[$vararg_buffer7>>2] = $9;
   $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
   HEAP32[$vararg_ptr10>>2] = $1;
   $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
   HEAP32[$vararg_ptr11>>2] = $2;
   $10 = (___syscall212(212,($vararg_buffer7|0))|0);
   $11 = (___syscall_ret($10)|0);
   $$0 = $11;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (___syscall_ret($4)|0);
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _getsid($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall147(147,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _sync() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 (___syscall36(36,($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function _chown($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall212(212,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _fchdir($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer5 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer5 = sp + 48|0;
 $vararg_buffer1 = sp + 40|0;
 $vararg_buffer = sp + 32|0;
 $1 = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $2 = (___syscall133(133,($vararg_buffer|0))|0);
 $3 = ($2|0)==(-9);
 if ($3) {
  HEAP32[$vararg_buffer1>>2] = $0;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 1;
  $4 = (___syscall221(221,($vararg_buffer1|0))|0);
  $5 = ($4|0)<(0);
  if ($5) {
   label = 3;
  } else {
   ___procfdname($1,$0);
   $7 = $1;
   HEAP32[$vararg_buffer5>>2] = $7;
   $8 = (___syscall12(12,($vararg_buffer5|0))|0);
   $9 = (___syscall_ret($8)|0);
   $$0 = $9;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $6 = (___syscall_ret($2)|0);
  $$0 = $6;
 }
 STACKTOP = sp;return ($$0|0);
}
function _readlinkat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $2;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $6 = (___syscall305(305,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _link($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall9(9,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _seteuid($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___setxid(208,-1,$0,-1)|0);
 return ($1|0);
}
function _getuid() {
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall199(199,($vararg_buffer|0))|0);
 STACKTOP = sp;return ($0|0);
}
function _ctermid($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = (gb + (166509) | 0);
 } else {
  $2 = (_strcpy($0,(gb + (166509) | 0))|0);
  $3 = $0;
 }
 return ($3|0);
}
function _setresgid($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___setxid(210,$0,$1,$2)|0);
 return ($3|0);
}
function _unlink($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall10(10,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _mkstemp($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___mkostemps($0,0,0)|0);
 return ($1|0);
}
function ___mkostemps($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = (_strlen($0)|0);
 $4 = ($3>>>0)<(6);
 $5 = (($3) + -6)|0;
 $6 = ($5>>>0)<($1>>>0);
 $or$cond = $4 | $6;
 L1: do {
  if ($or$cond) {
   label = 3;
  } else {
   $7 = (($0) + ($3)|0);
   $8 = (0 - ($1))|0;
   $9 = (($7) + ($8)|0);
   $10 = ((($9)) + -6|0);
   $11 = (_memcmp($10,(gb + (166518) | 0),6)|0);
   $12 = ($11|0)==(0);
   if ($12) {
    $14 = $2 & -2097348;
    $15 = $14 | 194;
    $$0 = 100;
    while(1) {
     (___randname($10)|0);
     HEAP32[$vararg_buffer>>2] = 384;
     $16 = (_open($0,$15,$vararg_buffer)|0);
     $17 = ($16|0)>(-1);
     if ($17) {
      $$1 = $16;
      break L1;
     }
     $18 = (($$0) + -1)|0;
     $19 = ($18|0)==(0);
     if ($19) {
      break;
     }
     $20 = (___errno_location()|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(17);
     if ($22) {
      $$0 = $18;
     } else {
      break;
     }
    }
    (_memcpy(($10|0),((gb + (166518) | 0)|0),6)|0);
    $$1 = -1;
   } else {
    label = 3;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $13 = (___errno_location()|0);
  HEAP32[$13>>2] = 22;
  $$1 = -1;
 }
 STACKTOP = sp;return ($$1|0);
}
function _memcmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01318 = 0, $$01417 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $14 = 0;
  } else {
   $$01318 = $0;$$01417 = $2;$$019 = $1;
   while(1) {
    $4 = HEAP8[$$01318>>0]|0;
    $5 = HEAP8[$$019>>0]|0;
    $6 = ($4<<24>>24)==($5<<24>>24);
    if (!($6)) {
     break;
    }
    $7 = (($$01417) + -1)|0;
    $8 = ((($$01318)) + 1|0);
    $9 = ((($$019)) + 1|0);
    $10 = ($7|0)==(0);
    if ($10) {
     $14 = 0;
     break L1;
    } else {
     $$01318 = $8;$$01417 = $7;$$019 = $9;
    }
   }
   $11 = $4&255;
   $12 = $5&255;
   $13 = (($11) - ($12))|0;
   $14 = $13;
  }
 } while(0);
 return ($14|0);
}
function ___randname($0) {
 $0 = $0|0;
 var $$01112 = 0, $$013 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 (___clock_gettime(0,($1|0))|0);
 $2 = ((($1)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3*65537)|0;
 $5 = $1;
 $6 = $5 >>> 4;
 $7 = $0;
 $8 = (($6) + ($7))|0;
 $9 = $4 ^ $8;
 $$01112 = 0;$$013 = $9;
 while(1) {
  $10 = $$013 & 15;
  $11 = (($10) + 65)|0;
  $12 = $$013 << 1;
  $13 = $12 & 32;
  $14 = $11 | $13;
  $15 = $14&255;
  $16 = (($0) + ($$01112)|0);
  HEAP8[$16>>0] = $15;
  $17 = (($$01112) + 1)|0;
  $18 = $$013 >>> 5;
  $exitcond = ($17|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $$01112 = $17;$$013 = $18;
  }
 }
 STACKTOP = sp;return ($0|0);
}
function _open($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0;
 var $expanded = 0, $expanded2 = 0, $expanded4 = 0, $expanded5 = 0, $expanded6 = 0, $or$cond14 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer3 = sp + 32|0;
 $vararg_buffer = sp + 16|0;
 $2 = sp;
 $3 = $1 & 4194368;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
 } else {
  HEAP32[$2>>2] = $varargs;
  $arglist_current = HEAP32[$2>>2]|0;
  $5 = $arglist_current;
  $6 = ((0) + 4|0);
  $expanded2 = $6;
  $expanded = (($expanded2) - 1)|0;
  $7 = (($5) + ($expanded))|0;
  $8 = ((0) + 4|0);
  $expanded6 = $8;
  $expanded5 = (($expanded6) - 1)|0;
  $expanded4 = $expanded5 ^ -1;
  $9 = $7 & $expanded4;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $arglist_next = ((($10)) + 4|0);
  HEAP32[$2>>2] = $arglist_next;
  $$0 = $11;
 }
 $12 = $0;
 $13 = $1 | 32768;
 HEAP32[$vararg_buffer>>2] = $12;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $13;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $$0;
 $14 = (___syscall5(5,($vararg_buffer|0))|0);
 $15 = ($14|0)<(0);
 $16 = $1 & 524288;
 $17 = ($16|0)==(0);
 $or$cond14 = $17 | $15;
 if (!($or$cond14)) {
  HEAP32[$vararg_buffer3>>2] = $14;
  $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
  HEAP32[$vararg_ptr6>>2] = 2;
  $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
  HEAP32[$vararg_ptr7>>2] = 1;
  (___syscall221(221,($vararg_buffer3|0))|0);
 }
 $18 = (___syscall_ret($14)|0);
 STACKTOP = sp;return ($18|0);
}
function _mkstemps($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___mkostemps($0,$1,0)|0);
 return ($2|0);
}
function _mkostemp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___mkostemps($0,0,$1)|0);
 return ($2|0);
}
function _mktemp($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $1 = sp;
 $2 = (_strlen($0)|0);
 $3 = ($2>>>0)<(6);
 do {
  if ($3) {
   label = 4;
  } else {
   $4 = (($0) + ($2)|0);
   $5 = ((($4)) + -6|0);
   $6 = (_memcmp($5,(gb + (166518) | 0),6)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    $$0 = 100;
    while(1) {
     (___randname($5)|0);
     $9 = (_stat($0,$1)|0);
     $10 = ($9|0)==(0);
     if (!($10)) {
      break;
     }
     $14 = (($$0) + -1)|0;
     $15 = ($14|0)==(0);
     if ($15) {
      label = 9;
      break;
     } else {
      $$0 = $14;
     }
    }
    if ((label|0) == 9) {
     HEAP8[$0>>0] = 0;
     $16 = (___errno_location()|0);
     HEAP32[$16>>2] = 17;
     break;
    }
    $11 = (___errno_location()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(2);
    if (!($13)) {
     HEAP8[$0>>0] = 0;
    }
   } else {
    label = 4;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $8 = (___errno_location()|0);
  HEAP32[$8>>2] = 22;
  HEAP8[$0>>0] = 0;
 }
 STACKTOP = sp;return ($0|0);
}
function _stat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall195(195,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _mkdtemp($0) {
 $0 = $0|0;
 var $$0 = 0, $$014 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strlen($0)|0);
 $2 = ($1>>>0)<(6);
 L1: do {
  if ($2) {
   label = 4;
  } else {
   $3 = (($0) + ($1)|0);
   $4 = ((($3)) + -6|0);
   $5 = (_memcmp($4,(gb + (166518) | 0),6)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 100;
    while(1) {
     (___randname($4)|0);
     $8 = (_mkdir($0,448)|0);
     $9 = ($8|0)==(0);
     if ($9) {
      $$014 = $0;
      break L1;
     }
     $10 = (($$0) + -1)|0;
     $11 = ($10|0)==(0);
     if ($11) {
      break;
     }
     $12 = (___errno_location()|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(17);
     if ($14) {
      $$0 = $10;
     } else {
      break;
     }
    }
    (_memcpy(($4|0),((gb + (166518) | 0)|0),6)|0);
    $$014 = 0;
   } else {
    label = 4;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$014 = 0;
 }
 return ($$014|0);
}
function _mkdir($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall39(39,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _fmal($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = +$2;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_fma($0,$1,$2));
 return (+$3);
}
function _fma($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = +$2;
 var $$0 = 0.0, $$0$$0$6 = 0.0, $$083 = 0.0, $$sroa$0$0$copyload = 0.0, $$sroa$031$0$copyload = 0.0, $$sroa$5$0$$sroa_idx34 = 0, $$sroa$5$0$copyload = 0.0, $$sroa$7$0$$sroa_idx28 = 0, $$sroa$7$0$copyload = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $20 = 0.0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp + 48|0;
 $4 = sp + 44|0;
 $5 = sp + 40|0;
 $6 = sp + 24|0;
 $7 = sp + 8|0;
 $8 = sp;
 (___DOUBLE_BITS_44($0)|0);
 $9 = (getTempRet0() | 0);
 $10 = $9 & 2146435072;
 $11 = (0)==(0);
 $12 = ($10|0)==(2146435072);
 $13 = $11 & $12;
 L1: do {
  if ($13) {
   label = 3;
  } else {
   (___DOUBLE_BITS_44($1)|0);
   $14 = (getTempRet0() | 0);
   $15 = $14 & 2146435072;
   $16 = (0)==(0);
   $17 = ($15|0)==(2146435072);
   $18 = $16 & $17;
   if ($18) {
    label = 3;
   } else {
    $21 = (___DOUBLE_BITS_44($2)|0);
    $22 = (getTempRet0() | 0);
    $23 = $22 & 2146435072;
    $24 = (0)==(0);
    $25 = ($23|0)==(2146435072);
    $26 = $24 & $25;
    if ($26) {
     $$0 = $2;
    } else {
     $27 = $0 == 0.0;
     $28 = $1 == 0.0;
     $or$cond = $27 | $28;
     if ($or$cond) {
      $29 = $0 * $1;
      $30 = $29 + $2;
      $$0 = $30;
      break;
     }
     $31 = $2 == 0.0;
     if ($31) {
      $32 = $0 * $1;
      $$0 = $32;
      break;
     }
     $33 = (+_frexp($0,$3));
     $34 = (+_frexp($1,$4));
     $35 = (+_frexp($2,$5));
     $36 = (_fegetround()|0);
     $37 = HEAP32[$3>>2]|0;
     $38 = HEAP32[$4>>2]|0;
     $39 = (($38) + ($37))|0;
     $40 = HEAP32[$5>>2]|0;
     $41 = (($39) - ($40))|0;
     $42 = ($41|0)<(-53);
     if ($42) {
      (_i64Add(($21|0),($22|0),0,1048576)|0);
      $43 = (getTempRet0() | 0);
      $44 = $43 & 2145386496;
      $45 = (0)==(0);
      $46 = ($44|0)==(0);
      $47 = $45 & $46;
      if ($47) {
      }
      switch ($36|0) {
      case 3072:  {
       $48 = $0 > 0.0;
       $49 = $1 < 0.0;
       $50 = $48 ^ $49;
       $51 = $2 < 0.0;
       $52 = $50 ^ $51;
       if ($52) {
        $$0 = $2;
        break L1;
       }
       $53 = (+_nextafter($2,0.0));
       $$0 = $53;
       break L1;
       break;
      }
      case 1024:  {
       $54 = $0 > 0.0;
       $55 = $1 < 0.0;
       $56 = $54 ^ $55;
       if ($56) {
        $$0 = $2;
        break L1;
       }
       $57 = (+_nextafter($2,-inf));
       $$0 = $57;
       break L1;
       break;
      }
      case 2048:  {
       $58 = $0 > 0.0;
       $59 = $1 < 0.0;
       $60 = $58 ^ $59;
       if (!($60)) {
        $$0 = $2;
        break L1;
       }
       $61 = (+_nextafter($2,inf));
       $$0 = $61;
       break L1;
       break;
      }
      default: {
       $$0 = $2;
       break L1;
      }
      }
     }
     $62 = ($41|0)<(107);
     if ($62) {
      $63 = (0 - ($41))|0;
      $64 = (+_scalbn($35,$63));
      $$083 = $64;
     } else {
      $65 = (+_copysign(2.2250738585072014E-308,$35));
      $$083 = $65;
     }
     (_fesetround(0)|0);
     _dd_mul($6,$33,$34);
     $$sroa$031$0$copyload = +HEAPF64[$6>>3];
     $$sroa$5$0$$sroa_idx34 = ((($6)) + 8|0);
     $$sroa$5$0$copyload = +HEAPF64[$$sroa$5$0$$sroa_idx34>>3];
     _dd_add($7,$$sroa$031$0$copyload,$$083);
     $$sroa$0$0$copyload = +HEAPF64[$7>>3];
     $$sroa$7$0$$sroa_idx28 = ((($7)) + 8|0);
     $$sroa$7$0$copyload = +HEAPF64[$$sroa$7$0$$sroa_idx28>>3];
     $66 = $$sroa$0$0$copyload == 0.0;
     if ($66) {
      (_fesetround($36)|0);
      HEAPF64[$8>>3] = $$083;
      $$0$$0$6 = +HEAPF64[$8>>3];
      $67 = $$sroa$031$0$copyload + $$0$$0$6;
      $68 = (+_scalbn($$sroa$5$0$copyload,$39));
      $69 = $67 + $68;
      $$0 = $69;
      break;
     }
     $70 = ($36|0)==(0);
     if ($70) {
      $80 = (+_add_adjusted($$sroa$7$0$copyload,$$sroa$5$0$copyload));
      $81 = (_ilogb($$sroa$0$0$copyload)|0);
      $82 = (($81) + ($39))|0;
      $83 = ($82|0)>(-1023);
      if ($83) {
       $84 = $$sroa$0$0$copyload + $80;
       $85 = (+_scalbn($84,$39));
       $$0 = $85;
       break;
      } else {
       $86 = (+_add_and_denormalize($$sroa$0$0$copyload,$80,$39));
       $$0 = $86;
       break;
      }
     }
     $71 = (_fetestexcept(32)|0);
     (_fesetround($36)|0);
     $72 = $$sroa$5$0$copyload + $$sroa$7$0$copyload;
     $73 = $$sroa$0$0$copyload + $72;
     $74 = (+_scalbn($73,$39));
     $75 = (_ilogb($74)|0);
     $76 = ($75|0)<(-1022);
     if ($76) {
      $77 = (_fetestexcept(32)|0);
      $78 = ($77|0)==(0);
      if (!($78)) {
       $$0 = $74;
       break;
      }
     }
     $79 = ($71|0)==(0);
     if ($79) {
      $$0 = $74;
     } else {
      $$0 = $74;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $19 = $0 * $1;
  $20 = $19 + $2;
  $$0 = $20;
 }
 STACKTOP = sp;return (+$$0);
}
function ___DOUBLE_BITS_44($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _frexp($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$016 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $storemerge = 0, $trunc$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $5 = (getTempRet0() | 0);
 $6 = $4&65535;
 $trunc$clear = $6 & 2047;
 switch ($trunc$clear<<16>>16) {
 case 0:  {
  $7 = $0 != 0.0;
  if ($7) {
   $8 = $0 * 1.8446744073709552E+19;
   $9 = (+_frexp($8,$1));
   $10 = HEAP32[$1>>2]|0;
   $11 = (($10) + -64)|0;
   $$016 = $9;$storemerge = $11;
  } else {
   $$016 = $0;$storemerge = 0;
  }
  HEAP32[$1>>2] = $storemerge;
  $$0 = $$016;
  break;
 }
 case 2047:  {
  $$0 = $0;
  break;
 }
 default: {
  $12 = $4 & 2047;
  $13 = (($12) + -1022)|0;
  HEAP32[$1>>2] = $13;
  $14 = $3 & -2146435073;
  $15 = $14 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $2;HEAP32[tempDoublePtr+4>>2] = $15;$16 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $16;
 }
 }
 return (+$$0);
}
function _fegetround() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _feraiseexcept($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _nextafter($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0.0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = (___DOUBLE_BITS_70($0)|0);
 $7 = (getTempRet0() | 0);
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)>(2146435072);
 $10 = ($6>>>0)>(0);
 $11 = ($8|0)==(2146435072);
 $12 = $11 & $10;
 $13 = $9 | $12;
 L1: do {
  if ($13) {
   label = 3;
  } else {
   $14 = (___DOUBLE_BITS_70($1)|0);
   $15 = (getTempRet0() | 0);
   $16 = $15 & 2147483647;
   $17 = ($16>>>0)>(2146435072);
   $18 = ($14>>>0)>(0);
   $19 = ($16|0)==(2146435072);
   $20 = $19 & $18;
   $21 = $17 | $20;
   if ($21) {
    label = 3;
   } else {
    $23 = ($2|0)==($4|0);
    $24 = ($3|0)==($5|0);
    $25 = $23 & $24;
    if ($25) {
     $$0 = $1;
    } else {
     $26 = $3 & 2147483647;
     $27 = $5 & 2147483647;
     $28 = ($2|0)==(0);
     $29 = ($26|0)==(0);
     $30 = $28 & $29;
     do {
      if ($30) {
       $31 = ($4|0)==(0);
       $32 = ($27|0)==(0);
       $33 = $31 & $32;
       if ($33) {
        $$0 = $1;
        break L1;
       }
       $34 = $5 & -2147483648;
       $47 = $34;$48 = 1;
      } else {
       $35 = ($26>>>0)>($27>>>0);
       $36 = ($2>>>0)>($4>>>0);
       $37 = ($26|0)==($27|0);
       $38 = $37 & $36;
       $39 = $35 | $38;
       $4 ^ $2;
       $40 = $5 ^ $3;
       $41 = ($40|0)<(0);
       $or$cond = $39 | $41;
       if ($or$cond) {
        $42 = (_i64Add(($2|0),($3|0),-1,-1)|0);
        $43 = (getTempRet0() | 0);
        $47 = $43;$48 = $42;
        break;
       } else {
        $44 = (_i64Add(($2|0),($3|0),1,0)|0);
        $45 = (getTempRet0() | 0);
        $47 = $45;$48 = $44;
        break;
       }
      }
     } while(0);
     HEAP32[tempDoublePtr>>2] = $48;HEAP32[tempDoublePtr+4>>2] = $47;$46 = +HEAPF64[tempDoublePtr>>3];
     $$0 = $46;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $22 = $0 + $1;
  $$0 = $22;
 }
 return (+$$0);
}
function _scalbn($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$020 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0;
 var $9 = 0, $spec$select = 0, $spec$select21 = 0.0, $spec$select22 = 0, $spec$select23 = 0.0, $spec$store$select = 0, $spec$store$select1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)>(1023);
 if ($2) {
  $3 = $0 * 8.9884656743115795E+307;
  $4 = (($1) + -1023)|0;
  $5 = ($1|0)>(2046);
  $6 = $3 * 8.9884656743115795E+307;
  $7 = (($1) + -2046)|0;
  $8 = ($7|0)<(1023);
  $spec$store$select = $8 ? $7 : 1023;
  $spec$select = $5 ? $spec$store$select : $4;
  $spec$select21 = $5 ? $6 : $3;
  $$0 = $spec$select21;$$020 = $spec$select;
 } else {
  $9 = ($1|0)<(-1022);
  if ($9) {
   $10 = $0 * 2.2250738585072014E-308;
   $11 = (($1) + 1022)|0;
   $12 = ($1|0)<(-2044);
   $13 = $10 * 2.2250738585072014E-308;
   $14 = (($1) + 2044)|0;
   $15 = ($14|0)>(-1022);
   $spec$store$select1 = $15 ? $14 : -1022;
   $spec$select22 = $12 ? $spec$store$select1 : $11;
   $spec$select23 = $12 ? $13 : $10;
   $$0 = $spec$select23;$$020 = $spec$select22;
  } else {
   $$0 = $0;$$020 = $1;
  }
 }
 $16 = (($$020) + 1023)|0;
 $17 = (_bitshift64Shl(($16|0),0,52)|0);
 $18 = (getTempRet0() | 0);
 HEAP32[tempDoublePtr>>2] = $17;HEAP32[tempDoublePtr+4>>2] = $18;$19 = +HEAPF64[tempDoublePtr>>3];
 $20 = $$0 * $19;
 return (+$20);
}
function _copysign($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = $3 & 2147483647;
 $7 = $5 & -2147483648;
 $8 = $7 | $6;
 HEAP32[tempDoublePtr>>2] = $2;HEAP32[tempDoublePtr+4>>2] = $8;$9 = +HEAPF64[tempDoublePtr>>3];
 return (+$9);
}
function _fesetround($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 & -3073;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (___fesetround($0)|0);
  $$0 = $3;
 } else {
  $$0 = -1;
 }
 return ($$0|0);
}
function _dd_mul($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $$sroa$5$0$$sroa_idx32 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1 * 134217729.0;
 $4 = $1 - $3;
 $5 = $3 + $4;
 $6 = $1 - $5;
 $7 = $2 * 134217729.0;
 $8 = $2 - $7;
 $9 = $7 + $8;
 $10 = $2 - $9;
 $11 = $5 * $9;
 $12 = $5 * $10;
 $13 = $6 * $9;
 $14 = $13 + $12;
 $15 = $11 + $14;
 $16 = $11 - $15;
 $17 = $14 + $16;
 $18 = $6 * $10;
 $19 = $18 + $17;
 HEAPF64[$0>>3] = $15;
 $$sroa$5$0$$sroa_idx32 = ((($0)) + 8|0);
 HEAPF64[$$sroa$5$0$$sroa_idx32>>3] = $19;
 return;
}
function _dd_add($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 var $$sroa$6$0$$sroa_idx5 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1 + $2;
 $4 = $3 - $1;
 $5 = $3 - $4;
 $6 = $1 - $5;
 $7 = $2 - $4;
 $8 = $7 + $6;
 HEAPF64[$0>>3] = $3;
 $$sroa$6$0$$sroa_idx5 = ((($0)) + 8|0);
 HEAPF64[$$sroa$6$0$$sroa_idx5>>3] = $8;
 return;
}
function _fetestexcept($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _feclearexcept($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _ilogb($0) {
 $0 = +$0;
 var $$016 = 0, $$018 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3&65535;
 $trunc$clear = $5 & 2047;
 switch ($trunc$clear<<16>>16) {
 case 0:  {
  $6 = (_bitshift64Shl(($1|0),($2|0),12)|0);
  $7 = (getTempRet0() | 0);
  $8 = ($6|0)==(0);
  $9 = ($7|0)==(0);
  $10 = $8 & $9;
  if ($10) {
   $$016 = -2147483648;
  } else {
   $11 = ($7|0)>(-1);
   $12 = ($6>>>0)>(4294967295);
   $13 = ($7|0)==(-1);
   $14 = $13 & $12;
   $15 = $11 | $14;
   if ($15) {
    $$018 = -1023;$17 = $6;$18 = $7;
    while(1) {
     $16 = (($$018) + -1)|0;
     $19 = (_bitshift64Shl(($17|0),($18|0),1)|0);
     $20 = (getTempRet0() | 0);
     $21 = ($20|0)>(-1);
     $22 = ($19>>>0)>(4294967295);
     $23 = ($20|0)==(-1);
     $24 = $23 & $22;
     $25 = $21 | $24;
     if ($25) {
      $$018 = $16;$17 = $19;$18 = $20;
     } else {
      $$016 = $16;
      break;
     }
    }
   } else {
    $$016 = -1023;
   }
  }
  break;
 }
 case 2047:  {
  $26 = $2 & 1048575;
  $27 = ($1|0)==(0);
  $28 = ($26|0)==(0);
  $29 = $27 & $28;
  $30 = $29 ? 2147483647 : -2147483648;
  $$016 = $30;
  break;
 }
 default: {
  $31 = $3 & 2047;
  $32 = (($31) + -1023)|0;
  $$016 = $32;
 }
 }
 return ($$016|0);
}
function _add_adjusted($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$sroa$06$0$copyload = 0.0, $$sroa$6$0$$sroa_idx9 = 0, $$sroa$6$0$copyload = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 _dd_add($2,$0,$1);
 $$sroa$06$0$copyload = +HEAPF64[$2>>3];
 $$sroa$6$0$$sroa_idx9 = ((($2)) + 8|0);
 $$sroa$6$0$copyload = +HEAPF64[$$sroa$6$0$$sroa_idx9>>3];
 $3 = $$sroa$6$0$copyload != 0.0;
 if ($3) {
  HEAPF64[tempDoublePtr>>3] = $$sroa$06$0$copyload;$4 = HEAP32[tempDoublePtr>>2]|0;
  $5 = HEAP32[tempDoublePtr+4>>2]|0;
  $6 = $4 & 1;
  $7 = ($6|0)==(0);
  $8 = (0)==(0);
  $9 = $7 & $8;
  HEAPF64[tempDoublePtr>>3] = $$sroa$6$0$copyload;$10 = HEAP32[tempDoublePtr>>2]|0;
  $11 = HEAP32[tempDoublePtr+4>>2]|0;
  $12 = $10 ^ $4;
  $13 = $11 ^ $5;
  $14 = (_bitshift64Lshr(($12|0),($13|0),62)|0);
  $15 = (getTempRet0() | 0);
  $16 = (_i64Add(($4|0),($5|0),1,0)|0);
  $17 = (getTempRet0() | 0);
  $18 = (_i64Subtract(($16|0),($17|0),($14|0),($15|0))|0);
  $19 = (getTempRet0() | 0);
  HEAP32[tempDoublePtr>>2] = $18;HEAP32[tempDoublePtr+4>>2] = $19;$20 = +HEAPF64[tempDoublePtr>>3];
  $spec$select = $9 ? $20 : $$sroa$06$0$copyload;
  STACKTOP = sp;return (+$spec$select);
 } else {
  STACKTOP = sp;return (+$$sroa$06$0$copyload);
 }
 return +(0.0);
}
function _add_and_denormalize($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $$sroa$08$0 = 0.0, $$sroa$08$0$copyload = 0.0, $$sroa$6$0$$sroa_idx11 = 0, $$sroa$6$0$copyload = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 _dd_add($3,$0,$1);
 $$sroa$08$0$copyload = +HEAPF64[$3>>3];
 $$sroa$6$0$$sroa_idx11 = ((($3)) + 8|0);
 $$sroa$6$0$copyload = +HEAPF64[$$sroa$6$0$$sroa_idx11>>3];
 $4 = $$sroa$6$0$copyload != 0.0;
 if ($4) {
  HEAPF64[tempDoublePtr>>3] = $$sroa$08$0$copyload;$5 = HEAP32[tempDoublePtr>>2]|0;
  $6 = HEAP32[tempDoublePtr+4>>2]|0;
  $7 = (_bitshift64Lshr(($5|0),($6|0),52)|0);
  $8 = (getTempRet0() | 0);
  $9 = $7 & 2047;
  $10 = (0 - ($9))|0;
  $11 = ($10|0)!=($2|0);
  $12 = $5 & 1;
  $13 = ($12|0)!=(0);
  $14 = (0)!=(0);
  $15 = $13 | $14;
  $16 = $15 ^ $11;
  HEAPF64[tempDoublePtr>>3] = $$sroa$6$0$copyload;$17 = HEAP32[tempDoublePtr>>2]|0;
  $18 = HEAP32[tempDoublePtr+4>>2]|0;
  $19 = $17 ^ $5;
  $20 = $18 ^ $6;
  $21 = (_bitshift64Lshr(($19|0),($20|0),62)|0);
  $22 = (getTempRet0() | 0);
  $23 = $21 & 2;
  $24 = (_i64Add(($5|0),($6|0),1,0)|0);
  $25 = (getTempRet0() | 0);
  $26 = (_i64Subtract(($24|0),($25|0),($23|0),0)|0);
  $27 = (getTempRet0() | 0);
  HEAP32[tempDoublePtr>>2] = $26;HEAP32[tempDoublePtr+4>>2] = $27;$28 = +HEAPF64[tempDoublePtr>>3];
  $spec$select = $16 ? $28 : $$sroa$08$0$copyload;
  $$sroa$08$0 = $spec$select;
 } else {
  $$sroa$08$0 = $$sroa$08$0$copyload;
 }
 $29 = (+_scalbn($$sroa$08$0,$2));
 STACKTOP = sp;return (+$29);
}
function ___fesetround($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function ___DOUBLE_BITS_70($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _lrintl($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_lrint($0)|0);
 return ($1|0);
}
function _lrint($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_fetestexcept(32)|0);
 $2 = (+_rint($0));
 $3 = ($1|0)==(0);
 if ($3) {
  $4 = $2 > 2147483647.0;
  $5 = $2 < -2147483648.0;
  $or$cond = $4 | $5;
  if ($or$cond) {
  }
 }
 $6 = (~~(($2)));
 return ($6|0);
}
function _rint($0) {
 $0 = +$0;
 var $$0 = 0.0, $$015 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2146435072;
 $4 = ($3>>>0)>(1126170624);
 $5 = (0)>(0);
 $6 = ($3|0)==(1126170624);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  $$015 = $0;
 } else {
  $9 = ($2|0)<(0);
  $10 = $0 + -4503599627370496.0;
  $11 = $10 + 4503599627370496.0;
  $12 = $0 + 4503599627370496.0;
  $13 = $12 + -4503599627370496.0;
  $$0 = $9 ? $11 : $13;
  $14 = $$0 == 0.0;
  if ($14) {
   $15 = $9 ? -0.0 : 0.0;
   $$015 = $15;
  } else {
   $$015 = $$0;
  }
 }
 return (+$$015);
}
function _lroundf($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_roundf((+$0)));
 $2 = (~~(($1)));
 return ($2|0);
}
function _nearbyintl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_nearbyint($0));
 return (+$1);
}
function _nearbyint($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_fetestexcept(32)|0);
 $2 = (+_rint($0));
 $3 = ($1|0)==(0);
 if ($3) {
 }
 return (+$2);
}
function _acoshl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_acosh($0));
 return (+$1);
}
function _acosh($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 & 2047;
 $6 = ($5>>>0)<(1024);
 do {
  if ($6) {
   $7 = $0 + -1.0;
   $8 = $7 * $7;
   $9 = $7 * 2.0;
   $10 = $8 + $9;
   $11 = (+Math_sqrt((+$10)));
   $12 = $7 + $11;
   $13 = (+_log1p($12));
   $$0 = $13;
  } else {
   $14 = ($5>>>0)<(1049);
   if ($14) {
    $15 = $0 * 2.0;
    $16 = $0 * $0;
    $17 = $16 + -1.0;
    $18 = (+Math_sqrt((+$17)));
    $19 = $18 + $0;
    $20 = 1.0 / $19;
    $21 = $15 - $20;
    $22 = (+Math_log((+$21)));
    $$0 = $22;
    break;
   } else {
    $23 = (+Math_log((+$0)));
    $24 = $23 + 0.69314718055994529;
    $$0 = $24;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _log1p($0) {
 $0 = +$0;
 var $$081 = 0.0, $$1 = 0.0, $$183 = 0.0, $$185 = 0.0, $$2 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0;
 var $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0;
 var $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, $or$cond = 0, $phitmp = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = ($2>>>0)<(1071284858);
 $4 = ($2|0)<(0);
 $or$cond = $4 | $3;
 do {
  if ($or$cond) {
   $5 = ($2>>>0)>(3220176895);
   if ($5) {
    $6 = $0 == -1.0;
    if ($6) {
     $$081 = -inf;
     break;
    }
    $7 = $0 - $0;
    $8 = $7 / 0.0;
    $$081 = $8;
    break;
   } else {
    $9 = (_bitshift64Shl(($2|0),0,1)|0);
    $10 = (getTempRet0() | 0);
    $11 = ($9>>>0)<(2034237440);
    if ($11) {
     $$081 = $0;
     break;
    }
    $12 = ($2>>>0)<(3218259653);
    if ($12) {
     $$1 = 0.0;$$183 = $0;$$2 = 0.0;
     label = 11;
     break;
    } else {
     label = 8;
     break;
    }
   }
  } else {
   $13 = ($2>>>0)>(2146435071);
   if ($13) {
    $$081 = $0;
   } else {
    label = 8;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $14 = $0 + 1.0;
  HEAPF64[tempDoublePtr>>3] = $14;$15 = HEAP32[tempDoublePtr>>2]|0;
  $16 = HEAP32[tempDoublePtr+4>>2]|0;
  $17 = (($16) + 614242)|0;
  $18 = $17 >>> 20;
  $19 = (($18) + -1023)|0;
  $20 = ($17>>>0)<(1129316352);
  if ($20) {
   $21 = ($17>>>0)>(1074790399);
   $22 = $14 - $0;
   $23 = 1.0 - $22;
   $24 = $14 + -1.0;
   $25 = $0 - $24;
   $26 = $21 ? $23 : $25;
   $27 = $26 / $14;
   $$185 = $27;
  } else {
   $$185 = 0.0;
  }
  $28 = $17 & 1048575;
  $29 = (($28) + 1072079006)|0;
  HEAP32[tempDoublePtr>>2] = $15;HEAP32[tempDoublePtr+4>>2] = $29;$30 = +HEAPF64[tempDoublePtr>>3];
  $31 = $30 + -1.0;
  $phitmp = (+($19|0));
  $$1 = $phitmp;$$183 = $31;$$2 = $$185;
  label = 11;
 }
 if ((label|0) == 11) {
  $32 = $$183 * 0.5;
  $33 = $$183 * $32;
  $34 = $$183 + 2.0;
  $35 = $$183 / $34;
  $36 = $35 * $35;
  $37 = $36 * $36;
  $38 = $37 * 0.15313837699209373;
  $39 = $38 + 0.22222198432149784;
  $40 = $37 * $39;
  $41 = $40 + 0.39999999999409419;
  $42 = $37 * $41;
  $43 = $37 * 0.14798198605116586;
  $44 = $43 + 0.1818357216161805;
  $45 = $37 * $44;
  $46 = $45 + 0.28571428743662391;
  $47 = $37 * $46;
  $48 = $47 + 0.66666666666667351;
  $49 = $36 * $48;
  $50 = $42 + $49;
  $51 = $33 + $50;
  $52 = $35 * $51;
  $53 = $$1 * 1.9082149292705877E-10;
  $54 = $$2 + $53;
  $55 = $54 + $52;
  $56 = $55 - $33;
  $57 = $$183 + $56;
  $58 = $$1 * 0.69314718036912382;
  $59 = $58 + $57;
  $$081 = $59;
 }
 return (+$$081);
}
function _j0($0) {
 $0 = +$0;
 var $$0 = 0.0, $$035 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2146435071);
 do {
  if ($4) {
   $5 = $0 * $0;
   $6 = 1.0 / $5;
   $$0 = $6;
  } else {
   $7 = (+Math_abs((+$0)));
   $8 = ($3>>>0)>(1073741823);
   if ($8) {
    $9 = (+_common($3,$7,0));
    $$0 = $9;
    break;
   }
   $10 = ($3>>>0)>(1059061759);
   if ($10) {
    $11 = $7 * $7;
    $12 = $11 * 4.6183268853210319E-9;
    $13 = 1.8295404953270067E-6 - $12;
    $14 = $11 * $13;
    $15 = $14 + -1.8997929423885472E-4;
    $16 = $11 * $15;
    $17 = $16 + 0.015624999999999995;
    $18 = $11 * $17;
    $19 = $11 * 1.1661400333379E-9;
    $20 = $19 + 5.1354655020731811E-7;
    $21 = $11 * $20;
    $22 = $21 + 1.1692678466333745E-4;
    $23 = $11 * $22;
    $24 = $23 + 0.015619102946489001;
    $25 = $11 * $24;
    $26 = $25 + 1.0;
    $27 = $7 * 0.5;
    $28 = $27 + 1.0;
    $29 = 1.0 - $27;
    $30 = $28 * $29;
    $31 = $18 / $26;
    $32 = $11 * $31;
    $33 = $30 + $32;
    $$0 = $33;
    break;
   } else {
    $34 = ($3>>>0)>(939524095);
    $35 = $7 * 0.25;
    $36 = $7 * $35;
    $$035 = $34 ? $36 : $7;
    $37 = 1.0 - $$035;
    $$0 = $37;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _common($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$032 = 0.0, $$033 = 0.0, $$1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, $spec$select = 0.0, $spec$select35 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+Math_sin((+$1)));
 $4 = (+Math_cos((+$1)));
 $5 = ($2|0)!=(0);
 $6 = - $4;
 $spec$select = $5 ? $6 : $4;
 $7 = $3 + $spec$select;
 $8 = ($0>>>0)<(2145386496);
 if ($8) {
  $9 = $3 - $spec$select;
  $10 = $1 * 2.0;
  $11 = (+Math_cos((+$10)));
  $12 = - $11;
  $13 = $3 * $spec$select;
  $14 = $13 < 0.0;
  if ($14) {
   $15 = $12 / $9;
   $$032 = $15;$$033 = $9;
  } else {
   $16 = $12 / $7;
   $$032 = $7;$$033 = $16;
  }
  $17 = ($0>>>0)<(1207959552);
  if ($17) {
   $18 = - $$033;
   $spec$select35 = $5 ? $18 : $$033;
   $19 = (+_pzero($1));
   $20 = $$032 * $19;
   $21 = (+_qzero($1));
   $22 = $spec$select35 * $21;
   $23 = $20 - $22;
   $$1 = $23;
  } else {
   $$1 = $$032;
  }
 } else {
  $$1 = $7;
 }
 $24 = $$1 * 0.56418958354775628;
 $25 = (+Math_sqrt((+$1)));
 $26 = $24 / $25;
 return (+$26);
}
function _pzero($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$041 = 0, $$42 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(1075838975);
 if ($4) {
  $$0 = (gb + (2944) | 0);$$041 = (gb + (2848) | 0);
 } else {
  $5 = ($3>>>0)>(1074933386);
  $6 = ($3>>>0)>(1074191212);
  if ($5) {
   $$0 = (gb + (2992) | 0);$$041 = (gb + (2896) | 0);
  } else {
   $$42 = $6 ? (gb + (2656) | 0) : (gb + (2704) | 0);
   $$ = $6 ? (gb + (2752) | 0) : (gb + (2800) | 0);
   $$0 = $$42;$$041 = $$;
  }
 }
 $7 = $0 * $0;
 $8 = 1.0 / $7;
 $9 = +HEAPF64[$$0>>3];
 $10 = ((($$0)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($$0)) + 16|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($$0)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($$0)) + 32|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($$0)) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $8 * $19;
 $21 = $17 + $20;
 $22 = $8 * $21;
 $23 = $15 + $22;
 $24 = $8 * $23;
 $25 = $13 + $24;
 $26 = $8 * $25;
 $27 = $11 + $26;
 $28 = $8 * $27;
 $29 = $9 + $28;
 $30 = +HEAPF64[$$041>>3];
 $31 = ((($$041)) + 8|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($$041)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($$041)) + 24|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($$041)) + 32|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $8 * $38;
 $40 = $36 + $39;
 $41 = $8 * $40;
 $42 = $34 + $41;
 $43 = $8 * $42;
 $44 = $32 + $43;
 $45 = $8 * $44;
 $46 = $30 + $45;
 $47 = $8 * $46;
 $48 = $47 + 1.0;
 $49 = $29 / $48;
 $50 = $49 + 1.0;
 return (+$50);
}
function _qzero($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$044 = 0, $$45 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(1075838975);
 if ($4) {
  $$0 = (gb + (2560) | 0);$$044 = (gb + (2464) | 0);
 } else {
  $5 = ($3>>>0)>(1074933386);
  $6 = ($3>>>0)>(1074191212);
  if ($5) {
   $$0 = (gb + (2608) | 0);$$044 = (gb + (2512) | 0);
  } else {
   $$45 = $6 ? (gb + (2272) | 0) : (gb + (2320) | 0);
   $$ = $6 ? (gb + (2368) | 0) : (gb + (2416) | 0);
   $$0 = $$45;$$044 = $$;
  }
 }
 $7 = $0 * $0;
 $8 = 1.0 / $7;
 $9 = +HEAPF64[$$0>>3];
 $10 = ((($$0)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($$0)) + 16|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($$0)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($$0)) + 32|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($$0)) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $8 * $19;
 $21 = $17 + $20;
 $22 = $8 * $21;
 $23 = $15 + $22;
 $24 = $8 * $23;
 $25 = $13 + $24;
 $26 = $8 * $25;
 $27 = $11 + $26;
 $28 = $8 * $27;
 $29 = $9 + $28;
 $30 = +HEAPF64[$$044>>3];
 $31 = ((($$044)) + 8|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($$044)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($$044)) + 24|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($$044)) + 32|0);
 $38 = +HEAPF64[$37>>3];
 $39 = ((($$044)) + 40|0);
 $40 = +HEAPF64[$39>>3];
 $41 = $8 * $40;
 $42 = $38 + $41;
 $43 = $8 * $42;
 $44 = $36 + $43;
 $45 = $8 * $44;
 $46 = $34 + $45;
 $47 = $8 * $46;
 $48 = $32 + $47;
 $49 = $8 * $48;
 $50 = $30 + $49;
 $51 = $8 * $50;
 $52 = $51 + 1.0;
 $53 = $29 / $52;
 $54 = $53 + -0.125;
 $55 = $54 / $0;
 return (+$55);
}
function _y0($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Shl(($2|0),0,1)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 | $1;
 $4 | $2;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $$0 = -inf;
  } else {
   $7 = ($2|0)<(0);
   if ($7) {
    $$0 = nan;
   } else {
    $8 = ($2>>>0)>(2146435071);
    if ($8) {
     $9 = 1.0 / $0;
     $$0 = $9;
     break;
    }
    $10 = ($2>>>0)>(1073741823);
    if ($10) {
     $11 = (+_common($2,$0,1));
     $$0 = $11;
     break;
    }
    $12 = ($2>>>0)>(1044381695);
    if ($12) {
     $13 = $0 * $0;
     $14 = $13 * 3.982051941321034E-11;
     $15 = 1.9559013703502292E-8 - $14;
     $16 = $13 * $15;
     $17 = $16 + -3.8140705372436416E-6;
     $18 = $13 * $17;
     $19 = $18 + 3.4745343209368365E-4;
     $20 = $13 * $19;
     $21 = $20 + -0.01381856719455969;
     $22 = $13 * $21;
     $23 = $22 + 0.17666645250918112;
     $24 = $13 * $23;
     $25 = $24 + -0.073804295108687232;
     $26 = $13 * 4.4111031133267547E-10;
     $27 = $26 + 2.5915085184045781E-7;
     $28 = $13 * $27;
     $29 = $28 + 7.6006862735035325E-5;
     $30 = $13 * $29;
     $31 = $30 + 0.01273048348341237;
     $32 = $13 * $31;
     $33 = $32 + 1.0;
     $34 = $25 / $33;
     $35 = (+_j0($0));
     $36 = (+Math_log((+$0)));
     $37 = $35 * $36;
     $38 = $37 * 0.63661977236758138;
     $39 = $34 + $38;
     $$0 = $39;
     break;
    } else {
     $40 = (+Math_log((+$0)));
     $41 = $40 * 0.63661977236758138;
     $42 = $41 + -0.073804295108687232;
     $$0 = $42;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function _frexpf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$016 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = $2 >>> 23;
 $trunc = $3&255;
 switch ($trunc<<24>>24) {
 case 0:  {
  $4 = $0 != 0.0;
  if ($4) {
   $5 = $0 * 1.8446744073709552E+19;
   $6 = (+_frexpf($5,$1));
   $7 = HEAP32[$1>>2]|0;
   $8 = (($7) + -64)|0;
   $$016 = $6;$storemerge = $8;
  } else {
   $$016 = $0;$storemerge = 0;
  }
  HEAP32[$1>>2] = $storemerge;
  $$0 = $$016;
  break;
 }
 case -1:  {
  $$0 = $0;
  break;
 }
 default: {
  $9 = $3 & 255;
  $10 = (($9) + -126)|0;
  HEAP32[$1>>2] = $10;
  $11 = $2 & -2139095041;
  $12 = $11 | 1056964608;
  $13 = (HEAP32[tempDoublePtr>>2]=$12,+HEAPF32[tempDoublePtr>>2]);
  $$0 = $13;
 }
 }
 return (+$$0);
}
function _logbl($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 (___DOUBLE_BITS($0)|0);
 $1 = (getTempRet0() | 0);
 $2 = $1 & 2146435072;
 $3 = (0)==(0);
 $4 = ($2|0)==(2146435072);
 $5 = $3 & $4;
 do {
  if ($5) {
   $6 = $0 * $0;
   $$0 = $6;
  } else {
   $7 = $0 == 0.0;
   if ($7) {
    $8 = $0 * $0;
    $9 = -1.0 / $8;
    $$0 = $9;
    break;
   } else {
    $10 = (_ilogbl($0)|0);
    $11 = (+($10|0));
    $$0 = $11;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function ___DOUBLE_BITS($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _ilogbl($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ilogb($0)|0);
 return ($1|0);
}
function _exp2($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(1083174911);
 do {
  if ($4) {
   $5 = ($3>>>0)>(1083179007);
   $6 = ($2|0)>(-1);
   $7 = ($1>>>0)>(4294967295);
   $8 = ($2|0)==(-1);
   $9 = $8 & $7;
   $10 = $6 | $9;
   $or$cond = $10 & $5;
   if ($or$cond) {
    $11 = $0 * 8.9884656743115795E+307;
    $$0 = $11;
    break;
   }
   $12 = ($3>>>0)>(2146435071);
   if ($12) {
    $13 = -1.0 / $0;
    $$0 = $13;
    break;
   } else {
    $14 = !($0 <= -1075.0);
    $or$cond43 = $14 | $10;
    if ($or$cond43) {
     label = 9;
     break;
    } else {
     $$0 = 0.0;
     break;
    }
   }
  } else {
   $15 = ($3>>>0)<(1016070144);
   if ($15) {
    $16 = $0 + 1.0;
    $$0 = $16;
   } else {
    label = 9;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $17 = $0 + 26388279066624.0;
  HEAPF64[tempDoublePtr>>3] = $17;$18 = HEAP32[tempDoublePtr>>2]|0;
  $19 = HEAP32[tempDoublePtr+4>>2]|0;
  $20 = (($18) + 128)|0;
  $21 = $20 & -256;
  $22 = (($21|0) / 256)&-1;
  $23 = $17 + -26388279066624.0;
  $24 = $0 - $23;
  $25 = $20 << 1;
  $26 = $25 & 510;
  $27 = ((gb + (3040) | 0) + ($26<<3)|0);
  $28 = +HEAPF64[$27>>3];
  $29 = $26 | 1;
  $30 = ((gb + (3040) | 0) + ($29<<3)|0);
  $31 = +HEAPF64[$30>>3];
  $32 = $24 - $31;
  $33 = $28 * $32;
  $34 = $32 * 0.0013333559164630223;
  $35 = $34 + 0.0096181298421260663;
  $36 = $32 * $35;
  $37 = $36 + 0.055504108664821403;
  $38 = $32 * $37;
  $39 = $38 + 0.2402265069591;
  $40 = $32 * $39;
  $41 = $40 + 0.69314718055994529;
  $42 = $33 * $41;
  $43 = $28 + $42;
  $44 = (+_scalbn($43,$22));
  $$0 = $44;
 }
 return (+$$0);
}
function _sincos($0,$1,$2) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0.0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAPF64[tempDoublePtr>>3] = $0;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6>>>0)<(1072243196);
 L1: do {
  if ($7) {
   $8 = ($6>>>0)<(1044816030);
   if ($8) {
    HEAPF64[$1>>3] = $0;
    HEAPF64[$2>>3] = 1.0;
    break;
   } else {
    $9 = (+___sin($0,0.0,0));
    HEAPF64[$1>>3] = $9;
    $10 = (+___cos($0,0.0));
    HEAPF64[$2>>3] = $10;
    break;
   }
  } else {
   $11 = ($6>>>0)>(2146435071);
   if ($11) {
    $12 = $0 - $0;
    HEAPF64[$2>>3] = $12;
    HEAPF64[$1>>3] = $12;
    break;
   }
   $13 = (___rem_pio2($0,$3)|0);
   $14 = +HEAPF64[$3>>3];
   $15 = ((($3)) + 8|0);
   $16 = +HEAPF64[$15>>3];
   $17 = (+___sin($14,$16,1));
   $18 = +HEAPF64[$3>>3];
   $19 = +HEAPF64[$15>>3];
   $20 = (+___cos($18,$19));
   $trunc = $13&255;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    HEAPF64[$1>>3] = $17;
    HEAPF64[$2>>3] = $20;
    break L1;
    break;
   }
   case 1:  {
    HEAPF64[$1>>3] = $20;
    $21 = - $17;
    HEAPF64[$2>>3] = $21;
    break L1;
    break;
   }
   case 2:  {
    $22 = - $17;
    HEAPF64[$1>>3] = $22;
    $23 = - $20;
    HEAPF64[$2>>3] = $23;
    break L1;
    break;
   }
   case 3:  {
    $24 = - $20;
    HEAPF64[$1>>3] = $24;
    HEAPF64[$2>>3] = $17;
    break L1;
    break;
   }
   default: {
    // unreachable;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function ___sin($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $3 = 0.0;
 var $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0 * $0;
 $4 = $3 * $3;
 $5 = $3 * 2.7557313707070068E-6;
 $6 = $5 + -1.9841269829857949E-4;
 $7 = $3 * $6;
 $8 = $7 + 0.0083333333333224895;
 $9 = $3 * $4;
 $10 = $3 * 1.5896909952115501E-10;
 $11 = $10 + -2.5050760253406863E-8;
 $12 = $9 * $11;
 $13 = $12 + $8;
 $14 = $3 * $0;
 $15 = ($2|0)==(0);
 if ($15) {
  $16 = $3 * $13;
  $17 = $16 + -0.16666666666666632;
  $18 = $14 * $17;
  $19 = $18 + $0;
  $$0 = $19;
 } else {
  $20 = $1 * 0.5;
  $21 = $14 * $13;
  $22 = $20 - $21;
  $23 = $3 * $22;
  $24 = $23 - $1;
  $25 = $14 * 0.16666666666666632;
  $26 = $25 + $24;
  $27 = $0 - $26;
  $$0 = $27;
 }
 return (+$$0);
}
function ___cos($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0;
 var $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 * $0;
 $3 = $2 * $2;
 $4 = $2 * 2.4801587289476729E-5;
 $5 = $4 + -0.001388888888887411;
 $6 = $2 * $5;
 $7 = $6 + 0.041666666666666602;
 $8 = $2 * $7;
 $9 = $3 * $3;
 $10 = $2 * 1.1359647557788195E-11;
 $11 = 2.0875723212981748E-9 - $10;
 $12 = $2 * $11;
 $13 = $12 + -2.7557314351390663E-7;
 $14 = $9 * $13;
 $15 = $8 + $14;
 $16 = $2 * 0.5;
 $17 = 1.0 - $16;
 $18 = 1.0 - $17;
 $19 = $18 - $16;
 $20 = $2 * $15;
 $21 = $0 * $1;
 $22 = $20 - $21;
 $23 = $19 + $22;
 $24 = $17 + $23;
 return (+$24);
}
function ___rem_pio2($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0144 = 0, $$0145148 = 0.0, $$0146 = 0.0, $$0147 = 0.0, $$0149 = 0, $$1$lcssa = 0, $$phi$trans$insert = 0, $$pre = 0.0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0.0, $11 = 0;
 var $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0.0, $128 = 0.0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0;
 var $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $2 = sp + 16|0;
 $3 = sp;
 HEAPF64[tempDoublePtr>>3] = $0;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = (_bitshift64Lshr(($4|0),($5|0),63)|0);
 $7 = (getTempRet0() | 0);
 $8 = $5 & 2147483647;
 $9 = ($8>>>0)<(1074752123);
 do {
  if ($9) {
   $10 = $5 & 1048575;
   $11 = ($10|0)==(598523);
   if ($11) {
    label = 21;
   } else {
    $12 = ($8>>>0)<(1073928573);
    $13 = ($6|0)!=(0);
    if ($12) {
     if ($13) {
      $19 = $0 + 1.5707963267341256;
      $20 = $19 + 6.0771005065061922E-11;
      HEAPF64[$1>>3] = $20;
      $21 = $19 - $20;
      $22 = $21 + 6.0771005065061922E-11;
      $23 = ((($1)) + 8|0);
      HEAPF64[$23>>3] = $22;
      $$0144 = -1;
      break;
     } else {
      $14 = $0 + -1.5707963267341256;
      $15 = $14 + -6.0771005065061922E-11;
      HEAPF64[$1>>3] = $15;
      $16 = $14 - $15;
      $17 = $16 + -6.0771005065061922E-11;
      $18 = ((($1)) + 8|0);
      HEAPF64[$18>>3] = $17;
      $$0144 = 1;
      break;
     }
    } else {
     if ($13) {
      $29 = $0 + 3.1415926534682512;
      $30 = $29 + 1.2154201013012384E-10;
      HEAPF64[$1>>3] = $30;
      $31 = $29 - $30;
      $32 = $31 + 1.2154201013012384E-10;
      $33 = ((($1)) + 8|0);
      HEAPF64[$33>>3] = $32;
      $$0144 = -2;
      break;
     } else {
      $24 = $0 + -3.1415926534682512;
      $25 = $24 + -1.2154201013012384E-10;
      HEAPF64[$1>>3] = $25;
      $26 = $24 - $25;
      $27 = $26 + -1.2154201013012384E-10;
      $28 = ((($1)) + 8|0);
      HEAPF64[$28>>3] = $27;
      $$0144 = 2;
      break;
     }
    }
   }
  } else {
   $34 = ($8>>>0)<(1075594812);
   if ($34) {
    $35 = ($8>>>0)<(1075183037);
    if ($35) {
     $36 = ($8|0)==(1074977148);
     if ($36) {
      label = 21;
      break;
     }
     $37 = ($6|0)==(0);
     if ($37) {
      $38 = $0 + -4.7123889802023768;
      $39 = $38 + -1.8231301519518578E-10;
      HEAPF64[$1>>3] = $39;
      $40 = $38 - $39;
      $41 = $40 + -1.8231301519518578E-10;
      $42 = ((($1)) + 8|0);
      HEAPF64[$42>>3] = $41;
      $$0144 = 3;
      break;
     } else {
      $43 = $0 + 4.7123889802023768;
      $44 = $43 + 1.8231301519518578E-10;
      HEAPF64[$1>>3] = $44;
      $45 = $43 - $44;
      $46 = $45 + 1.8231301519518578E-10;
      $47 = ((($1)) + 8|0);
      HEAPF64[$47>>3] = $46;
      $$0144 = -3;
      break;
     }
    } else {
     $48 = ($8|0)==(1075388923);
     if ($48) {
      label = 21;
      break;
     }
     $49 = ($6|0)==(0);
     if ($49) {
      $50 = $0 + -6.2831853069365025;
      $51 = $50 + -2.4308402026024769E-10;
      HEAPF64[$1>>3] = $51;
      $52 = $50 - $51;
      $53 = $52 + -2.4308402026024769E-10;
      $54 = ((($1)) + 8|0);
      HEAPF64[$54>>3] = $53;
      $$0144 = 4;
      break;
     } else {
      $55 = $0 + 6.2831853069365025;
      $56 = $55 + 2.4308402026024769E-10;
      HEAPF64[$1>>3] = $56;
      $57 = $55 - $56;
      $58 = $57 + 2.4308402026024769E-10;
      $59 = ((($1)) + 8|0);
      HEAPF64[$59>>3] = $58;
      $$0144 = -4;
      break;
     }
    }
   }
   $60 = ($8>>>0)<(1094263291);
   if ($60) {
    label = 21;
   } else {
    $102 = ($8>>>0)>(2146435071);
    if ($102) {
     $103 = $0 - $0;
     $104 = ((($1)) + 8|0);
     HEAPF64[$104>>3] = $103;
     HEAPF64[$1>>3] = $103;
     $$0144 = 0;
     break;
    }
    $105 = $5 & 1048575;
    $106 = $105 | 1096810496;
    HEAP32[tempDoublePtr>>2] = $4;HEAP32[tempDoublePtr+4>>2] = $106;$107 = +HEAPF64[tempDoublePtr>>3];
    $$0145148 = $107;$$0149 = 0;
    while(1) {
     $108 = (~~(($$0145148)));
     $109 = (+($108|0));
     $110 = (($2) + ($$0149<<3)|0);
     HEAPF64[$110>>3] = $109;
     $111 = $$0145148 - $109;
     $112 = $111 * 16777216.0;
     $113 = (($$0149) + 1)|0;
     $exitcond = ($113|0)==(2);
     if ($exitcond) {
      break;
     } else {
      $$0145148 = $112;$$0149 = $113;
     }
    }
    $114 = ((($2)) + 16|0);
    HEAPF64[$114>>3] = $112;
    $115 = $112 == 0.0;
    if ($115) {
     $116 = 1;
     while(1) {
      $$phi$trans$insert = (($2) + ($116<<3)|0);
      $$pre = +HEAPF64[$$phi$trans$insert>>3];
      $117 = $$pre == 0.0;
      $118 = (($116) + -1)|0;
      if ($117) {
       $116 = $118;
      } else {
       $$1$lcssa = $116;
       break;
      }
     }
    } else {
     $$1$lcssa = 2;
    }
    $119 = $8 >>> 20;
    $120 = (($119) + -1046)|0;
    $121 = (($$1$lcssa) + 1)|0;
    $122 = (___rem_pio2_large($2,$3,$120,$121,1)|0);
    $123 = ($6|0)==(0);
    $124 = +HEAPF64[$3>>3];
    if ($123) {
     HEAPF64[$1>>3] = $124;
     $131 = ((($3)) + 8|0);
     $132 = +HEAPF64[$131>>3];
     $133 = ((($1)) + 8|0);
     HEAPF64[$133>>3] = $132;
     $$0144 = $122;
     break;
    } else {
     $125 = - $124;
     HEAPF64[$1>>3] = $125;
     $126 = ((($3)) + 8|0);
     $127 = +HEAPF64[$126>>3];
     $128 = - $127;
     $129 = ((($1)) + 8|0);
     HEAPF64[$129>>3] = $128;
     $130 = (0 - ($122))|0;
     $$0144 = $130;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $61 = $0 * 0.63661977236758138;
  $62 = $61 + 6755399441055744.0;
  $63 = $62 + -6755399441055744.0;
  $64 = (~~(($63)));
  $65 = $63 * 1.5707963267341256;
  $66 = $0 - $65;
  $67 = $63 * 6.0771005065061922E-11;
  $68 = $66 - $67;
  HEAPF64[$1>>3] = $68;
  HEAPF64[tempDoublePtr>>3] = $68;$69 = HEAP32[tempDoublePtr>>2]|0;
  $70 = HEAP32[tempDoublePtr+4>>2]|0;
  $71 = (_bitshift64Lshr(($69|0),($70|0),52)|0);
  $72 = (getTempRet0() | 0);
  $73 = $71 & 2047;
  $74 = $8 >>> 20;
  $75 = (($74) - ($73))|0;
  $76 = ($75|0)>(16);
  if ($76) {
   $77 = $63 * 6.077100506303966E-11;
   $78 = $66 - $77;
   $79 = $63 * 2.0222662487959506E-21;
   $80 = $66 - $78;
   $81 = $80 - $77;
   $82 = $79 - $81;
   $83 = $78 - $82;
   HEAPF64[$1>>3] = $83;
   HEAPF64[tempDoublePtr>>3] = $83;$84 = HEAP32[tempDoublePtr>>2]|0;
   $85 = HEAP32[tempDoublePtr+4>>2]|0;
   $86 = (_bitshift64Lshr(($84|0),($85|0),52)|0);
   $87 = (getTempRet0() | 0);
   $88 = $86 & 2047;
   $89 = (($74) - ($88))|0;
   $90 = ($89|0)>(49);
   $91 = $63 * 2.0222662487111665E-21;
   $92 = $78 - $91;
   $93 = $63 * 8.4784276603688995E-32;
   $94 = $78 - $92;
   $95 = $94 - $91;
   $96 = $93 - $95;
   if ($90) {
    $97 = $92 - $96;
    HEAPF64[$1>>3] = $97;
    $$0146 = $96;$$0147 = $92;$99 = $97;
   } else {
    $$0146 = $82;$$0147 = $78;$99 = $83;
   }
  } else {
   $$0146 = $67;$$0147 = $66;$99 = $68;
  }
  $98 = $$0147 - $99;
  $100 = $98 - $$0146;
  $101 = ((($1)) + 8|0);
  HEAPF64[$101>>3] = $100;
  $$0144 = $64;
 }
 STACKTOP = sp;return ($$0144|0);
}
function ___rem_pio2_large($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0.0, $$0248$lcssa = 0.0, $$0248336 = 0.0, $$0250 = 0, $$0250278 = 0, $$0250279 = 0, $$0251 = 0, $$0251$in = 0, $$0253 = 0, $$0256 = 0, $$0258373 = 0, $$0263372 = 0, $$0271 = 0, $$0271277 = 0, $$0273$lcssa = 0, $$0273341 = 0, $$0363 = 0.0, $$1$lcssa = 0.0, $$10291 = 0, $$11313 = 0;
 var $$12309 = 0, $$1249 = 0.0, $$1252 = 0, $$1252$ph = 0, $$1254 = 0, $$1254$in = 0, $$1257318 = 0, $$1259362 = 0, $$1264368 = 0, $$1272 = 0, $$1274 = 0, $$1274$ph = 0, $$13303 = 0, $$1354 = 0.0, $$2255 = 0, $$2260335 = 0, $$2265334 = 0, $$2330 = 0.0, $$3261347 = 0, $$3266342 = 0;
 var $$3319 = 0.0, $$4$lcssa = 0.0, $$4262353 = 0, $$4267348 = 0, $$4267348$in = 0, $$4290 = 0.0, $$5$lcssa = 0.0, $$5268361 = 0, $$5268361$in = 0, $$5298 = 0.0, $$6$lcssa = 0.0, $$6269329 = 0, $$6292 = 0.0, $$7$lcssa = 0.0, $$7270324 = 0, $$7304 = 0.0, $$8289 = 0, $$9297 = 0, $$neg = 0, $$neg281 = 0;
 var $$phi$trans$insert = 0, $$phi$trans$insert395 = 0, $$pre = 0.0, $$pre396 = 0.0, $$sink = 0, $$sink425 = 0, $$sink427 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0.0;
 var $166 = 0.0, $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0.0;
 var $184 = 0.0, $185 = 0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0.0, $204 = 0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0.0, $214 = 0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0.0, $222 = 0.0, $223 = 0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0, $228 = 0.0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0.0, $232 = 0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0.0, $237 = 0, $238 = 0;
 var $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond391 = 0, $exitcond392 = 0, $exitcond393 = 0, $exitcond394 = 0, $or$cond = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(560|0);
 $5 = sp + 480|0;
 $6 = sp + 320|0;
 $7 = sp + 160|0;
 $8 = sp;
 $9 = ((gb + (7136) | 0) + ($4<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($3) + -1)|0;
 $12 = (($2) + -3)|0;
 $13 = (($12|0) / 24)&-1;
 $14 = ($13|0)>(0);
 $spec$store$select = $14 ? $13 : 0;
 $$neg = Math_imul($spec$store$select, -24)|0;
 $$neg281 = (($2) + -24)|0;
 $15 = (($$neg281) + ($$neg))|0;
 $16 = (($10) + ($11))|0;
 $17 = ($16|0)<(0);
 if (!($17)) {
  $18 = (($spec$store$select) - ($11))|0;
  $19 = (($10) + ($3))|0;
  $$0258373 = $18;$$0263372 = 0;
  while(1) {
   $20 = ($$0258373|0)<(0);
   if ($20) {
    $25 = 0.0;
   } else {
    $21 = ((gb + (7152) | 0) + ($$0258373<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (+($22|0));
    $25 = $23;
   }
   $24 = (($6) + ($$0263372<<3)|0);
   HEAPF64[$24>>3] = $25;
   $26 = (($$0263372) + 1)|0;
   $27 = (($$0258373) + 1)|0;
   $exitcond394 = ($26|0)==($19|0);
   if ($exitcond394) {
    break;
   } else {
    $$0258373 = $27;$$0263372 = $26;
   }
  }
 }
 $28 = ($3|0)>(0);
 $$1264368 = 0;
 while(1) {
  if ($28) {
   $29 = (($$1264368) + ($11))|0;
   $$0363 = 0.0;$$1259362 = 0;
   while(1) {
    $30 = (($0) + ($$1259362<<3)|0);
    $31 = +HEAPF64[$30>>3];
    $32 = (($29) - ($$1259362))|0;
    $33 = (($6) + ($32<<3)|0);
    $34 = +HEAPF64[$33>>3];
    $35 = $31 * $34;
    $36 = $$0363 + $35;
    $37 = (($$1259362) + 1)|0;
    $exitcond393 = ($37|0)==($3|0);
    if ($exitcond393) {
     $$0$lcssa = $36;
     break;
    } else {
     $$0363 = $36;$$1259362 = $37;
    }
   }
  } else {
   $$0$lcssa = 0.0;
  }
  $38 = (($8) + ($$1264368<<3)|0);
  HEAPF64[$38>>3] = $$0$lcssa;
  $39 = (($$1264368) + 1)|0;
  $40 = ($$1264368|0)<($10|0);
  if ($40) {
   $$1264368 = $39;
  } else {
   break;
  }
 }
 $41 = ($15|0)>(0);
 $42 = (24 - ($15))|0;
 $43 = (23 - ($15))|0;
 $44 = ($15|0)==(0);
 $45 = ($3|0)>(0);
 $$0253 = $10;
 while(1) {
  $46 = (($8) + ($$0253<<3)|0);
  $47 = +HEAPF64[$46>>3];
  $48 = ($$0253|0)>(0);
  if ($48) {
   $$0248336 = $47;$$2260335 = $$0253;$$2265334 = 0;
   while(1) {
    $49 = $$0248336 * 5.9604644775390625E-8;
    $50 = (~~(($49)));
    $51 = (+($50|0));
    $52 = $51 * 16777216.0;
    $53 = $$0248336 - $52;
    $54 = (~~(($53)));
    $55 = (($5) + ($$2265334<<2)|0);
    HEAP32[$55>>2] = $54;
    $56 = (($$2260335) + -1)|0;
    $57 = (($8) + ($56<<3)|0);
    $58 = +HEAPF64[$57>>3];
    $59 = $58 + $51;
    $60 = (($$2265334) + 1)|0;
    $61 = ($$2260335|0)>(1);
    if ($61) {
     $$0248336 = $59;$$2260335 = $56;$$2265334 = $60;
    } else {
     $$0248$lcssa = $59;
     break;
    }
   }
  } else {
   $$0248$lcssa = $47;
  }
  $62 = (+_scalbn($$0248$lcssa,$15));
  $63 = $62 * 0.125;
  $64 = (+Math_floor((+$63)));
  $65 = $64 * 8.0;
  $66 = $62 - $65;
  $67 = (~~(($66)));
  $68 = (+($67|0));
  $69 = $66 - $68;
  do {
   if ($41) {
    $70 = (($$0253) + -1)|0;
    $71 = (($5) + ($70<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = $72 >> $42;
    $74 = (($73) + ($67))|0;
    $75 = $73 << $42;
    $76 = (($72) - ($75))|0;
    HEAP32[$71>>2] = $76;
    $77 = $76 >> $43;
    $$0250 = $77;$$0271 = $74;
    label = 21;
   } else {
    if ($44) {
     $78 = (($$0253) + -1)|0;
     $79 = (($5) + ($78<<2)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = $80 >> 23;
     $$0250 = $81;$$0271 = $67;
     label = 21;
     break;
    } else {
     $82 = !($69 >= 0.5);
     if ($82) {
      $$0250279 = 0;$$1249 = $69;$$1272 = $67;
      break;
     } else {
      $$0250278 = 2;$$0271277 = $67;
      label = 22;
      break;
     }
    }
   }
  } while(0);
  if ((label|0) == 21) {
   label = 0;
   $83 = ($$0250|0)>(0);
   if ($83) {
    $$0250278 = $$0250;$$0271277 = $$0271;
    label = 22;
   } else {
    $$0250279 = $$0250;$$1249 = $69;$$1272 = $$0271;
   }
  }
  if ((label|0) == 22) {
   label = 0;
   $84 = (($$0271277) + 1)|0;
   if ($48) {
    $$0273341 = 0;$$3266342 = 0;
    while(1) {
     $85 = (($5) + ($$3266342<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($$0273341|0)==(0);
     if ($87) {
      $88 = ($86|0)==(0);
      if ($88) {
       $$1274 = 0;
      } else {
       $$1274$ph = 1;$$sink425 = 16777216;
       label = 26;
      }
     } else {
      $$1274$ph = $$0273341;$$sink425 = 16777215;
      label = 26;
     }
     if ((label|0) == 26) {
      label = 0;
      $89 = (($$sink425) - ($86))|0;
      HEAP32[$85>>2] = $89;
      $$1274 = $$1274$ph;
     }
     $90 = (($$3266342) + 1)|0;
     $exitcond391 = ($90|0)==($$0253|0);
     if ($exitcond391) {
      $$0273$lcssa = $$1274;
      break;
     } else {
      $$0273341 = $$1274;$$3266342 = $90;
     }
    }
   } else {
    $$0273$lcssa = 0;
   }
   L44: do {
    if ($41) {
     switch ($15|0) {
     case 1:  {
      $91 = (($$0253) + -1)|0;
      $92 = (($5) + ($91<<2)|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = $93 & 8388607;
      HEAP32[$92>>2] = $94;
      break L44;
      break;
     }
     case 2:  {
      $95 = (($$0253) + -1)|0;
      $96 = (($5) + ($95<<2)|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = $97 & 4194303;
      HEAP32[$96>>2] = $98;
      break L44;
      break;
     }
     default: {
      break L44;
     }
     }
    }
   } while(0);
   $99 = ($$0250278|0)==(2);
   if ($99) {
    $100 = 1.0 - $69;
    $101 = ($$0273$lcssa|0)==(0);
    if ($101) {
     $$0250279 = 2;$$1249 = $100;$$1272 = $84;
    } else {
     $102 = (+_scalbn(1.0,$15));
     $103 = $100 - $102;
     $$0250279 = 2;$$1249 = $103;$$1272 = $84;
    }
   } else {
    $$0250279 = $$0250278;$$1249 = $69;$$1272 = $84;
   }
  }
  $104 = $$1249 == 0.0;
  if (!($104)) {
   label = 49;
   break;
  }
  $105 = ($$0253|0)>($10|0);
  if ($105) {
   $$3261347 = 0;$$4267348$in = $$0253;
   while(1) {
    $$4267348 = (($$4267348$in) + -1)|0;
    $106 = (($5) + ($$4267348<<2)|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = $107 | $$3261347;
    $109 = ($$4267348|0)>($10|0);
    if ($109) {
     $$3261347 = $108;$$4267348$in = $$4267348;
    } else {
     break;
    }
   }
   $110 = ($108|0)==(0);
   if (!($110)) {
    label = 41;
    break;
   }
  }
  $$0256 = 1;
  while(1) {
   $111 = (($10) - ($$0256))|0;
   $112 = (($5) + ($111<<2)|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0);
   $115 = (($$0256) + 1)|0;
   if ($114) {
    $$0256 = $115;
   } else {
    break;
   }
  }
  $116 = (($$0256) + ($$0253))|0;
  $$5268361$in = $$0253;
  while(1) {
   $$5268361 = (($$5268361$in) + 1)|0;
   $117 = (($$5268361) + ($spec$store$select))|0;
   $118 = ((gb + (7152) | 0) + ($117<<2)|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (+($119|0));
   $121 = (($$5268361$in) + ($3))|0;
   $122 = (($6) + ($121<<3)|0);
   HEAPF64[$122>>3] = $120;
   if ($45) {
    $$1354 = 0.0;$$4262353 = 0;
    while(1) {
     $123 = (($0) + ($$4262353<<3)|0);
     $124 = +HEAPF64[$123>>3];
     $125 = (($121) - ($$4262353))|0;
     $126 = (($6) + ($125<<3)|0);
     $127 = +HEAPF64[$126>>3];
     $128 = $124 * $127;
     $129 = $$1354 + $128;
     $130 = (($$4262353) + 1)|0;
     $exitcond392 = ($130|0)==($3|0);
     if ($exitcond392) {
      $$1$lcssa = $129;
      break;
     } else {
      $$1354 = $129;$$4262353 = $130;
     }
    }
   } else {
    $$1$lcssa = 0.0;
   }
   $131 = (($8) + ($$5268361<<3)|0);
   HEAPF64[$131>>3] = $$1$lcssa;
   $132 = ($$5268361|0)<($116|0);
   if ($132) {
    $$5268361$in = $$5268361;
   } else {
    break;
   }
  }
  $$0253 = $116;
 }
 if ((label|0) == 41) {
  $$0251$in = $15;$$1254$in = $$0253;
  while(1) {
   $$0251 = (($$0251$in) + -24)|0;
   $$1254 = (($$1254$in) + -1)|0;
   $133 = (($5) + ($$1254<<2)|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ($134|0)==(0);
   if ($135) {
    $$0251$in = $$0251;$$1254$in = $$1254;
   } else {
    $$1252 = $$0251;$$2255 = $$1254;
    break;
   }
  }
 }
 else if ((label|0) == 49) {
  $136 = (0 - ($15))|0;
  $137 = (+_scalbn($$1249,$136));
  $138 = !($137 >= 16777216.0);
  if ($138) {
   $148 = (~~(($137)));
   $$1252$ph = $15;$$sink = $148;$$sink427 = $$0253;
  } else {
   $139 = $137 * 5.9604644775390625E-8;
   $140 = (~~(($139)));
   $141 = (+($140|0));
   $142 = $141 * 16777216.0;
   $143 = $137 - $142;
   $144 = (~~(($143)));
   $145 = (($5) + ($$0253<<2)|0);
   HEAP32[$145>>2] = $144;
   $146 = (($$0253) + 1)|0;
   $147 = (($$neg) + ($2))|0;
   $$1252$ph = $147;$$sink = $140;$$sink427 = $146;
  }
  $149 = (($5) + ($$sink427<<2)|0);
  HEAP32[$149>>2] = $$sink;
  $$1252 = $$1252$ph;$$2255 = $$sink427;
 }
 $150 = (+_scalbn(1.0,$$1252));
 $151 = ($$2255|0)>(-1);
 if ($151) {
  $$2330 = $150;$$6269329 = $$2255;
  while(1) {
   $152 = (($5) + ($$6269329<<2)|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = (+($153|0));
   $155 = $$2330 * $154;
   $156 = (($8) + ($$6269329<<3)|0);
   HEAPF64[$156>>3] = $155;
   $157 = $$2330 * 5.9604644775390625E-8;
   $158 = (($$6269329) + -1)|0;
   $159 = ($$6269329|0)>(0);
   if ($159) {
    $$2330 = $157;$$6269329 = $158;
   } else {
    break;
   }
  }
  if ($151) {
   $$7270324 = $$2255;
   while(1) {
    $160 = (($$2255) - ($$7270324))|0;
    $$1257318 = 0;$$3319 = 0.0;
    while(1) {
     $161 = ((gb + (7424) | 0) + ($$1257318<<3)|0);
     $162 = +HEAPF64[$161>>3];
     $163 = (($$1257318) + ($$7270324))|0;
     $164 = (($8) + ($163<<3)|0);
     $165 = +HEAPF64[$164>>3];
     $166 = $162 * $165;
     $167 = $$3319 + $166;
     $168 = (($$1257318) + 1)|0;
     $169 = ($$1257318|0)>=($10|0);
     $170 = ($$1257318>>>0)>=($160>>>0);
     $or$cond = $169 | $170;
     if ($or$cond) {
      break;
     } else {
      $$1257318 = $168;$$3319 = $167;
     }
    }
    $171 = (($7) + ($160<<3)|0);
    HEAPF64[$171>>3] = $167;
    $172 = (($$7270324) + -1)|0;
    $173 = ($$7270324|0)>(0);
    if ($173) {
     $$7270324 = $172;
    } else {
     break;
    }
   }
  }
 }
 L93: do {
  switch ($4|0) {
  case 0:  {
   if ($151) {
    $$4290 = 0.0;$$8289 = $$2255;
    while(1) {
     $174 = (($7) + ($$8289<<3)|0);
     $175 = +HEAPF64[$174>>3];
     $176 = $$4290 + $175;
     $177 = (($$8289) + -1)|0;
     $178 = ($$8289|0)>(0);
     if ($178) {
      $$4290 = $176;$$8289 = $177;
     } else {
      $$4$lcssa = $176;
      break;
     }
    }
   } else {
    $$4$lcssa = 0.0;
   }
   $179 = ($$0250279|0)==(0);
   $180 = - $$4$lcssa;
   $181 = $179 ? $$4$lcssa : $180;
   HEAPF64[$1>>3] = $181;
   break;
  }
  case 2: case 1:  {
   if ($151) {
    $$5298 = 0.0;$$9297 = $$2255;
    while(1) {
     $182 = (($7) + ($$9297<<3)|0);
     $183 = +HEAPF64[$182>>3];
     $184 = $$5298 + $183;
     $185 = (($$9297) + -1)|0;
     $186 = ($$9297|0)>(0);
     if ($186) {
      $$5298 = $184;$$9297 = $185;
     } else {
      $$5$lcssa = $184;
      break;
     }
    }
   } else {
    $$5$lcssa = 0.0;
   }
   $187 = ($$0250279|0)==(0);
   $188 = - $$5$lcssa;
   $189 = $187 ? $$5$lcssa : $188;
   HEAPF64[$1>>3] = $189;
   $190 = +HEAPF64[$7>>3];
   $191 = $190 - $$5$lcssa;
   $192 = ($$2255|0)<(1);
   if ($192) {
    $$6$lcssa = $191;
   } else {
    $$10291 = 1;$$6292 = $191;
    while(1) {
     $193 = (($7) + ($$10291<<3)|0);
     $194 = +HEAPF64[$193>>3];
     $195 = $$6292 + $194;
     $196 = (($$10291) + 1)|0;
     $exitcond = ($$10291|0)==($$2255|0);
     if ($exitcond) {
      $$6$lcssa = $195;
      break;
     } else {
      $$10291 = $196;$$6292 = $195;
     }
    }
   }
   $197 = - $$6$lcssa;
   $198 = $187 ? $$6$lcssa : $197;
   $199 = ((($1)) + 8|0);
   HEAPF64[$199>>3] = $198;
   break;
  }
  case 3:  {
   $200 = ($$2255|0)>(0);
   if ($200) {
    $$phi$trans$insert = (($7) + ($$2255<<3)|0);
    $$pre = +HEAPF64[$$phi$trans$insert>>3];
    $$11313 = $$2255;$206 = $$pre;
    while(1) {
     $201 = (($$11313) + -1)|0;
     $202 = (($7) + ($201<<3)|0);
     $203 = +HEAPF64[$202>>3];
     $204 = (($7) + ($$11313<<3)|0);
     $205 = $203 + $206;
     $207 = $203 - $205;
     $208 = $206 + $207;
     HEAPF64[$204>>3] = $208;
     HEAPF64[$202>>3] = $205;
     $209 = ($$11313|0)>(1);
     if ($209) {
      $$11313 = $201;$206 = $205;
     } else {
      break;
     }
    }
    $210 = ($$2255|0)>(1);
    if ($210) {
     $$phi$trans$insert395 = (($7) + ($$2255<<3)|0);
     $$pre396 = +HEAPF64[$$phi$trans$insert395>>3];
     $$12309 = $$2255;$216 = $$pre396;
     while(1) {
      $211 = (($$12309) + -1)|0;
      $212 = (($7) + ($211<<3)|0);
      $213 = +HEAPF64[$212>>3];
      $214 = (($7) + ($$12309<<3)|0);
      $215 = $213 + $216;
      $217 = $213 - $215;
      $218 = $216 + $217;
      HEAPF64[$214>>3] = $218;
      HEAPF64[$212>>3] = $215;
      $219 = ($$12309|0)>(2);
      if ($219) {
       $$12309 = $211;$216 = $215;
      } else {
       break;
      }
     }
     if ($210) {
      $$13303 = $$2255;$$7304 = 0.0;
      while(1) {
       $220 = (($7) + ($$13303<<3)|0);
       $221 = +HEAPF64[$220>>3];
       $222 = $$7304 + $221;
       $223 = (($$13303) + -1)|0;
       $224 = ($$13303|0)>(2);
       if ($224) {
        $$13303 = $223;$$7304 = $222;
       } else {
        $$7$lcssa = $222;
        break;
       }
      }
     } else {
      $$7$lcssa = 0.0;
     }
    } else {
     $$7$lcssa = 0.0;
    }
   } else {
    $$7$lcssa = 0.0;
   }
   $225 = ($$0250279|0)==(0);
   $226 = +HEAPF64[$7>>3];
   if ($225) {
    HEAPF64[$1>>3] = $226;
    $227 = ((($7)) + 8|0);
    $228 = +HEAPF64[$227>>3];
    $229 = ((($1)) + 8|0);
    HEAPF64[$229>>3] = $228;
    $230 = ((($1)) + 16|0);
    HEAPF64[$230>>3] = $$7$lcssa;
    break L93;
   } else {
    $231 = - $226;
    HEAPF64[$1>>3] = $231;
    $232 = ((($7)) + 8|0);
    $233 = +HEAPF64[$232>>3];
    $234 = - $233;
    $235 = ((($1)) + 8|0);
    HEAPF64[$235>>3] = $234;
    $236 = - $$7$lcssa;
    $237 = ((($1)) + 16|0);
    HEAPF64[$237>>3] = $236;
    break L93;
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 $238 = $$1272 & 7;
 STACKTOP = sp;return ($238|0);
}
function _llrintl($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_llrint($0)|0);
 $2 = (getTempRet0() | 0);
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _llrint($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_rint($0));
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (~~+Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 setTempRet0(($3) | 0);
 return ($2|0);
}
function ___tan($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0.0, $$087 = 0.0, $$088 = 0.0, $$090 = 0, $$1 = 0.0, $$189 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0;
 var $79 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$3 = HEAP32[tempDoublePtr>>2]|0;
 $4 = HEAP32[tempDoublePtr+4>>2]|0;
 $5 = $4 & 2147483640;
 $6 = ($5>>>0)>(1072010279);
 $7 = (0)>(0);
 $8 = ($5|0)==(1072010279);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if ($10) {
  $11 = (_bitshift64Lshr(($3|0),($4|0),63)|0);
  $12 = (getTempRet0() | 0);
  $13 = ($11|0)==(0);
  $14 = - $0;
  $15 = - $1;
  $$088 = $13 ? $1 : $15;
  $$087 = $13 ? $0 : $14;
  $16 = 0.78539816339744828 - $$087;
  $17 = 3.061616997868383E-17 - $$088;
  $18 = $16 + $17;
  $$090 = $11;$$1 = $18;$$189 = 0.0;
 } else {
  $$090 = 0;$$1 = $0;$$189 = $1;
 }
 $19 = $$1 * $$1;
 $20 = $19 * $19;
 $21 = $20 * 1.8558637485527546E-5;
 $22 = 7.8179444293955709E-5 - $21;
 $23 = $20 * $22;
 $24 = $23 + 5.880412408202641E-4;
 $25 = $20 * $24;
 $26 = $25 + 0.0035920791075913124;
 $27 = $20 * $26;
 $28 = $27 + 0.021869488294859542;
 $29 = $20 * $28;
 $30 = $29 + 0.13333333333320124;
 $31 = $20 * 2.5907305186363371E-5;
 $32 = $31 + 7.1407249138260819E-5;
 $33 = $20 * $32;
 $34 = $33 + 2.4646313481846991E-4;
 $35 = $20 * $34;
 $36 = $35 + 0.0014562094543252903;
 $37 = $20 * $36;
 $38 = $37 + 0.0088632398235993;
 $39 = $20 * $38;
 $40 = $39 + 0.053968253976226052;
 $41 = $19 * $40;
 $42 = $$1 * $19;
 $43 = $30 + $41;
 $44 = $42 * $43;
 $45 = $$189 + $44;
 $46 = $19 * $45;
 $47 = $$189 + $46;
 $48 = $42 * 0.33333333333333409;
 $49 = $48 + $47;
 $50 = $$1 + $49;
 if ($10) {
  $51 = $2 << 1;
  $52 = (1 - ($51))|0;
  $53 = (+($52|0));
  $54 = $50 * $50;
  $55 = $50 + $53;
  $56 = $54 / $55;
  $57 = $49 - $56;
  $58 = $$1 + $57;
  $59 = $58 * 2.0;
  $60 = $53 - $59;
  $61 = ($$090|0)==(0);
  $62 = - $60;
  $63 = $61 ? $60 : $62;
  $$0 = $63;
 } else {
  $64 = ($2|0)==(0);
  if ($64) {
   $$0 = $50;
  } else {
   HEAPF64[tempDoublePtr>>3] = $50;$65 = HEAP32[tempDoublePtr>>2]|0;
   $66 = HEAP32[tempDoublePtr+4>>2]|0;
   HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $66;$67 = +HEAPF64[tempDoublePtr>>3];
   $68 = $67 - $$1;
   $69 = $49 - $68;
   $70 = -1.0 / $50;
   HEAPF64[tempDoublePtr>>3] = $70;$71 = HEAP32[tempDoublePtr>>2]|0;
   $72 = HEAP32[tempDoublePtr+4>>2]|0;
   HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $72;$73 = +HEAPF64[tempDoublePtr>>3];
   $74 = $67 * $73;
   $75 = $74 + 1.0;
   $76 = $69 * $73;
   $77 = $75 + $76;
   $78 = $70 * $77;
   $79 = $78 + $73;
   $$0 = $79;
  }
 }
 return (+$$0);
}
function _log2l($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_log2($0));
 return (+$1);
}
function _log2($0) {
 $0 = +$0;
 var $$0 = 0, $$096 = 0, $$097 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, $or$cond = 0, $or$cond101 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = ($2>>>0)<(1048576);
 $4 = ($2|0)<(0);
 $or$cond = $4 | $3;
 do {
  if ($or$cond) {
   $5 = $2 & 2147483647;
   $6 = ($1|0)==(0);
   $7 = ($5|0)==(0);
   $8 = $6 & $7;
   if ($8) {
    $9 = $0 * $0;
    $10 = -1.0 / $9;
    $$097 = $10;
    break;
   }
   if ($4) {
    $11 = $0 - $0;
    $12 = $11 / 0.0;
    $$097 = $12;
    break;
   } else {
    $13 = $0 * 18014398509481984.0;
    HEAPF64[tempDoublePtr>>3] = $13;$14 = HEAP32[tempDoublePtr>>2]|0;
    $15 = HEAP32[tempDoublePtr+4>>2]|0;
    $$0 = -1077;$$096 = $15;$27 = 0;$29 = $14;
    label = 9;
    break;
   }
  } else {
   $16 = ($2>>>0)>(2146435071);
   if ($16) {
    $$097 = $0;
   } else {
    $17 = ($2|0)==(1072693248);
    $18 = ($1|0)==(0);
    $19 = (0)==(0);
    $20 = $18 & $19;
    $or$cond101 = $20 & $17;
    if ($or$cond101) {
     $$097 = 0.0;
    } else {
     $$0 = -1023;$$096 = $2;$27 = 0;$29 = $1;
     label = 9;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $21 = (($$096) + 614242)|0;
  $22 = $21 >>> 20;
  $23 = (($$0) + ($22))|0;
  $24 = $21 & 1048575;
  $25 = (($24) + 1072079006)|0;
  $26 = $25 | $27;
  HEAP32[tempDoublePtr>>2] = $29;HEAP32[tempDoublePtr+4>>2] = $26;$28 = +HEAPF64[tempDoublePtr>>3];
  $30 = $28 + -1.0;
  $31 = $30 * 0.5;
  $32 = $30 * $31;
  $33 = $30 + 2.0;
  $34 = $30 / $33;
  $35 = $34 * $34;
  $36 = $35 * $35;
  $37 = $36 * 0.15313837699209373;
  $38 = $37 + 0.22222198432149784;
  $39 = $36 * $38;
  $40 = $39 + 0.39999999999409419;
  $41 = $36 * $40;
  $42 = $36 * 0.14798198605116586;
  $43 = $42 + 0.1818357216161805;
  $44 = $36 * $43;
  $45 = $44 + 0.28571428743662391;
  $46 = $36 * $45;
  $47 = $46 + 0.66666666666667351;
  $48 = $35 * $47;
  $49 = $41 + $48;
  $50 = $30 - $32;
  HEAPF64[tempDoublePtr>>3] = $50;$51 = HEAP32[tempDoublePtr>>2]|0;
  $52 = HEAP32[tempDoublePtr+4>>2]|0;
  HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $52;$53 = +HEAPF64[tempDoublePtr>>3];
  $54 = $30 - $53;
  $55 = $54 - $32;
  $56 = $32 + $49;
  $57 = $34 * $56;
  $58 = $55 + $57;
  $59 = $53 * 1.4426950407214463;
  $60 = $58 + $53;
  $61 = $60 * 1.6751713164886512E-10;
  $62 = $58 * 1.4426950407214463;
  $63 = $62 + $61;
  $64 = (+($23|0));
  $65 = $59 + $64;
  $66 = $64 - $65;
  $67 = $59 + $66;
  $68 = $67 + $63;
  $69 = $65 + $68;
  $$097 = $69;
 }
 return (+$$097);
}
function _jn($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0156 = 0.0, $$0157215 = 0.0, $$0158 = 0.0, $$0159214 = 0.0, $$0160213 = 0.0, $$0160213$phi = 0.0, $$0161208 = 0.0, $$0162 = 0.0, $$0163184 = 0.0, $$0167183 = 0.0, $$0167183$phi = 0.0, $$0173 = 0, $$0174182 = 0, $$0179 = 0, $$0216 = 0, $$1164$lcssa = 0.0, $$1164187 = 0.0, $$1168$lcssa = 0.0, $$1168186 = 0.0, $$1175185 = 0;
 var $$1201 = 0.0, $$2 = 0.0, $$2165193 = 0.0, $$2169192 = 0.0, $$2169192$phi = 0.0, $$2176207 = 0, $$2176207$ph = 0, $$3 = 0.0, $$3166200 = 0.0, $$3170199 = 0.0, $$3177191 = 0, $$4 = 0.0, $$4171 = 0.0, $$4178198 = 0, $$5 = 0.0, $$5172 = 0.0, $$7 = 0.0, $10 = 0, $100 = 0.0, $101 = 0.0;
 var $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0, $117 = 0.0, $118 = 0.0, $12 = 0, $13 = 0.0;
 var $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0;
 var $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0;
 var $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0;
 var $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0.0;
 var $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $exitcond = 0, $exitcond227 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $1;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($2|0),($3|0),63)|0);
 $5 = (getTempRet0() | 0);
 $6 = $3 & 2147483647;
 $7 = (0 - ($2))|0;
 $8 = $2 | $7;
 $9 = $8 >>> 31;
 $10 = $6 | $9;
 $11 = ($10>>>0)>(2146435072);
 do {
  if ($11) {
   $$0156 = $1;
  } else {
   $12 = ($0|0)==(0);
   if ($12) {
    $13 = (+_j0($1));
    $$0156 = $13;
    break;
   }
   $14 = ($0|0)<(0);
   if ($14) {
    $15 = $0 ^ -1;
    $16 = - $1;
    $17 = $4 ^ 1;
    $$0158 = $16;$$0173 = $17;$$0179 = $15;
   } else {
    $18 = (($0) + -1)|0;
    $$0158 = $1;$$0173 = $4;$$0179 = $18;
   }
   $19 = ($$0179|0)==(0);
   if ($19) {
    $20 = (+_j1($$0158));
    $$0156 = $20;
    break;
   }
   $21 = $$0173 & $0;
   $22 = (+Math_abs((+$$0158)));
   $23 = $6 | $2;
   $24 = ($23|0)==(0);
   $25 = ($6|0)==(2146435072);
   $or$cond = $25 | $24;
   L13: do {
    if ($or$cond) {
     $$7 = 0.0;
    } else {
     $26 = (+($$0179|0));
     $27 = $22 > $26;
     if ($27) {
      $28 = ($6>>>0)>(1389363199);
      if (!($28)) {
       $45 = (+_j0($22));
       $46 = (+_j1($22));
       $47 = ($$0179|0)>(0);
       if (!($47)) {
        $$7 = $46;
        break;
       }
       $$0163184 = $46;$$0167183 = $45;$$0174182 = 0;
       while(1) {
        $48 = (($$0174182) + 1)|0;
        $49 = (+($48|0));
        $50 = $49 * 2.0;
        $51 = $50 / $22;
        $52 = $$0163184 * $51;
        $53 = $52 - $$0167183;
        $exitcond = ($48|0)==($$0179|0);
        if ($exitcond) {
         $$7 = $53;
         break L13;
        } else {
         $$0167183$phi = $$0163184;$$0163184 = $53;$$0174182 = $48;$$0167183 = $$0167183$phi;
        }
       }
      }
      $trunc = $$0179&255;
      $trunc$clear = $trunc & 3;
      switch ($trunc$clear<<24>>24) {
      case 0:  {
       $29 = (+Math_cos((+$22)));
       $30 = (+Math_sin((+$22)));
       $31 = $30 - $29;
       $$0162 = $31;
       break;
      }
      case 1:  {
       $32 = (+Math_cos((+$22)));
       $33 = - $32;
       $34 = (+Math_sin((+$22)));
       $35 = $33 - $34;
       $$0162 = $35;
       break;
      }
      case 2:  {
       $36 = (+Math_cos((+$22)));
       $37 = (+Math_sin((+$22)));
       $38 = $36 - $37;
       $$0162 = $38;
       break;
      }
      case 3:  {
       $39 = (+Math_cos((+$22)));
       $40 = (+Math_sin((+$22)));
       $41 = $39 + $40;
       $$0162 = $41;
       break;
      }
      default: {
       // unreachable;
      }
      }
      $42 = $$0162 * 0.56418958354775628;
      $43 = (+Math_sqrt((+$22)));
      $44 = $42 / $43;
      $$7 = $44;
      break;
     }
     $54 = ($6>>>0)<(1041235968);
     if ($54) {
      $55 = ($$0179|0)>(32);
      if ($55) {
       $$7 = 0.0;
       break;
      }
      $56 = $22 * 0.5;
      $57 = ($$0179|0)<(1);
      if ($57) {
       $$1164$lcssa = $56;$$1168$lcssa = 1.0;
      } else {
       $58 = (($$0179) + 1)|0;
       $$1164187 = $56;$$1168186 = 1.0;$$1175185 = 2;
       while(1) {
        $59 = (+($$1175185|0));
        $60 = $$1168186 * $59;
        $61 = $56 * $$1164187;
        $62 = (($$1175185) + 1)|0;
        $exitcond227 = ($$1175185|0)==($58|0);
        if ($exitcond227) {
         $$1164$lcssa = $61;$$1168$lcssa = $60;
         break;
        } else {
         $$1164187 = $61;$$1168186 = $60;$$1175185 = $62;
        }
       }
      }
      $63 = $$1164$lcssa / $$1168$lcssa;
      $$7 = $63;
      break;
     }
     $64 = $26 + 1.0;
     $65 = $64 * 2.0;
     $66 = $65 / $22;
     $67 = 2.0 / $22;
     $68 = $66 + $67;
     $69 = $66 * $68;
     $70 = $69 + -1.0;
     $71 = $70 < 1.0E+9;
     if ($71) {
      $$0157215 = $68;$$0159214 = $70;$$0160213 = $66;$$0216 = 1;
      while(1) {
       $72 = (($$0216) + 1)|0;
       $73 = $67 + $$0157215;
       $74 = $$0159214 * $73;
       $75 = $74 - $$0160213;
       $76 = $75 < 1.0E+9;
       if ($76) {
        $$0160213$phi = $$0159214;$$0157215 = $73;$$0159214 = $75;$$0216 = $72;$$0160213 = $$0160213$phi;
       } else {
        $$2176207$ph = $72;
        break;
       }
      }
     } else {
      $$2176207$ph = 1;
     }
     $$0161208 = 0.0;$$2176207 = $$2176207$ph;
     while(1) {
      $77 = (+($$2176207|0));
      $78 = $64 + $77;
      $79 = $78 * 2.0;
      $80 = $79 / $22;
      $81 = $80 - $$0161208;
      $82 = 1.0 / $81;
      $83 = (($$2176207) + -1)|0;
      $84 = ($$2176207|0)>(0);
      if ($84) {
       $$0161208 = $82;$$2176207 = $83;
      } else {
       break;
      }
     }
     $85 = (+Math_abs((+$66)));
     $86 = (+Math_log((+$85)));
     $87 = $64 * $86;
     $88 = $87 < 709.78271289338397;
     $89 = ($$0179|0)>(0);
     if ($88) {
      if ($89) {
       $$2165193 = 1.0;$$2169192 = $82;$$3177191 = $$0179;
       while(1) {
        $90 = (+($$3177191|0));
        $91 = $90 * 2.0;
        $92 = $$2165193 * $91;
        $93 = $92 / $22;
        $94 = $93 - $$2169192;
        $95 = (($$3177191) + -1)|0;
        $96 = ($$3177191|0)>(1);
        if ($96) {
         $$2169192$phi = $$2165193;$$2165193 = $94;$$3177191 = $95;$$2169192 = $$2169192$phi;
        } else {
         $$3 = $82;$$5 = $94;$$5172 = $$2165193;
         break;
        }
       }
      } else {
       $$3 = $82;$$5 = 1.0;$$5172 = $82;
      }
     } else {
      if ($89) {
       $$1201 = $82;$$3166200 = 1.0;$$3170199 = $82;$$4178198 = $$0179;
       while(1) {
        $97 = (+($$4178198|0));
        $98 = $97 * 2.0;
        $99 = $$3166200 * $98;
        $100 = $99 / $22;
        $101 = $100 - $$3170199;
        $102 = $101 > 3.2733906078961419E+150;
        if ($102) {
         $103 = $$3166200 / $101;
         $104 = $$1201 / $101;
         $$2 = $104;$$4 = 1.0;$$4171 = $103;
        } else {
         $$2 = $$1201;$$4 = $101;$$4171 = $$3166200;
        }
        $105 = (($$4178198) + -1)|0;
        $106 = ($$4178198|0)>(1);
        if ($106) {
         $$1201 = $$2;$$3166200 = $$4;$$3170199 = $$4171;$$4178198 = $105;
        } else {
         $$3 = $$2;$$5 = $$4;$$5172 = $$4171;
         break;
        }
       }
      } else {
       $$3 = $82;$$5 = 1.0;$$5172 = $82;
      }
     }
     $107 = (+_j0($22));
     $108 = (+_j1($22));
     $109 = (+Math_abs((+$107)));
     $110 = (+Math_abs((+$108)));
     $111 = !($109 >= $110);
     if ($111) {
      $114 = $$3 * $108;
      $115 = $114 / $$5172;
      $$7 = $115;
      break;
     } else {
      $112 = $$3 * $107;
      $113 = $112 / $$5;
      $$7 = $113;
      break;
     }
    }
   } while(0);
   $116 = ($21|0)==(0);
   $117 = - $$7;
   $118 = $116 ? $$7 : $117;
   $$0156 = $118;
  }
 } while(0);
 return (+$$0156);
}
function _j1($0) {
 $0 = +$0;
 var $$0 = 0.0, $$035 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $4 = (getTempRet0() | 0);
 $5 = $2 & 2147483647;
 $6 = ($5>>>0)>(2146435071);
 do {
  if ($6) {
   $7 = $0 * $0;
   $8 = 1.0 / $7;
   $$0 = $8;
  } else {
   $9 = ($5>>>0)>(1073741823);
   if ($9) {
    $10 = (+Math_abs((+$0)));
    $11 = (+_common_47($5,$10,0,$3));
    $$0 = $11;
    break;
   }
   $12 = ($5>>>0)>(939524095);
   if ($12) {
    $13 = $0 * $0;
    $14 = $13 * 4.9672799960958445E-8;
    $15 = $14 + -1.599556310840356E-5;
    $16 = $13 * $15;
    $17 = $16 + 0.0014070566695518971;
    $18 = $13 * $17;
    $19 = $18 + -0.0625;
    $20 = $13 * $19;
    $21 = $13 * 1.2354227442613791E-11;
    $22 = $21 + 5.0463625707621704E-9;
    $23 = $13 * $22;
    $24 = $23 + 1.1771846404262368E-6;
    $25 = $13 * $24;
    $26 = $25 + 1.8594678558863092E-4;
    $27 = $13 * $26;
    $28 = $27 + 0.019153759953836346;
    $29 = $13 * $28;
    $30 = $29 + 1.0;
    $31 = $20 / $30;
    $$035 = $31;
   } else {
    $$035 = $0;
   }
   $32 = $$035 + 0.5;
   $33 = $32 * $0;
   $$0 = $33;
  }
 } while(0);
 return (+$$0);
}
function _common_47($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0.0, $$034 = 0.0, $$1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, $spec$select = 0.0, $spec$select37 = 0.0, $spec$select38 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (+Math_sin((+$1)));
 $5 = ($2|0)!=(0);
 $6 = - $4;
 $spec$select = $5 ? $6 : $4;
 $7 = (+Math_cos((+$1)));
 $8 = $spec$select - $7;
 $9 = ($0>>>0)<(2145386496);
 if ($9) {
  $10 = - $spec$select;
  $11 = $10 - $7;
  $12 = $1 * 2.0;
  $13 = (+Math_cos((+$12)));
  $14 = $spec$select * $7;
  $15 = $14 > 0.0;
  if ($15) {
   $16 = $13 / $11;
   $$0 = $16;$$034 = $11;
  } else {
   $17 = $13 / $8;
   $$0 = $8;$$034 = $17;
  }
  $18 = ($0>>>0)<(1207959552);
  if ($18) {
   $19 = - $$034;
   $spec$select37 = $5 ? $19 : $$034;
   $20 = (+_pone($1));
   $21 = $$0 * $20;
   $22 = (+_qone($1));
   $23 = $spec$select37 * $22;
   $24 = $21 - $23;
   $$1 = $24;
  } else {
   $$1 = $$0;
  }
 } else {
  $$1 = $8;
 }
 $25 = ($3|0)==(0);
 $26 = - $$1;
 $spec$select38 = $25 ? $$1 : $26;
 $27 = $spec$select38 * 0.56418958354775628;
 $28 = (+Math_sqrt((+$1)));
 $29 = $27 / $28;
 return (+$29);
}
function _pone($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$041 = 0, $$42 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(1075838975);
 if ($4) {
  $$0 = (gb + (8160) | 0);$$041 = (gb + (8064) | 0);
 } else {
  $5 = ($3>>>0)>(1074933386);
  $6 = ($3>>>0)>(1074191212);
  if ($5) {
   $$0 = (gb + (8208) | 0);$$041 = (gb + (8112) | 0);
  } else {
   $$42 = $6 ? (gb + (7872) | 0) : (gb + (7920) | 0);
   $$ = $6 ? (gb + (7968) | 0) : (gb + (8016) | 0);
   $$0 = $$42;$$041 = $$;
  }
 }
 $7 = $0 * $0;
 $8 = 1.0 / $7;
 $9 = +HEAPF64[$$0>>3];
 $10 = ((($$0)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($$0)) + 16|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($$0)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($$0)) + 32|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($$0)) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $8 * $19;
 $21 = $17 + $20;
 $22 = $8 * $21;
 $23 = $15 + $22;
 $24 = $8 * $23;
 $25 = $13 + $24;
 $26 = $8 * $25;
 $27 = $11 + $26;
 $28 = $8 * $27;
 $29 = $9 + $28;
 $30 = +HEAPF64[$$041>>3];
 $31 = ((($$041)) + 8|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($$041)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($$041)) + 24|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($$041)) + 32|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $8 * $38;
 $40 = $36 + $39;
 $41 = $8 * $40;
 $42 = $34 + $41;
 $43 = $8 * $42;
 $44 = $32 + $43;
 $45 = $8 * $44;
 $46 = $30 + $45;
 $47 = $8 * $46;
 $48 = $47 + 1.0;
 $49 = $29 / $48;
 $50 = $49 + 1.0;
 return (+$50);
}
function _qone($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$044 = 0, $$45 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(1075838975);
 if ($4) {
  $$0 = (gb + (7776) | 0);$$044 = (gb + (7680) | 0);
 } else {
  $5 = ($3>>>0)>(1074933386);
  $6 = ($3>>>0)>(1074191212);
  if ($5) {
   $$0 = (gb + (7824) | 0);$$044 = (gb + (7728) | 0);
  } else {
   $$45 = $6 ? (gb + (7488) | 0) : (gb + (7536) | 0);
   $$ = $6 ? (gb + (7584) | 0) : (gb + (7632) | 0);
   $$0 = $$45;$$044 = $$;
  }
 }
 $7 = $0 * $0;
 $8 = 1.0 / $7;
 $9 = +HEAPF64[$$0>>3];
 $10 = ((($$0)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($$0)) + 16|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($$0)) + 24|0);
 $15 = +HEAPF64[$14>>3];
 $16 = ((($$0)) + 32|0);
 $17 = +HEAPF64[$16>>3];
 $18 = ((($$0)) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $8 * $19;
 $21 = $17 + $20;
 $22 = $8 * $21;
 $23 = $15 + $22;
 $24 = $8 * $23;
 $25 = $13 + $24;
 $26 = $8 * $25;
 $27 = $11 + $26;
 $28 = $8 * $27;
 $29 = $9 + $28;
 $30 = +HEAPF64[$$044>>3];
 $31 = ((($$044)) + 8|0);
 $32 = +HEAPF64[$31>>3];
 $33 = ((($$044)) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($$044)) + 24|0);
 $36 = +HEAPF64[$35>>3];
 $37 = ((($$044)) + 32|0);
 $38 = +HEAPF64[$37>>3];
 $39 = ((($$044)) + 40|0);
 $40 = +HEAPF64[$39>>3];
 $41 = $8 * $40;
 $42 = $38 + $41;
 $43 = $8 * $42;
 $44 = $36 + $43;
 $45 = $8 * $44;
 $46 = $34 + $45;
 $47 = $8 * $46;
 $48 = $32 + $47;
 $49 = $8 * $48;
 $50 = $30 + $49;
 $51 = $8 * $50;
 $52 = $51 + 1.0;
 $53 = $29 / $52;
 $54 = $53 + 0.375;
 $55 = $54 / $0;
 return (+$55);
}
function _yn($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0.0, $$071 = 0.0, $$07280 = 0.0, $$07379 = 0.0, $$07379$phi = 0.0, $$07478 = 0, $$075 = 0, $$076 = 0, $$1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0;
 var $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0;
 var $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $8 = 0, $9 = 0, $or$cond = 0, $trunc = 0;
 var $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $1;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (0 - ($2))|0;
 $6 = $2 | $5;
 $7 = $6 >>> 31;
 $8 = $4 | $7;
 $9 = ($8>>>0)>(2146435072);
 do {
  if ($9) {
   $$0 = $1;
  } else {
   $10 = ($3|0)>(-1);
   $11 = ($2>>>0)>(4294967295);
   $12 = ($3|0)==(-1);
   $13 = $12 & $11;
   $14 = $10 | $13;
   $15 = $4 | $2;
   $16 = ($15|0)==(0);
   $or$cond = $14 | $16;
   if ($or$cond) {
    $17 = ($4|0)==(2146435072);
    if ($17) {
     $$0 = 0.0;
    } else {
     $18 = ($0|0)==(0);
     if ($18) {
      $19 = (+_y0($1));
      $$0 = $19;
      break;
     }
     $20 = ($0|0)<(0);
     $21 = $0 ^ -1;
     $22 = $0 & 1;
     $23 = (($0) + -1)|0;
     $$076 = $20 ? $21 : $23;
     $$075 = $20 ? $22 : 0;
     $24 = ($$076|0)==(0);
     if ($24) {
      $25 = ($$075|0)==(0);
      $26 = (+_y1($1));
      $27 = - $26;
      $28 = $25 ? $26 : $27;
      $$0 = $28;
      break;
     }
     $29 = ($4>>>0)>(1389363199);
     if ($29) {
      $trunc = $$076&255;
      $trunc$clear = $trunc & 3;
      switch ($trunc$clear<<24>>24) {
      case 0:  {
       $30 = (+Math_sin((+$1)));
       $31 = - $30;
       $32 = (+Math_cos((+$1)));
       $33 = $31 - $32;
       $$071 = $33;
       break;
      }
      case 1:  {
       $34 = (+Math_sin((+$1)));
       $35 = (+Math_cos((+$1)));
       $36 = $35 - $34;
       $$071 = $36;
       break;
      }
      case 2:  {
       $37 = (+Math_sin((+$1)));
       $38 = (+Math_cos((+$1)));
       $39 = $37 + $38;
       $$071 = $39;
       break;
      }
      case 3:  {
       $40 = (+Math_sin((+$1)));
       $41 = (+Math_cos((+$1)));
       $42 = $40 - $41;
       $$071 = $42;
       break;
      }
      default: {
       // unreachable;
      }
      }
      $43 = $$071 * 0.56418958354775628;
      $44 = (+Math_sqrt((+$1)));
      $45 = $43 / $44;
      $$1 = $45;
     } else {
      $46 = (+_y0($1));
      $47 = (+_y1($1));
      HEAPF64[tempDoublePtr>>3] = $47;$48 = HEAP32[tempDoublePtr>>2]|0;
      $49 = HEAP32[tempDoublePtr+4>>2]|0;
      $50 = ($$076|0)>(0);
      $51 = (0)!=(0);
      $52 = ($49|0)!=(-1048576);
      $53 = $51 | $52;
      $54 = $50 & $53;
      if ($54) {
       $$07280 = $47;$$07379 = $46;$$07478 = 0;
       while(1) {
        $55 = (($$07478) + 1)|0;
        $56 = (+($55|0));
        $57 = $56 * 2.0;
        $58 = $57 / $1;
        $59 = $$07280 * $58;
        $60 = $59 - $$07379;
        HEAPF64[tempDoublePtr>>3] = $60;$61 = HEAP32[tempDoublePtr>>2]|0;
        $62 = HEAP32[tempDoublePtr+4>>2]|0;
        $63 = ($55|0)<($$076|0);
        $64 = (0)!=(0);
        $65 = ($62|0)!=(-1048576);
        $66 = $64 | $65;
        $67 = $63 & $66;
        if ($67) {
         $$07379$phi = $$07280;$$07280 = $60;$$07478 = $55;$$07379 = $$07379$phi;
        } else {
         $$1 = $60;
         break;
        }
       }
      } else {
       $$1 = $47;
      }
     }
     $68 = ($$075|0)==(0);
     $69 = - $$1;
     $70 = $68 ? $$1 : $69;
     $$0 = $70;
    }
   } else {
    $$0 = nan;
   }
  }
 } while(0);
 return (+$$0);
}
function _y1($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Shl(($2|0),0,1)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 | $1;
 $4 | $2;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $$0 = -inf;
  } else {
   $7 = ($2|0)<(0);
   if ($7) {
    $$0 = nan;
   } else {
    $8 = ($2>>>0)>(2146435071);
    if ($8) {
     $9 = 1.0 / $0;
     $$0 = $9;
     break;
    }
    $10 = ($2>>>0)>(1073741823);
    if ($10) {
     $11 = (+_common_47($2,$0,1,0));
     $$0 = $11;
     break;
    }
    $12 = ($2>>>0)<(1016070144);
    if ($12) {
     $13 = -0.63661977236758138 / $0;
     $$0 = $13;
     break;
    } else {
     $14 = $0 * $0;
     $15 = $14 * 9.1909915803987887E-8;
     $16 = 2.352526005616105E-5 - $15;
     $17 = $14 * $16;
     $18 = $17 + -0.0019125689587576355;
     $19 = $14 * $18;
     $20 = $19 + 0.050443871663981128;
     $21 = $14 * $20;
     $22 = $21 + -0.19605709064623894;
     $23 = $14 * 1.6655924620799208E-11;
     $24 = $23 + 6.227414523646215E-9;
     $25 = $14 * $24;
     $26 = $25 + 1.3560880109751623E-6;
     $27 = $14 * $26;
     $28 = $27 + 2.0255258102513517E-4;
     $29 = $14 * $28;
     $30 = $29 + 0.01991673182366499;
     $31 = $14 * $30;
     $32 = $31 + 1.0;
     $33 = $22 / $32;
     $34 = $33 * $0;
     $35 = (+_j1($0));
     $36 = (+Math_log((+$0)));
     $37 = $35 * $36;
     $38 = 1.0 / $0;
     $39 = $37 - $38;
     $40 = $39 * 0.63661977236758138;
     $41 = $34 + $40;
     $$0 = $41;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function ___fpclassify($0) {
 $0 = +$0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3&65535;
 $trunc$clear = $5 & 2047;
 switch ($trunc$clear<<16>>16) {
 case 0:  {
  $6 = $2 & 2147483647;
  $7 = ($1|0)==(0);
  $8 = ($6|0)==(0);
  $9 = $7 & $8;
  $10 = $9 ? 2 : 3;
  $$0 = $10;
  break;
 }
 case 2047:  {
  $11 = $2 & 1048575;
  $12 = ($1|0)==(0);
  $13 = ($11|0)==(0);
  $14 = $12 & $13;
  $15 = $14&1;
  $$0 = $15;
  break;
 }
 default: {
  $$0 = 4;
 }
 }
 return ($$0|0);
}
function _ldexpf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbnf($0,$1));
 return (+$2);
}
function _scalbnf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$020 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0;
 var $spec$select = 0, $spec$select21 = 0.0, $spec$select22 = 0, $spec$select23 = 0.0, $spec$store$select = 0, $spec$store$select1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)>(127);
 if ($2) {
  $3 = $0 * 1.7014118346046923E+38;
  $4 = (($1) + -127)|0;
  $5 = ($1|0)>(254);
  $6 = $3 * 1.7014118346046923E+38;
  $7 = (($1) + -254)|0;
  $8 = ($7|0)<(127);
  $spec$store$select = $8 ? $7 : 127;
  $spec$select = $5 ? $spec$store$select : $4;
  $spec$select21 = $5 ? $6 : $3;
  $$0 = $spec$select21;$$020 = $spec$select;
 } else {
  $9 = ($1|0)<(-126);
  if ($9) {
   $10 = $0 * 1.1754943508222875E-38;
   $11 = (($1) + 126)|0;
   $12 = ($1|0)<(-252);
   $13 = $10 * 1.1754943508222875E-38;
   $14 = (($1) + 252)|0;
   $15 = ($14|0)>(-126);
   $spec$store$select1 = $15 ? $14 : -126;
   $spec$select22 = $12 ? $spec$store$select1 : $11;
   $spec$select23 = $12 ? $13 : $10;
   $$0 = $spec$select23;$$020 = $spec$select22;
  } else {
   $$0 = $0;$$020 = $1;
  }
 }
 $16 = $$020 << 23;
 $17 = (($16) + 1065353216)|0;
 $18 = (HEAP32[tempDoublePtr>>2]=$17,+HEAPF32[tempDoublePtr>>2]);
 $19 = $$0 * $18;
 return (+$19);
}
function _sincosl($0,$1,$2) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 _sincos($0,$3,$4);
 $5 = +HEAPF64[$3>>3];
 HEAPF64[$1>>3] = $5;
 $6 = +HEAPF64[$4>>3];
 HEAPF64[$2>>3] = $6;
 STACKTOP = sp;return;
}
function _fmin($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___DOUBLE_BITS_19($0)|0);
 $3 = (getTempRet0() | 0);
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2146435072);
 $6 = ($2>>>0)>(0);
 $7 = ($4|0)==(2146435072);
 $8 = $7 & $6;
 $9 = $5 | $8;
 do {
  if ($9) {
   $$0 = $1;
  } else {
   $10 = (___DOUBLE_BITS_19($1)|0);
   $11 = (getTempRet0() | 0);
   $12 = $11 & 2147483647;
   $13 = ($12>>>0)>(2146435072);
   $14 = ($10>>>0)>(0);
   $15 = ($12|0)==(2146435072);
   $16 = $15 & $14;
   $17 = $13 | $16;
   if ($17) {
    $$0 = $0;
   } else {
    $18 = (_bitshift64Lshr(($2|0),($3|0),63)|0);
    $19 = (getTempRet0() | 0);
    $20 = (_bitshift64Lshr(($10|0),($11|0),63)|0);
    $21 = (getTempRet0() | 0);
    $22 = ($18|0)==($20|0);
    if ($22) {
     $25 = $0 < $1;
     $26 = $25 ? $0 : $1;
     $$0 = $26;
     break;
    } else {
     $23 = ($3|0)<(0);
     $24 = $23 ? $0 : $1;
     $$0 = $24;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function ___DOUBLE_BITS_19($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _cbrtf($0) {
 $0 = +$0;
 var $$039 = 0.0, $$sink40 = 0, $$sink41 = 0, $$sroa$0$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(2139095039);
 do {
  if ($3) {
   $4 = $0 + $0;
   $$039 = $4;
  } else {
   $5 = ($2>>>0)<(8388608);
   if ($5) {
    $6 = ($2|0)==(0);
    if ($6) {
     $$039 = $0;
     break;
    }
    $7 = $0 * 16777216.0;
    $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
    $9 = $8 & 2147483647;
    $$sink40 = 642849266;$$sink41 = $9;$$sroa$0$0 = $8;
   } else {
    $$sink40 = 709958130;$$sink41 = $2;$$sroa$0$0 = $1;
   }
   $10 = (($$sink41>>>0) / 3)&-1;
   $11 = (($10) + ($$sink40))|0;
   $12 = $$sroa$0$0 & -2147483648;
   $13 = $12 | $11;
   $14 = (HEAP32[tempDoublePtr>>2]=$13,+HEAPF32[tempDoublePtr>>2]);
   $15 = $14;
   $16 = $15 * $15;
   $17 = $16 * $15;
   $18 = $0;
   $19 = $18 + $18;
   $20 = $19 + $17;
   $21 = $20 * $15;
   $22 = $17 + $18;
   $23 = $17 + $22;
   $24 = $21 / $23;
   $25 = $24 * $24;
   $26 = $24 * $25;
   $27 = $19 + $26;
   $28 = $24 * $27;
   $29 = $26 + $18;
   $30 = $26 + $29;
   $31 = $28 / $30;
   $32 = $31;
   $$039 = $32;
  }
 } while(0);
 return (+$$039);
}
function _nexttowardf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$sroa$0$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = (___FLOAT_BITS($0)|0);
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2139095040);
 do {
  if ($5) {
   label = 3;
  } else {
   $6 = (___DOUBLE_BITS_20($1)|0);
   $7 = (getTempRet0() | 0);
   $8 = $7 & 2147483647;
   $9 = ($8>>>0)>(2146435072);
   $10 = ($6>>>0)>(0);
   $11 = ($8|0)==(2146435072);
   $12 = $11 & $10;
   $13 = $9 | $12;
   if ($13) {
    label = 3;
   } else {
    $17 = $0;
    $18 = $17 == $1;
    if ($18) {
     $19 = $1;
     $$0 = $19;
     break;
    }
    $20 = $0 == 0.0;
    do {
     if ($20) {
      $21 = $7 & -2147483648;
      $22 = $21 | 1;
      $$sroa$0$0 = $22;
     } else {
      $23 = $17 < $1;
      $24 = ($3|0)<(0);
      if ($23) {
       if ($24) {
        $25 = (($2) + -1)|0;
        $$sroa$0$0 = $25;
        break;
       } else {
        $26 = (($2) + 1)|0;
        $$sroa$0$0 = $26;
        break;
       }
      } else {
       if ($24) {
        $27 = (($2) + 1)|0;
        $$sroa$0$0 = $27;
        break;
       } else {
        $28 = (($2) + -1)|0;
        $$sroa$0$0 = $28;
        break;
       }
      }
     }
    } while(0);
    $29 = (HEAP32[tempDoublePtr>>2]=$$sroa$0$0,+HEAPF32[tempDoublePtr>>2]);
    $$0 = $29;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $14 = $0;
  $15 = $14 + $1;
  $16 = $15;
  $$0 = $16;
 }
 return (+$$0);
}
function ___FLOAT_BITS($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function ___DOUBLE_BITS_20($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _sinh($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0;
 var $7 = 0.0, $8 = 0, $9 = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = ($2|0)<(0);
 $spec$select = $3 ? -0.5 : 0.5;
 $4 = $2 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $1;HEAP32[tempDoublePtr+4>>2] = $4;$5 = +HEAPF64[tempDoublePtr>>3];
 $6 = ($4>>>0)<(1082535490);
 do {
  if ($6) {
   $7 = (+_expm1($5));
   $8 = ($4>>>0)<(1072693248);
   if (!($8)) {
    $16 = $7 + 1.0;
    $17 = $7 / $16;
    $18 = $7 + $17;
    $19 = $spec$select * $18;
    $$0 = $19;
    break;
   }
   $9 = ($4>>>0)<(1045430272);
   if ($9) {
    $$0 = $0;
   } else {
    $10 = $7 * 2.0;
    $11 = $7 * $7;
    $12 = $7 + 1.0;
    $13 = $11 / $12;
    $14 = $10 - $13;
    $15 = $spec$select * $14;
    $$0 = $15;
   }
  } else {
   $20 = $spec$select * 2.0;
   $21 = (+___expo2($5));
   $22 = $20 * $21;
   $$0 = $22;
  }
 } while(0);
 return (+$$0);
}
function _expm1($0) {
 $0 = +$0;
 var $$0 = 0.0, $$0105 = 0, $$0106 = 0.0, $$0107 = 0.0, $$0109 = 0.0, $$0110 = 0.0, $$0111 = 0.0, $$1 = 0, $$1108 = 0.0, $$sink = 0.0, $$sink113 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0;
 var $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0;
 var $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0;
 var $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0;
 var $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $5 = (getTempRet0() | 0);
 $6 = ($3>>>0)>(1078159481);
 do {
  if ($6) {
   $7 = (___DOUBLE_BITS_88($0)|0);
   $8 = (getTempRet0() | 0);
   $9 = $8 & 2147483647;
   $10 = ($9>>>0)>(2146435072);
   $11 = ($7>>>0)>(0);
   $12 = ($9|0)==(2146435072);
   $13 = $12 & $11;
   $14 = $10 | $13;
   if ($14) {
    $$0 = $0;
   } else {
    $15 = ($4|0)==(0);
    if ($15) {
     $16 = $0 > 709.78271289338397;
     if ($16) {
      $17 = $0 * 8.9884656743115795E+307;
      $$0 = $17;
     } else {
      label = 11;
     }
    } else {
     $$0 = -1.0;
    }
   }
  } else {
   $18 = ($3>>>0)>(1071001154);
   if (!($18)) {
    $35 = ($3>>>0)<(1016070144);
    if ($35) {
     $$0 = $0;
     break;
    } else {
     $$0106 = $0;$$0111 = 0.0;$$1 = 0;
     label = 14;
     break;
    }
   }
   $19 = ($3>>>0)<(1072734898);
   if ($19) {
    $20 = ($4|0)==(0);
    if ($20) {
     $21 = $0 + -0.69314718036912382;
     $$0105 = 1;$$0109 = $21;$$0110 = 1.9082149292705877E-10;
     label = 12;
     break;
    } else {
     $22 = $0 + 0.69314718036912382;
     $$0105 = -1;$$0109 = $22;$$0110 = -1.9082149292705877E-10;
     label = 12;
     break;
    }
   } else {
    label = 11;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $23 = $0 * 1.4426950408889634;
  $24 = ($4|0)==(0);
  $25 = $24 ? 0.5 : -0.5;
  $26 = $23 + $25;
  $27 = (~~(($26)));
  $28 = (+($27|0));
  $29 = $28 * 0.69314718036912382;
  $30 = $0 - $29;
  $31 = $28 * 1.9082149292705877E-10;
  $$0105 = $27;$$0109 = $30;$$0110 = $31;
  label = 12;
 }
 if ((label|0) == 12) {
  $32 = $$0109 - $$0110;
  $33 = $$0109 - $32;
  $34 = $33 - $$0110;
  $$0106 = $32;$$0111 = $34;$$1 = $$0105;
  label = 14;
 }
 L18: do {
  if ((label|0) == 14) {
   $36 = $$0106 * 0.5;
   $37 = $$0106 * $36;
   $38 = $37 * 2.0109921818362437E-7;
   $39 = 4.0082178273293624E-6 - $38;
   $40 = $37 * $39;
   $41 = $40 + -7.9365075786748794E-5;
   $42 = $37 * $41;
   $43 = $42 + 0.0015873015872548146;
   $44 = $37 * $43;
   $45 = $44 + -0.033333333333333132;
   $46 = $37 * $45;
   $47 = $46 + 1.0;
   $48 = $36 * $47;
   $49 = 3.0 - $48;
   $50 = $47 - $49;
   $51 = $$0106 * $49;
   $52 = 6.0 - $51;
   $53 = $50 / $52;
   $54 = $37 * $53;
   $55 = ($$1|0)==(0);
   if ($55) {
    $56 = $$0106 * $54;
    $57 = $56 - $37;
    $58 = $$0106 - $57;
    $$0 = $58;
    break;
   }
   $59 = $54 - $$0111;
   $60 = $$0106 * $59;
   $61 = $60 - $$0111;
   $62 = $61 - $37;
   switch ($$1|0) {
   case -1:  {
    $63 = $$0106 - $62;
    $64 = $63 * 0.5;
    $65 = $64 + -0.5;
    $$0 = $65;
    break L18;
    break;
   }
   case 1:  {
    $66 = $$0106 < -0.25;
    if ($66) {
     $67 = $$0106 + 0.5;
     $68 = $62 - $67;
     $69 = $68 * -2.0;
     $$0 = $69;
     break L18;
    } else {
     $70 = $$0106 - $62;
     $71 = $70 * 2.0;
     $72 = $71 + 1.0;
     $$0 = $72;
     break L18;
    }
    break;
   }
   default: {
    $73 = (($$1) + 1023)|0;
    $74 = (_bitshift64Shl(($73|0),0,52)|0);
    $75 = (getTempRet0() | 0);
    HEAP32[tempDoublePtr>>2] = $74;HEAP32[tempDoublePtr+4>>2] = $75;$76 = +HEAPF64[tempDoublePtr>>3];
    $77 = ($$1>>>0)>(56);
    if ($77) {
     $78 = $$0106 - $62;
     $79 = $78 + 1.0;
     $80 = ($$1|0)==(1024);
     $81 = $79 * 2.0;
     $82 = $81 * 8.9884656743115795E+307;
     $83 = $79 * $76;
     $$0107 = $80 ? $82 : $83;
     $84 = $$0107 + -1.0;
     $$0 = $84;
     break L18;
    }
    $85 = (1023 - ($$1))|0;
    $86 = (_bitshift64Shl(($85|0),0,52)|0);
    $87 = (getTempRet0() | 0);
    $88 = ($$1|0)<(20);
    if ($88) {
     $89 = $$0106 - $62;
     HEAP32[tempDoublePtr>>2] = $86;HEAP32[tempDoublePtr+4>>2] = $87;$90 = +HEAPF64[tempDoublePtr>>3];
     $91 = 1.0 - $90;
     $$sink = $91;$$sink113 = $89;
    } else {
     HEAP32[tempDoublePtr>>2] = $86;HEAP32[tempDoublePtr+4>>2] = $87;$92 = +HEAPF64[tempDoublePtr>>3];
     $93 = $62 + $92;
     $94 = $$0106 - $93;
     $$sink = $94;$$sink113 = 1.0;
    }
    $95 = $$sink + $$sink113;
    $$1108 = $95 * $76;
    $$0 = $$1108;
    break L18;
   }
   }
  }
 } while(0);
 return (+$$0);
}
function ___expo2($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 + -1416.0996898839683;
 $2 = (+Math_exp((+$1)));
 $3 = $2 * 2.2471164185778949E+307;
 $4 = $3 * 2.2471164185778949E+307;
 return (+$4);
}
function ___DOUBLE_BITS_88($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _tgammal($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_tgamma($0));
 return (+$1);
}
function _tgamma($0) {
 $0 = +$0;
 var $$ = 0.0, $$0 = 0.0, $$055 = 0.0, $$056 = 0.0, $$057 = 0.0, $$1 = 0.0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0;
 var $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0;
 var $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $5 = (getTempRet0() | 0);
 $6 = ($3>>>0)>(2146435071);
 do {
  if ($6) {
   $7 = $0 + inf;
   $$0 = $7;
  } else {
   $8 = ($3>>>0)<(1016070144);
   if ($8) {
    $9 = 1.0 / $0;
    $$0 = $9;
    break;
   }
   $10 = (+Math_floor((+$0)));
   $11 = $10 == $0;
   if ($11) {
    $12 = ($4|0)==(0);
    if (!($12)) {
     $$0 = nan;
     break;
    }
    $13 = !($0 <= 23.0);
    if (!($13)) {
     $14 = (~~(($0)));
     $15 = (($14) + -1)|0;
     $16 = ((gb + (8256) | 0) + ($15<<3)|0);
     $17 = +HEAPF64[$16>>3];
     $$0 = $17;
     break;
    }
   }
   $18 = ($3>>>0)>(1080492031);
   $19 = ($4|0)!=(0);
   if ($18) {
    if ($19) {
     $20 = (+Math_floor((+$0)));
     $21 = $20 * 0.5;
     $22 = $0 * 0.5;
     $23 = (+Math_floor((+$22)));
     $24 = $21 == $23;
     $$ = $24 ? 0.0 : -0.0;
     $$0 = $$;
     break;
    } else {
     $25 = $0 * 8.9884656743115795E+307;
     $$0 = $25;
     break;
    }
   } else {
    $26 = - $0;
    $27 = $19 ? $26 : $0;
    $28 = $27 + 5.5246800407767296;
    $29 = $27 > 5.5246800407767296;
    $30 = $28 - $27;
    $31 = $30 + -5.5246800407767296;
    $32 = $28 + -5.5246800407767296;
    $33 = $32 - $27;
    $$057 = $29 ? $31 : $33;
    $34 = $27 + -0.5;
    $35 = (+_S($27));
    $36 = - $28;
    $37 = (+Math_exp((+$36)));
    $38 = $35 * $37;
    $39 = $0 < 0.0;
    if ($39) {
     $40 = - $34;
     $41 = - $$057;
     $42 = (+_sinpi($27));
     $43 = $27 * $42;
     $44 = $38 * $43;
     $45 = -3.1415926535897931 / $44;
     $$055 = $45;$$056 = $40;$$1 = $41;
    } else {
     $$055 = $38;$$056 = $34;$$1 = $$057;
    }
    $46 = $$1 * 6.0246800407767296;
    $47 = $46 * $$055;
    $48 = $47 / $28;
    $49 = $$055 + $48;
    $50 = $$056 * 0.5;
    $51 = (+Math_pow((+$28),(+$50)));
    $52 = $51 * $49;
    $53 = $51 * $52;
    $$0 = $53;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _S($0) {
 $0 = +$0;
 var $$02330 = 0.0, $$02529 = 0.0, $$031 = 0, $$12433 = 0.0, $$12632 = 0.0, $$134 = 0, $$2 = 0.0, $$227 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0.0;
 var $20 = 0, $21 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 < 8.0;
 if ($1) {
  $$02330 = 0.0;$$02529 = 0.0;$$031 = 12;
  while(1) {
   $2 = $$02529 * $0;
   $3 = ((gb + (8448) | 0) + ($$031<<3)|0);
   $4 = +HEAPF64[$3>>3];
   $5 = $2 + $4;
   $6 = $$02330 * $0;
   $7 = ((gb + (8560) | 0) + ($$031<<3)|0);
   $8 = +HEAPF64[$7>>3];
   $9 = $6 + $8;
   $10 = (($$031) + -1)|0;
   $11 = ($$031|0)==(0);
   if ($11) {
    $$2 = $9;$$227 = $5;
    break;
   } else {
    $$02330 = $9;$$02529 = $5;$$031 = $10;
   }
  }
 } else {
  $$12433 = 0.0;$$12632 = 0.0;$$134 = 0;
  while(1) {
   $12 = $$12632 / $0;
   $13 = ((gb + (8448) | 0) + ($$134<<3)|0);
   $14 = +HEAPF64[$13>>3];
   $15 = $12 + $14;
   $16 = $$12433 / $0;
   $17 = ((gb + (8560) | 0) + ($$134<<3)|0);
   $18 = +HEAPF64[$17>>3];
   $19 = $16 + $18;
   $20 = (($$134) + 1)|0;
   $exitcond = ($20|0)==(13);
   if ($exitcond) {
    $$2 = $19;$$227 = $15;
    break;
   } else {
    $$12433 = $19;$$12632 = $15;$$134 = $20;
   }
  }
 }
 $21 = $$227 / $$2;
 return (+$21);
}
function _sinpi($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = $0 * 0.5;
 $2 = (+Math_floor((+$1)));
 $3 = $1 - $2;
 $4 = $3 * 2.0;
 $5 = $4 * 4.0;
 $6 = (~~(($5)));
 $7 = (($6) + 1)|0;
 $8 = (($7|0) / 2)&-1;
 $9 = (+($8|0));
 $10 = $9 * 0.5;
 $11 = $4 - $10;
 $12 = $11 * 3.1415926535897931;
 switch ($8|0) {
 case 3:  {
  $17 = (+___cos($12,0.0));
  $18 = - $17;
  $$0 = $18;
  break;
 }
 case 1:  {
  $14 = (+___cos($12,0.0));
  $$0 = $14;
  break;
 }
 case 2:  {
  $15 = - $12;
  $16 = (+___sin($15,0.0,0));
  $$0 = $16;
  break;
 }
 default: {
  $13 = (+___sin($12,0.0,0));
  $$0 = $13;
 }
 }
 return (+$$0);
}
function _expm1f($0) {
 $0 = +$0;
 var $$0 = 0.0, $$0102 = 0, $$0103 = 0.0, $$0104 = 0.0, $$0106 = 0.0, $$0107 = 0.0, $$0108 = 0.0, $$1 = 0, $$1105 = 0.0, $$sink = 0.0, $$sink110 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0;
 var $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0;
 var $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0;
 var $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0;
 var $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = $1 >>> 31;
 $4 = ($2>>>0)>(1100331075);
 do {
  if ($4) {
   $5 = ($2>>>0)>(2139095040);
   if ($5) {
    $$0 = $0;
   } else {
    $6 = ($3|0)==(0);
    if ($6) {
     $7 = $0 > 88.7216796875;
     if ($7) {
      $8 = $0 * 1.7014118346046923E+38;
      $$0 = $8;
     } else {
      label = 11;
     }
    } else {
     $$0 = -1.0;
    }
   }
  } else {
   $9 = ($2>>>0)>(1051816472);
   if (!($9)) {
    $26 = ($2>>>0)<(855638016);
    if ($26) {
     $$0 = $0;
     break;
    } else {
     $$0103 = $0;$$0108 = 0.0;$$1 = 0;
     label = 14;
     break;
    }
   }
   $10 = ($2>>>0)<(1065686418);
   if ($10) {
    $11 = ($3|0)==(0);
    if ($11) {
     $12 = $0 + -0.69313812255859375;
     $$0102 = 1;$$0106 = $12;$$0107 = 9.0580006144591607E-6;
     label = 12;
     break;
    } else {
     $13 = $0 + 0.69313812255859375;
     $$0102 = -1;$$0106 = $13;$$0107 = -9.0580006144591607E-6;
     label = 12;
     break;
    }
   } else {
    label = 11;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $14 = $0 * 1.4426950216293335;
  $15 = ($3|0)==(0);
  $16 = $15 ? 0.5 : -0.5;
  $17 = $14 + $16;
  $18 = (~~(($17)));
  $19 = (+($18|0));
  $20 = $19 * 0.69313812255859375;
  $21 = $0 - $20;
  $22 = $19 * 9.0580006144591607E-6;
  $$0102 = $18;$$0106 = $21;$$0107 = $22;
  label = 12;
 }
 if ((label|0) == 12) {
  $23 = $$0106 - $$0107;
  $24 = $$0106 - $23;
  $25 = $24 - $$0107;
  $$0103 = $23;$$0108 = $25;$$1 = $$0102;
  label = 14;
 }
 L18: do {
  if ((label|0) == 14) {
   $27 = $$0103 * 0.5;
   $28 = $$0103 * $27;
   $29 = $28 * 0.0015807170420885086;
   $30 = $29 + -0.03333321213722229;
   $31 = $28 * $30;
   $32 = $31 + 1.0;
   $33 = $27 * $32;
   $34 = 3.0 - $33;
   $35 = $32 - $34;
   $36 = $$0103 * $34;
   $37 = 6.0 - $36;
   $38 = $35 / $37;
   $39 = $28 * $38;
   $40 = ($$1|0)==(0);
   if ($40) {
    $41 = $$0103 * $39;
    $42 = $41 - $28;
    $43 = $$0103 - $42;
    $$0 = $43;
    break;
   }
   $44 = $39 - $$0108;
   $45 = $$0103 * $44;
   $46 = $45 - $$0108;
   $47 = $46 - $28;
   switch ($$1|0) {
   case -1:  {
    $48 = $$0103 - $47;
    $49 = $48 * 0.5;
    $50 = $49 + -0.5;
    $$0 = $50;
    break L18;
    break;
   }
   case 1:  {
    $51 = $$0103 < -0.25;
    if ($51) {
     $52 = $$0103 + 0.5;
     $53 = $47 - $52;
     $54 = $53 * -2.0;
     $$0 = $54;
     break L18;
    } else {
     $55 = $$0103 - $47;
     $56 = $55 * 2.0;
     $57 = $56 + 1.0;
     $$0 = $57;
     break L18;
    }
    break;
   }
   default: {
    $58 = $$1 << 23;
    $59 = (($58) + 1065353216)|0;
    $60 = (HEAP32[tempDoublePtr>>2]=$59,+HEAPF32[tempDoublePtr>>2]);
    $61 = ($$1>>>0)>(56);
    if ($61) {
     $62 = $$0103 - $47;
     $63 = $62 + 1.0;
     $64 = ($$1|0)==(128);
     $65 = $63 * 2.0;
     $66 = $65 * 1.7014118346046923E+38;
     $67 = $63 * $60;
     $$0104 = $64 ? $66 : $67;
     $68 = $$0104 + -1.0;
     $$0 = $68;
     break L18;
    }
    $69 = (1065353216 - ($58))|0;
    $70 = ($$1|0)<(23);
    if ($70) {
     $71 = $$0103 - $47;
     $72 = (HEAP32[tempDoublePtr>>2]=$69,+HEAPF32[tempDoublePtr>>2]);
     $73 = 1.0 - $72;
     $$sink = $73;$$sink110 = $71;
    } else {
     $74 = (HEAP32[tempDoublePtr>>2]=$69,+HEAPF32[tempDoublePtr>>2]);
     $75 = $47 + $74;
     $76 = $$0103 - $75;
     $$sink = $76;$$sink110 = 1.0;
    }
    $77 = $$sink + $$sink110;
    $$1105 = $77 * $60;
    $$0 = $$1105;
    break L18;
   }
   }
  }
 } while(0);
 return (+$$0);
}
function _scalb($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___DOUBLE_BITS_21($0)|0);
 $3 = (getTempRet0() | 0);
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2146435072);
 $6 = ($2>>>0)>(0);
 $7 = ($4|0)==(2146435072);
 $8 = $7 & $6;
 $9 = $5 | $8;
 do {
  if ($9) {
   label = 3;
  } else {
   $10 = (___DOUBLE_BITS_21($1)|0);
   $11 = (getTempRet0() | 0);
   $12 = $11 & 2147483647;
   $13 = ($12>>>0)>(2146435072);
   $14 = ($10>>>0)>(0);
   $15 = ($12|0)==(2146435072);
   $16 = $15 & $14;
   $17 = $13 | $16;
   if ($17) {
    label = 3;
   } else {
    $19 = $11 & 2146435072;
    $20 = (0)==(0);
    $21 = ($19|0)==(2146435072);
    $22 = $20 & $21;
    if ($22) {
     $23 = $1 > 0.0;
     if ($23) {
      $24 = $0 * $1;
      $$0 = $24;
      break;
     } else {
      $25 = - $1;
      $26 = $0 / $25;
      $$0 = $26;
      break;
     }
    }
    $27 = (+_rint($1));
    $28 = $27 != $1;
    if ($28) {
     $29 = $1 - $1;
     $30 = $29 / $29;
     $$0 = $30;
     break;
    }
    $31 = $1 > 65000.0;
    if ($31) {
     $32 = (+_scalbn($0,65000));
     $$0 = $32;
     break;
    }
    $33 = $1 < -65000.0;
    if ($33) {
     $34 = (+_scalbn($0,-65000));
     $$0 = $34;
     break;
    } else {
     $35 = (~~(($1)));
     $36 = (+_scalbn($0,$35));
     $$0 = $36;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $18 = $0 * $1;
  $$0 = $18;
 }
 return (+$$0);
}
function ___DOUBLE_BITS_21($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _log10($0) {
 $0 = +$0;
 var $$0 = 0, $$0100 = 0, $$0101 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0;
 var $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $8 = 0, $9 = 0.0, $or$cond = 0, $or$cond105 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = ($2>>>0)<(1048576);
 $4 = ($2|0)<(0);
 $or$cond = $4 | $3;
 do {
  if ($or$cond) {
   $5 = $2 & 2147483647;
   $6 = ($1|0)==(0);
   $7 = ($5|0)==(0);
   $8 = $6 & $7;
   if ($8) {
    $9 = $0 * $0;
    $10 = -1.0 / $9;
    $$0101 = $10;
    break;
   }
   if ($4) {
    $11 = $0 - $0;
    $12 = $11 / 0.0;
    $$0101 = $12;
    break;
   } else {
    $13 = $0 * 18014398509481984.0;
    HEAPF64[tempDoublePtr>>3] = $13;$14 = HEAP32[tempDoublePtr>>2]|0;
    $15 = HEAP32[tempDoublePtr+4>>2]|0;
    $$0 = -1077;$$0100 = $15;$27 = 0;$29 = $14;
    label = 9;
    break;
   }
  } else {
   $16 = ($2>>>0)>(2146435071);
   if ($16) {
    $$0101 = $0;
   } else {
    $17 = ($2|0)==(1072693248);
    $18 = ($1|0)==(0);
    $19 = (0)==(0);
    $20 = $18 & $19;
    $or$cond105 = $20 & $17;
    if ($or$cond105) {
     $$0101 = 0.0;
    } else {
     $$0 = -1023;$$0100 = $2;$27 = 0;$29 = $1;
     label = 9;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $21 = (($$0100) + 614242)|0;
  $22 = $21 >>> 20;
  $23 = (($$0) + ($22))|0;
  $24 = $21 & 1048575;
  $25 = (($24) + 1072079006)|0;
  $26 = $25 | $27;
  HEAP32[tempDoublePtr>>2] = $29;HEAP32[tempDoublePtr+4>>2] = $26;$28 = +HEAPF64[tempDoublePtr>>3];
  $30 = $28 + -1.0;
  $31 = $30 * 0.5;
  $32 = $30 * $31;
  $33 = $30 + 2.0;
  $34 = $30 / $33;
  $35 = $34 * $34;
  $36 = $35 * $35;
  $37 = $36 * 0.15313837699209373;
  $38 = $37 + 0.22222198432149784;
  $39 = $36 * $38;
  $40 = $39 + 0.39999999999409419;
  $41 = $36 * $40;
  $42 = $36 * 0.14798198605116586;
  $43 = $42 + 0.1818357216161805;
  $44 = $36 * $43;
  $45 = $44 + 0.28571428743662391;
  $46 = $36 * $45;
  $47 = $46 + 0.66666666666667351;
  $48 = $35 * $47;
  $49 = $41 + $48;
  $50 = $30 - $32;
  HEAPF64[tempDoublePtr>>3] = $50;$51 = HEAP32[tempDoublePtr>>2]|0;
  $52 = HEAP32[tempDoublePtr+4>>2]|0;
  HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $52;$53 = +HEAPF64[tempDoublePtr>>3];
  $54 = $30 - $53;
  $55 = $54 - $32;
  $56 = $32 + $49;
  $57 = $34 * $56;
  $58 = $55 + $57;
  $59 = $53 * 0.43429448187816888;
  $60 = (+($23|0));
  $61 = $60 * 0.30102999566361177;
  $62 = $60 * 3.6942390771589308E-13;
  $63 = $58 + $53;
  $64 = $63 * 2.5082946711645275E-11;
  $65 = $62 + $64;
  $66 = $58 * 0.43429448187816888;
  $67 = $66 + $65;
  $68 = $61 + $59;
  $69 = $61 - $68;
  $70 = $59 + $69;
  $71 = $70 + $67;
  $72 = $68 + $71;
  $$0101 = $72;
 }
 return (+$$0101);
}
function _finitef($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___FLOAT_BITS_22($0)|0);
 $2 = $1 & 2139095040;
 $3 = ($2|0)!=(2139095040);
 $4 = $3&1;
 return ($4|0);
}
function ___FLOAT_BITS_22($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _fmaxf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$unshifted = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___FLOAT_BITS_27($0)|0);
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095040);
 do {
  if ($4) {
   $$0 = $1;
  } else {
   $5 = (___FLOAT_BITS_27($1)|0);
   $6 = $5 & 2147483647;
   $7 = ($6>>>0)>(2139095040);
   if ($7) {
    $$0 = $0;
   } else {
    $$unshifted = $5 ^ $2;
    $8 = ($$unshifted|0)<(0);
    if ($8) {
     $9 = ($2|0)<(0);
     $10 = $9 ? $1 : $0;
     $$0 = $10;
     break;
    } else {
     $11 = $0 < $1;
     $12 = $11 ? $1 : $0;
     $$0 = $12;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function ___FLOAT_BITS_27($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _modff($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$mask = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = $2 >>> 23;
 $4 = $3 & 255;
 $5 = (($4) + -127)|0;
 $6 = ($4>>>0)>(149);
 if ($6) {
  HEAPF32[$1>>2] = $0;
  $7 = ($5|0)!=(128);
  $$mask = $2 & 8388607;
  $8 = ($$mask|0)==(0);
  $or$cond = $8 | $7;
  $9 = $2 & -2147483648;
  $10 = (HEAP32[tempDoublePtr>>2]=$9,+HEAPF32[tempDoublePtr>>2]);
  $spec$select = $or$cond ? $10 : $0;
  return (+$spec$select);
 }
 $11 = ($4>>>0)<(127);
 do {
  if ($11) {
   $12 = $2 & -2147483648;
   HEAP32[$1>>2] = $12;
   $$0 = $0;
  } else {
   $13 = 8388607 >>> $5;
   $14 = $13 & $2;
   $15 = ($14|0)==(0);
   if ($15) {
    HEAPF32[$1>>2] = $0;
    $16 = $2 & -2147483648;
    $17 = (HEAP32[tempDoublePtr>>2]=$16,+HEAPF32[tempDoublePtr>>2]);
    $$0 = $17;
    break;
   } else {
    $18 = -8388608 >> $5;
    $19 = $18 & $2;
    $20 = (HEAP32[tempDoublePtr>>2]=$19,+HEAPF32[tempDoublePtr>>2]);
    HEAP32[$1>>2] = $19;
    $21 = $0 - $20;
    $$0 = $21;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function ___cosdf($0) {
 $0 = +$0;
 var $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 * $0;
 $2 = $1 * $1;
 $3 = $1 * 2.4390448796277409E-5;
 $4 = $3 + -0.0013886763774609929;
 $5 = $1 * 0.499999997251031;
 $6 = 1.0 - $5;
 $7 = $2 * 0.041666623323739063;
 $8 = $6 + $7;
 $9 = $1 * $2;
 $10 = $9 * $4;
 $11 = $8 + $10;
 $12 = $11;
 return (+$12);
}
function _j1f($0) {
 $0 = +$0;
 var $$0 = 0.0, $$035 = 0.0, $$035$in = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 31;
 $3 = $1 & 2147483647;
 $4 = ($3>>>0)>(2139095039);
 do {
  if ($4) {
   $5 = $0 * $0;
   $6 = 1.0 / $5;
   $$0 = $6;
  } else {
   $7 = ($3>>>0)>(1073741823);
   if ($7) {
    $8 = (+Math_abs((+$0)));
    $9 = (+_common_28($3,$8,0,$2));
    $$0 = $9;
    break;
   }
   $10 = ($3>>>0)>(838860799);
   if ($10) {
    $11 = $0 * $0;
    $12 = $11 * 4.9672799207201024E-8;
    $13 = $12 + -1.5995563444448635E-5;
    $14 = $11 * $13;
    $15 = $14 + 0.0014070566976442933;
    $16 = $11 * $15;
    $17 = $16 + -0.0625;
    $18 = $11 * $17;
    $19 = $11 * 1.2354227016397878E-11;
    $20 = $19 + 5.0463624390317818E-9;
    $21 = $11 * $20;
    $22 = $21 + 1.1771846857300261E-6;
    $23 = $11 * $22;
    $24 = $23 + 1.8594678840599954E-4;
    $25 = $11 * $24;
    $26 = $25 + 0.019153760746121407;
    $27 = $11 * $26;
    $28 = $27 + 1.0;
    $29 = $18 / $28;
    $$035$in = $29;
   } else {
    $$035$in = $0;
   }
   $$035 = $$035$in + 0.5;
   $30 = $$035 * $0;
   $$0 = $30;
  }
 } while(0);
 return (+$$0);
}
function _common_28($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0.0, $$034 = 0.0, $$1 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $spec$select = 0.0, $spec$select37 = 0.0, $spec$select38 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = (+Math_sin((+$1)));
 $5 = $4;
 $6 = ($2|0)!=(0);
 $7 = - $5;
 $spec$select = $6 ? $7 : $5;
 $8 = (+Math_cos((+$1)));
 $9 = $8;
 $10 = $spec$select - $9;
 $11 = ($0>>>0)<(2130706432);
 if ($11) {
  $12 = - $spec$select;
  $13 = $12 - $9;
  $14 = $1 * 2.0;
  $15 = (+Math_cos((+$14)));
  $16 = $15;
  $17 = $spec$select * $9;
  $18 = $17 > 0.0;
  if ($18) {
   $19 = $16 / $13;
   $$0 = $19;$$034 = $13;
  } else {
   $20 = $16 / $10;
   $$0 = $10;$$034 = $20;
  }
  $21 = ($0>>>0)<(1484783616);
  if ($21) {
   $22 = - $$034;
   $spec$select37 = $6 ? $22 : $$034;
   $23 = (+_ponef($1));
   $24 = $23;
   $25 = $$0 * $24;
   $26 = (+_qonef($1));
   $27 = $26;
   $28 = $spec$select37 * $27;
   $29 = $25 - $28;
   $$1 = $29;
  } else {
   $$1 = $$0;
  }
 } else {
  $$1 = $10;
 }
 $30 = ($3|0)==(0);
 $31 = - $$1;
 $spec$select38 = $30 ? $$1 : $31;
 $32 = $spec$select38 * 0.564189612865448;
 $33 = (+Math_sqrt((+$1)));
 $34 = $33;
 $35 = $32 / $34;
 $36 = $35;
 return (+$36);
}
function _ponef($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$041 = 0, $$42 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(1090519039);
 if ($3) {
  $$0 = (gb + (8992) | 0);$$041 = (gb + (8928) | 0);
 } else {
  $4 = ($2>>>0)>(1089936471);
  $5 = ($2>>>0)>(1077336935);
  if ($4) {
   $$0 = (gb + (9024) | 0);$$041 = (gb + (8960) | 0);
  } else {
   $$42 = $5 ? (gb + (8800) | 0) : (gb + (8832) | 0);
   $$ = $5 ? (gb + (8864) | 0) : (gb + (8896) | 0);
   $$0 = $$42;$$041 = $$;
  }
 }
 $6 = $0 * $0;
 $7 = 1.0 / $6;
 $8 = +HEAPF32[$$0>>2];
 $9 = ((($$0)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = ((($$0)) + 8|0);
 $12 = +HEAPF32[$11>>2];
 $13 = ((($$0)) + 12|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($$0)) + 16|0);
 $16 = +HEAPF32[$15>>2];
 $17 = ((($$0)) + 20|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $7 * $18;
 $20 = $16 + $19;
 $21 = $7 * $20;
 $22 = $14 + $21;
 $23 = $7 * $22;
 $24 = $12 + $23;
 $25 = $7 * $24;
 $26 = $10 + $25;
 $27 = $7 * $26;
 $28 = $8 + $27;
 $29 = +HEAPF32[$$041>>2];
 $30 = ((($$041)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($$041)) + 8|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($$041)) + 12|0);
 $35 = +HEAPF32[$34>>2];
 $36 = ((($$041)) + 16|0);
 $37 = +HEAPF32[$36>>2];
 $38 = $7 * $37;
 $39 = $35 + $38;
 $40 = $7 * $39;
 $41 = $33 + $40;
 $42 = $7 * $41;
 $43 = $31 + $42;
 $44 = $7 * $43;
 $45 = $29 + $44;
 $46 = $7 * $45;
 $47 = $46 + 1.0;
 $48 = $28 / $47;
 $49 = $48 + 1.0;
 return (+$49);
}
function _qonef($0) {
 $0 = +$0;
 var $$0 = 0, $$044 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2145386496;
 $3 = ($2>>>0)>(1075838975);
 $$044 = $3 ? (gb + (8672) | 0) : (gb + (8704) | 0);
 $$0 = $3 ? (gb + (8736) | 0) : (gb + (8768) | 0);
 $4 = $0 * $0;
 $5 = 1.0 / $4;
 $6 = +HEAPF32[$$0>>2];
 $7 = ((($$0)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = ((($$0)) + 8|0);
 $10 = +HEAPF32[$9>>2];
 $11 = ((($$0)) + 12|0);
 $12 = +HEAPF32[$11>>2];
 $13 = ((($$0)) + 16|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($$0)) + 20|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $5 * $16;
 $18 = $14 + $17;
 $19 = $5 * $18;
 $20 = $12 + $19;
 $21 = $5 * $20;
 $22 = $10 + $21;
 $23 = $5 * $22;
 $24 = $8 + $23;
 $25 = $5 * $24;
 $26 = $6 + $25;
 $27 = +HEAPF32[$$044>>2];
 $28 = ((($$044)) + 4|0);
 $29 = +HEAPF32[$28>>2];
 $30 = ((($$044)) + 8|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($$044)) + 12|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($$044)) + 16|0);
 $35 = +HEAPF32[$34>>2];
 $36 = ((($$044)) + 20|0);
 $37 = +HEAPF32[$36>>2];
 $38 = $5 * $37;
 $39 = $35 + $38;
 $40 = $5 * $39;
 $41 = $33 + $40;
 $42 = $5 * $41;
 $43 = $31 + $42;
 $44 = $5 * $43;
 $45 = $29 + $44;
 $46 = $5 * $45;
 $47 = $27 + $46;
 $48 = $5 * $47;
 $49 = $48 + 1.0;
 $50 = $26 / $49;
 $51 = $50 + 0.375;
 $52 = $51 / $0;
 return (+$52);
}
function _y1f($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $$0 = -inf;
  } else {
   $4 = ($1|0)<(0);
   if ($4) {
    $$0 = nan;
   } else {
    $5 = ($1>>>0)>(2139095039);
    if ($5) {
     $6 = 1.0 / $0;
     $$0 = $6;
     break;
    }
    $7 = ($1>>>0)>(1073741823);
    if ($7) {
     $8 = (+_common_28($1,$0,1,0));
     $$0 = $8;
     break;
    }
    $9 = ($1>>>0)<(838860800);
    if ($9) {
     $10 = -0.63661974668502808 / $0;
     $$0 = $10;
     break;
    } else {
     $11 = $0 * $0;
     $12 = $11 * 9.1909917898647109E-8;
     $13 = 2.3525259166490287E-5 - $12;
     $14 = $11 * $13;
     $15 = $14 + -0.0019125689286738634;
     $16 = $11 * $15;
     $17 = $16 + 0.050443872809410095;
     $18 = $11 * $17;
     $19 = $18 + -0.19605709612369537;
     $20 = $11 * 1.6655924903186126E-11;
     $21 = $20 + 6.2274145840035544E-9;
     $22 = $11 * $21;
     $23 = $22 + 1.3560879779106472E-6;
     $24 = $11 * $23;
     $25 = $24 + 2.0255257550161332E-4;
     $26 = $11 * $25;
     $27 = $26 + 0.019916731864213943;
     $28 = $11 * $27;
     $29 = $28 + 1.0;
     $30 = $19 / $29;
     $31 = $30 * $0;
     $32 = (+_j1f($0));
     $33 = (+Math_log((+$0)));
     $34 = $32 * $33;
     $35 = 1.0 / $0;
     $36 = $34 - $35;
     $37 = $36 * 0.63661974668502808;
     $38 = $31 + $37;
     $$0 = $38;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function _atanhf($0) {
 $0 = +$0;
 var $$0 = 0.0, $$sink16 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = (HEAP32[tempDoublePtr>>2]=$2,+HEAPF32[tempDoublePtr>>2]);
 $4 = ($2>>>0)<(1056964608);
 if ($4) {
  $5 = ($2>>>0)<(796917760);
  if ($5) {
   $$0 = $3;
  } else {
   $6 = $3 * 2.0;
   $7 = $6 * $3;
   $8 = 1.0 - $3;
   $9 = $7 / $8;
   $10 = $6 + $9;
   $$sink16 = $10;
   label = 5;
  }
 } else {
  $11 = 1.0 - $3;
  $12 = $3 / $11;
  $13 = $12 * 2.0;
  $$sink16 = $13;
  label = 5;
 }
 if ((label|0) == 5) {
  $14 = (+_log1pf($$sink16));
  $15 = $14 * 0.5;
  $$0 = $15;
 }
 $16 = ($1|0)<(0);
 $17 = - $$0;
 $18 = $16 ? $17 : $$0;
 return (+$18);
}
function _log1pf($0) {
 $0 = +$0;
 var $$077 = 0.0, $$1 = 0.0, $$179 = 0.0, $$181 = 0.0, $$2 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0;
 var $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $or$cond = 0, $phitmp = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = ($1>>>0)<(1054086096);
 $3 = ($1|0)<(0);
 $or$cond = $2 | $3;
 do {
  if ($or$cond) {
   $4 = ($1>>>0)>(3212836863);
   if ($4) {
    $5 = $0 == -1.0;
    if ($5) {
     $$077 = -inf;
     break;
    }
    $6 = $0 - $0;
    $7 = $6 / 0.0;
    $$077 = $7;
    break;
   } else {
    $8 = $1 << 1;
    $9 = ($8>>>0)<(1728053248);
    if ($9) {
     $$077 = $0;
     break;
    }
    $10 = ($1>>>0)<(3197498906);
    if ($10) {
     $$1 = 0.0;$$179 = $0;$$2 = 0.0;
     label = 11;
     break;
    } else {
     label = 8;
     break;
    }
   }
  } else {
   $11 = ($1>>>0)>(2139095039);
   if ($11) {
    $$077 = $0;
   } else {
    label = 8;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $12 = $0 + 1.0;
  $13 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
  $14 = (($13) + 4913933)|0;
  $15 = $14 >>> 23;
  $16 = (($15) + -127)|0;
  $17 = ($14>>>0)<(1275068416);
  if ($17) {
   $18 = ($14>>>0)>(1082130431);
   $19 = $12 - $0;
   $20 = 1.0 - $19;
   $21 = $12 + -1.0;
   $22 = $0 - $21;
   $23 = $18 ? $20 : $22;
   $24 = $23 / $12;
   $$181 = $24;
  } else {
   $$181 = 0.0;
  }
  $25 = $14 & 8388607;
  $26 = (($25) + 1060439283)|0;
  $27 = (HEAP32[tempDoublePtr>>2]=$26,+HEAPF32[tempDoublePtr>>2]);
  $28 = $27 + -1.0;
  $phitmp = (+($16|0));
  $$1 = $phitmp;$$179 = $28;$$2 = $$181;
  label = 11;
 }
 if ((label|0) == 11) {
  $29 = $$179 + 2.0;
  $30 = $$179 / $29;
  $31 = $30 * $30;
  $32 = $31 * $31;
  $33 = $32 * 0.24279078841209412;
  $34 = $33 + 0.40000972151756287;
  $35 = $32 * $34;
  $36 = $32 * 0.28498786687850952;
  $37 = $36 + 0.66666662693023682;
  $38 = $31 * $37;
  $39 = $38 + $35;
  $40 = $$179 * 0.5;
  $41 = $$179 * $40;
  $42 = $41 + $39;
  $43 = $30 * $42;
  $44 = $$1 * 9.0580006144591607E-6;
  $45 = $$2 + $44;
  $46 = $45 + $43;
  $47 = $46 - $41;
  $48 = $$179 + $47;
  $49 = $$1 * 0.69313812255859375;
  $50 = $49 + $48;
  $$077 = $50;
 }
 return (+$$077);
}
function _llrintf($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_rintf((+$0)));
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (~~+Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 setTempRet0(($3) | 0);
 return ($2|0);
}
function _asinhl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_asinh($0));
 return (+$1);
}
function _asinh($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 & 2047;
 $6 = $2 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $1;HEAP32[tempDoublePtr+4>>2] = $6;$7 = +HEAPF64[tempDoublePtr>>3];
 $8 = ($5>>>0)>(1048);
 do {
  if ($8) {
   $9 = (+Math_log((+$7)));
   $10 = $9 + 0.69314718055994529;
   $$0 = $10;
  } else {
   $11 = ($5>>>0)>(1023);
   if ($11) {
    $12 = $7 * 2.0;
    $13 = $7 * $7;
    $14 = $13 + 1.0;
    $15 = (+Math_sqrt((+$14)));
    $16 = $15 + $7;
    $17 = 1.0 / $16;
    $18 = $12 + $17;
    $19 = (+Math_log((+$18)));
    $$0 = $19;
    break;
   }
   $20 = ($5>>>0)>(996);
   if ($20) {
    $21 = $7 * $7;
    $22 = $21 + 1.0;
    $23 = (+Math_sqrt((+$22)));
    $24 = $23 + 1.0;
    $25 = $21 / $24;
    $26 = $25 + $7;
    $27 = (+_log1p($26));
    $$0 = $27;
   } else {
    $$0 = $7;
   }
  }
 } while(0);
 $28 = ($2|0)<(0);
 $29 = - $$0;
 $30 = $28 ? $29 : $$0;
 return (+$30);
}
function _fdimf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $10 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___FLOAT_BITS_31($0)|0);
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095040);
 if ($4) {
  return (+$0);
 } else {
  $5 = (___FLOAT_BITS_31($1)|0);
  $6 = $5 & 2147483647;
  $7 = ($6>>>0)>(2139095040);
  $8 = $0 > $1;
  $9 = $0 - $1;
  $10 = $8 ? $9 : 0.0;
  $spec$select = $7 ? $1 : $10;
  return (+$spec$select);
 }
 return +(0.0);
}
function ___FLOAT_BITS_31($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _tanh($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $1;HEAP32[tempDoublePtr+4>>2] = $3;$4 = +HEAPF64[tempDoublePtr>>3];
 $5 = ($3>>>0)>(1071748074);
 do {
  if ($5) {
   $6 = ($3>>>0)>(1077149696);
   if ($6) {
    $7 = 0.0 / $4;
    $8 = 1.0 - $7;
    $$0 = $8;
    break;
   } else {
    $9 = $4 * 2.0;
    $10 = (+_expm1($9));
    $11 = $10 + 2.0;
    $12 = 2.0 / $11;
    $13 = 1.0 - $12;
    $$0 = $13;
    break;
   }
  } else {
   $14 = ($3>>>0)>(1070618798);
   if ($14) {
    $15 = $4 * 2.0;
    $16 = (+_expm1($15));
    $17 = $16 + 2.0;
    $18 = $16 / $17;
    $$0 = $18;
    break;
   }
   $19 = ($3>>>0)>(1048575);
   if ($19) {
    $20 = $4 * -2.0;
    $21 = (+_expm1($20));
    $22 = - $21;
    $23 = $21 + 2.0;
    $24 = $22 / $23;
    $$0 = $24;
   } else {
    $$0 = $4;
   }
  }
 } while(0);
 $25 = ($2|0)<(0);
 $26 = - $$0;
 $27 = $25 ? $26 : $$0;
 return (+$27);
}
function _llround($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_round((+$0)));
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (~~+Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 setTempRet0(($3) | 0);
 return ($2|0);
}
function _fmaxl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_fmax($0,$1));
 return (+$2);
}
function _fmax($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0.0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___DOUBLE_BITS_140($0)|0);
 $3 = (getTempRet0() | 0);
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2146435072);
 $6 = ($2>>>0)>(0);
 $7 = ($4|0)==(2146435072);
 $8 = $7 & $6;
 $9 = $5 | $8;
 do {
  if ($9) {
   $$0 = $1;
  } else {
   $10 = (___DOUBLE_BITS_140($1)|0);
   $11 = (getTempRet0() | 0);
   $12 = $11 & 2147483647;
   $13 = ($12>>>0)>(2146435072);
   $14 = ($10>>>0)>(0);
   $15 = ($12|0)==(2146435072);
   $16 = $15 & $14;
   $17 = $13 | $16;
   if ($17) {
    $$0 = $0;
   } else {
    $18 = (_bitshift64Lshr(($2|0),($3|0),63)|0);
    $19 = (getTempRet0() | 0);
    $20 = (_bitshift64Lshr(($10|0),($11|0),63)|0);
    $21 = (getTempRet0() | 0);
    $22 = ($18|0)==($20|0);
    if ($22) {
     $25 = $0 < $1;
     $26 = $25 ? $1 : $0;
     $$0 = $26;
     break;
    } else {
     $23 = ($3|0)<(0);
     $24 = $23 ? $1 : $0;
     $$0 = $24;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function ___DOUBLE_BITS_140($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _nearbyintf($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_fetestexcept(32)|0);
 $2 = (+_rintf((+$0)));
 $3 = ($1|0)==(0);
 if ($3) {
 }
 return (+$2);
}
function _erfl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_erf($0));
 return (+$1);
}
function _erf($0) {
 $0 = +$0;
 var $$0 = 0.0, $$041 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $4 = (getTempRet0() | 0);
 $5 = $2 & 2147483647;
 $6 = ($5>>>0)>(2146435071);
 do {
  if ($6) {
   $7 = (_bitshift64Shl(($3|0),($4|0),1)|0);
   $8 = (getTempRet0() | 0);
   $9 = (1 - ($7))|0;
   $10 = (+($9|0));
   $11 = 1.0 / $0;
   $12 = $11 + $10;
   $$0 = $12;
  } else {
   $13 = ($5>>>0)<(1072365568);
   if ($13) {
    $14 = ($5>>>0)<(1043333120);
    if ($14) {
     $15 = $0 * 8.0;
     $16 = $0 * 1.0270333367641007;
     $17 = $15 + $16;
     $18 = $17 * 0.125;
     $$0 = $18;
     break;
    } else {
     $19 = $0 * $0;
     $20 = $19 * 2.3763016656650163E-5;
     $21 = -0.0057702702964894416 - $20;
     $22 = $19 * $21;
     $23 = $22 + -0.02848174957559851;
     $24 = $19 * $23;
     $25 = $24 + -0.3250421072470015;
     $26 = $19 * $25;
     $27 = $26 + 0.12837916709551256;
     $28 = $19 * 3.9602282787753681E-6;
     $29 = 1.3249473800432164E-4 - $28;
     $30 = $19 * $29;
     $31 = $30 + 0.0050813062818757656;
     $32 = $19 * $31;
     $33 = $32 + 0.065022249988767294;
     $34 = $19 * $33;
     $35 = $34 + 0.39791722395915535;
     $36 = $19 * $35;
     $37 = $36 + 1.0;
     $38 = $27 / $37;
     $39 = $38 * $0;
     $40 = $39 + $0;
     $$0 = $40;
     break;
    }
   } else {
    $41 = ($5>>>0)<(1075314688);
    if ($41) {
     $42 = (+_erfc2($5,$0));
     $43 = 1.0 - $42;
     $$041 = $43;
    } else {
     $$041 = 1.0;
    }
    $44 = ($3|0)==(0);
    $45 = ($4|0)==(0);
    $46 = $44 & $45;
    $47 = - $$041;
    $48 = $46 ? $$041 : $47;
    $$0 = $48;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _erfc2($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0.0, $$047 = 0.0, $$047$in = 0.0, $$048 = 0.0, $$sink49 = 0.0, $$sink51 = 0.0, $$sink53 = 0.0, $$sink55 = 0.0, $$sink57 = 0.0, $$sink58 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0;
 var $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0;
 var $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0;
 var $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)<(1072955392);
 if ($2) {
  $3 = (+_erfc1($1));
  $$0 = $3;
 } else {
  $4 = (+Math_abs((+$1)));
  $5 = $4 * $4;
  $6 = 1.0 / $5;
  $7 = ($0>>>0)<(1074191213);
  if ($7) {
   $8 = $6 * 9.8143293441691454;
   $9 = -81.287435506306593 - $8;
   $10 = $6 * $9;
   $11 = $10 + -184.60509290671104;
   $12 = $6 * $11;
   $13 = $12 + -162.39666946257347;
   $14 = $6 * $13;
   $15 = $14 + -62.375332450326006;
   $16 = $6 * $15;
   $17 = $16 + -10.558626225323291;
   $18 = $6 * $17;
   $19 = $18 + -0.69385857270718176;
   $20 = $6 * $19;
   $21 = $20 + -0.0098649440348471482;
   $22 = $6 * 0.060424415214858099;
   $23 = 6.5702497703192817 - $22;
   $24 = $6 * $23;
   $25 = $24 + 108.63500554177944;
   $$048 = $21;$$sink49 = 19.651271667439257;$$sink51 = 137.65775414351904;$$sink53 = 434.56587747522923;$$sink55 = 645.38727173326788;$$sink57 = 429.00814002756783;$$sink58 = $25;
  } else {
   $26 = $6 * 483.5191916086514;
   $27 = -1025.0951316110772 - $26;
   $28 = $6 * $27;
   $29 = $28 + -637.56644336838963;
   $30 = $6 * $29;
   $31 = $30 + -160.63638485582192;
   $32 = $6 * $31;
   $33 = $32 + -17.757954917754752;
   $34 = $6 * $33;
   $35 = $34 + -0.79928323768052301;
   $36 = $6 * $35;
   $37 = $36 + -0.0098649429247000992;
   $38 = $6 * 22.440952446585818;
   $39 = 474.52854120695537 - $38;
   $$048 = $37;$$sink49 = 30.338060743482458;$$sink51 = 325.79251299657392;$$sink53 = 1536.729586084437;$$sink55 = 3199.8582195085955;$$sink57 = 2553.0504064331644;$$sink58 = $39;
  }
  $40 = $6 * $$sink58;
  $41 = $40 + $$sink57;
  $42 = $6 * $41;
  $43 = $42 + $$sink55;
  $44 = $6 * $43;
  $45 = $44 + $$sink53;
  $46 = $6 * $45;
  $47 = $46 + $$sink51;
  $48 = $6 * $47;
  $49 = $48 + $$sink49;
  $$047$in = $6 * $49;
  $$047 = $$047$in + 1.0;
  HEAPF64[tempDoublePtr>>3] = $4;$50 = HEAP32[tempDoublePtr>>2]|0;
  $51 = HEAP32[tempDoublePtr+4>>2]|0;
  HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $51;$52 = +HEAPF64[tempDoublePtr>>3];
  $53 = $52 * $52;
  $54 = -0.5625 - $53;
  $55 = (+Math_exp((+$54)));
  $56 = $52 - $4;
  $57 = $4 + $52;
  $58 = $56 * $57;
  $59 = $$048 / $$047;
  $60 = $58 + $59;
  $61 = (+Math_exp((+$60)));
  $62 = $55 * $61;
  $63 = $62 / $4;
  $$0 = $63;
 }
 return (+$$0);
}
function _erfc1($0) {
 $0 = +$0;
 var $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_abs((+$0)));
 $2 = $1 + -1.0;
 $3 = $2 * 0.0021663755948687908;
 $4 = 0.035478304325618236 - $3;
 $5 = $2 * $4;
 $6 = $5 + -0.11089469428239668;
 $7 = $2 * $6;
 $8 = $7 + 0.31834661990116175;
 $9 = $2 * $8;
 $10 = $9 + -0.37220787603570132;
 $11 = $2 * $10;
 $12 = $11 + 0.41485611868374833;
 $13 = $2 * $12;
 $14 = $13 + -0.0023621185607526594;
 $15 = $2 * 0.011984499846799107;
 $16 = $15 + 0.013637083912029051;
 $17 = $2 * $16;
 $18 = $17 + 0.12617121980876164;
 $19 = $2 * $18;
 $20 = $19 + 0.071828654414196266;
 $21 = $2 * $20;
 $22 = $21 + 0.54039791770217105;
 $23 = $2 * $22;
 $24 = $23 + 0.10642088040084423;
 $25 = $2 * $24;
 $26 = $25 + 1.0;
 $27 = $14 / $26;
 $28 = 0.15493708848953247 - $27;
 return (+$28);
}
function _erfcl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_erfc($0));
 return (+$1);
}
function _erfc($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $4 = (getTempRet0() | 0);
 $5 = $2 & 2147483647;
 $6 = ($5>>>0)>(2146435071);
 do {
  if ($6) {
   $7 = (_bitshift64Shl(($3|0),($4|0),1)|0);
   $8 = (getTempRet0() | 0);
   $9 = (+($7|0));
   $10 = 1.0 / $0;
   $11 = $10 + $9;
   $$0 = $11;
  } else {
   $12 = ($5>>>0)<(1072365568);
   if (!($12)) {
    $44 = ($5>>>0)<(1077673984);
    $45 = ($3|0)!=(0);
    if ($44) {
     $46 = (+_erfc2($5,$0));
     $47 = 2.0 - $46;
     $48 = $45 ? $47 : $46;
     $$0 = $48;
     break;
    } else {
     $49 = $45 ? 2.0 : 0.0;
     $$0 = $49;
     break;
    }
   }
   $13 = ($5>>>0)<(1013972992);
   if ($13) {
    $14 = 1.0 - $0;
    $$0 = $14;
    break;
   }
   $15 = $0 * $0;
   $16 = $15 * 2.3763016656650163E-5;
   $17 = -0.0057702702964894416 - $16;
   $18 = $15 * $17;
   $19 = $18 + -0.02848174957559851;
   $20 = $15 * $19;
   $21 = $20 + -0.3250421072470015;
   $22 = $15 * $21;
   $23 = $22 + 0.12837916709551256;
   $24 = $15 * 3.9602282787753681E-6;
   $25 = 1.3249473800432164E-4 - $24;
   $26 = $15 * $25;
   $27 = $26 + 0.0050813062818757656;
   $28 = $15 * $27;
   $29 = $28 + 0.065022249988767294;
   $30 = $15 * $29;
   $31 = $30 + 0.39791722395915535;
   $32 = $15 * $31;
   $33 = $32 + 1.0;
   $34 = $23 / $33;
   $35 = ($3|0)!=(0);
   $36 = ($5>>>0)<(1070596096);
   $or$cond = $35 | $36;
   if ($or$cond) {
    $37 = $34 * $0;
    $38 = $37 + $0;
    $39 = 1.0 - $38;
    $$0 = $39;
    break;
   } else {
    $40 = $0 + -0.5;
    $41 = $34 * $0;
    $42 = $40 + $41;
    $43 = 0.5 - $42;
    $$0 = $43;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _tanhf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = (HEAP32[tempDoublePtr>>2]=$2,+HEAPF32[tempDoublePtr>>2]);
 $4 = ($2>>>0)>(1057791828);
 do {
  if ($4) {
   $5 = ($2>>>0)>(1092616192);
   if ($5) {
    $6 = 0.0 / $3;
    $7 = $6 + 1.0;
    $$0 = $7;
    break;
   } else {
    $8 = $3 * 2.0;
    $9 = (+_expm1f($8));
    $10 = $9 + 2.0;
    $11 = 2.0 / $10;
    $12 = 1.0 - $11;
    $$0 = $12;
    break;
   }
  } else {
   $13 = ($2>>>0)>(1048757624);
   if ($13) {
    $14 = $3 * 2.0;
    $15 = (+_expm1f($14));
    $16 = $15 + 2.0;
    $17 = $15 / $16;
    $$0 = $17;
    break;
   }
   $18 = ($2>>>0)>(8388607);
   if ($18) {
    $19 = $3 * -2.0;
    $20 = (+_expm1f($19));
    $21 = - $20;
    $22 = $20 + 2.0;
    $23 = $21 / $22;
    $$0 = $23;
   } else {
    $$0 = $3;
   }
  }
 } while(0);
 $24 = ($1|0)<(0);
 $25 = - $$0;
 $26 = $24 ? $25 : $$0;
 return (+$26);
}
function _nexttowardl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_nextafterl($0,$1));
 return (+$2);
}
function _nextafterl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_nextafter($0,$1));
 return (+$2);
}
function _nexttoward($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_nextafter($0,$1));
 return (+$2);
}
function _hypot($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$036 = 0.0, $$037 = 0.0, $$038 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select40 = 0.0, $spec$select41 = 0.0, $spec$select42 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 HEAPF64[tempDoublePtr>>3] = $0;$6 = HEAP32[tempDoublePtr>>2]|0;
 $7 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$8 = HEAP32[tempDoublePtr>>2]|0;
 $9 = HEAP32[tempDoublePtr+4>>2]|0;
 $10 = $7 & 2147483647;
 $11 = $9 & 2147483647;
 $12 = ($10>>>0)<($11>>>0);
 $13 = ($6>>>0)<($8>>>0);
 $14 = ($10|0)==($11|0);
 $15 = $14 & $13;
 $16 = $12 | $15;
 $17 = $16 ? $8 : $6;
 $18 = $16 ? $11 : $10;
 $19 = $16 ? $6 : $8;
 $20 = $16 ? $10 : $11;
 $21 = (_bitshift64Lshr(($17|0),($18|0),52)|0);
 $22 = (getTempRet0() | 0);
 $23 = (_bitshift64Lshr(($19|0),($20|0),52)|0);
 $24 = (getTempRet0() | 0);
 HEAP32[tempDoublePtr>>2] = $17;HEAP32[tempDoublePtr+4>>2] = $18;$25 = +HEAPF64[tempDoublePtr>>3];
 HEAP32[tempDoublePtr>>2] = $19;HEAP32[tempDoublePtr+4>>2] = $20;$26 = +HEAPF64[tempDoublePtr>>3];
 $27 = ($23|0)==(2047);
 do {
  if ($27) {
   $$036 = $26;
  } else {
   $28 = ($21|0)==(2047);
   $29 = ($19|0)==(0);
   $30 = ($20|0)==(0);
   $31 = $29 & $30;
   $or$cond = $31 | $28;
   if ($or$cond) {
    $$036 = $25;
   } else {
    $32 = (($21) - ($23))|0;
    $33 = ($32|0)>(64);
    if ($33) {
     $34 = $25 + $26;
     $$036 = $34;
     break;
    }
    $35 = ($21|0)>(1533);
    if ($35) {
     $36 = $25 * 1.9010915662951598E-211;
     $37 = $26 * 1.9010915662951598E-211;
     $$0 = 5.2601359015483735E+210;$$037 = $36;$$038 = $37;
    } else {
     $38 = ($23|0)<(573);
     $39 = $25 * 5.2601359015483735E+210;
     $40 = $26 * 5.2601359015483735E+210;
     $spec$select40 = $38 ? $40 : $26;
     $spec$select41 = $38 ? $39 : $25;
     $spec$select42 = $38 ? 1.9010915662951598E-211 : 1.0;
     $$0 = $spec$select42;$$037 = $spec$select41;$$038 = $spec$select40;
    }
    _sq($2,$3,$$037);
    _sq($4,$5,$$038);
    $41 = +HEAPF64[$5>>3];
    $42 = +HEAPF64[$3>>3];
    $43 = $41 + $42;
    $44 = +HEAPF64[$4>>3];
    $45 = $43 + $44;
    $46 = +HEAPF64[$2>>3];
    $47 = $45 + $46;
    $48 = (+Math_sqrt((+$47)));
    $49 = $$0 * $48;
    $$036 = $49;
   }
  }
 } while(0);
 STACKTOP = sp;return (+$$036);
}
function _sq($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = +$2;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 * 134217729.0;
 $4 = $2 - $3;
 $5 = $3 + $4;
 $6 = $2 - $5;
 $7 = $2 * $2;
 HEAPF64[$0>>3] = $7;
 $8 = $5 * $5;
 $9 = $8 - $7;
 $10 = $5 * 2.0;
 $11 = $10 * $6;
 $12 = $9 + $11;
 $13 = $6 * $6;
 $14 = $13 + $12;
 HEAPF64[$1>>3] = $14;
 return;
}
function _fmaf($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = +$2;
 var $$0 = 0.0, $$0$$0$10 = 0.0, $$0$$0$7 = 0.0, $$041 = 0.0, $$041$in = 0.0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0;
 var $9 = 0.0, $or$cond = 0, $or$cond44 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 8|0;
 $4 = sp;
 $5 = $0;
 $6 = $1;
 $7 = $5 * $6;
 $8 = $2;
 $9 = $7 + $8;
 HEAPF64[tempDoublePtr>>3] = $9;$10 = HEAP32[tempDoublePtr>>2]|0;
 $11 = HEAP32[tempDoublePtr+4>>2]|0;
 $12 = (_bitshift64Lshr(($10|0),($11|0),52)|0);
 $13 = (getTempRet0() | 0);
 $14 = $12 & 2047;
 $15 = $10 & 536870911;
 $16 = ($15|0)!=(268435456);
 $17 = (0)!=(0);
 $18 = $16 | $17;
 $19 = ($14|0)==(2047);
 $or$cond = $18 | $19;
 $20 = $9 - $7;
 $21 = $20 == $8;
 $or$cond44 = $21 | $or$cond;
 if ($or$cond44) {
  label = 3;
 } else {
  $22 = (_fegetround()|0);
  $23 = ($22|0)==(0);
  if ($23) {
   (_fesetround(3072)|0);
   HEAPF64[$4>>3] = $7;
   $$0$$0$7 = +HEAPF64[$4>>3];
   $31 = $$0$$0$7 + $8;
   (_fesetround(0)|0);
   $32 = $9 == $31;
   HEAPF64[tempDoublePtr>>3] = $31;$33 = HEAP32[tempDoublePtr>>2]|0;
   $34 = HEAP32[tempDoublePtr+4>>2]|0;
   $35 = (_i64Add(($33|0),($34|0),1,0)|0);
   $36 = (getTempRet0() | 0);
   HEAP32[tempDoublePtr>>2] = $35;HEAP32[tempDoublePtr+4>>2] = $36;$37 = +HEAPF64[tempDoublePtr>>3];
   $$0 = $32 ? $37 : $31;
   $$041$in = $$0;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $$off = (($14) + -874)|0;
  $24 = ($$off>>>0)<(23);
  if ($24) {
   $25 = (_fetestexcept(32)|0);
   $26 = ($25|0)==(0);
   if ($26) {
    $$041$in = $9;
   } else {
    HEAPF32[$3>>2] = $2;
    $$0$$0$10 = +HEAPF32[$3>>2];
    $27 = $$0$$0$10;
    $28 = $7 + $27;
    $29 = (_fetestexcept(32)|0);
    $30 = ($29|0)==(0);
    if ($30) {
    } else {
    }
    $$041$in = $28;
   }
  } else {
   $$041$in = $9;
  }
 }
 $$041 = $$041$in;
 STACKTOP = sp;return (+$$041);
}
function _coshl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_cosh($0));
 return (+$1);
}
function _cosh($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $1;HEAP32[tempDoublePtr+4>>2] = $3;$4 = +HEAPF64[tempDoublePtr>>3];
 $5 = ($3>>>0)<(1072049730);
 do {
  if ($5) {
   $6 = ($3>>>0)<(1045430272);
   if ($6) {
    $$0 = 1.0;
   } else {
    $7 = (+_expm1($4));
    $8 = $7 * $7;
    $9 = $7 + 1.0;
    $10 = $9 * 2.0;
    $11 = $8 / $10;
    $12 = $11 + 1.0;
    $$0 = $12;
   }
  } else {
   $13 = ($3>>>0)<(1082535490);
   if ($13) {
    $14 = (+Math_exp((+$4)));
    $15 = 1.0 / $14;
    $16 = $14 + $15;
    $17 = $16 * 0.5;
    $$0 = $17;
    break;
   } else {
    $18 = (+___expo2($4));
    $$0 = $18;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _significand($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ilogb($0)|0);
 $2 = (0 - ($1))|0;
 $3 = (+_scalbn($0,$2));
 return (+$3);
}
function _expm1l($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_expm1($0));
 return (+$1);
}
function ___expo2f($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 + -162.88958740234375;
 $2 = (+Math_exp((+$1)));
 $3 = $2 * 1.6615349947311448E+35;
 $4 = $3 * 1.6615349947311448E+35;
 return (+$4);
}
function _lround($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_round((+$0)));
 $2 = (~~(($1)));
 return ($2|0);
}
function _scalbln($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbn($0,$1));
 return (+$2);
}
function _ldexpl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbnl($0,$1));
 return (+$2);
}
function _scalbnl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbn($0,$1));
 return (+$2);
}
function _fmod($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$070 = 0.0, $$071$lcssa = 0, $$07194 = 0, $$073$lcssa = 0, $$073100 = 0, $$172 = 0, $$174 = 0, $$275$lcssa = 0, $$27585 = 0, $$376$lcssa = 0, $$37682 = 0, $$lcssa = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $7 = (getTempRet0() | 0);
 $8 = $6 & 2047;
 $9 = (_bitshift64Lshr(($4|0),($5|0),52)|0);
 $10 = (getTempRet0() | 0);
 $11 = $9 & 2047;
 $12 = $3 & -2147483648;
 $13 = (_bitshift64Shl(($4|0),($5|0),1)|0);
 $14 = (getTempRet0() | 0);
 $15 = ($13|0)==(0);
 $16 = ($14|0)==(0);
 $17 = $15 & $16;
 L1: do {
  if ($17) {
   label = 3;
  } else {
   $18 = (___DOUBLE_BITS_71($1)|0);
   $19 = (getTempRet0() | 0);
   $20 = $19 & 2147483647;
   $21 = ($20>>>0)>(2146435072);
   $22 = ($18>>>0)>(0);
   $23 = ($20|0)==(2146435072);
   $24 = $23 & $22;
   $25 = $21 | $24;
   $26 = ($8|0)==(2047);
   $or$cond = $26 | $25;
   if ($or$cond) {
    label = 3;
   } else {
    $29 = (_bitshift64Shl(($2|0),($3|0),1)|0);
    $30 = (getTempRet0() | 0);
    $31 = ($30>>>0)>($14>>>0);
    $32 = ($29>>>0)>($13>>>0);
    $33 = ($30|0)==($14|0);
    $34 = $33 & $32;
    $35 = $31 | $34;
    if (!($35)) {
     $36 = ($29|0)==($13|0);
     $37 = ($30|0)==($14|0);
     $38 = $36 & $37;
     $39 = $0 * 0.0;
     $spec$select = $38 ? $39 : $0;
     return (+$spec$select);
    }
    $40 = ($8|0)==(0);
    if ($40) {
     $41 = (_bitshift64Shl(($2|0),($3|0),12)|0);
     $42 = (getTempRet0() | 0);
     $43 = ($42|0)>(-1);
     $44 = ($41>>>0)>(4294967295);
     $45 = ($42|0)==(-1);
     $46 = $45 & $44;
     $47 = $43 | $46;
     if ($47) {
      $$073100 = 0;$49 = $41;$50 = $42;
      while(1) {
       $48 = (($$073100) + -1)|0;
       $51 = (_bitshift64Shl(($49|0),($50|0),1)|0);
       $52 = (getTempRet0() | 0);
       $53 = ($52|0)>(-1);
       $54 = ($51>>>0)>(4294967295);
       $55 = ($52|0)==(-1);
       $56 = $55 & $54;
       $57 = $53 | $56;
       if ($57) {
        $$073100 = $48;$49 = $51;$50 = $52;
       } else {
        $$073$lcssa = $48;
        break;
       }
      }
     } else {
      $$073$lcssa = 0;
     }
     $58 = (1 - ($$073$lcssa))|0;
     $59 = (_bitshift64Shl(($2|0),($3|0),($58|0))|0);
     $60 = (getTempRet0() | 0);
     $$174 = $$073$lcssa;$87 = $59;$88 = $60;
    } else {
     $61 = $3 & 1048575;
     $62 = $61 | 1048576;
     $$174 = $8;$87 = $2;$88 = $62;
    }
    $63 = ($11|0)==(0);
    if ($63) {
     $64 = (_bitshift64Shl(($4|0),($5|0),12)|0);
     $65 = (getTempRet0() | 0);
     $66 = ($65|0)>(-1);
     $67 = ($64>>>0)>(4294967295);
     $68 = ($65|0)==(-1);
     $69 = $68 & $67;
     $70 = $66 | $69;
     if ($70) {
      $$07194 = 0;$72 = $64;$73 = $65;
      while(1) {
       $71 = (($$07194) + -1)|0;
       $74 = (_bitshift64Shl(($72|0),($73|0),1)|0);
       $75 = (getTempRet0() | 0);
       $76 = ($75|0)>(-1);
       $77 = ($74>>>0)>(4294967295);
       $78 = ($75|0)==(-1);
       $79 = $78 & $77;
       $80 = $76 | $79;
       if ($80) {
        $$07194 = $71;$72 = $74;$73 = $75;
       } else {
        $$071$lcssa = $71;
        break;
       }
      }
     } else {
      $$071$lcssa = 0;
     }
     $81 = (1 - ($$071$lcssa))|0;
     $82 = (_bitshift64Shl(($4|0),($5|0),($81|0))|0);
     $83 = (getTempRet0() | 0);
     $$172 = $$071$lcssa;$89 = $82;$90 = $83;
    } else {
     $84 = $5 & 1048575;
     $85 = $84 | 1048576;
     $$172 = $11;$89 = $4;$90 = $85;
    }
    $86 = ($$174|0)>($$172|0);
    $91 = (_i64Subtract(($87|0),($88|0),($89|0),($90|0))|0);
    $92 = (getTempRet0() | 0);
    $93 = ($92|0)>(-1);
    $94 = ($91>>>0)>(4294967295);
    $95 = ($92|0)==(-1);
    $96 = $95 & $94;
    $97 = $93 | $96;
    L25: do {
     if ($86) {
      $$27585 = $$174;$101 = $92;$158 = $97;$159 = $87;$160 = $88;$99 = $91;
      while(1) {
       if ($158) {
        $98 = ($99|0)==(0);
        $100 = ($101|0)==(0);
        $102 = $98 & $100;
        if ($102) {
         break;
        } else {
         $104 = $99;$105 = $101;
        }
       } else {
        $104 = $159;$105 = $160;
       }
       $106 = (_bitshift64Shl(($104|0),($105|0),1)|0);
       $107 = (getTempRet0() | 0);
       $108 = (($$27585) + -1)|0;
       $109 = ($108|0)>($$172|0);
       $110 = (_i64Subtract(($106|0),($107|0),($89|0),($90|0))|0);
       $111 = (getTempRet0() | 0);
       $112 = ($111|0)>(-1);
       $113 = ($110>>>0)>(4294967295);
       $114 = ($111|0)==(-1);
       $115 = $114 & $113;
       $116 = $112 | $115;
       if ($109) {
        $$27585 = $108;$101 = $111;$158 = $116;$159 = $106;$160 = $107;$99 = $110;
       } else {
        $$275$lcssa = $108;$$lcssa = $116;$118 = $110;$120 = $111;$156 = $106;$157 = $107;
        break L25;
       }
      }
      $103 = $0 * 0.0;
      $$070 = $103;
      break L1;
     } else {
      $$275$lcssa = $$174;$$lcssa = $97;$118 = $91;$120 = $92;$156 = $87;$157 = $88;
     }
    } while(0);
    if ($$lcssa) {
     $117 = ($118|0)==(0);
     $119 = ($120|0)==(0);
     $121 = $117 & $119;
     if ($121) {
      $122 = $0 * 0.0;
      $$070 = $122;
      break;
     } else {
      $124 = $120;$126 = $118;
     }
    } else {
     $124 = $157;$126 = $156;
    }
    $123 = ($124>>>0)<(1048576);
    $125 = ($126>>>0)<(0);
    $127 = ($124|0)==(1048576);
    $128 = $127 & $125;
    $129 = $123 | $128;
    if ($129) {
     $$37682 = $$275$lcssa;$130 = $126;$131 = $124;
     while(1) {
      $132 = (_bitshift64Shl(($130|0),($131|0),1)|0);
      $133 = (getTempRet0() | 0);
      $134 = (($$37682) + -1)|0;
      $135 = ($133>>>0)<(1048576);
      $136 = ($132>>>0)<(0);
      $137 = ($133|0)==(1048576);
      $138 = $137 & $136;
      $139 = $135 | $138;
      if ($139) {
       $$37682 = $134;$130 = $132;$131 = $133;
      } else {
       $$376$lcssa = $134;$141 = $132;$142 = $133;
       break;
      }
     }
    } else {
     $$376$lcssa = $$275$lcssa;$141 = $126;$142 = $124;
    }
    $140 = ($$376$lcssa|0)>(0);
    if ($140) {
     $143 = (_i64Add(($141|0),($142|0),0,-1048576)|0);
     $144 = (getTempRet0() | 0);
     $145 = (_bitshift64Shl(($$376$lcssa|0),0,52)|0);
     $146 = (getTempRet0() | 0);
     $147 = $143 | $145;
     $148 = $144 | $146;
     $153 = $148;$155 = $147;
    } else {
     $149 = (1 - ($$376$lcssa))|0;
     $150 = (_bitshift64Lshr(($141|0),($142|0),($149|0))|0);
     $151 = (getTempRet0() | 0);
     $153 = $151;$155 = $150;
    }
    $152 = $153 | $12;
    HEAP32[tempDoublePtr>>2] = $155;HEAP32[tempDoublePtr+4>>2] = $152;$154 = +HEAPF64[tempDoublePtr>>3];
    $$070 = $154;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $27 = $0 * $1;
  $28 = $27 / $27;
  $$070 = $28;
 }
 return (+$$070);
}
function ___DOUBLE_BITS_71($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function ___sindf($0) {
 $0 = +$0;
 var $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 * $0;
 $2 = $1 * $1;
 $3 = $1 * 2.7183114939898219E-6;
 $4 = $3 + -1.9839334836096632E-4;
 $5 = $1 * $0;
 $6 = $1 * 0.0083333293858894632;
 $7 = $6 + -0.16666666641626524;
 $8 = $5 * $7;
 $9 = $8 + $0;
 $10 = $5 * $2;
 $11 = $10 * $4;
 $12 = $11 + $9;
 $13 = $12;
 return (+$13);
}
function _jnf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0139 = 0.0, $$0140198 = 0.0, $$0141 = 0.0, $$0142197 = 0.0, $$0143196 = 0.0, $$0143196$phi = 0.0, $$0144191 = 0.0, $$0145167 = 0.0, $$0149166 = 0.0, $$0149166$phi = 0.0, $$0155165 = 0, $$0160 = 0, $$0161 = 0, $$0199 = 0, $$1146$lcssa = 0.0, $$1146170 = 0.0, $$1150$lcssa = 0.0, $$1150169 = 0.0, $$1156168 = 0, $$1184 = 0.0;
 var $$2 = 0.0, $$2147176 = 0.0, $$2151175 = 0.0, $$2151175$phi = 0.0, $$2157190 = 0, $$2157190$ph = 0, $$3 = 0.0, $$3148183 = 0.0, $$3152182 = 0.0, $$3158174 = 0, $$4 = 0.0, $$4153 = 0.0, $$4159181 = 0, $$5 = 0.0, $$5154 = 0.0, $$7 = 0.0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0;
 var $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0;
 var $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0;
 var $69 = 0, $7 = 0.0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0;
 var $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $exitcond = 0, $spec$select = 0, $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $3 = $2 >>> 31;
 $4 = $2 & 2147483647;
 $5 = ($4>>>0)>(2139095040);
 do {
  if ($5) {
   $$0139 = $1;
  } else {
   $6 = ($0|0)==(0);
   if ($6) {
    $7 = (+_j0f($1));
    $$0139 = $7;
    break;
   }
   $8 = ($0|0)<(0);
   if ($8) {
    $9 = $0 ^ -1;
    $10 = - $1;
    $11 = $3 ^ 1;
    $$0141 = $10;$$0160 = $11;$$0161 = $9;
   } else {
    $12 = (($0) + -1)|0;
    $$0141 = $1;$$0160 = $3;$$0161 = $12;
   }
   $13 = ($$0161|0)==(0);
   if ($13) {
    $14 = (+_j1f($$0141));
    $$0139 = $14;
    break;
   }
   $15 = $$0160 & $0;
   $16 = (+Math_abs((+$$0141)));
   $switch$split2D = ($2|0)<(0);
   L13: do {
    if ($switch$split2D) {
     $switch$split12D = ($2|0)<(-8388608);
     if ($switch$split12D) {
      switch ($2|0) {
      case -2147483648:  {
       $$7 = 0.0;
       break L13;
       break;
      }
      default: {
       label = 10;
       break L13;
      }
      }
     } else {
      switch ($2|0) {
      case -8388608:  {
       $$7 = 0.0;
       break L13;
       break;
      }
      default: {
       label = 10;
       break L13;
      }
      }
     }
    } else {
     $switch$split42D = ($2|0)<(2139095040);
     if ($switch$split42D) {
      switch ($2|0) {
      case 0:  {
       $$7 = 0.0;
       break L13;
       break;
      }
      default: {
       label = 10;
       break L13;
      }
      }
     } else {
      switch ($2|0) {
      case 2139095040:  {
       $$7 = 0.0;
       break L13;
       break;
      }
      default: {
       label = 10;
       break L13;
      }
      }
     }
    }
   } while(0);
   L22: do {
    if ((label|0) == 10) {
     $17 = (+($$0161|0));
     $18 = $16 > $17;
     if ($18) {
      $19 = (+_j0f($16));
      $20 = (+_j1f($16));
      $21 = ($$0161|0)>(0);
      if (!($21)) {
       $$7 = $20;
       break;
      }
      $$0145167 = $20;$$0149166 = $19;$$0155165 = 0;
      while(1) {
       $22 = (($$0155165) + 1)|0;
       $23 = (+($22|0));
       $24 = $23 * 2.0;
       $25 = $24 / $16;
       $26 = $$0145167 * $25;
       $27 = $26 - $$0149166;
       $exitcond = ($22|0)==($$0161|0);
       if ($exitcond) {
        $$7 = $27;
        break L22;
       } else {
        $$0149166$phi = $$0145167;$$0145167 = $27;$$0155165 = $22;$$0149166 = $$0149166$phi;
       }
      }
     }
     $28 = ($4>>>0)<(897581056);
     if ($28) {
      $29 = ($$0161|0)<(8);
      $spec$select = $29 ? $$0161 : 8;
      $30 = $16 * 0.5;
      $31 = ($spec$select|0)<(1);
      if ($31) {
       $$1146$lcssa = $30;$$1150$lcssa = 1.0;
      } else {
       $$1146170 = $30;$$1150169 = 1.0;$$1156168 = 2;
       while(1) {
        $32 = (+($$1156168|0));
        $33 = $$1150169 * $32;
        $34 = $30 * $$1146170;
        $35 = (($$1156168) + 1)|0;
        $36 = ($$1156168|0)>($spec$select|0);
        if ($36) {
         $$1146$lcssa = $34;$$1150$lcssa = $33;
         break;
        } else {
         $$1146170 = $34;$$1150169 = $33;$$1156168 = $35;
        }
       }
      }
      $37 = $$1146$lcssa / $$1150$lcssa;
      $$7 = $37;
      break;
     }
     $38 = $17 + 1.0;
     $39 = $38 * 2.0;
     $40 = $39 / $16;
     $41 = 2.0 / $16;
     $42 = $40 + $41;
     $43 = $40 * $42;
     $44 = $43 + -1.0;
     $45 = $44 < 1.0E+4;
     if ($45) {
      $$0140198 = $42;$$0142197 = $44;$$0143196 = $40;$$0199 = 1;
      while(1) {
       $46 = (($$0199) + 1)|0;
       $47 = $41 + $$0140198;
       $48 = $$0142197 * $47;
       $49 = $48 - $$0143196;
       $50 = $49 < 1.0E+4;
       if ($50) {
        $$0143196$phi = $$0142197;$$0140198 = $47;$$0142197 = $49;$$0199 = $46;$$0143196 = $$0143196$phi;
       } else {
        $$2157190$ph = $46;
        break;
       }
      }
     } else {
      $$2157190$ph = 1;
     }
     $$0144191 = 0.0;$$2157190 = $$2157190$ph;
     while(1) {
      $51 = (+($$2157190|0));
      $52 = $38 + $51;
      $53 = $52 * 2.0;
      $54 = $53 / $16;
      $55 = $54 - $$0144191;
      $56 = 1.0 / $55;
      $57 = (($$2157190) + -1)|0;
      $58 = ($$2157190|0)>(0);
      if ($58) {
       $$0144191 = $56;$$2157190 = $57;
      } else {
       break;
      }
     }
     $59 = (+Math_abs((+$40)));
     $60 = (+Math_log((+$59)));
     $61 = $38 * $60;
     $62 = $61 < 88.7216796875;
     $63 = ($$0161|0)>(0);
     if ($62) {
      if ($63) {
       $$2147176 = 1.0;$$2151175 = $56;$$3158174 = $$0161;
       while(1) {
        $64 = (+($$3158174|0));
        $65 = $64 * 2.0;
        $66 = $65 * $$2147176;
        $67 = $66 / $16;
        $68 = $67 - $$2151175;
        $69 = (($$3158174) + -1)|0;
        $70 = ($$3158174|0)>(1);
        if ($70) {
         $$2151175$phi = $$2147176;$$2147176 = $68;$$3158174 = $69;$$2151175 = $$2151175$phi;
        } else {
         $$3 = $56;$$5 = $68;$$5154 = $$2147176;
         break;
        }
       }
      } else {
       $$3 = $56;$$5 = 1.0;$$5154 = $56;
      }
     } else {
      if ($63) {
       $$1184 = $56;$$3148183 = 1.0;$$3152182 = $56;$$4159181 = $$0161;
       while(1) {
        $71 = (+($$4159181|0));
        $72 = $71 * 2.0;
        $73 = $72 * $$3148183;
        $74 = $73 / $16;
        $75 = $74 - $$3152182;
        $76 = $75 > 1.152921504606847E+18;
        if ($76) {
         $77 = $$3148183 / $75;
         $78 = $$1184 / $75;
         $$2 = $78;$$4 = 1.0;$$4153 = $77;
        } else {
         $$2 = $$1184;$$4 = $75;$$4153 = $$3148183;
        }
        $79 = (($$4159181) + -1)|0;
        $80 = ($$4159181|0)>(1);
        if ($80) {
         $$1184 = $$2;$$3148183 = $$4;$$3152182 = $$4153;$$4159181 = $79;
        } else {
         $$3 = $$2;$$5 = $$4;$$5154 = $$4153;
         break;
        }
       }
      } else {
       $$3 = $56;$$5 = 1.0;$$5154 = $56;
      }
     }
     $81 = (+_j0f($16));
     $82 = (+_j1f($16));
     $83 = (+Math_abs((+$81)));
     $84 = (+Math_abs((+$82)));
     $85 = !($83 >= $84);
     if ($85) {
      $88 = $$3 * $82;
      $89 = $88 / $$5154;
      $$7 = $89;
      break;
     } else {
      $86 = $$3 * $81;
      $87 = $86 / $$5;
      $$7 = $87;
      break;
     }
    }
   } while(0);
   $90 = ($15|0)==(0);
   $91 = - $$7;
   $92 = $90 ? $$7 : $91;
   $$0139 = $92;
  }
 } while(0);
 return (+$$0139);
}
function _j0f($0) {
 $0 = +$0;
 var $$0 = 0.0, $$035 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(2139095039);
 do {
  if ($3) {
   $4 = $0 * $0;
   $5 = 1.0 / $4;
   $$0 = $5;
  } else {
   $6 = (+Math_abs((+$0)));
   $7 = ($2>>>0)>(1073741823);
   if ($7) {
    $8 = (+_common_100($2,$6,0));
    $$0 = $8;
    break;
   }
   $9 = ($2>>>0)>(973078527);
   if ($9) {
    $10 = $6 * $6;
    $11 = $10 * 4.618327054117799E-9;
    $12 = 1.8295404515811242E-6 - $11;
    $13 = $10 * $12;
    $14 = $13 + -1.8997929873876274E-4;
    $15 = $10 * $14;
    $16 = $15 + 0.015625;
    $17 = $10 * $16;
    $18 = $10 * 1.1661400733942173E-9;
    $19 = $18 + 5.1354652441659709E-7;
    $20 = $10 * $19;
    $21 = $20 + 1.1692678526742384E-4;
    $22 = $10 * $21;
    $23 = $22 + 0.015619102865457535;
    $24 = $10 * $23;
    $25 = $24 + 1.0;
    $26 = $6 * 0.5;
    $27 = $26 + 1.0;
    $28 = 1.0 - $26;
    $29 = $27 * $28;
    $30 = $17 / $25;
    $31 = $10 * $30;
    $32 = $29 + $31;
    $$0 = $32;
    break;
   } else {
    $33 = ($2>>>0)>(562036735);
    $34 = $6 * 0.25;
    $35 = $6 * $34;
    $$035 = $33 ? $35 : $6;
    $36 = 1.0 - $$035;
    $$0 = $36;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _common_100($0,$1,$2) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0.0, $$032 = 0.0, $$1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, $spec$select = 0.0, $spec$select35 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+Math_sin((+$1)));
 $4 = (+Math_cos((+$1)));
 $5 = ($2|0)!=(0);
 $6 = - $4;
 $spec$select = $5 ? $6 : $4;
 $7 = $3 + $spec$select;
 $8 = ($0>>>0)<(2130706432);
 if ($8) {
  $9 = $3 - $spec$select;
  $10 = $1 * 2.0;
  $11 = (+Math_cos((+$10)));
  $12 = - $11;
  $13 = $3 * $spec$select;
  $14 = $13 < 0.0;
  if ($14) {
   $15 = $12 / $9;
   $$0 = $15;$$032 = $9;
  } else {
   $16 = $12 / $7;
   $$0 = $7;$$032 = $16;
  }
  $17 = ($0>>>0)<(1484783616);
  if ($17) {
   $18 = - $$032;
   $spec$select35 = $5 ? $18 : $$032;
   $19 = (+_pzerof($1));
   $20 = $$0 * $19;
   $21 = (+_qzerof($1));
   $22 = $spec$select35 * $21;
   $23 = $20 - $22;
   $$1 = $23;
  } else {
   $$1 = $$0;
  }
 } else {
  $$1 = $7;
 }
 $24 = $$1 * 0.564189612865448;
 $25 = (+Math_sqrt((+$1)));
 $26 = $24 / $25;
 return (+$26);
}
function _pzerof($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$041 = 0, $$42 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(1090519039);
 if ($3) {
  $$0 = (gb + (9504) | 0);$$041 = (gb + (9440) | 0);
 } else {
  $4 = ($2>>>0)>(1089936471);
  $5 = ($2>>>0)>(1077336935);
  if ($4) {
   $$0 = (gb + (9536) | 0);$$041 = (gb + (9472) | 0);
  } else {
   $$42 = $5 ? (gb + (9312) | 0) : (gb + (9344) | 0);
   $$ = $5 ? (gb + (9376) | 0) : (gb + (9408) | 0);
   $$0 = $$42;$$041 = $$;
  }
 }
 $6 = $0 * $0;
 $7 = 1.0 / $6;
 $8 = +HEAPF32[$$0>>2];
 $9 = ((($$0)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = ((($$0)) + 8|0);
 $12 = +HEAPF32[$11>>2];
 $13 = ((($$0)) + 12|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($$0)) + 16|0);
 $16 = +HEAPF32[$15>>2];
 $17 = ((($$0)) + 20|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $7 * $18;
 $20 = $16 + $19;
 $21 = $7 * $20;
 $22 = $14 + $21;
 $23 = $7 * $22;
 $24 = $12 + $23;
 $25 = $7 * $24;
 $26 = $10 + $25;
 $27 = $7 * $26;
 $28 = $8 + $27;
 $29 = +HEAPF32[$$041>>2];
 $30 = ((($$041)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($$041)) + 8|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($$041)) + 12|0);
 $35 = +HEAPF32[$34>>2];
 $36 = ((($$041)) + 16|0);
 $37 = +HEAPF32[$36>>2];
 $38 = $7 * $37;
 $39 = $35 + $38;
 $40 = $7 * $39;
 $41 = $33 + $40;
 $42 = $7 * $41;
 $43 = $31 + $42;
 $44 = $7 * $43;
 $45 = $29 + $44;
 $46 = $7 * $45;
 $47 = $46 + 1.0;
 $48 = $28 / $47;
 $49 = $48 + 1.0;
 return (+$49);
}
function _qzerof($0) {
 $0 = +$0;
 var $$ = 0, $$0 = 0, $$044 = 0, $$45 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(1090519039);
 if ($3) {
  $$0 = (gb + (9248) | 0);$$044 = (gb + (9184) | 0);
 } else {
  $4 = ($2>>>0)>(1089936471);
  $5 = ($2>>>0)>(1077336935);
  if ($4) {
   $$0 = (gb + (9280) | 0);$$044 = (gb + (9216) | 0);
  } else {
   $$45 = $5 ? (gb + (9056) | 0) : (gb + (9088) | 0);
   $$ = $5 ? (gb + (9120) | 0) : (gb + (9152) | 0);
   $$0 = $$45;$$044 = $$;
  }
 }
 $6 = $0 * $0;
 $7 = 1.0 / $6;
 $8 = +HEAPF32[$$0>>2];
 $9 = ((($$0)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = ((($$0)) + 8|0);
 $12 = +HEAPF32[$11>>2];
 $13 = ((($$0)) + 12|0);
 $14 = +HEAPF32[$13>>2];
 $15 = ((($$0)) + 16|0);
 $16 = +HEAPF32[$15>>2];
 $17 = ((($$0)) + 20|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $7 * $18;
 $20 = $16 + $19;
 $21 = $7 * $20;
 $22 = $14 + $21;
 $23 = $7 * $22;
 $24 = $12 + $23;
 $25 = $7 * $24;
 $26 = $10 + $25;
 $27 = $7 * $26;
 $28 = $8 + $27;
 $29 = +HEAPF32[$$044>>2];
 $30 = ((($$044)) + 4|0);
 $31 = +HEAPF32[$30>>2];
 $32 = ((($$044)) + 8|0);
 $33 = +HEAPF32[$32>>2];
 $34 = ((($$044)) + 12|0);
 $35 = +HEAPF32[$34>>2];
 $36 = ((($$044)) + 16|0);
 $37 = +HEAPF32[$36>>2];
 $38 = ((($$044)) + 20|0);
 $39 = +HEAPF32[$38>>2];
 $40 = $7 * $39;
 $41 = $37 + $40;
 $42 = $7 * $41;
 $43 = $35 + $42;
 $44 = $7 * $43;
 $45 = $33 + $44;
 $46 = $7 * $45;
 $47 = $31 + $46;
 $48 = $7 * $47;
 $49 = $29 + $48;
 $50 = $7 * $49;
 $51 = $50 + 1.0;
 $52 = $28 / $51;
 $53 = $52 + -0.125;
 $54 = $53 / $0;
 return (+$54);
}
function _ynf($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0.0, $$053 = 0, $$05359 = 0, $$054 = 0, $$055$lcssa = 0.0, $$05562 = 0.0, $$05661 = 0.0, $$05661$phi = 0.0, $$05760 = 0, $$058 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0;
 var $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095040);
 do {
  if ($4) {
   $$0 = $1;
  } else {
   $5 = ($2|0)<(0);
   $6 = ($3|0)!=(0);
   $or$cond = $5 & $6;
   if ($or$cond) {
    $$0 = nan;
   } else {
    $7 = ($3|0)==(2139095040);
    if ($7) {
     $$0 = 0.0;
    } else {
     $8 = ($0|0)==(0);
     if ($8) {
      $9 = (+_y0f($1));
      $$0 = $9;
      break;
     }
     $10 = ($0|0)<(0);
     $11 = $0 ^ -1;
     $12 = $0 & 1;
     $13 = (($0) + -1)|0;
     $$058 = $10 ? $12 : 0;
     $$054 = $10 ? $11 : $13;
     $14 = ($$054|0)==(0);
     if ($14) {
      $15 = ($$058|0)==(0);
      $16 = (+_y1f($1));
      $17 = - $16;
      $18 = $15 ? $16 : $17;
      $$0 = $18;
      break;
     }
     $19 = (+_y0f($1));
     $20 = (+_y1f($1));
     $$05359 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
     $21 = ($$054|0)>(0);
     $22 = ($$05359|0)!=(-8388608);
     $23 = $21 & $22;
     if ($23) {
      $$05562 = $20;$$05661 = $19;$$05760 = 0;
      while(1) {
       $24 = (($$05760) + 1)|0;
       $25 = (+($24|0));
       $26 = $25 * 2.0;
       $27 = $26 / $1;
       $28 = $$05562 * $27;
       $29 = $28 - $$05661;
       $$053 = (HEAPF32[tempDoublePtr>>2]=$29,HEAP32[tempDoublePtr>>2]|0);
       $30 = ($24|0)<($$054|0);
       $31 = ($$053|0)!=(-8388608);
       $32 = $30 & $31;
       if ($32) {
        $$05661$phi = $$05562;$$05562 = $29;$$05760 = $24;$$05661 = $$05661$phi;
       } else {
        $$055$lcssa = $29;
        break;
       }
      }
     } else {
      $$055$lcssa = $20;
     }
     $33 = ($$058|0)==(0);
     $34 = - $$055$lcssa;
     $35 = $33 ? $$055$lcssa : $34;
     $$0 = $35;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function _y0f($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $$0 = -inf;
  } else {
   $4 = ($1|0)<(0);
   if ($4) {
    $$0 = nan;
   } else {
    $5 = ($1>>>0)>(2139095039);
    if ($5) {
     $6 = 1.0 / $0;
     $$0 = $6;
     break;
    }
    $7 = ($1>>>0)>(1073741823);
    if ($7) {
     $8 = (+_common_100($1,$0,1));
     $$0 = $8;
     break;
    }
    $9 = ($1>>>0)>(956301311);
    if ($9) {
     $10 = $0 * $0;
     $11 = $10 * 3.9820518410449424E-11;
     $12 = 1.955901396399895E-8 - $11;
     $13 = $10 * $12;
     $14 = $13 + -3.8140706237754785E-6;
     $15 = $10 * $14;
     $16 = $15 + 3.4745343145914376E-4;
     $17 = $10 * $16;
     $18 = $17 + -0.013818567618727684;
     $19 = $10 * $18;
     $20 = $19 + 0.17666645348072052;
     $21 = $10 * $20;
     $22 = $21 + -0.073804296553134918;
     $23 = $10 * 4.4111031494153963E-10;
     $24 = $23 + 2.5915085188898956E-7;
     $25 = $10 * $24;
     $26 = $25 + 7.6006865128874779E-5;
     $27 = $10 * $26;
     $28 = $27 + 0.012730483897030354;
     $29 = $10 * $28;
     $30 = $29 + 1.0;
     $31 = $22 / $30;
     $32 = (+_j0f($0));
     $33 = (+Math_log((+$0)));
     $34 = $32 * $33;
     $35 = $34 * 0.63661974668502808;
     $36 = $31 + $35;
     $$0 = $36;
     break;
    } else {
     $37 = (+Math_log((+$0)));
     $38 = $37 * 0.63661974668502808;
     $39 = $38 + -0.073804296553134918;
     $$0 = $39;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function _acoshf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0;
 var $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<(1073741824);
 do {
  if ($3) {
   $4 = $0 + -1.0;
   $5 = $4 * $4;
   $6 = $4 * 2.0;
   $7 = $5 + $6;
   $8 = (+Math_sqrt((+$7)));
   $9 = $4 + $8;
   $10 = (+_log1pf($9));
   $$0 = $10;
  } else {
   $11 = ($2>>>0)<(1166016512);
   if ($11) {
    $12 = $0 * 2.0;
    $13 = $0 * $0;
    $14 = $13 + -1.0;
    $15 = (+Math_sqrt((+$14)));
    $16 = $15 + $0;
    $17 = 1.0 / $16;
    $18 = $12 - $17;
    $19 = (+Math_log((+$18)));
    $$0 = $19;
    break;
   } else {
    $20 = (+Math_log((+$0)));
    $21 = $20 + 0.69314718246459961;
    $$0 = $21;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _fdim($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___DOUBLE_BITS_72($0)|0);
 $3 = (getTempRet0() | 0);
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2146435072);
 $6 = ($2>>>0)>(0);
 $7 = ($4|0)==(2146435072);
 $8 = $7 & $6;
 $9 = $5 | $8;
 if ($9) {
  return (+$0);
 } else {
  $10 = (___DOUBLE_BITS_72($1)|0);
  $11 = (getTempRet0() | 0);
  $12 = $11 & 2147483647;
  $13 = ($12>>>0)>(2146435072);
  $14 = ($10>>>0)>(0);
  $15 = ($12|0)==(2146435072);
  $16 = $15 & $14;
  $17 = $13 | $16;
  $18 = $0 > $1;
  $19 = $0 - $1;
  $20 = $18 ? $19 : 0.0;
  $spec$select = $17 ? $1 : $20;
  return (+$spec$select);
 }
 return +(0.0);
}
function ___DOUBLE_BITS_72($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _log1pl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_log1p($0));
 return (+$1);
}
function _lgammaf($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+___lgammaf_r($0,(gb + (171128) | 0)));
 return (+$1);
}
function ___lgammaf_r($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $$0174 = 0.0, $$0175186 = 0.0, $$0175189 = 0.0, $$0175192 = 0.0, $$0177 = 0.0, $$0178185 = 0.0, $$0178188 = 0.0, $$0178191 = 0.0, $$0179 = 0.0, $$0180 = 0.0, $$1 = 0.0, $$1176 = 0.0, $$1181 = 0.0, $$2182 = 0.0, $$3 = 0.0, $$pn = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0;
 var $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0.0;
 var $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0;
 var $139 = 0.0, $14 = 0.0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0;
 var $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0.0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0;
 var $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0, $81 = 0.0;
 var $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $spec$select = 0.0;
 var $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$1>>2] = 1;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095039);
 do {
  if ($4) {
   $5 = $0 * $0;
   $$0 = $5;
  } else {
   $6 = ($3>>>0)<(889192448);
   $7 = ($2|0)<(0);
   if ($6) {
    if ($7) {
     $8 = - $0;
     HEAP32[$1>>2] = -1;
     $$0174 = $8;
    } else {
     $$0174 = $0;
    }
    $9 = (+Math_log((+$$0174)));
    $10 = - $9;
    $$0 = $10;
    break;
   }
   if ($7) {
    $11 = - $0;
    $12 = (+_sin_pi($11));
    $13 = $12 == 0.0;
    if ($13) {
     $14 = $0 - $0;
     $15 = 1.0 / $14;
     $$0 = $15;
     break;
    }
    $16 = $12 > 0.0;
    if ($16) {
     HEAP32[$1>>2] = -1;
     $$0177 = $12;
    } else {
     $17 = - $12;
     $$0177 = $17;
    }
    $18 = $$0177 * $11;
    $19 = 3.1415927410125732 / $18;
    $20 = (+Math_log((+$19)));
    $$0179 = $20;$$1 = $11;
   } else {
    $$0179 = 0.0;$$1 = $0;
   }
   $switch$split2D = ($2|0)<(1065353216);
   L20: do {
    if ($switch$split2D) {
     $switch$split12D = ($2|0)<(-1073741824);
     if ($switch$split12D) {
      switch ($2|0) {
      case -1082130432:  {
       $$1176 = 0.0;
       break L20;
       break;
      }
      default: {
       label = 15;
       break L20;
      }
      }
     } else {
      switch ($2|0) {
      case -1073741824:  {
       $$1176 = 0.0;
       break L20;
       break;
      }
      default: {
       label = 15;
       break L20;
      }
      }
     }
    } else {
     $switch$split42D = ($2|0)<(1073741824);
     if ($switch$split42D) {
      switch ($2|0) {
      case 1065353216:  {
       $$1176 = 0.0;
       break L20;
       break;
      }
      default: {
       label = 15;
       break L20;
      }
      }
     } else {
      switch ($2|0) {
      case 1073741824:  {
       $$1176 = 0.0;
       break L20;
       break;
      }
      default: {
       label = 15;
       break L20;
      }
      }
     }
    }
   } while(0);
   L29: do {
    if ((label|0) == 15) {
     $21 = ($3>>>0)<(1073741824);
     if ($21) {
      $22 = ($3>>>0)<(1063675495);
      do {
       if ($22) {
        $23 = (+Math_log((+$$1)));
        $24 = - $23;
        $25 = ($3>>>0)>(1060850207);
        if ($25) {
         $$0175186 = $24;$$pn = 1.0;
         label = 23;
        } else {
         $30 = ($3>>>0)>(1047343879);
         $31 = $$1 + -0.4616321325302124;
         if ($30) {
          $$0175189 = $24;$$0178188 = $31;
          label = 24;
         } else {
          $$0175192 = $24;$$0178191 = $$1;
          label = 25;
         }
        }
       } else {
        $26 = ($3>>>0)>(1071490583);
        if ($26) {
         $$0175186 = 0.0;$$pn = 2.0;
         label = 23;
        } else {
         $27 = ($3>>>0)>(1067296287);
         if ($27) {
          $28 = $$1 + -1.4616321325302124;
          $$0175189 = 0.0;$$0178188 = $28;
          label = 24;
          break;
         } else {
          $29 = $$1 + -1.0;
          $$0175192 = 0.0;$$0178191 = $29;
          label = 25;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 23) {
       $$0178185 = $$pn - $$1;
       $32 = $$0178185 * $$0178185;
       $33 = $32 * 2.5214456400135532E-5;
       $34 = $33 + 2.2086278477218002E-4;
       $35 = $32 * $34;
       $36 = $35 + 0.0011927076848223805;
       $37 = $32 * $36;
       $38 = $37 + 0.0073855509981513023;
       $39 = $32 * $38;
       $40 = $39 + 0.067352302372455597;
       $41 = $32 * $40;
       $42 = $41 + 0.077215664088726044;
       $43 = $32 * 4.4864096707897261E-5;
       $44 = $43 + 1.0801156895468011E-4;
       $45 = $32 * $44;
       $46 = $45 + 5.1006977446377277E-4;
       $47 = $32 * $46;
       $48 = $47 + 0.0028905137442052364;
       $49 = $32 * $48;
       $50 = $49 + 0.020580807700753212;
       $51 = $32 * $50;
       $52 = $51 + 0.32246702909469604;
       $53 = $32 * $52;
       $54 = $$0178185 * $42;
       $55 = $54 + $53;
       $56 = $$0178185 * 0.5;
       $57 = $55 - $56;
       $58 = $$0175186 + $57;
       $$1176 = $58;
       break;
      }
      else if ((label|0) == 24) {
       $59 = $$0178188 * $$0178188;
       $60 = $$0178188 * $59;
       $61 = $60 * 3.15632059937343E-4;
       $62 = $61 + -0.0014034647028893232;
       $63 = $60 * $62;
       $64 = $63 + 0.0061005386523902416;
       $65 = $60 * $64;
       $66 = $65 + -0.032788541167974472;
       $67 = $60 * $66;
       $68 = $67 + 0.48383611440658569;
       $69 = $60 * 3.1275415676645935E-4;
       $70 = 8.8108185445889831E-4 - $69;
       $71 = $60 * $70;
       $72 = $71 + -0.0036845202557742596;
       $73 = $60 * $72;
       $74 = $73 + 0.017970675602555275;
       $75 = $60 * $74;
       $76 = $75 + -0.14758771657943726;
       $77 = $60 * 3.3552918466739357E-4;
       $78 = $77 + -5.3859531180933118E-4;
       $79 = $60 * $78;
       $80 = $79 + 0.0022596477065235376;
       $81 = $60 * $80;
       $82 = $81 + -0.010314224287867546;
       $83 = $60 * $82;
       $84 = $83 + 0.06462494283914566;
       $85 = $59 * $68;
       $86 = $$0178188 * $84;
       $87 = $76 + $86;
       $88 = $60 * $87;
       $89 = 6.6971006518201648E-9 - $88;
       $90 = $85 - $89;
       $91 = $90 + -0.12148628383874893;
       $92 = $$0175189 + $91;
       $$1176 = $92;
       break;
      }
      else if ((label|0) == 25) {
       $93 = $$0178191 * 0.013381091877818108;
       $94 = $93 + 0.22896373271942139;
       $95 = $$0178191 * $94;
       $96 = $95 + 0.97771751880645751;
       $97 = $$0178191 * $96;
       $98 = $97 + 1.4549225568771362;
       $99 = $$0178191 * $98;
       $100 = $99 + 0.6328270435333252;
       $101 = $$0178191 * $100;
       $102 = $101 + -0.077215664088726044;
       $103 = $$0178191 * $102;
       $104 = $$0178191 * 0.0032170924823731184;
       $105 = $104 + 0.10422264784574509;
       $106 = $$0178191 * $105;
       $107 = $106 + 0.76928514242172241;
       $108 = $$0178191 * $107;
       $109 = $108 + 2.1284897327423096;
       $110 = $$0178191 * $109;
       $111 = $110 + 2.4559779167175293;
       $112 = $$0178191 * $111;
       $113 = $112 + 1.0;
       $114 = $$0178191 * 0.5;
       $115 = $103 / $113;
       $116 = $115 - $114;
       $117 = $$0175192 + $116;
       $$1176 = $117;
       break;
      }
     } else {
      $118 = ($3>>>0)<(1090519040);
      if (!($118)) {
       $161 = ($3>>>0)<(1551892480);
       $162 = (+Math_log((+$$1)));
       if ($161) {
        $163 = 1.0 / $$1;
        $164 = $163 * $163;
        $165 = $164 * 0.0016309292986989021;
        $166 = 8.3633989561349154E-4 - $165;
        $167 = $164 * $166;
        $168 = $167 + -5.9518753550946712E-4;
        $169 = $164 * $168;
        $170 = $169 + 7.9365057172253728E-4;
        $171 = $164 * $170;
        $172 = $171 + -0.0027777778450399637;
        $173 = $164 * $172;
        $174 = $173 + 0.083333335816860198;
        $175 = $163 * $174;
        $176 = $175 + 0.41893854737281799;
        $177 = $$1 + -0.5;
        $178 = $162 + -1.0;
        $179 = $177 * $178;
        $180 = $176 + $179;
        $$1176 = $180;
        break;
       } else {
        $181 = $162 + -1.0;
        $182 = $$1 * $181;
        $$1176 = $182;
        break;
       }
      }
      $119 = (~~(($$1)));
      $120 = (+($119|0));
      $121 = $$1 - $120;
      $122 = $121 * 3.194753298885189E-5;
      $123 = $122 + 0.0018402845598757267;
      $124 = $121 * $123;
      $125 = $124 + 0.026642270386219025;
      $126 = $121 * $125;
      $127 = $126 + 0.14635047316551208;
      $128 = $121 * $127;
      $129 = $128 + 0.3257787823677063;
      $130 = $121 * $129;
      $131 = $130 + 0.21498242020606995;
      $132 = $121 * $131;
      $133 = $132 + -0.077215664088726044;
      $134 = $121 * $133;
      $135 = $121 * 7.3266842264274601E-6;
      $136 = $135 + 7.7794247772544622E-4;
      $137 = $121 * $136;
      $138 = $137 + 0.018645919859409332;
      $139 = $121 * $138;
      $140 = $139 + 0.1719338595867157;
      $141 = $121 * $140;
      $142 = $141 + 0.72193557024002075;
      $143 = $121 * $142;
      $144 = $143 + 1.3920053243637085;
      $145 = $121 * $144;
      $146 = $145 + 1.0;
      $147 = $121 * 0.5;
      $148 = $134 / $146;
      $149 = $147 + $148;
      switch ($119|0) {
      case 7:  {
       $150 = $121 + 6.0;
       $$0180 = $150;
       label = 29;
       break;
      }
      case 6:  {
       $$0180 = 1.0;
       label = 29;
       break;
      }
      case 5:  {
       $$1181 = 1.0;
       label = 30;
       break;
      }
      case 4:  {
       $$2182 = 1.0;
       label = 31;
       break;
      }
      case 3:  {
       $$3 = 1.0;
       break;
      }
      default: {
       $$1176 = $149;
       break L29;
      }
      }
      if ((label|0) == 29) {
       $151 = $121 + 5.0;
       $152 = $151 * $$0180;
       $$1181 = $152;
       label = 30;
      }
      if ((label|0) == 30) {
       $153 = $121 + 4.0;
       $154 = $153 * $$1181;
       $$2182 = $154;
       label = 31;
      }
      if ((label|0) == 31) {
       $155 = $121 + 3.0;
       $156 = $155 * $$2182;
       $$3 = $156;
      }
      $157 = $121 + 2.0;
      $158 = $157 * $$3;
      $159 = (+Math_log((+$158)));
      $160 = $149 + $159;
      $$1176 = $160;
      break;
     }
    }
   } while(0);
   $183 = $$0179 - $$1176;
   $spec$select = $7 ? $183 : $$1176;
   $$0 = $spec$select;
  }
 } while(0);
 return (+$$0);
}
function _sin_pi($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 * 0.5;
 $2 = (+Math_floor((+$1)));
 $3 = $1 - $2;
 $4 = $3 * 2.0;
 $5 = $4 * 4.0;
 $6 = (~~(($5)));
 $7 = (($6) + 1)|0;
 $8 = (($7|0) / 2)&-1;
 $9 = (+($8|0));
 $10 = $9 * 0.5;
 $11 = $4 - $10;
 $12 = $11;
 $13 = $12 * 3.1415926535897931;
 switch ($8|0) {
 case 3:  {
  $18 = (+___cosdf($13));
  $19 = - $18;
  $$0 = $19;
  break;
 }
 case 1:  {
  $15 = (+___cosdf($13));
  $$0 = $15;
  break;
 }
 case 2:  {
  $16 = - $13;
  $17 = (+___sindf($16));
  $$0 = $17;
  break;
 }
 default: {
  $14 = (+___sindf($13));
  $$0 = $14;
 }
 }
 return (+$$0);
}
function _cbrtl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_cbrt($0));
 return (+$1);
}
function _cbrt($0) {
 $0 = +$0;
 var $$052 = 0.0, $$sink53 = 0, $$sink54 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0;
 var $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2146435071);
 do {
  if ($4) {
   $5 = $0 + $0;
   $$052 = $5;
  } else {
   $6 = ($3>>>0)<(1048576);
   if ($6) {
    $7 = $0 * 18014398509481984.0;
    HEAPF64[tempDoublePtr>>3] = $7;$8 = HEAP32[tempDoublePtr>>2]|0;
    $9 = HEAP32[tempDoublePtr+4>>2]|0;
    $10 = $9 & 2147483647;
    $11 = ($10|0)==(0);
    if ($11) {
     $$052 = $0;
     break;
    } else {
     $$sink53 = 696219795;$$sink54 = $10;$15 = $9;$46 = $8;
    }
   } else {
    $$sink53 = 715094163;$$sink54 = $3;$15 = $2;$46 = $1;
   }
   $12 = (($$sink54>>>0) / 3)&-1;
   $13 = (($12) + ($$sink53))|0;
   $14 = $15 & -2147483648;
   $16 = $13 | $14;
   HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
   $18 = $17 * $17;
   $19 = $17 / $0;
   $20 = $18 * $19;
   $21 = $20 * 1.6214297201053545;
   $22 = $21 + -1.8849797954337717;
   $23 = $20 * $22;
   $24 = $23 + 1.8759518242717701;
   $25 = $20 * $20;
   $26 = $20 * $25;
   $27 = $20 * 0.14599619288661245;
   $28 = $27 + -0.75839793477876605;
   $29 = $26 * $28;
   $30 = $29 + $24;
   $31 = $30 * $17;
   HEAPF64[tempDoublePtr>>3] = $31;$32 = HEAP32[tempDoublePtr>>2]|0;
   $33 = HEAP32[tempDoublePtr+4>>2]|0;
   $34 = (_i64Add(($32|0),($33|0),-2147483648,0)|0);
   $35 = (getTempRet0() | 0);
   $36 = $34 & -1073741824;
   HEAP32[tempDoublePtr>>2] = $36;HEAP32[tempDoublePtr+4>>2] = $35;$37 = +HEAPF64[tempDoublePtr>>3];
   $38 = $37 * $37;
   $39 = $0 / $38;
   $40 = $37 + $37;
   $41 = $39 - $37;
   $42 = $40 + $39;
   $43 = $41 / $42;
   $44 = $43 * $37;
   $45 = $44 + $37;
   $$052 = $45;
  }
 } while(0);
 return (+$$052);
}
function _remainder($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (+_remquo($0,$1,$2));
 STACKTOP = sp;return (+$3);
}
function _remquo($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $$0102 = 0.0, $$0103 = 0.0, $$0104$lcssa = 0, $$0104141 = 0, $$0106$lcssa = 0, $$0106147 = 0, $$097 = 0, $$1105 = 0, $$1107 = 0, $$2108$lcssa = 0, $$2108134 = 0, $$3100 = 0, $$3100125 = 0, $$3100126 = 0, $$3109128 = 0, $$4101 = 0, $$4110 = 0, $$4110123 = 0, $$4110124 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0.0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond122 = 0, $spec$select = 0;
 var $spec$select$lcssa = 0, $spec$select120 = 0.0, $spec$select132 = 0, $spec$select135 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$3 = HEAP32[tempDoublePtr>>2]|0;
 $4 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $1;$5 = HEAP32[tempDoublePtr>>2]|0;
 $6 = HEAP32[tempDoublePtr+4>>2]|0;
 $7 = (_bitshift64Lshr(($3|0),($4|0),52)|0);
 $8 = (getTempRet0() | 0);
 $9 = $7 & 2047;
 $10 = (_bitshift64Lshr(($5|0),($6|0),52)|0);
 $11 = (getTempRet0() | 0);
 $12 = $10 & 2047;
 $13 = (_bitshift64Lshr(($3|0),($4|0),63)|0);
 $14 = (getTempRet0() | 0);
 $15 = (_bitshift64Lshr(($5|0),($6|0),63)|0);
 $16 = (getTempRet0() | 0);
 HEAP32[$2>>2] = 0;
 $17 = $6 & 2147483647;
 $18 = ($5|0)==(0);
 $19 = ($17|0)==(0);
 $20 = $18 & $19;
 do {
  if ($20) {
   label = 3;
  } else {
   $21 = (___DOUBLE_BITS_79($1)|0);
   $22 = (getTempRet0() | 0);
   $23 = $22 & 2147483647;
   $24 = ($23>>>0)>(2146435072);
   $25 = ($21>>>0)>(0);
   $26 = ($23|0)==(2146435072);
   $27 = $26 & $25;
   $28 = $24 | $27;
   $29 = ($9|0)==(2047);
   $or$cond = $29 | $28;
   if ($or$cond) {
    label = 3;
   } else {
    $32 = $4 & 2147483647;
    $33 = ($3|0)==(0);
    $34 = ($32|0)==(0);
    $35 = $33 & $34;
    if ($35) {
     $$0102 = $0;
    } else {
     $36 = ($9|0)==(0);
     if ($36) {
      $37 = (_bitshift64Shl(($3|0),($4|0),12)|0);
      $38 = (getTempRet0() | 0);
      $39 = ($38|0)>(-1);
      $40 = ($37>>>0)>(4294967295);
      $41 = ($38|0)==(-1);
      $42 = $41 & $40;
      $43 = $39 | $42;
      if ($43) {
       $$0106147 = 0;$45 = $37;$46 = $38;
       while(1) {
        $44 = (($$0106147) + -1)|0;
        $47 = (_bitshift64Shl(($45|0),($46|0),1)|0);
        $48 = (getTempRet0() | 0);
        $49 = ($48|0)>(-1);
        $50 = ($47>>>0)>(4294967295);
        $51 = ($48|0)==(-1);
        $52 = $51 & $50;
        $53 = $49 | $52;
        if ($53) {
         $$0106147 = $44;$45 = $47;$46 = $48;
        } else {
         $$0106$lcssa = $44;
         break;
        }
       }
      } else {
       $$0106$lcssa = 0;
      }
      $54 = (1 - ($$0106$lcssa))|0;
      $55 = (_bitshift64Shl(($3|0),($4|0),($54|0))|0);
      $56 = (getTempRet0() | 0);
      $$1107 = $$0106$lcssa;$86 = $55;$87 = $56;
     } else {
      $57 = $4 & 1048575;
      $58 = $57 | 1048576;
      $$1107 = $9;$86 = $3;$87 = $58;
     }
     $59 = ($12|0)==(0);
     if ($59) {
      $60 = (_bitshift64Shl(($5|0),($6|0),12)|0);
      $61 = (getTempRet0() | 0);
      $62 = ($61|0)>(-1);
      $63 = ($60>>>0)>(4294967295);
      $64 = ($61|0)==(-1);
      $65 = $64 & $63;
      $66 = $62 | $65;
      if ($66) {
       $$0104141 = 0;$68 = $60;$69 = $61;
       while(1) {
        $67 = (($$0104141) + -1)|0;
        $70 = (_bitshift64Shl(($68|0),($69|0),1)|0);
        $71 = (getTempRet0() | 0);
        $72 = ($71|0)>(-1);
        $73 = ($70>>>0)>(4294967295);
        $74 = ($71|0)==(-1);
        $75 = $74 & $73;
        $76 = $72 | $75;
        if ($76) {
         $$0104141 = $67;$68 = $70;$69 = $71;
        } else {
         $$0104$lcssa = $67;
         break;
        }
       }
      } else {
       $$0104$lcssa = 0;
      }
      $77 = (1 - ($$0104$lcssa))|0;
      $78 = (_bitshift64Shl(($5|0),($6|0),($77|0))|0);
      $79 = (getTempRet0() | 0);
      $$1105 = $$0104$lcssa;$88 = $78;$89 = $79;
     } else {
      $80 = $6 & 1048575;
      $81 = $80 | 1048576;
      $$1105 = $12;$88 = $5;$89 = $81;
     }
     $82 = ($$1107|0)<($$1105|0);
     if ($82) {
      $83 = (($$1107) + 1)|0;
      $84 = ($83|0)==($$1105|0);
      if ($84) {
       $$3100 = 0;$$4110 = $$1107;$140 = $86;$141 = $87;
       label = 26;
      } else {
       $$0102 = $0;
       break;
      }
     } else {
      $85 = ($$1107|0)>($$1105|0);
      $90 = (_i64Subtract(($86|0),($87|0),($88|0),($89|0))|0);
      $91 = (getTempRet0() | 0);
      $92 = ($91|0)>(-1);
      $93 = ($90>>>0)>(4294967295);
      $94 = ($91|0)==(-1);
      $95 = $94 & $93;
      $96 = $92 | $95;
      $97 = (_bitshift64Lshr(($90|0),($91|0),63)|0);
      $98 = (getTempRet0() | 0);
      $spec$select132 = $97 ^ 1;
      $99 = $96 ? $90 : $86;
      $100 = $96 ? $91 : $87;
      if ($85) {
       $$2108134 = $$1107;$101 = $99;$102 = $100;$spec$select135 = $spec$select132;
       while(1) {
        $103 = (_bitshift64Shl(($101|0),($102|0),1)|0);
        $104 = (getTempRet0() | 0);
        $105 = $spec$select135 << 1;
        $106 = (($$2108134) + -1)|0;
        $107 = ($106|0)>($$1105|0);
        $108 = (_i64Subtract(($103|0),($104|0),($88|0),($89|0))|0);
        $109 = (getTempRet0() | 0);
        $110 = ($109|0)>(-1);
        $111 = ($108>>>0)>(4294967295);
        $112 = ($109|0)==(-1);
        $113 = $112 & $111;
        $114 = $110 | $113;
        $115 = (_bitshift64Lshr(($108|0),($109|0),63)|0);
        $116 = (getTempRet0() | 0);
        $$097 = $105 | $115;
        $spec$select = $$097 ^ 1;
        $117 = $114 ? $108 : $103;
        $118 = $114 ? $109 : $104;
        if ($107) {
         $$2108134 = $106;$101 = $117;$102 = $118;$spec$select135 = $spec$select;
        } else {
         $$2108$lcssa = $$1105;$120 = $117;$122 = $118;$spec$select$lcssa = $spec$select;
         break;
        }
       }
      } else {
       $$2108$lcssa = $$1107;$120 = $99;$122 = $100;$spec$select$lcssa = $spec$select132;
      }
      $119 = ($120|0)==(0);
      $121 = ($122|0)==(0);
      $123 = $119 & $121;
      if ($123) {
       $$3100126 = $spec$select$lcssa;$$4110124 = -60;$149 = 0;$150 = 0;
       label = 28;
      } else {
       $124 = ($122>>>0)<(1048576);
       $125 = ($120>>>0)<(0);
       $126 = ($122|0)==(1048576);
       $127 = $126 & $125;
       $128 = $124 | $127;
       if ($128) {
        $$3109128 = $$2108$lcssa;$129 = $120;$130 = $122;
        while(1) {
         $131 = (_bitshift64Shl(($129|0),($130|0),1)|0);
         $132 = (getTempRet0() | 0);
         $133 = (($$3109128) + -1)|0;
         $134 = ($132>>>0)<(1048576);
         $135 = ($131>>>0)<(0);
         $136 = ($132|0)==(1048576);
         $137 = $136 & $135;
         $138 = $134 | $137;
         if ($138) {
          $$3109128 = $133;$129 = $131;$130 = $132;
         } else {
          $$3100 = $spec$select$lcssa;$$4110 = $133;$140 = $131;$141 = $132;
          label = 26;
          break;
         }
        }
       } else {
        $$3100 = $spec$select$lcssa;$$4110 = $$2108$lcssa;$140 = $120;$141 = $122;
        label = 26;
       }
      }
     }
     if ((label|0) == 26) {
      $139 = ($$4110|0)>(0);
      if ($139) {
       $142 = (_i64Add(($140|0),($141|0),0,-1048576)|0);
       $143 = (getTempRet0() | 0);
       $144 = (_bitshift64Shl(($$4110|0),0,52)|0);
       $145 = (getTempRet0() | 0);
       $146 = $142 | $144;
       $147 = $143 | $145;
       $$3100125 = $$3100;$$4110123 = $$4110;$154 = $147;$155 = $146;
      } else {
       $$3100126 = $$3100;$$4110124 = $$4110;$149 = $140;$150 = $141;
       label = 28;
      }
     }
     if ((label|0) == 28) {
      $148 = (1 - ($$4110124))|0;
      $151 = (_bitshift64Lshr(($149|0),($150|0),($148|0))|0);
      $152 = (getTempRet0() | 0);
      $$3100125 = $$3100126;$$4110123 = $$4110124;$154 = $152;$155 = $151;
     }
     HEAP32[tempDoublePtr>>2] = $155;HEAP32[tempDoublePtr+4>>2] = $154;$153 = +HEAPF64[tempDoublePtr>>3];
     $156 = ($15|0)==(0);
     $157 = ($16|0)==(0);
     $158 = $156 & $157;
     $159 = - $1;
     $spec$select120 = $158 ? $1 : $159;
     $160 = ($$4110123|0)==($$1105|0);
     if ($160) {
      label = 33;
     } else {
      $161 = (($$4110123) + 1)|0;
      $162 = ($161|0)==($$1105|0);
      if ($162) {
       $163 = $153 * 2.0;
       $164 = $163 > $spec$select120;
       if ($164) {
        label = 33;
       } else {
        $165 = $163 != $spec$select120;
        $166 = $$3100125 & 1;
        $167 = ($166|0)==(0);
        $or$cond122 = $167 | $165;
        if ($or$cond122) {
         $$0103 = $153;$$4101 = $$3100125;
        } else {
         label = 33;
        }
       }
      } else {
       $$0103 = $153;$$4101 = $$3100125;
      }
     }
     if ((label|0) == 33) {
      $168 = $153 - $spec$select120;
      $169 = (($$3100125) + 1)|0;
      $$0103 = $168;$$4101 = $169;
     }
     $170 = $$4101 & 2147483647;
     $171 = ($13|0)==($15|0);
     $172 = ($14|0)==($16|0);
     $173 = $171 & $172;
     $174 = (0 - ($170))|0;
     $175 = $173 ? $170 : $174;
     HEAP32[$2>>2] = $175;
     $176 = ($13|0)==(0);
     $177 = ($14|0)==(0);
     $178 = $176 & $177;
     $179 = - $$0103;
     $180 = $178 ? $$0103 : $179;
     $$0102 = $180;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $30 = $0 * $1;
  $31 = $30 / $30;
  $$0102 = $31;
 }
 return (+$$0102);
}
function ___DOUBLE_BITS_79($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _fmodl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_fmod($0,$1));
 return (+$2);
}
function _exp10l($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_exp10($0));
 return (+$1);
}
function _exp10($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $3 = 0.0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (+_modf($0,$1));
 $3 = +HEAPF64[$1>>3];
 HEAPF64[tempDoublePtr>>3] = $3;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = $5 & 2146435072;
 $7 = ($6>>>0)<(1076887552);
 $8 = (0)<(0);
 $9 = ($6|0)==(1076887552);
 $10 = $9 & $8;
 $11 = $7 | $10;
 do {
  if ($11) {
   $12 = $2 != 0.0;
   if ($12) {
    $17 = $2 * 3.3219280948873622;
    $18 = (+_exp2($17));
    $19 = (~~(($3)));
    $20 = (($19) + 15)|0;
    $21 = ((gb + (9568) | 0) + ($20<<3)|0);
    $22 = +HEAPF64[$21>>3];
    $23 = $18 * $22;
    $$0 = $23;
    break;
   } else {
    $13 = (~~(($3)));
    $14 = (($13) + 15)|0;
    $15 = ((gb + (9568) | 0) + ($14<<3)|0);
    $16 = +HEAPF64[$15>>3];
    $$0 = $16;
    break;
   }
  } else {
   $24 = (+Math_pow(10.0,(+$0)));
   $$0 = $24;
  }
 } while(0);
 STACKTOP = sp;return (+$$0);
}
function _modf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $5 = (getTempRet0() | 0);
 $6 = $4 & 2047;
 $7 = (($6) + -1023)|0;
 $8 = ($6>>>0)>(1074);
 if ($8) {
  HEAPF64[$1>>3] = $0;
  $9 = ($7|0)!=(1024);
  $10 = $3 & 1048575;
  $11 = ($2|0)==(0);
  $12 = ($10|0)==(0);
  $13 = $11 & $12;
  $or$cond = $13 | $9;
  $14 = $3 & -2147483648;
  HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $14;$15 = +HEAPF64[tempDoublePtr>>3];
  $spec$select = $or$cond ? $15 : $0;
  return (+$spec$select);
 }
 $16 = ($6>>>0)<(1023);
 do {
  if ($16) {
   $17 = $3 & -2147483648;
   $18 = $1;
   $19 = $18;
   HEAP32[$19>>2] = 0;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP32[$21>>2] = $17;
   $$0 = $0;
  } else {
   $22 = (_bitshift64Lshr(-1,1048575,($7|0))|0);
   $23 = (getTempRet0() | 0);
   $24 = $22 & $2;
   $25 = $23 & $3;
   $26 = ($24|0)==(0);
   $27 = ($25|0)==(0);
   $28 = $26 & $27;
   if ($28) {
    HEAPF64[$1>>3] = $0;
    $29 = $3 & -2147483648;
    HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $29;$30 = +HEAPF64[tempDoublePtr>>3];
    $$0 = $30;
    break;
   } else {
    $31 = (_bitshift64Ashr(0,-1048576,($7|0))|0);
    $32 = (getTempRet0() | 0);
    $33 = $31 & $2;
    $34 = $32 & $3;
    HEAP32[tempDoublePtr>>2] = $33;HEAP32[tempDoublePtr+4>>2] = $34;$35 = +HEAPF64[tempDoublePtr>>3];
    $36 = $1;
    $37 = $36;
    HEAP32[$37>>2] = $33;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $34;
    $40 = $0 - $35;
    $$0 = $40;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _log10l($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_log10($0));
 return (+$1);
}
function _remainderf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (+_remquof($0,$1,$2));
 STACKTOP = sp;return (+$3);
}
function _remquof($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $$0 = 0, $$0102 = 0.0, $$0103 = 0.0, $$0104$lcssa = 0, $$0104141 = 0, $$0106$lcssa = 0, $$0106147 = 0, $$095148 = 0, $$097 = 0, $$1105 = 0, $$1107 = 0, $$196142 = 0, $$2108$lcssa = 0, $$2108134 = 0, $$3100 = 0, $$3100125 = 0, $$3100126 = 0, $$3109128 = 0, $$4101 = 0, $$4110 = 0;
 var $$4110123 = 0, $$4110124 = 0, $$4129 = 0, $$5 = 0, $$5127 = 0, $$6 = 0, $$lobit = 0, $$lobit131 = 0, $$mask = 0, $$mask112 = 0, $$sroa$0$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $9 = 0, $or$cond = 0, $or$cond122 = 0, $spec$select = 0, $spec$select$lcssa = 0, $spec$select117 = 0, $spec$select117$lcssa = 0, $spec$select117133 = 0, $spec$select117136 = 0, $spec$select120 = 0.0, $spec$select132 = 0;
 var $spec$select135 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $4 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $5 = $3 >>> 23;
 $6 = $5 & 255;
 $7 = $4 >>> 23;
 $8 = $7 & 255;
 $9 = $3 >>> 31;
 $10 = $4 >>> 31;
 HEAP32[$2>>2] = 0;
 $$mask = $4 & 2147483647;
 $11 = ($$mask|0)==(0);
 do {
  if ($11) {
   label = 3;
  } else {
   $12 = (___FLOAT_BITS_83($1)|0);
   $13 = $12 & 2147483647;
   $14 = ($13>>>0)>(2139095040);
   $15 = ($6|0)==(255);
   $or$cond = $15 | $14;
   if ($or$cond) {
    label = 3;
   } else {
    $$mask112 = $3 & 2147483647;
    $18 = ($$mask112|0)==(0);
    if ($18) {
     $$0102 = $0;
    } else {
     $19 = ($6|0)==(0);
     if ($19) {
      $20 = $3 << 9;
      $21 = ($20|0)>(-1);
      if ($21) {
       $$0106147 = 0;$$095148 = $20;
       while(1) {
        $22 = (($$0106147) + -1)|0;
        $23 = $$095148 << 1;
        $24 = ($23|0)>(-1);
        if ($24) {
         $$0106147 = $22;$$095148 = $23;
        } else {
         $$0106$lcssa = $22;
         break;
        }
       }
      } else {
       $$0106$lcssa = 0;
      }
      $25 = (1 - ($$0106$lcssa))|0;
      $26 = $3 << $25;
      $$0 = $26;$$1107 = $$0106$lcssa;
     } else {
      $27 = $3 & 8388607;
      $28 = $27 | 8388608;
      $$0 = $28;$$1107 = $6;
     }
     $29 = ($8|0)==(0);
     if ($29) {
      $30 = $4 << 9;
      $31 = ($30|0)>(-1);
      if ($31) {
       $$0104141 = 0;$$196142 = $30;
       while(1) {
        $32 = (($$0104141) + -1)|0;
        $33 = $$196142 << 1;
        $34 = ($33|0)>(-1);
        if ($34) {
         $$0104141 = $32;$$196142 = $33;
        } else {
         $$0104$lcssa = $32;
         break;
        }
       }
      } else {
       $$0104$lcssa = 0;
      }
      $35 = (1 - ($$0104$lcssa))|0;
      $36 = $4 << $35;
      $$1105 = $$0104$lcssa;$$sroa$0$0 = $36;
     } else {
      $37 = $4 & 8388607;
      $38 = $37 | 8388608;
      $$1105 = $8;$$sroa$0$0 = $38;
     }
     $39 = ($$1107|0)<($$1105|0);
     if ($39) {
      $40 = (($$1107) + 1)|0;
      $41 = ($40|0)==($$1105|0);
      if ($41) {
       $$3100 = 0;$$4110 = $$1107;$$5 = $$0;
       label = 26;
      } else {
       $$0102 = $0;
       break;
      }
     } else {
      $42 = ($$1107|0)>($$1105|0);
      $43 = (($$0) - ($$sroa$0$0))|0;
      $44 = ($43|0)>(-1);
      $$lobit131 = $43 >>> 31;
      $spec$select132 = $$lobit131 ^ 1;
      $spec$select117133 = $44 ? $43 : $$0;
      if ($42) {
       $$2108134 = $$1107;$spec$select117136 = $spec$select117133;$spec$select135 = $spec$select132;
       while(1) {
        $45 = $spec$select117136 << 1;
        $46 = $spec$select135 << 1;
        $47 = (($$2108134) + -1)|0;
        $48 = ($47|0)>($$1105|0);
        $49 = (($45) - ($$sroa$0$0))|0;
        $50 = ($49|0)>(-1);
        $$lobit = $49 >>> 31;
        $$097 = $$lobit | $46;
        $spec$select = $$097 ^ 1;
        $spec$select117 = $50 ? $49 : $45;
        if ($48) {
         $$2108134 = $47;$spec$select117136 = $spec$select117;$spec$select135 = $spec$select;
        } else {
         $$2108$lcssa = $$1105;$spec$select$lcssa = $spec$select;$spec$select117$lcssa = $spec$select117;
         break;
        }
       }
      } else {
       $$2108$lcssa = $$1107;$spec$select$lcssa = $spec$select132;$spec$select117$lcssa = $spec$select117133;
      }
      $51 = ($spec$select117$lcssa|0)==(0);
      if ($51) {
       $$3100126 = $spec$select$lcssa;$$4110124 = -30;$$5127 = 0;
       label = 28;
      } else {
       $52 = ($spec$select117$lcssa>>>0)<(8388608);
       if ($52) {
        $$3109128 = $$2108$lcssa;$$4129 = $spec$select117$lcssa;
        while(1) {
         $53 = $$4129 << 1;
         $54 = (($$3109128) + -1)|0;
         $55 = ($53>>>0)<(8388608);
         if ($55) {
          $$3109128 = $54;$$4129 = $53;
         } else {
          $$3100 = $spec$select$lcssa;$$4110 = $54;$$5 = $53;
          label = 26;
          break;
         }
        }
       } else {
        $$3100 = $spec$select$lcssa;$$4110 = $$2108$lcssa;$$5 = $spec$select117$lcssa;
        label = 26;
       }
      }
     }
     if ((label|0) == 26) {
      $56 = ($$4110|0)>(0);
      if ($56) {
       $57 = (($$5) + -8388608)|0;
       $58 = $$4110 << 23;
       $59 = $57 | $58;
       $$3100125 = $$3100;$$4110123 = $$4110;$$6 = $59;
      } else {
       $$3100126 = $$3100;$$4110124 = $$4110;$$5127 = $$5;
       label = 28;
      }
     }
     if ((label|0) == 28) {
      $60 = (1 - ($$4110124))|0;
      $61 = $$5127 >>> $60;
      $$3100125 = $$3100126;$$4110123 = $$4110124;$$6 = $61;
     }
     $62 = (HEAP32[tempDoublePtr>>2]=$$6,+HEAPF32[tempDoublePtr>>2]);
     $63 = ($10|0)==(0);
     $64 = - $1;
     $spec$select120 = $63 ? $1 : $64;
     $65 = ($$4110123|0)==($$1105|0);
     if ($65) {
      label = 33;
     } else {
      $66 = (($$4110123) + 1)|0;
      $67 = ($66|0)==($$1105|0);
      if ($67) {
       $68 = $62 * 2.0;
       $69 = $68 > $spec$select120;
       if ($69) {
        label = 33;
       } else {
        $70 = $68 != $spec$select120;
        $71 = $$3100125 & 1;
        $72 = ($71|0)==(0);
        $or$cond122 = $72 | $70;
        if ($or$cond122) {
         $$0103 = $62;$$4101 = $$3100125;
        } else {
         label = 33;
        }
       }
      } else {
       $$0103 = $62;$$4101 = $$3100125;
      }
     }
     if ((label|0) == 33) {
      $73 = $62 - $spec$select120;
      $74 = (($$3100125) + 1)|0;
      $$0103 = $73;$$4101 = $74;
     }
     $75 = $$4101 & 2147483647;
     $76 = ($9|0)==($10|0);
     $77 = (0 - ($75))|0;
     $78 = $76 ? $75 : $77;
     HEAP32[$2>>2] = $78;
     $79 = ($9|0)==(0);
     $80 = - $$0103;
     $81 = $79 ? $$0103 : $80;
     $$0102 = $81;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $16 = $0 * $1;
  $17 = $16 / $16;
  $$0102 = $17;
 }
 return (+$$0102);
}
function ___FLOAT_BITS_83($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _scalbf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___FLOAT_BITS_80($0)|0);
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095040);
 do {
  if ($4) {
   label = 3;
  } else {
   $5 = (___FLOAT_BITS_80($1)|0);
   $6 = $5 & 2147483647;
   $7 = ($6>>>0)>(2139095040);
   if ($7) {
    label = 3;
   } else {
    $9 = $5 & 2139095040;
    $10 = ($9|0)==(2139095040);
    if ($10) {
     $11 = $1 > 0.0;
     if ($11) {
      $12 = $0 * $1;
      $$0 = $12;
      break;
     } else {
      $13 = - $1;
      $14 = $0 / $13;
      $$0 = $14;
      break;
     }
    }
    $15 = (+_rintf((+$1)));
    $16 = $15 != $1;
    if ($16) {
     $17 = $1 - $1;
     $18 = $17 / $17;
     $$0 = $18;
     break;
    }
    $19 = $1 > 65000.0;
    if ($19) {
     $20 = (+_scalbnf($0,65000));
     $$0 = $20;
     break;
    }
    $21 = $1 < -65000.0;
    if ($21) {
     $22 = (+_scalbnf($0,-65000));
     $$0 = $22;
     break;
    } else {
     $23 = (~~(($1)));
     $24 = (+_scalbnf($0,$23));
     $$0 = $24;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = $0 * $1;
  $$0 = $8;
 }
 return (+$$0);
}
function ___FLOAT_BITS_80($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _ilogbf($0) {
 $0 = +$0;
 var $$01517 = 0, $$016 = 0, $$018 = 0, $$mask = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 23;
 $trunc = $2&255;
 switch ($trunc<<24>>24) {
 case 0:  {
  $3 = $1 << 9;
  $4 = ($3|0)==(0);
  if ($4) {
   $$016 = -2147483648;
  } else {
   $5 = ($3|0)>(-1);
   if ($5) {
    $$01517 = $3;$$018 = -127;
    while(1) {
     $6 = (($$018) + -1)|0;
     $7 = $$01517 << 1;
     $8 = ($7|0)>(-1);
     if ($8) {
      $$01517 = $7;$$018 = $6;
     } else {
      $$016 = $6;
      break;
     }
    }
   } else {
    $$016 = -127;
   }
  }
  break;
 }
 case -1:  {
  $$mask = $1 & 8388607;
  $9 = ($$mask|0)==(0);
  $10 = $9 ? 2147483647 : -2147483648;
  $$016 = $10;
  break;
 }
 default: {
  $11 = $2 & 255;
  $12 = (($11) + -127)|0;
  $$016 = $12;
 }
 }
 return ($$016|0);
}
function ___lgammal_r($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+___lgamma_r($0,$1));
 return (+$2);
}
function ___lgamma_r($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0174 = 0.0, $$0175 = 0.0, $$0176187 = 0.0, $$0176190 = 0.0, $$0176193 = 0.0, $$0178 = 0.0, $$0179186 = 0.0, $$0179189 = 0.0, $$0179192 = 0.0, $$0180 = 0.0, $$0181 = 0.0, $$1 = 0.0, $$1177 = 0.0, $$1182 = 0.0, $$2183 = 0.0, $$3 = 0.0, $$pn = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0;
 var $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0.0;
 var $120 = 0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0;
 var $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0;
 var $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0.0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0;
 var $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0;
 var $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0;
 var $99 = 0.0, $spec$select = 0.0, $switch$split12D = 0, $switch$split2D = 0, $switch$split42D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAP32[$1>>2] = 1;
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)>(2146435071);
 do {
  if ($5) {
   $6 = $0 * $0;
   $$0174 = $6;
  } else {
   $7 = ($4>>>0)<(999292928);
   $8 = ($3|0)<(0);
   if ($7) {
    if ($8) {
     $9 = - $0;
     HEAP32[$1>>2] = -1;
     $$0175 = $9;
    } else {
     $$0175 = $0;
    }
    $10 = (+Math_log((+$$0175)));
    $11 = - $10;
    $$0174 = $11;
    break;
   }
   if ($8) {
    $12 = - $0;
    $13 = (+_sin_pi_94($12));
    $14 = $13 == 0.0;
    if ($14) {
     $15 = $0 - $0;
     $16 = 1.0 / $15;
     $$0174 = $16;
     break;
    }
    $17 = $13 > 0.0;
    if ($17) {
     HEAP32[$1>>2] = -1;
     $$0178 = $13;
    } else {
     $18 = - $13;
     $$0178 = $18;
    }
    $19 = $$0178 * $12;
    $20 = 3.1415926535897931 / $19;
    $21 = (+Math_log((+$20)));
    $$0180 = $21;$$1 = $12;
   } else {
    $$0180 = 0.0;$$1 = $0;
   }
   $switch$split2D = ($3|0)<(1072693248);
   L20: do {
    if ($switch$split2D) {
     $switch$split12D = ($3|0)<(-1073741824);
     if ($switch$split12D) {
      switch ($3|0) {
      case -1074790400:  {
       label = 15;
       break L20;
       break;
      }
      default: {
       label = 16;
       break L20;
      }
      }
     } else {
      switch ($3|0) {
      case -1073741824:  {
       label = 15;
       break L20;
       break;
      }
      default: {
       label = 16;
       break L20;
      }
      }
     }
    } else {
     $switch$split42D = ($3|0)<(1073741824);
     if ($switch$split42D) {
      switch ($3|0) {
      case 1072693248:  {
       label = 15;
       break L20;
       break;
      }
      default: {
       label = 16;
       break L20;
      }
      }
     } else {
      switch ($3|0) {
      case 1073741824:  {
       label = 15;
       break L20;
       break;
      }
      default: {
       label = 16;
       break L20;
      }
      }
     }
    }
   } while(0);
   if ((label|0) == 15) {
    $22 = ($2|0)==(0);
    if ($22) {
     $$1177 = 0.0;
    } else {
     label = 16;
    }
   }
   L31: do {
    if ((label|0) == 16) {
     $23 = ($4>>>0)<(1073741824);
     if ($23) {
      $24 = ($4>>>0)<(1072483533);
      do {
       if ($24) {
        $25 = (+Math_log((+$$1)));
        $26 = - $25;
        $27 = ($4>>>0)>(1072130371);
        if ($27) {
         $$0176187 = $26;$$pn = 1.0;
         label = 24;
        } else {
         $32 = ($4>>>0)>(1070442080);
         $33 = $$1 + -0.46163214496836225;
         if ($32) {
          $$0176190 = $26;$$0179189 = $33;
          label = 25;
         } else {
          $$0176193 = $26;$$0179192 = $$1;
          label = 26;
         }
        }
       } else {
        $28 = ($4>>>0)>(1073460418);
        if ($28) {
         $$0176187 = 0.0;$$pn = 2.0;
         label = 24;
        } else {
         $29 = ($4>>>0)>(1072936131);
         if ($29) {
          $30 = $$1 + -1.4616321449683622;
          $$0176190 = 0.0;$$0179189 = $30;
          label = 25;
          break;
         } else {
          $31 = $$1 + -1.0;
          $$0176193 = 0.0;$$0179192 = $31;
          label = 26;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 24) {
       $$0179186 = $$pn - $$1;
       $34 = $$0179186 * $$0179186;
       $35 = $34 * 2.5214456545125733E-5;
       $36 = $35 + 2.2086279071390839E-4;
       $37 = $34 * $36;
       $38 = $37 + 0.0011927076318336207;
       $39 = $34 * $38;
       $40 = $39 + 0.0073855508608140288;
       $41 = $34 * $40;
       $42 = $41 + 0.067352301053129268;
       $43 = $34 * $42;
       $44 = $43 + 0.077215664901532866;
       $45 = $34 * 4.4864094961891516E-5;
       $46 = $45 + 1.0801156724758394E-4;
       $47 = $34 * $46;
       $48 = $47 + 5.1006979215351134E-4;
       $49 = $34 * $48;
       $50 = $49 + 0.0028905138367341563;
       $51 = $34 * $50;
       $52 = $51 + 0.020580808432516733;
       $53 = $34 * $52;
       $54 = $53 + 0.32246703342411359;
       $55 = $34 * $54;
       $56 = $$0179186 * $44;
       $57 = $56 + $55;
       $58 = $$0179186 * 0.5;
       $59 = $57 - $58;
       $60 = $$0176187 + $59;
       $$1177 = $60;
       break;
      }
      else if ((label|0) == 25) {
       $61 = $$0179189 * $$0179189;
       $62 = $$0179189 * $61;
       $63 = $62 * 3.1563207090362595E-4;
       $64 = $63 + -0.0014034646998923284;
       $65 = $62 * $64;
       $66 = $65 + 0.0061005387024629133;
       $67 = $62 * $66;
       $68 = $67 + -0.032788541075985965;
       $69 = $62 * $68;
       $70 = $69 + 0.48383612272381005;
       $71 = $62 * 3.1275416837512086E-4;
       $72 = 8.8108188243765401E-4 - $71;
       $73 = $62 * $72;
       $74 = $73 + -0.0036845201678113826;
       $75 = $62 * $74;
       $76 = $75 + 0.017970675081182039;
       $77 = $62 * $76;
       $78 = $77 + -0.14758772299459391;
       $79 = $62 * 3.3552919263551907E-4;
       $80 = $79 + -5.3859530535674055E-4;
       $81 = $62 * $80;
       $82 = $81 + 0.0022596478090061247;
       $83 = $62 * $82;
       $84 = $83 + -0.010314224129834144;
       $85 = $62 * $84;
       $86 = $85 + 0.064624940239133385;
       $87 = $61 * $70;
       $88 = $$0179189 * $86;
       $89 = $78 + $88;
       $90 = $62 * $89;
       $91 = -3.6386769970395054E-18 - $90;
       $92 = $87 - $91;
       $93 = $92 + -0.12148629053584961;
       $94 = $$0176190 + $93;
       $$1177 = $94;
       break;
      }
      else if ((label|0) == 26) {
       $95 = $$0179192 * 0.013381091853678766;
       $96 = $95 + 0.22896372806469245;
       $97 = $$0179192 * $96;
       $98 = $97 + 0.97771752796337275;
       $99 = $$0179192 * $98;
       $100 = $99 + 1.4549225013723477;
       $101 = $$0179192 * $100;
       $102 = $101 + 0.63282706402509337;
       $103 = $$0179192 * $102;
       $104 = $103 + -0.077215664901532866;
       $105 = $$0179192 * $104;
       $106 = $$0179192 * 0.0032170924228242391;
       $107 = $106 + 0.10422264559336913;
       $108 = $$0179192 * $107;
       $109 = $108 + 0.76928515045667278;
       $110 = $$0179192 * $109;
       $111 = $110 + 2.128489763798934;
       $112 = $$0179192 * $111;
       $113 = $112 + 2.4559779371304113;
       $114 = $$0179192 * $113;
       $115 = $114 + 1.0;
       $116 = $$0179192 * 0.5;
       $117 = $105 / $115;
       $118 = $117 - $116;
       $119 = $$0176193 + $118;
       $$1177 = $119;
       break;
      }
     } else {
      $120 = ($4>>>0)<(1075838976);
      if (!($120)) {
       $163 = ($4>>>0)<(1133510656);
       $164 = (+Math_log((+$$1)));
       if ($163) {
        $165 = 1.0 / $$1;
        $166 = $165 * $165;
        $167 = $166 * 0.0016309293409657527;
        $168 = 8.3633991899628213E-4 - $167;
        $169 = $166 * $168;
        $170 = $169 + -5.9518755745033996E-4;
        $171 = $166 * $170;
        $172 = $171 + 7.9365055864301956E-4;
        $173 = $166 * $172;
        $174 = $173 + -0.0027777777772877554;
        $175 = $166 * $174;
        $176 = $175 + 0.083333333333332968;
        $177 = $165 * $176;
        $178 = $177 + 0.41893853320467273;
        $179 = $$1 + -0.5;
        $180 = $164 + -1.0;
        $181 = $179 * $180;
        $182 = $178 + $181;
        $$1177 = $182;
        break;
       } else {
        $183 = $164 + -1.0;
        $184 = $$1 * $183;
        $$1177 = $184;
        break;
       }
      }
      $121 = (~~(($$1)));
      $122 = (+($121|0));
      $123 = $$1 - $122;
      $124 = $123 * 3.1947532658410087E-5;
      $125 = $124 + 0.0018402845140733772;
      $126 = $123 * $125;
      $127 = $126 + 0.026642270303363861;
      $128 = $123 * $127;
      $129 = $128 + 0.14635047265246445;
      $130 = $123 * $129;
      $131 = $130 + 0.32577879640893098;
      $132 = $123 * $131;
      $133 = $132 + 0.21498241596060885;
      $134 = $123 * $133;
      $135 = $134 + -0.077215664901532866;
      $136 = $123 * $135;
      $137 = $123 * 7.3266843074462564E-6;
      $138 = $137 + 7.779424963818936E-4;
      $139 = $123 * $138;
      $140 = $139 + 0.01864591917156529;
      $141 = $123 * $140;
      $142 = $141 + 0.17193386563280308;
      $143 = $123 * $142;
      $144 = $143 + 0.72193554756713807;
      $145 = $123 * $144;
      $146 = $145 + 1.3920053346762105;
      $147 = $123 * $146;
      $148 = $147 + 1.0;
      $149 = $123 * 0.5;
      $150 = $136 / $148;
      $151 = $149 + $150;
      switch ($121|0) {
      case 7:  {
       $152 = $123 + 6.0;
       $$0181 = $152;
       label = 30;
       break;
      }
      case 6:  {
       $$0181 = 1.0;
       label = 30;
       break;
      }
      case 5:  {
       $$1182 = 1.0;
       label = 31;
       break;
      }
      case 4:  {
       $$2183 = 1.0;
       label = 32;
       break;
      }
      case 3:  {
       $$3 = 1.0;
       break;
      }
      default: {
       $$1177 = $151;
       break L31;
      }
      }
      if ((label|0) == 30) {
       $153 = $123 + 5.0;
       $154 = $153 * $$0181;
       $$1182 = $154;
       label = 31;
      }
      if ((label|0) == 31) {
       $155 = $123 + 4.0;
       $156 = $155 * $$1182;
       $$2183 = $156;
       label = 32;
      }
      if ((label|0) == 32) {
       $157 = $123 + 3.0;
       $158 = $157 * $$2183;
       $$3 = $158;
      }
      $159 = $123 + 2.0;
      $160 = $159 * $$3;
      $161 = (+Math_log((+$160)));
      $162 = $151 + $161;
      $$1177 = $162;
      break;
     }
    }
   } while(0);
   $185 = $$0180 - $$1177;
   $spec$select = $8 ? $185 : $$1177;
   $$0174 = $spec$select;
  }
 } while(0);
 return (+$$0174);
}
function _sin_pi_94($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 * 0.5;
 $2 = (+Math_floor((+$1)));
 $3 = $1 - $2;
 $4 = $3 * 2.0;
 $5 = $4 * 4.0;
 $6 = (~~(($5)));
 $7 = (($6) + 1)|0;
 $8 = (($7|0) / 2)&-1;
 $9 = (+($8|0));
 $10 = $9 * 0.5;
 $11 = $10;
 $12 = $4 - $11;
 $13 = $12 * 3.1415926535897931;
 switch ($8|0) {
 case 3:  {
  $18 = (+___cos($13,0.0));
  $19 = - $18;
  $$0 = $19;
  break;
 }
 case 1:  {
  $15 = (+___cos($13,0.0));
  $$0 = $15;
  break;
 }
 case 2:  {
  $16 = - $13;
  $17 = (+___sin($16,0.0,0));
  $$0 = $17;
  break;
 }
 default: {
  $14 = (+___sin($13,0.0,0));
  $$0 = $14;
 }
 }
 return (+$$0);
}
function _lgammal($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+___lgammal_r($0,(gb + (171128) | 0)));
 return (+$1);
}
function ___signbitl($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___signbit($0)|0);
 return ($1|0);
}
function ___signbit($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),63)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _exp2f($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)>(1123811328);
 do {
  if ($3) {
   $4 = ($2>>>0)>(2139095040);
   if ($4) {
    $$0 = $0;
   } else {
    $5 = ($1>>>0)>(1124073471);
    $6 = ($1|0)>(-1);
    $or$cond = $5 & $6;
    if ($or$cond) {
     $7 = $0 * 1.7014118346046923E+38;
     $$0 = $7;
     break;
    } else {
     $8 = ($1>>>0)>(3272998911);
     if ($8) {
      $$0 = 0.0;
      break;
     } else {
      label = 8;
      break;
     }
    }
   }
  } else {
   $9 = ($2>>>0)<(855638017);
   if ($9) {
    $10 = $0 + 1.0;
    $$0 = $10;
   } else {
    label = 8;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $11 = $0 + 786432.0;
  $12 = (HEAPF32[tempDoublePtr>>2]=$11,HEAP32[tempDoublePtr>>2]|0);
  $13 = (($12) + 8)|0;
  $14 = $13 >>> 4;
  $15 = (($14) + 1023)|0;
  $16 = (_bitshift64Shl(($15|0),0,52)|0);
  $17 = (getTempRet0() | 0);
  $18 = $13 & 15;
  $19 = $11 + -786432.0;
  $20 = $0 - $19;
  $21 = $20;
  $22 = ((gb + (9824) | 0) + ($18<<3)|0);
  $23 = +HEAPF64[$22>>3];
  $24 = $23 * $21;
  $25 = $21 * 0.24022650718688965;
  $26 = $25 + 0.69314718246459961;
  $27 = $26 * $24;
  $28 = $23 + $27;
  $29 = $21 * $21;
  $30 = $29 * $24;
  $31 = $21 * 0.0096183549612760544;
  $32 = $31 + 0.055505409836769104;
  $33 = $32 * $30;
  $34 = $28 + $33;
  HEAP32[tempDoublePtr>>2] = $16;HEAP32[tempDoublePtr+4>>2] = $17;$35 = +HEAPF64[tempDoublePtr>>3];
  $36 = $34 * $35;
  $37 = $36;
  $$0 = $37;
 }
 return (+$$0);
}
function _logbf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___FLOAT_BITS_91($0)|0);
 $2 = $1 & 2139095040;
 $3 = ($2|0)==(2139095040);
 do {
  if ($3) {
   $4 = $0 * $0;
   $$0 = $4;
  } else {
   $5 = $0 == 0.0;
   if ($5) {
    $6 = $0 * $0;
    $7 = -1.0 / $6;
    $$0 = $7;
    break;
   } else {
    $8 = (_ilogbf($0)|0);
    $9 = (+($8|0));
    $$0 = $9;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function ___FLOAT_BITS_91($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _coshf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = (HEAP32[tempDoublePtr>>2]=$2,+HEAPF32[tempDoublePtr>>2]);
 $4 = ($2>>>0)<(1060205079);
 do {
  if ($4) {
   $5 = ($2>>>0)<(964689920);
   if ($5) {
    $$0 = 1.0;
   } else {
    $6 = (+_expm1f($3));
    $7 = $6 * $6;
    $8 = $6 + 1.0;
    $9 = $8 * 2.0;
    $10 = $7 / $9;
    $11 = $10 + 1.0;
    $$0 = $11;
   }
  } else {
   $12 = ($2>>>0)<(1118925335);
   if ($12) {
    $13 = (+Math_exp((+$3)));
    $14 = 1.0 / $13;
    $15 = $13 + $14;
    $16 = $15 * 0.5;
    $$0 = $16;
    break;
   } else {
    $17 = (+___expo2f($3));
    $$0 = $17;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _asinhf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 & 2147483647;
 $3 = (HEAP32[tempDoublePtr>>2]=$2,+HEAPF32[tempDoublePtr>>2]);
 $4 = ($2>>>0)>(1166016511);
 do {
  if ($4) {
   $5 = (+Math_log((+$3)));
   $6 = $5 + 0.69314718246459961;
   $$0 = $6;
  } else {
   $7 = ($2>>>0)>(1073741823);
   if ($7) {
    $8 = $3 * 2.0;
    $9 = $3 * $3;
    $10 = $9 + 1.0;
    $11 = (+Math_sqrt((+$10)));
    $12 = $11 + $3;
    $13 = 1.0 / $12;
    $14 = $8 + $13;
    $15 = (+Math_log((+$14)));
    $$0 = $15;
    break;
   }
   $16 = ($2>>>0)>(964689919);
   if ($16) {
    $17 = $3 * $3;
    $18 = $17 + 1.0;
    $19 = (+Math_sqrt((+$18)));
    $20 = $19 + 1.0;
    $21 = $17 / $20;
    $22 = $21 + $3;
    $23 = (+_log1pf($22));
    $$0 = $23;
   } else {
    $$0 = $3;
   }
  }
 } while(0);
 $24 = ($1|0)<(0);
 $25 = - $$0;
 $26 = $24 ? $25 : $$0;
 return (+$26);
}
function _sinhf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0;
 var $8 = 0, $9 = 0.0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = ($1|0)<(0);
 $spec$select = $2 ? -0.5 : 0.5;
 $3 = $1 & 2147483647;
 $4 = (HEAP32[tempDoublePtr>>2]=$3,+HEAPF32[tempDoublePtr>>2]);
 $5 = ($3>>>0)<(1118925335);
 do {
  if ($5) {
   $6 = (+_expm1f($4));
   $7 = ($3>>>0)<(1065353216);
   if (!($7)) {
    $15 = $6 + 1.0;
    $16 = $6 / $15;
    $17 = $6 + $16;
    $18 = $spec$select * $17;
    $$0 = $18;
    break;
   }
   $8 = ($3>>>0)<(964689920);
   if ($8) {
    $$0 = $0;
   } else {
    $9 = $6 * 2.0;
    $10 = $6 * $6;
    $11 = $6 + 1.0;
    $12 = $10 / $11;
    $13 = $9 - $12;
    $14 = $spec$select * $13;
    $$0 = $14;
   }
  } else {
   $19 = $spec$select * 2.0;
   $20 = (+___expo2f($4));
   $21 = $19 * $20;
   $$0 = $21;
  }
 } while(0);
 return (+$$0);
}
function _frexpl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_frexp($0,$1));
 return (+$2);
}
function _finite($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (___DOUBLE_BITS_95($0)|0);
 $1 = (getTempRet0() | 0);
 $2 = $1 & 2146435072;
 $3 = (0)!=(0);
 $4 = ($2|0)!=(2146435072);
 $5 = $3 | $4;
 $6 = $5&1;
 return ($6|0);
}
function ___DOUBLE_BITS_95($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function ___fpclassifyf($0) {
 $0 = +$0;
 var $$0 = 0, $$mask = 0, $$mask7 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 23;
 $trunc = $2&255;
 switch ($trunc<<24>>24) {
 case 0:  {
  $$mask = $1 & 2147483647;
  $3 = ($$mask|0)==(0);
  $4 = $3 ? 2 : 3;
  $$0 = $4;
  break;
 }
 case -1:  {
  $$mask7 = $1 & 8388607;
  $5 = ($$mask7|0)==(0);
  $6 = $5&1;
  $$0 = $6;
  break;
 }
 default: {
  $$0 = 4;
 }
 }
 return ($$0|0);
}
function _copysignl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_copysign($0,$1));
 return (+$2);
}
function _tgammaf($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = (+_tgamma($1));
 $3 = $2;
 return (+$3);
}
function _llroundl($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_roundl($0));
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (~~+Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 setTempRet0(($3) | 0);
 return ($2|0);
}
function _roundl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_round((+$0)));
 return (+$1);
}
function _truncl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_trunc($0));
 return (+$1);
}
function _trunc($0) {
 $0 = +$0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $spec$select15 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 & 2047;
 $6 = ($5>>>0)>(1074);
 if ($6) {
  return (+$0);
 } else {
  $7 = (($5) + -1011)|0;
  $8 = ($5>>>0)<(1023);
  $9 = (_bitshift64Lshr(-1,-1,($7|0))|0);
  $10 = (getTempRet0() | 0);
  $11 = $8 ? -1 : $9;
  $12 = $8 ? 2147483647 : $10;
  $13 = $11 & $1;
  $14 = $12 & $2;
  $15 = ($13|0)==(0);
  $16 = ($14|0)==(0);
  $17 = $15 & $16;
  $18 = $11 ^ -1;
  $19 = $12 ^ -1;
  $20 = $18 & $1;
  $21 = $19 & $2;
  HEAP32[tempDoublePtr>>2] = $20;HEAP32[tempDoublePtr+4>>2] = $21;$22 = +HEAPF64[tempDoublePtr>>3];
  $spec$select15 = $17 ? $0 : $22;
  return (+$spec$select15);
 }
 return +(0.0);
}
function _ldexp($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbn($0,$1));
 return (+$2);
}
function _log2f($0) {
 $0 = +$0;
 var $$0 = 0, $$076 = 0, $$077 = 0.0, $$mask = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = ($1>>>0)<(8388608);
 $3 = ($1|0)<(0);
 $or$cond = $2 | $3;
 do {
  if ($or$cond) {
   $$mask = $1 & 2147483647;
   $4 = ($$mask|0)==(0);
   if ($4) {
    $5 = $0 * $0;
    $6 = -1.0 / $5;
    $$077 = $6;
    break;
   }
   if ($3) {
    $7 = $0 - $0;
    $8 = $7 / 0.0;
    $$077 = $8;
    break;
   } else {
    $9 = $0 * 33554432.0;
    $10 = (HEAPF32[tempDoublePtr>>2]=$9,HEAP32[tempDoublePtr>>2]|0);
    $$0 = -152;$$076 = $10;
    label = 9;
    break;
   }
  } else {
   $11 = ($1>>>0)>(2139095039);
   if ($11) {
    $$077 = $0;
   } else {
    $12 = ($1|0)==(1065353216);
    if ($12) {
     $$077 = 0.0;
    } else {
     $$0 = -127;$$076 = $1;
     label = 9;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $13 = (($$076) + 4913933)|0;
  $14 = $13 >>> 23;
  $15 = (($$0) + ($14))|0;
  $16 = $13 & 8388607;
  $17 = (($16) + 1060439283)|0;
  $18 = (HEAP32[tempDoublePtr>>2]=$17,+HEAPF32[tempDoublePtr>>2]);
  $19 = $18 + -1.0;
  $20 = $19 + 2.0;
  $21 = $19 / $20;
  $22 = $21 * $21;
  $23 = $22 * $22;
  $24 = $23 * 0.24279078841209412;
  $25 = $24 + 0.40000972151756287;
  $26 = $23 * $25;
  $27 = $23 * 0.28498786687850952;
  $28 = $27 + 0.66666662693023682;
  $29 = $22 * $28;
  $30 = $29 + $26;
  $31 = $19 * 0.5;
  $32 = $19 * $31;
  $33 = $19 - $32;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $35 = $34 & -4096;
  $36 = (HEAP32[tempDoublePtr>>2]=$35,+HEAPF32[tempDoublePtr>>2]);
  $37 = $19 - $36;
  $38 = $37 - $32;
  $39 = $32 + $30;
  $40 = $21 * $39;
  $41 = $38 + $40;
  $42 = $41 + $36;
  $43 = $42 * 1.7605285393074155E-4;
  $44 = $41 * 1.44287109375;
  $45 = $44 - $43;
  $46 = $36 * 1.44287109375;
  $47 = $46 + $45;
  $48 = (+($15|0));
  $49 = $47 + $48;
  $$077 = $49;
 }
 return (+$$077);
}
function _exp2l($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_exp2($0));
 return (+$1);
}
function _lgamma($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+___lgamma_r($0,(gb + (171128) | 0)));
 return (+$1);
}
function _hypotf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$032 = 0.0, $$033 = 0.0, $$034 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, $or$cond = 0, $or$cond37 = 0, $spec$select = 0, $spec$select35 = 0, $spec$select38 = 0.0, $spec$select39 = 0.0, $spec$select40 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $4 = $2 & 2147483647;
 $5 = $3 & 2147483647;
 $6 = ($4>>>0)<($5>>>0);
 $spec$select = $6 ? $5 : $4;
 $spec$select35 = $6 ? $4 : $5;
 $7 = (HEAP32[tempDoublePtr>>2]=$spec$select,+HEAPF32[tempDoublePtr>>2]);
 $8 = (HEAP32[tempDoublePtr>>2]=$spec$select35,+HEAPF32[tempDoublePtr>>2]);
 $9 = ($spec$select35|0)==(2139095040);
 do {
  if ($9) {
   $$032 = $8;
  } else {
   $10 = ($spec$select>>>0)>(2139095039);
   $11 = ($spec$select35|0)==(0);
   $or$cond = $10 | $11;
   $12 = (($spec$select) - ($spec$select35))|0;
   $13 = ($12>>>0)>(209715199);
   $or$cond37 = $or$cond | $13;
   if ($or$cond37) {
    $14 = $7 + $8;
    $$032 = $14;
    break;
   }
   $15 = ($spec$select>>>0)>(1568669695);
   if ($15) {
    $16 = $7 * 8.0779356694631609E-28;
    $17 = $8 * 8.0779356694631609E-28;
    $$0 = 1.2379400392853803E+27;$$033 = $17;$$034 = $16;
   } else {
    $18 = ($spec$select35>>>0)<(562036736);
    $19 = $7 * 1.2379400392853803E+27;
    $20 = $8 * 1.2379400392853803E+27;
    $spec$select38 = $18 ? $19 : $7;
    $spec$select39 = $18 ? $20 : $8;
    $spec$select40 = $18 ? 8.0779356694631609E-28 : 1.0;
    $$0 = $spec$select40;$$033 = $spec$select39;$$034 = $spec$select38;
   }
   $21 = $$034;
   $22 = $21 * $21;
   $23 = $$033;
   $24 = $23 * $23;
   $25 = $22 + $24;
   $26 = $25;
   $27 = (+Math_sqrt((+$26)));
   $28 = $$0 * $27;
   $$032 = $28;
  }
 } while(0);
 return (+$$032);
}
function _significandf($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ilogbf($0)|0);
 $2 = (0 - ($1))|0;
 $3 = (+_scalbnf($0,$2));
 return (+$3);
}
function _fmodf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0, $$068101 = 0, $$070 = 0.0, $$071$lcssa = 0, $$07194 = 0, $$073$lcssa = 0, $$073100 = 0, $$1$lcssa = 0, $$16995 = 0, $$172 = 0, $$174 = 0, $$186 = 0, $$2 = 0, $$275$lcssa = 0, $$27585 = 0, $$3 = 0, $$376$lcssa = 0, $$37682 = 0, $$4$lcssa = 0, $$483 = 0;
 var $$5 = 0, $$lcssa = 0, $$lcssa78 = 0, $$sroa$0$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $4 = $2 >>> 23;
 $5 = $4 & 255;
 $6 = $3 >>> 23;
 $7 = $6 & 255;
 $8 = $2 & -2147483648;
 $9 = $3 << 1;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 3;
  } else {
   $11 = (___FLOAT_BITS_137($1)|0);
   $12 = $11 & 2147483647;
   $13 = ($12>>>0)>(2139095040);
   $14 = ($5|0)==(255);
   $or$cond = $14 | $13;
   if ($or$cond) {
    label = 3;
   } else {
    $17 = $2 << 1;
    $18 = ($17>>>0)>($9>>>0);
    if (!($18)) {
     $19 = ($17|0)==($9|0);
     $20 = $0 * 0.0;
     $spec$select = $19 ? $20 : $0;
     return (+$spec$select);
    }
    $21 = ($5|0)==(0);
    if ($21) {
     $22 = $2 << 9;
     $23 = ($22|0)>(-1);
     if ($23) {
      $$068101 = $22;$$073100 = 0;
      while(1) {
       $24 = (($$073100) + -1)|0;
       $25 = $$068101 << 1;
       $26 = ($25|0)>(-1);
       if ($26) {
        $$068101 = $25;$$073100 = $24;
       } else {
        $$073$lcssa = $24;
        break;
       }
      }
     } else {
      $$073$lcssa = 0;
     }
     $27 = (1 - ($$073$lcssa))|0;
     $28 = $2 << $27;
     $$0 = $28;$$174 = $$073$lcssa;
    } else {
     $29 = $2 & 8388607;
     $30 = $29 | 8388608;
     $$0 = $30;$$174 = $5;
    }
    $31 = ($7|0)==(0);
    if ($31) {
     $32 = $3 << 9;
     $33 = ($32|0)>(-1);
     if ($33) {
      $$07194 = 0;$$16995 = $32;
      while(1) {
       $34 = (($$07194) + -1)|0;
       $35 = $$16995 << 1;
       $36 = ($35|0)>(-1);
       if ($36) {
        $$07194 = $34;$$16995 = $35;
       } else {
        $$071$lcssa = $34;
        break;
       }
      }
     } else {
      $$071$lcssa = 0;
     }
     $37 = (1 - ($$071$lcssa))|0;
     $38 = $3 << $37;
     $$172 = $$071$lcssa;$$sroa$0$0 = $38;
    } else {
     $39 = $3 & 8388607;
     $40 = $39 | 8388608;
     $$172 = $7;$$sroa$0$0 = $40;
    }
    $41 = ($$174|0)>($$172|0);
    $42 = (($$0) - ($$sroa$0$0))|0;
    $43 = ($42|0)>(-1);
    L25: do {
     if ($41) {
      $$186 = $$0;$$27585 = $$174;$45 = $42;$66 = $43;
      while(1) {
       if ($66) {
        $44 = ($45|0)==(0);
        if ($44) {
         break;
        } else {
         $$2 = $45;
        }
       } else {
        $$2 = $$186;
       }
       $47 = $$2 << 1;
       $48 = (($$27585) + -1)|0;
       $49 = ($48|0)>($$172|0);
       $50 = (($47) - ($$sroa$0$0))|0;
       $51 = ($50|0)>(-1);
       if ($49) {
        $$186 = $47;$$27585 = $48;$45 = $50;$66 = $51;
       } else {
        $$1$lcssa = $47;$$275$lcssa = $48;$$lcssa = $51;$$lcssa78 = $50;
        break L25;
       }
      }
      $46 = $0 * 0.0;
      $$070 = $46;
      break L1;
     } else {
      $$1$lcssa = $$0;$$275$lcssa = $$174;$$lcssa = $43;$$lcssa78 = $42;
     }
    } while(0);
    if ($$lcssa) {
     $52 = ($$lcssa78|0)==(0);
     if ($52) {
      $53 = $0 * 0.0;
      $$070 = $53;
      break;
     } else {
      $$3 = $$lcssa78;
     }
    } else {
     $$3 = $$1$lcssa;
    }
    $54 = ($$3>>>0)<(8388608);
    if ($54) {
     $$37682 = $$275$lcssa;$$483 = $$3;
     while(1) {
      $55 = $$483 << 1;
      $56 = (($$37682) + -1)|0;
      $57 = ($55>>>0)<(8388608);
      if ($57) {
       $$37682 = $56;$$483 = $55;
      } else {
       $$376$lcssa = $56;$$4$lcssa = $55;
       break;
      }
     }
    } else {
     $$376$lcssa = $$275$lcssa;$$4$lcssa = $$3;
    }
    $58 = ($$376$lcssa|0)>(0);
    if ($58) {
     $59 = (($$4$lcssa) + -8388608)|0;
     $60 = $$376$lcssa << 23;
     $61 = $59 | $60;
     $$5 = $61;
    } else {
     $62 = (1 - ($$376$lcssa))|0;
     $63 = $$4$lcssa >>> $62;
     $$5 = $63;
    }
    $64 = $$5 | $8;
    $65 = (HEAP32[tempDoublePtr>>2]=$64,+HEAPF32[tempDoublePtr>>2]);
    $$070 = $65;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $15 = $0 * $1;
  $16 = $15 / $15;
  $$070 = $16;
 }
 return (+$$070);
}
function ___FLOAT_BITS_137($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _modfl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (+_modf($0,$2));
 $4 = +HEAPF64[$2>>3];
 HEAPF64[$1>>3] = $4;
 STACKTOP = sp;return (+$3);
}
function _truncf($0) {
 $0 = +$0;
 var $$op = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select15 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 23;
 $3 = $2 & 255;
 $4 = ($3>>>0)>(149);
 if ($4) {
  return (+$0);
 } else {
  $5 = (($3) + -118)|0;
  $6 = ($3>>>0)<(127);
  $$op = -1 >>> $5;
  $7 = $6 ? 2147483647 : $$op;
  $8 = $7 & $1;
  $9 = ($8|0)==(0);
  $10 = $7 ^ -1;
  $11 = $10 & $1;
  $12 = (HEAP32[tempDoublePtr>>2]=$11,+HEAPF32[tempDoublePtr>>2]);
  $spec$select15 = $9 ? $0 : $12;
  return (+$spec$select15);
 }
 return +(0.0);
}
function ___fpclassifyl($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___fpclassify($0)|0);
 return ($1|0);
}
function _sinhl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_sinh($0));
 return (+$1);
}
function _sincosf($0,$1,$2) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 var $$sink = 0.0, $$sink69 = 0.0, $$v = 0.0, $$v67 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0;
 var $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $storemerge = 0.0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $5 = $4 >>> 31;
 $6 = $4 & 2147483647;
 $7 = ($6>>>0)<(1061752795);
 L1: do {
  if ($7) {
   $8 = ($6>>>0)<(964689920);
   if ($8) {
    HEAPF32[$1>>2] = $0;
    HEAPF32[$2>>2] = 1.0;
    break;
   } else {
    $9 = $0;
    $10 = (+___sindf($9));
    HEAPF32[$1>>2] = $10;
    $11 = (+___cosdf($9));
    HEAPF32[$2>>2] = $11;
    break;
   }
  } else {
   $12 = ($6>>>0)<(1081824210);
   if ($12) {
    $13 = ($6>>>0)<(1075235812);
    $14 = ($5|0)!=(0);
    $15 = $0;
    if (!($13)) {
     $$v67 = $14 ? 3.1415926535897931 : -3.1415926535897931;
     $22 = $$v67 + $15;
     $23 = (+___sindf($22));
     $24 = - $23;
     HEAPF32[$1>>2] = $24;
     $25 = (+___cosdf($22));
     $26 = - $25;
     HEAPF32[$2>>2] = $26;
     break;
    }
    if ($14) {
     $16 = $15 + 1.5707963267948966;
     $17 = (+___cosdf($16));
     $18 = - $17;
     $$sink = $16;$$sink69 = $18;
    } else {
     $19 = 1.5707963267948966 - $15;
     $20 = (+___cosdf($19));
     $$sink = $19;$$sink69 = $20;
    }
    HEAPF32[$1>>2] = $$sink69;
    $21 = (+___sindf($$sink));
    HEAPF32[$2>>2] = $21;
    break;
   }
   $27 = ($6>>>0)<(1088565718);
   if ($27) {
    $28 = ($6>>>0)<(1085271520);
    $29 = ($5|0)!=(0);
    $30 = $0;
    if (!($28)) {
     $$v = $29 ? 6.2831853071795862 : -6.2831853071795862;
     $39 = $$v + $30;
     $40 = (+___sindf($39));
     HEAPF32[$1>>2] = $40;
     $41 = (+___cosdf($39));
     HEAPF32[$2>>2] = $41;
     break;
    }
    if ($29) {
     $31 = $30 + 4.7123889803846897;
     $32 = (+___cosdf($31));
     HEAPF32[$1>>2] = $32;
     $33 = (+___sindf($31));
     $34 = - $33;
     $storemerge = $34;
    } else {
     $35 = $30 + -4.7123889803846897;
     $36 = (+___cosdf($35));
     $37 = - $36;
     HEAPF32[$1>>2] = $37;
     $38 = (+___sindf($35));
     $storemerge = $38;
    }
    HEAPF32[$2>>2] = $storemerge;
    break;
   }
   $42 = ($6>>>0)>(2139095039);
   if ($42) {
    $43 = $0 - $0;
    HEAPF32[$2>>2] = $43;
    HEAPF32[$1>>2] = $43;
    break;
   }
   $44 = (___rem_pio2f($0,$3)|0);
   $45 = +HEAPF64[$3>>3];
   $46 = (+___sindf($45));
   $47 = +HEAPF64[$3>>3];
   $48 = (+___cosdf($47));
   $trunc = $44&255;
   $trunc$clear = $trunc & 3;
   switch ($trunc$clear<<24>>24) {
   case 0:  {
    HEAPF32[$1>>2] = $46;
    HEAPF32[$2>>2] = $48;
    break L1;
    break;
   }
   case 1:  {
    HEAPF32[$1>>2] = $48;
    $49 = - $46;
    HEAPF32[$2>>2] = $49;
    break L1;
    break;
   }
   case 2:  {
    $50 = - $46;
    HEAPF32[$1>>2] = $50;
    $51 = - $48;
    HEAPF32[$2>>2] = $51;
    break L1;
    break;
   }
   case 3:  {
    $52 = - $48;
    HEAPF32[$1>>2] = $52;
    HEAPF32[$2>>2] = $46;
    break L1;
    break;
   }
   default: {
    // unreachable;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function ___rem_pio2f($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0.0;
 var $28 = 0.0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 8|0;
 $3 = sp;
 $4 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $5 = $4 & 2147483647;
 $6 = ($5>>>0)<(1305022427);
 do {
  if ($6) {
   $7 = $0;
   $8 = $7 * 0.63661977236758138;
   $9 = $8 + 6755399441055744.0;
   $10 = $9 + -6755399441055744.0;
   $11 = (~~(($10)));
   $12 = $10 * 1.5707963109016418;
   $13 = $7 - $12;
   $14 = $10 * 1.5893254773528196E-8;
   $15 = $13 - $14;
   HEAPF64[$1>>3] = $15;
   $$0 = $11;
  } else {
   $16 = ($5>>>0)>(2139095039);
   if ($16) {
    $17 = $0 - $0;
    $18 = $17;
    HEAPF64[$1>>3] = $18;
    $$0 = 0;
    break;
   }
   $19 = $5 >>> 23;
   $20 = (($19) + -150)|0;
   $21 = $20 << 23;
   $22 = (($5) - ($21))|0;
   $23 = (HEAP32[tempDoublePtr>>2]=$22,+HEAPF32[tempDoublePtr>>2]);
   $24 = $23;
   HEAPF64[$2>>3] = $24;
   $25 = (___rem_pio2_large($2,$3,$20,1,0)|0);
   $26 = ($4|0)<(0);
   $27 = +HEAPF64[$3>>3];
   if ($26) {
    $28 = - $27;
    HEAPF64[$1>>3] = $28;
    $29 = (0 - ($25))|0;
    $$0 = $29;
    break;
   } else {
    HEAPF64[$1>>3] = $27;
    $$0 = $25;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _atanhl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_atanh($0));
 return (+$1);
}
function _atanh($0) {
 $0 = +$0;
 var $$0 = 0.0, $$sink19 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = (_bitshift64Lshr(($1|0),($2|0),52)|0);
 $4 = (getTempRet0() | 0);
 $5 = $3 & 2047;
 $6 = $2 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $1;HEAP32[tempDoublePtr+4>>2] = $6;$7 = +HEAPF64[tempDoublePtr>>3];
 $8 = ($5>>>0)<(1022);
 if ($8) {
  $9 = ($5>>>0)<(991);
  if ($9) {
   $$0 = $7;
  } else {
   $10 = $7 * 2.0;
   $11 = $10 * $7;
   $12 = 1.0 - $7;
   $13 = $11 / $12;
   $14 = $10 + $13;
   $$sink19 = $14;
   label = 5;
  }
 } else {
  $15 = 1.0 - $7;
  $16 = $7 / $15;
  $17 = $16 * 2.0;
  $$sink19 = $17;
  label = 5;
 }
 if ((label|0) == 5) {
  $18 = (+_log1p($$sink19));
  $19 = $18 * 0.5;
  $$0 = $19;
 }
 $20 = ($2|0)<(0);
 $21 = - $$0;
 $22 = $20 ? $21 : $$0;
 return (+$22);
}
function _logb($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 (___DOUBLE_BITS_141($0)|0);
 $1 = (getTempRet0() | 0);
 $2 = $1 & 2146435072;
 $3 = (0)==(0);
 $4 = ($2|0)==(2146435072);
 $5 = $3 & $4;
 do {
  if ($5) {
   $6 = $0 * $0;
   $$0 = $6;
  } else {
   $7 = $0 == 0.0;
   if ($7) {
    $8 = $0 * $0;
    $9 = -1.0 / $8;
    $$0 = $9;
    break;
   } else {
    $10 = (_ilogb($0)|0);
    $11 = (+($10|0));
    $$0 = $11;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function ___DOUBLE_BITS_141($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _remainderl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_remainder($0,$1));
 return (+$2);
}
function _nanl($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +nan;
}
function _llroundf($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_roundf((+$0)));
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (~~+Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 setTempRet0(($3) | 0);
 return ($2|0);
}
function _scalblnl($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbln($0,$1));
 return (+$2);
}
function ___signbitf($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 31;
 return ($2|0);
}
function _lrintf($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_rintf((+$0)));
 $2 = (~~(($1)));
 return ($2|0);
}
function _fminl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_fmin($0,$1));
 return (+$2);
}
function _copysignf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $4 = $2 & 2147483647;
 $5 = $3 & -2147483648;
 $6 = $5 | $4;
 $7 = (HEAP32[tempDoublePtr>>2]=$6,+HEAPF32[tempDoublePtr>>2]);
 return (+$7);
}
function _nanf($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +nan;
}
function _tanhl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_tanh($0));
 return (+$1);
}
function _rintl($0) {
 $0 = +$0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_rint($0));
 return (+$1);
}
function _exp10f($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (+_modff($0,$1));
 $3 = +HEAPF32[$1>>2];
 $4 = (HEAPF32[tempDoublePtr>>2]=$3,HEAP32[tempDoublePtr>>2]|0);
 $5 = $4 & 2130706432;
 $6 = ($5>>>0)<(1090519040);
 do {
  if ($6) {
   $7 = $2 != 0.0;
   if ($7) {
    $12 = $2 * 3.3219280242919922;
    $13 = (+_exp2f($12));
    $14 = (~~(($3)));
    $15 = (($14) + 7)|0;
    $16 = ((gb + (9952) | 0) + ($15<<2)|0);
    $17 = +HEAPF32[$16>>2];
    $18 = $13 * $17;
    $$0 = $18;
    break;
   } else {
    $8 = (~~(($3)));
    $9 = (($8) + 7)|0;
    $10 = ((gb + (9952) | 0) + ($9<<2)|0);
    $11 = +HEAPF32[$10>>2];
    $$0 = $11;
    break;
   }
  } else {
   $19 = $0;
   $20 = $19 * 3.3219280948873622;
   $21 = (+_exp2($20));
   $22 = $21;
   $$0 = $22;
  }
 } while(0);
 STACKTOP = sp;return (+$$0);
}
function _nextafterf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$sroa$015$0 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $3 = (HEAPF32[tempDoublePtr>>2]=$1,HEAP32[tempDoublePtr>>2]|0);
 $4 = (___FLOAT_BITS_146($0)|0);
 $5 = $4 & 2147483647;
 $6 = ($5>>>0)>(2139095040);
 L1: do {
  if ($6) {
   label = 3;
  } else {
   $7 = (___FLOAT_BITS_146($1)|0);
   $8 = $7 & 2147483647;
   $9 = ($8>>>0)>(2139095040);
   if ($9) {
    label = 3;
   } else {
    $11 = ($2|0)==($3|0);
    if ($11) {
     $$0 = $1;
    } else {
     $12 = $2 & 2147483647;
     $13 = $3 & 2147483647;
     $14 = ($12|0)==(0);
     do {
      if ($14) {
       $15 = ($13|0)==(0);
       if ($15) {
        $$0 = $1;
        break L1;
       }
       $16 = $3 & -2147483648;
       $17 = $16 | 1;
       $$sroa$015$0 = $17;
      } else {
       $18 = ($12>>>0)>($13>>>0);
       $19 = $3 ^ $2;
       $20 = ($19|0)<(0);
       $or$cond = $18 | $20;
       if ($or$cond) {
        $21 = (($2) + -1)|0;
        $$sroa$015$0 = $21;
        break;
       } else {
        $22 = (($2) + 1)|0;
        $$sroa$015$0 = $22;
        break;
       }
      }
     } while(0);
     $23 = (HEAP32[tempDoublePtr>>2]=$$sroa$015$0,+HEAPF32[tempDoublePtr>>2]);
     $$0 = $23;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $10 = $0 + $1;
  $$0 = $10;
 }
 return (+$$0);
}
function ___FLOAT_BITS_146($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _nan($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return +nan;
}
function _lroundl($0) {
 $0 = +$0;
 var $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_roundl($0));
 $2 = (~~(($1)));
 return ($2|0);
}
function _fdiml($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_fdim($0,$1));
 return (+$2);
}
function ___tandf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 * $0;
 $3 = $2 * 0.0094656478494367316;
 $4 = $3 + 0.002974357433599673;
 $5 = $2 * 0.024528318116654728;
 $6 = $5 + 0.053381237844567039;
 $7 = $2 * $2;
 $8 = $2 * $0;
 $9 = $2 * 0.13339200271297674;
 $10 = $9 + 0.3333313950307914;
 $11 = $8 * $10;
 $12 = $11 + $0;
 $13 = $8 * $7;
 $14 = $7 * $4;
 $15 = $6 + $14;
 $16 = $13 * $15;
 $17 = $12 + $16;
 $18 = ($1|0)==(0);
 $19 = -1.0 / $17;
 $20 = $18 ? $17 : $19;
 $21 = $20;
 return (+$21);
}
function _log10f($0) {
 $0 = +$0;
 var $$0 = 0, $$080 = 0, $$081 = 0.0, $$mask = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0;
 var $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = ($1>>>0)<(8388608);
 $3 = ($1|0)<(0);
 $or$cond = $2 | $3;
 do {
  if ($or$cond) {
   $$mask = $1 & 2147483647;
   $4 = ($$mask|0)==(0);
   if ($4) {
    $5 = $0 * $0;
    $6 = -1.0 / $5;
    $$081 = $6;
    break;
   }
   if ($3) {
    $7 = $0 - $0;
    $8 = $7 / 0.0;
    $$081 = $8;
    break;
   } else {
    $9 = $0 * 33554432.0;
    $10 = (HEAPF32[tempDoublePtr>>2]=$9,HEAP32[tempDoublePtr>>2]|0);
    $$0 = -152;$$080 = $10;
    label = 9;
    break;
   }
  } else {
   $11 = ($1>>>0)>(2139095039);
   if ($11) {
    $$081 = $0;
   } else {
    $12 = ($1|0)==(1065353216);
    if ($12) {
     $$081 = 0.0;
    } else {
     $$0 = -127;$$080 = $1;
     label = 9;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $13 = (($$080) + 4913933)|0;
  $14 = $13 >>> 23;
  $15 = (($$0) + ($14))|0;
  $16 = $13 & 8388607;
  $17 = (($16) + 1060439283)|0;
  $18 = (HEAP32[tempDoublePtr>>2]=$17,+HEAPF32[tempDoublePtr>>2]);
  $19 = $18 + -1.0;
  $20 = $19 + 2.0;
  $21 = $19 / $20;
  $22 = $21 * $21;
  $23 = $22 * $22;
  $24 = $23 * 0.24279078841209412;
  $25 = $24 + 0.40000972151756287;
  $26 = $23 * $25;
  $27 = $23 * 0.28498786687850952;
  $28 = $27 + 0.66666662693023682;
  $29 = $22 * $28;
  $30 = $29 + $26;
  $31 = $19 * 0.5;
  $32 = $19 * $31;
  $33 = $19 - $32;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $35 = $34 & -4096;
  $36 = (HEAP32[tempDoublePtr>>2]=$35,+HEAPF32[tempDoublePtr>>2]);
  $37 = $19 - $36;
  $38 = $37 - $32;
  $39 = $32 + $30;
  $40 = $21 * $39;
  $41 = $38 + $40;
  $42 = (+($15|0));
  $43 = $42 * 7.9034151667656261E-7;
  $44 = $41 + $36;
  $45 = $44 * 3.1689971365267411E-5;
  $46 = $43 - $45;
  $47 = $41 * 0.434326171875;
  $48 = $47 + $46;
  $49 = $36 * 0.434326171875;
  $50 = $49 + $48;
  $51 = $42 * 0.30102920532226563;
  $52 = $51 + $50;
  $$081 = $52;
 }
 return (+$$081);
}
function _remquol($0,$1,$2) {
 $0 = +$0;
 $1 = +$1;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_remquo($0,$1,$2));
 return (+$3);
}
function _hypotl($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_hypot($0,$1));
 return (+$2);
}
function _scalblnf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_scalbnf($0,$1));
 return (+$2);
}
function _erff($0) {
 $0 = +$0;
 var $$0 = 0.0, $$041 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0;
 var $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 31;
 $3 = $1 & 2147483647;
 $4 = ($3>>>0)>(2139095039);
 do {
  if ($4) {
   $5 = $2 << 1;
   $6 = (1 - ($5))|0;
   $7 = (+($6|0));
   $8 = 1.0 / $0;
   $9 = $8 + $7;
   $$0 = $9;
  } else {
   $10 = ($3>>>0)<(1062731776);
   if ($10) {
    $11 = ($3>>>0)<(830472192);
    if ($11) {
     $12 = $0 * 8.0;
     $13 = $0 * 1.0270333290100098;
     $14 = $12 + $13;
     $15 = $14 * 0.125;
     $$0 = $15;
     break;
    } else {
     $16 = $0 * $0;
     $17 = $16 * 2.3763017452438362E-5;
     $18 = -0.0057702702470123768 - $17;
     $19 = $16 * $18;
     $20 = $19 + -0.028481749817728996;
     $21 = $16 * $20;
     $22 = $21 + -0.32504209876060486;
     $23 = $16 * $22;
     $24 = $23 + 0.12837916612625122;
     $25 = $16 * 3.9602282413397916E-6;
     $26 = 1.3249473704490811E-4 - $25;
     $27 = $16 * $26;
     $28 = $27 + 0.0050813062116503716;
     $29 = $16 * $28;
     $30 = $29 + 0.06502225250005722;
     $31 = $16 * $30;
     $32 = $31 + 0.39791721105575562;
     $33 = $16 * $32;
     $34 = $33 + 1.0;
     $35 = $24 / $34;
     $36 = $35 * $0;
     $37 = $36 + $0;
     $$0 = $37;
     break;
    }
   } else {
    $38 = ($3>>>0)<(1086324736);
    if ($38) {
     $39 = (+_erfc2_157($3,$0));
     $40 = 1.0 - $39;
     $$041 = $40;
    } else {
     $$041 = 1.0;
    }
    $41 = ($2|0)==(0);
    $42 = - $$041;
    $43 = $41 ? $$041 : $42;
    $$0 = $43;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _erfc2_157($0,$1) {
 $0 = $0|0;
 $1 = +$1;
 var $$0 = 0.0, $$048 = 0.0, $$048$in = 0.0, $$049 = 0.0, $$sink50 = 0.0, $$sink52 = 0.0, $$sink54 = 0.0, $$sink56 = 0.0, $$sink58 = 0.0, $$sink59 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0;
 var $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0;
 var $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0;
 var $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)<(1067450368);
 if ($2) {
  $3 = (+_erfc1_158($1));
  $$0 = $3;
 } else {
  $4 = (+Math_abs((+$1)));
  $5 = $4 * $4;
  $6 = 1.0 / $5;
  $7 = ($0>>>0)<(1077336941);
  if ($7) {
   $8 = $6 * 9.8143291473388671;
   $9 = -81.287437438964844 - $8;
   $10 = $6 * $9;
   $11 = $10 + -184.60508728027344;
   $12 = $6 * $11;
   $13 = $12 + -162.39666748046875;
   $14 = $6 * $13;
   $15 = $14 + -62.375331878662109;
   $16 = $6 * $15;
   $17 = $16 + -10.558626174926758;
   $18 = $6 * $17;
   $19 = $18 + -0.6938585638999939;
   $20 = $6 * $19;
   $21 = $20 + -0.0098649440333247185;
   $22 = $6 * 0.060424413532018661;
   $23 = 6.5702495574951172 - $22;
   $24 = $6 * $23;
   $25 = $24 + 108.63500213623047;
   $$049 = $21;$$sink50 = 19.651271820068359;$$sink52 = 137.65776062011719;$$sink54 = 434.56588745117188;$$sink56 = 645.38726806640625;$$sink58 = 429.00814819335938;$$sink59 = $25;
  } else {
   $26 = $6 * 483.51919555664063;
   $27 = -1025.0950927734375 - $26;
   $28 = $6 * $27;
   $29 = $28 + -637.56646728515625;
   $30 = $6 * $29;
   $31 = $30 + -160.63638305664063;
   $32 = $6 * $31;
   $33 = $32 + -17.757955551147461;
   $34 = $6 * $33;
   $35 = $34 + -0.79928326606750488;
   $36 = $6 * $35;
   $37 = $36 + -0.0098649431020021439;
   $38 = $6 * 22.440952301025391;
   $39 = 474.52853393554688 - $38;
   $$049 = $37;$$sink50 = 30.33806037902832;$$sink52 = 325.79251098632813;$$sink54 = 1536.7296142578125;$$sink56 = 3199.858154296875;$$sink58 = 2553.05029296875;$$sink59 = $39;
  }
  $40 = $6 * $$sink59;
  $41 = $40 + $$sink58;
  $42 = $6 * $41;
  $43 = $42 + $$sink56;
  $44 = $6 * $43;
  $45 = $44 + $$sink54;
  $46 = $6 * $45;
  $47 = $46 + $$sink52;
  $48 = $6 * $47;
  $49 = $48 + $$sink50;
  $$048$in = $6 * $49;
  $$048 = $$048$in + 1.0;
  $50 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
  $51 = $50 & -8192;
  $52 = (HEAP32[tempDoublePtr>>2]=$51,+HEAPF32[tempDoublePtr>>2]);
  $53 = $52 * $52;
  $54 = -0.5625 - $53;
  $55 = (+Math_exp((+$54)));
  $56 = $52 - $4;
  $57 = $4 + $52;
  $58 = $56 * $57;
  $59 = $$049 / $$048;
  $60 = $58 + $59;
  $61 = (+Math_exp((+$60)));
  $62 = $55 * $61;
  $63 = $62 / $4;
  $$0 = $63;
 }
 return (+$$0);
}
function _erfc1_158($0) {
 $0 = +$0;
 var $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+Math_abs((+$0)));
 $2 = $1 + -1.0;
 $3 = $2 * 0.0021663755178451538;
 $4 = 0.035478305071592331 - $3;
 $5 = $2 * $4;
 $6 = $5 + -0.11089469492435455;
 $7 = $2 * $6;
 $8 = $7 + 0.31834661960601807;
 $9 = $2 * $8;
 $10 = $9 + -0.3722078800201416;
 $11 = $2 * $10;
 $12 = $11 + 0.41485610604286194;
 $13 = $2 * $12;
 $14 = $13 + -0.0023621185682713985;
 $15 = $2 * 0.011984500102698803;
 $16 = $15 + 0.01363708358258009;
 $17 = $2 * $16;
 $18 = $17 + 0.12617121636867523;
 $19 = $2 * $18;
 $20 = $19 + 0.071828655898571014;
 $21 = $2 * $20;
 $22 = $21 + 0.54039794206619263;
 $23 = $2 * $22;
 $24 = $23 + 0.10642088204622269;
 $25 = $2 * $24;
 $26 = $25 + 1.0;
 $27 = $14 / $26;
 $28 = 0.15493708848953247 - $27;
 return (+$28);
}
function _erfcf($0) {
 $0 = +$0;
 var $$0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 $2 = $1 >>> 31;
 $3 = $1 & 2147483647;
 $4 = ($3>>>0)>(2139095039);
 do {
  if ($4) {
   $5 = $2 << 1;
   $6 = (+($5|0));
   $7 = 1.0 / $0;
   $8 = $7 + $6;
   $$0 = $8;
  } else {
   $9 = ($3>>>0)<(1062731776);
   if (!($9)) {
    $41 = ($3>>>0)<(1105199104);
    $42 = ($2|0)!=(0);
    if ($41) {
     $43 = (+_erfc2_157($3,$0));
     $44 = 2.0 - $43;
     $45 = $42 ? $44 : $43;
     $$0 = $45;
     break;
    } else {
     $46 = $42 ? 2.0 : 0.0;
     $$0 = $46;
     break;
    }
   }
   $10 = ($3>>>0)<(595591168);
   if ($10) {
    $11 = 1.0 - $0;
    $$0 = $11;
    break;
   }
   $12 = $0 * $0;
   $13 = $12 * 2.3763017452438362E-5;
   $14 = -0.0057702702470123768 - $13;
   $15 = $12 * $14;
   $16 = $15 + -0.028481749817728996;
   $17 = $12 * $16;
   $18 = $17 + -0.32504209876060486;
   $19 = $12 * $18;
   $20 = $19 + 0.12837916612625122;
   $21 = $12 * 3.9602282413397916E-6;
   $22 = 1.3249473704490811E-4 - $21;
   $23 = $12 * $22;
   $24 = $23 + 0.0050813062116503716;
   $25 = $12 * $24;
   $26 = $25 + 0.06502225250005722;
   $27 = $12 * $26;
   $28 = $27 + 0.39791721105575562;
   $29 = $12 * $28;
   $30 = $29 + 1.0;
   $31 = $20 / $30;
   $32 = ($2|0)!=(0);
   $33 = ($3>>>0)<(1048576000);
   $or$cond = $32 | $33;
   if ($or$cond) {
    $34 = $31 * $0;
    $35 = $34 + $0;
    $36 = 1.0 - $35;
    $$0 = $36;
    break;
   } else {
    $37 = $0 + -0.5;
    $38 = $31 * $0;
    $39 = $37 + $38;
    $40 = 0.5 - $39;
    $$0 = $40;
    break;
   }
  }
 } while(0);
 return (+$$0);
}
function _fminf($0,$1) {
 $0 = +$0;
 $1 = +$1;
 var $$0 = 0.0, $$unshifted = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___FLOAT_BITS_159($0)|0);
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2139095040);
 do {
  if ($4) {
   $$0 = $1;
  } else {
   $5 = (___FLOAT_BITS_159($1)|0);
   $6 = $5 & 2147483647;
   $7 = ($6>>>0)>(2139095040);
   if ($7) {
    $$0 = $0;
   } else {
    $$unshifted = $5 ^ $2;
    $8 = ($$unshifted|0)<(0);
    if ($8) {
     $9 = ($2|0)<(0);
     $10 = $9 ? $0 : $1;
     $$0 = $10;
     break;
    } else {
     $11 = $0 < $1;
     $12 = $11 ? $0 : $1;
     $$0 = $12;
     break;
    }
   }
  }
 } while(0);
 return (+$$0);
}
function ___FLOAT_BITS_159($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _nrand48($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___rand48_step($0,((((gb + (166356) | 0)) + 6|0)))|0);
 $2 = (getTempRet0() | 0);
 $3 = (_bitshift64Lshr(($1|0),($2|0),17)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function ___rand48_step($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP16[$0>>1]|0;
 $3 = $2&65535;
 $4 = ((($0)) + 2|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = $6 << 16;
 $8 = $7 | $3;
 $9 = ((($0)) + 4|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = HEAP16[$1>>1]|0;
 $13 = $12&65535;
 $14 = ((($1)) + 2|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = $16 << 16;
 $18 = $17 | $13;
 $19 = ((($1)) + 4|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (___muldi3(($18|0),($21|0),($8|0),($11|0))|0);
 $23 = (getTempRet0() | 0);
 $24 = ((($1)) + 6|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = $25&65535;
 $27 = (_i64Add(($22|0),($23|0),($26|0),0)|0);
 $28 = (getTempRet0() | 0);
 $29 = $27&65535;
 HEAP16[$0>>1] = $29;
 $30 = (_bitshift64Lshr(($27|0),($28|0),16)|0);
 $31 = (getTempRet0() | 0);
 $32 = $30&65535;
 HEAP16[$4>>1] = $32;
 $33 = $28&65535;
 HEAP16[$9>>1] = $33;
 $34 = $28 & 65535;
 setTempRet0(($34) | 0);
 return ($27|0);
}
function _lrand48() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_nrand48((gb + (166356) | 0))|0);
 return ($0|0);
}
function _erand48($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___rand48_step($0,((((gb + (166356) | 0)) + 6|0)))|0);
 $2 = (getTempRet0() | 0);
 $3 = (_bitshift64Shl(($1|0),($2|0),4)|0);
 $4 = (getTempRet0() | 0);
 $5 = $4 | 1072693248;
 HEAP32[tempDoublePtr>>2] = $3;HEAP32[tempDoublePtr+4>>2] = $5;$6 = +HEAPF64[tempDoublePtr>>3];
 $7 = $6 + -1.0;
 return (+$7);
}
function _drand48() {
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_erand48((gb + (166356) | 0)));
 return (+$0);
}
function _srandom($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___lock(((gb + (171276) | 0)|0));
 ___srandom($0);
 ___unlock(((gb + (171276) | 0)|0));
 return;
}
function ___srandom($0) {
 $0 = $0|0;
 var $$01011 = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161948) | 0)>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[(gb + (161952) | 0)>>2]|0;
  HEAP32[$3>>2] = $0;
 } else {
  $4 = ($1|0)==(31);
  $5 = ($1|0)==(7);
  $6 = $4 | $5;
  $7 = $6 ? 3 : 1;
  HEAP32[(gb + (161956) | 0)>>2] = $7;
  HEAP32[(gb + (171284) | 0)>>2] = 0;
  $8 = ($1|0)>(0);
  if ($8) {
   $9 = HEAP32[(gb + (161952) | 0)>>2]|0;
   $$01011 = 0;$10 = $0;$11 = 0;
   while(1) {
    $12 = (_lcg64($10,$11)|0);
    $13 = (getTempRet0() | 0);
    $14 = (($9) + ($$01011<<2)|0);
    HEAP32[$14>>2] = $13;
    $15 = (($$01011) + 1)|0;
    $exitcond = ($15|0)==($1|0);
    if ($exitcond) {
     $17 = $9;
     break;
    } else {
     $$01011 = $15;$10 = $12;$11 = $13;
    }
   }
  } else {
   $$pre = HEAP32[(gb + (161952) | 0)>>2]|0;
   $17 = $$pre;
  }
  $16 = HEAP32[$17>>2]|0;
  $18 = $16 | 1;
  HEAP32[$17>>2] = $18;
 }
 return;
}
function _lcg64($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___muldi3(($0|0),($1|0),1284865837,1481765933)|0);
 $3 = (getTempRet0() | 0);
 $4 = (_i64Add(($2|0),($3|0),1,0)|0);
 $5 = (getTempRet0() | 0);
 setTempRet0(($5) | 0);
 return ($4|0);
}
function _initstate($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$sink = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2>>>0)<(8);
 if ($3) {
  $$0 = 0;
 } else {
  ___lock(((gb + (171276) | 0)|0));
  $4 = (_savestate()|0);
  $5 = ($2>>>0)<(32);
  if ($5) {
   $$sink = 0;
  } else {
   $6 = ($2>>>0)<(64);
   if ($6) {
    $$sink = 7;
   } else {
    $7 = ($2>>>0)<(128);
    if ($7) {
     $$sink = 15;
    } else {
     $8 = ($2>>>0)<(256);
     $$ = $8 ? 31 : 63;
     $$sink = $$;
    }
   }
  }
  HEAP32[(gb + (161948) | 0)>>2] = $$sink;
  $9 = ((($1)) + 4|0);
  HEAP32[(gb + (161952) | 0)>>2] = $9;
  ___srandom($0);
  (_savestate()|0);
  ___unlock(((gb + (171276) | 0)|0));
  $$0 = $4;
 }
 return ($$0|0);
}
function _savestate() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(gb + (161948) | 0)>>2]|0;
 $1 = $0 << 16;
 $2 = HEAP32[(gb + (161956) | 0)>>2]|0;
 $3 = $2 << 8;
 $4 = $3 | $1;
 $5 = HEAP32[(gb + (171284) | 0)>>2]|0;
 $6 = $4 | $5;
 $7 = HEAP32[(gb + (161952) | 0)>>2]|0;
 $8 = ((($7)) + -4|0);
 HEAP32[$8>>2] = $6;
 return ($8|0);
}
function _setstate($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ___lock(((gb + (171276) | 0)|0));
 $1 = (_savestate()|0);
 _loadstate($0);
 ___unlock(((gb + (171276) | 0)|0));
 return ($1|0);
}
function _loadstate($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 HEAP32[(gb + (161952) | 0)>>2] = $1;
 $2 = HEAP32[$0>>2]|0;
 $3 = $2 >>> 16;
 HEAP32[(gb + (161948) | 0)>>2] = $3;
 $4 = $2 >>> 8;
 $5 = $4 & 255;
 HEAP32[(gb + (161956) | 0)>>2] = $5;
 $6 = $2 & 255;
 HEAP32[(gb + (171284) | 0)>>2] = $6;
 return;
}
function _random() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$store$select = 0, $spec$store$select1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___lock(((gb + (171276) | 0)|0));
 $0 = HEAP32[(gb + (161948) | 0)>>2]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[(gb + (161952) | 0)>>2]|0;
 if ($1) {
  $3 = HEAP32[$2>>2]|0;
  $4 = (_lcg31($3)|0);
  HEAP32[$2>>2] = $4;
  $$0 = $4;
 } else {
  $5 = HEAP32[(gb + (171284) | 0)>>2]|0;
  $6 = (($2) + ($5<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[(gb + (161956) | 0)>>2]|0;
  $9 = (($2) + ($8<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($7))|0;
  HEAP32[$9>>2] = $11;
  $12 = $11 >>> 1;
  $13 = (($8) + 1)|0;
  $14 = ($13|0)==($0|0);
  $spec$store$select = $14 ? 0 : $13;
  HEAP32[(gb + (161956) | 0)>>2] = $spec$store$select;
  $15 = (($5) + 1)|0;
  $16 = ($15|0)==($0|0);
  $spec$store$select1 = $16 ? 0 : $15;
  HEAP32[(gb + (171284) | 0)>>2] = $spec$store$select1;
  $$0 = $12;
 }
 ___unlock(((gb + (171276) | 0)|0));
 return ($$0|0);
}
function _lcg31($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = Math_imul($0, 1103515245)|0;
 $2 = (($1) + 12345)|0;
 $3 = $2 & 2147483647;
 return ($3|0);
}
function _seed48($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_memcpy(((gb + (172112) | 0)|0),((gb + (166356) | 0)|0),6)|0);
 (_memcpy(((gb + (166356) | 0)|0),($0|0),6)|0);
 return ((gb + (172112) | 0)|0);
}
function _rand_r($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_imul($1, 1103515245)|0;
 $3 = (($2) + 12345)|0;
 HEAP32[$0>>2] = $3;
 $4 = (_temper($3)|0);
 $5 = $4 >>> 1;
 return ($5|0);
}
function _temper($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 >>> 11;
 $2 = $1 ^ $0;
 $3 = $2 << 7;
 $4 = $3 & -1658038656;
 $5 = $4 ^ $2;
 $6 = $5 << 15;
 $7 = $6 & -272236544;
 $8 = $7 ^ $5;
 $9 = $8 >>> 18;
 $10 = $9 ^ $8;
 return ($10|0);
}
function _srand48($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP16[$1>>1] = 13070;
 $2 = ((($1)) + 2|0);
 $3 = $0&65535;
 HEAP16[$2>>1] = $3;
 $4 = ((($1)) + 4|0);
 $5 = $0 >>> 16;
 $6 = $5&65535;
 HEAP16[$4>>1] = $6;
 (_seed48($1)|0);
 STACKTOP = sp;return;
}
function _srand($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -1)|0;
 $2 = (gb + (170624) | 0);
 $3 = $2;
 HEAP32[$3>>2] = $1;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 return;
}
function _rand() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (gb + (170624) | 0);
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___muldi3(($2|0),($5|0),1284865837,1481765933)|0);
 $7 = (getTempRet0() | 0);
 $8 = (_i64Add(($6|0),($7|0),1,0)|0);
 $9 = (getTempRet0() | 0);
 $10 = (gb + (170624) | 0);
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (_bitshift64Lshr(($8|0),($9|0),33)|0);
 $15 = (getTempRet0() | 0);
 return ($14|0);
}
function _jrand48($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___rand48_step($0,((((gb + (166356) | 0)) + 6|0)))|0);
 $2 = (getTempRet0() | 0);
 $3 = (_bitshift64Lshr(($1|0),($2|0),16)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _mrand48() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_jrand48((gb + (166356) | 0))|0);
 return ($0|0);
}
function _lcong48($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_memcpy(((gb + (166356) | 0)|0),($0|0),14)|0);
 return;
}
function _posix_fallocate($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = $1 >> 31;
 $4 = $2 >> 31;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $2;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $4;
 $5 = (___syscall324(324,($vararg_buffer|0))|0);
 $6 = (0 - ($5))|0;
 STACKTOP = sp;return ($6|0);
}
function _openat($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded2 = 0, $expanded4 = 0;
 var $expanded5 = 0, $expanded6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp + 16|0;
 $3 = sp;
 $4 = $2 & 4194368;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
 } else {
  HEAP32[$3>>2] = $varargs;
  $arglist_current = HEAP32[$3>>2]|0;
  $6 = $arglist_current;
  $7 = ((0) + 4|0);
  $expanded2 = $7;
  $expanded = (($expanded2) - 1)|0;
  $8 = (($6) + ($expanded))|0;
  $9 = ((0) + 4|0);
  $expanded6 = $9;
  $expanded5 = (($expanded6) - 1)|0;
  $expanded4 = $expanded5 ^ -1;
  $10 = $8 & $expanded4;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $arglist_next = ((($11)) + 4|0);
  HEAP32[$3>>2] = $arglist_next;
  $$0 = $12;
 }
 $13 = $1;
 $14 = $2 | 32768;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $13;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $14;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $$0;
 $15 = (___syscall295(295,($vararg_buffer|0))|0);
 $16 = (___syscall_ret($15)|0);
 STACKTOP = sp;return ($16|0);
}
function _creat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_open($0,577,$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function _posix_fadvise($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $4 = $1 >> 31;
 $5 = $2 >> 31;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $1;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $4;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $2;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $5;
 $vararg_ptr6 = ((($vararg_buffer)) + 24|0);
 HEAP32[$vararg_ptr6>>2] = $3;
 $6 = (___syscall272(272,($vararg_buffer|0))|0);
 $7 = (0 - ($6))|0;
 STACKTOP = sp;return ($7|0);
}
function _fcntl($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $$0 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded2 = 0, $expanded4 = 0, $expanded5 = 0, $expanded6 = 0, $spec$select = 0, $vararg_buffer = 0, $vararg_buffer13 = 0, $vararg_buffer18 = 0, $vararg_buffer23 = 0, $vararg_buffer28 = 0, $vararg_buffer3 = 0, $vararg_buffer31 = 0, $vararg_buffer36 = 0, $vararg_buffer41 = 0, $vararg_buffer46 = 0, $vararg_buffer8 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr11 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr17 = 0, $vararg_ptr2 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr34 = 0, $vararg_ptr35 = 0, $vararg_ptr39 = 0, $vararg_ptr40 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, $vararg_ptr49 = 0, $vararg_ptr50 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $vararg_buffer46 = sp + 168|0;
 $vararg_buffer41 = sp + 152|0;
 $vararg_buffer36 = sp + 136|0;
 $vararg_buffer31 = sp + 120|0;
 $vararg_buffer28 = sp + 112|0;
 $vararg_buffer23 = sp + 96|0;
 $vararg_buffer18 = sp + 80|0;
 $vararg_buffer13 = sp + 64|0;
 $vararg_buffer8 = sp + 48|0;
 $vararg_buffer3 = sp + 32|0;
 $vararg_buffer = sp + 16|0;
 $2 = sp;
 $3 = sp + 184|0;
 HEAP32[$2>>2] = $varargs;
 $arglist_current = HEAP32[$2>>2]|0;
 $4 = $arglist_current;
 $5 = ((0) + 4|0);
 $expanded2 = $5;
 $expanded = (($expanded2) - 1)|0;
 $6 = (($4) + ($expanded))|0;
 $7 = ((0) + 4|0);
 $expanded6 = $7;
 $expanded5 = (($expanded6) - 1)|0;
 $expanded4 = $expanded5 ^ -1;
 $8 = $6 & $expanded4;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $arglist_next = ((($9)) + 4|0);
 HEAP32[$2>>2] = $arglist_next;
 $11 = ($1|0)==(4);
 $12 = $10 | 32768;
 $spec$select = $11 ? $12 : $10;
 L1: do {
  switch ($1|0) {
  case 14:  {
   HEAP32[$vararg_buffer>>2] = $0;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 14;
   $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $spec$select;
   $13 = (___syscall221(221,($vararg_buffer|0))|0);
   $14 = (___syscall_ret($13)|0);
   $$2 = $14;
   break;
  }
  case 9:  {
   $15 = $3;
   HEAP32[$vararg_buffer3>>2] = $0;
   $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
   HEAP32[$vararg_ptr6>>2] = 16;
   $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
   HEAP32[$vararg_ptr7>>2] = $15;
   $16 = (___syscall221(221,($vararg_buffer3|0))|0);
   switch ($16|0) {
   case -22:  {
    HEAP32[$vararg_buffer8>>2] = $0;
    $vararg_ptr11 = ((($vararg_buffer8)) + 4|0);
    HEAP32[$vararg_ptr11>>2] = 9;
    $vararg_ptr12 = ((($vararg_buffer8)) + 8|0);
    HEAP32[$vararg_ptr12>>2] = $spec$select;
    $17 = (___syscall221(221,($vararg_buffer8|0))|0);
    $$0 = $17;
    break;
   }
   case 0:  {
    $19 = HEAP32[$3>>2]|0;
    $20 = ($19|0)==(2);
    $21 = ((($3)) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (0 - ($22))|0;
    $24 = $20 ? $23 : $22;
    $$0 = $24;
    break;
   }
   default: {
    $18 = (___syscall_ret($16)|0);
    $$0 = $18;
   }
   }
   $$2 = $$0;
   break;
  }
  case 1030:  {
   HEAP32[$vararg_buffer13>>2] = $0;
   $vararg_ptr16 = ((($vararg_buffer13)) + 4|0);
   HEAP32[$vararg_ptr16>>2] = 1030;
   $vararg_ptr17 = ((($vararg_buffer13)) + 8|0);
   HEAP32[$vararg_ptr17>>2] = $spec$select;
   $25 = (___syscall221(221,($vararg_buffer13|0))|0);
   $26 = ($25|0)==(-22);
   if (!($26)) {
    $27 = ($25|0)>(-1);
    if ($27) {
     HEAP32[$vararg_buffer18>>2] = $25;
     $vararg_ptr21 = ((($vararg_buffer18)) + 4|0);
     HEAP32[$vararg_ptr21>>2] = 2;
     $vararg_ptr22 = ((($vararg_buffer18)) + 8|0);
     HEAP32[$vararg_ptr22>>2] = 1;
     (___syscall221(221,($vararg_buffer18|0))|0);
    }
    $28 = (___syscall_ret($25)|0);
    $$2 = $28;
    break L1;
   }
   HEAP32[$vararg_buffer23>>2] = $0;
   $vararg_ptr26 = ((($vararg_buffer23)) + 4|0);
   HEAP32[$vararg_ptr26>>2] = 1030;
   $vararg_ptr27 = ((($vararg_buffer23)) + 8|0);
   HEAP32[$vararg_ptr27>>2] = 0;
   $29 = (___syscall221(221,($vararg_buffer23|0))|0);
   $30 = ($29|0)==(-22);
   if ($30) {
    HEAP32[$vararg_buffer31>>2] = $0;
    $vararg_ptr34 = ((($vararg_buffer31)) + 4|0);
    HEAP32[$vararg_ptr34>>2] = 0;
    $vararg_ptr35 = ((($vararg_buffer31)) + 8|0);
    HEAP32[$vararg_ptr35>>2] = $spec$select;
    $33 = (___syscall221(221,($vararg_buffer31|0))|0);
    $34 = ($33|0)>(-1);
    if ($34) {
     HEAP32[$vararg_buffer36>>2] = $33;
     $vararg_ptr39 = ((($vararg_buffer36)) + 4|0);
     HEAP32[$vararg_ptr39>>2] = 2;
     $vararg_ptr40 = ((($vararg_buffer36)) + 8|0);
     HEAP32[$vararg_ptr40>>2] = 1;
     (___syscall221(221,($vararg_buffer36|0))|0);
    }
    $35 = (___syscall_ret($33)|0);
    $$2 = $35;
    break L1;
   } else {
    $31 = ($29|0)>(-1);
    if ($31) {
     HEAP32[$vararg_buffer28>>2] = $29;
     (___syscall6(6,($vararg_buffer28|0))|0);
    }
    $32 = (___syscall_ret(-22)|0);
    $$2 = $32;
    break L1;
   }
   break;
  }
  case 15: case 16: case 12: case 13:  {
   HEAP32[$vararg_buffer41>>2] = $0;
   $vararg_ptr44 = ((($vararg_buffer41)) + 4|0);
   HEAP32[$vararg_ptr44>>2] = $1;
   $vararg_ptr45 = ((($vararg_buffer41)) + 8|0);
   HEAP32[$vararg_ptr45>>2] = $spec$select;
   $36 = (___syscall221(221,($vararg_buffer41|0))|0);
   $37 = (___syscall_ret($36)|0);
   $$2 = $37;
   break;
  }
  default: {
   HEAP32[$vararg_buffer46>>2] = $0;
   $vararg_ptr49 = ((($vararg_buffer46)) + 4|0);
   HEAP32[$vararg_ptr49>>2] = $1;
   $vararg_ptr50 = ((($vararg_buffer46)) + 8|0);
   HEAP32[$vararg_ptr50>>2] = $spec$select;
   $38 = (___syscall221(221,($vararg_buffer46|0))|0);
   $39 = (___syscall_ret($38)|0);
   $$2 = $39;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$2|0);
}
function _towctrans_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_towctrans($0,$1)|0);
 return ($3|0);
}
function _towctrans($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $magicptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $magicptr = $1;
 switch ($magicptr|0) {
 case 1:  {
  $2 = (_towupper($0)|0);
  $$0 = $2;
  break;
 }
 case 2:  {
  $3 = (_towlower($0)|0);
  $$0 = $3;
  break;
 }
 default: {
  $$0 = $0;
 }
 }
 return ($$0|0);
}
function _towupper($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___towcase($0,0)|0);
 return ($1|0);
}
function _towlower($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___towcase($0,1)|0);
 return ($1|0);
}
function ___towcase($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06283 = 0, $$16382 = 0, $$2 = 0, $$neg75 = 0, $$neg77 = 0, $$neg78 = 0, $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond65 = 0, $or$cond67 = 0, $or$cond69 = 0, $or$cond71 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 << 1;
 $3 = (($2) + -1)|0;
 $4 = (($1) + -1)|0;
 $5 = (_iswalpha($0)|0);
 $6 = ($5|0)==(0);
 $7 = (($0) + -1536)|0;
 $8 = ($7>>>0)<(2560);
 $or$cond65 = $8 | $6;
 $9 = (($0) + -11776)|0;
 $10 = ($9>>>0)<(30784);
 $or$cond67 = $10 | $or$cond65;
 $11 = (($0) + -43008)|0;
 $12 = ($11>>>0)<(22272);
 $or$cond69 = $12 | $or$cond67;
 L1: do {
  if ($or$cond69) {
   $$2 = $0;
  } else {
   $13 = ($1|0)!=(0);
   $14 = (($0) + -4256)|0;
   $15 = ($14>>>0)<(46);
   $or$cond71 = $13 & $15;
   if ($or$cond71) {
    $16 = ($0|0)>(4293);
    if ($16) {
     switch ($0|0) {
     case 4295: case 4301:  {
      break;
     }
     default: {
      $$2 = $0;
      break L1;
     }
     }
    }
    $17 = (($0) + 7264)|0;
    $$2 = $17;
    break;
   }
   $$not = $13 ^ 1;
   $18 = (($0) + -11520)|0;
   $19 = ($18>>>0)<(38);
   $or$cond = $19 & $$not;
   if ($or$cond) {
    $20 = (($0) + -7264)|0;
    $$2 = $20;
    break;
   }
   $$06283 = 0;
   while(1) {
    $23 = ((((gb + (10144) | 0) + ($$06283<<2)|0)) + 3|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ((gb + (10144) | 0) + ($$06283<<2)|0);
    $26 = HEAP16[$25>>1]|0;
    $27 = $26&65535;
    $28 = ((((gb + (10144) | 0) + ($$06283<<2)|0)) + 2|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = $29 << 24 >> 24;
    $31 = $4 & $30;
    $$neg75 = (($0) - ($27))|0;
    $32 = (($$neg75) - ($31))|0;
    $33 = $24&255;
    $34 = ($32>>>0)<($33>>>0);
    $22 = (($$06283) + 1)|0;
    if ($34) {
     label = 11;
     break;
    }
    $21 = ($22|0)==(61);
    if ($21) {
     break;
    } else {
     $$06283 = $22;
    }
   }
   if ((label|0) == 11) {
    $35 = ($29<<24>>24)==(1);
    if ($35) {
     $36 = (($1) + ($0))|0;
     $37 = $$neg75 & 1;
     $38 = (($36) - ($37))|0;
     $$2 = $38;
     break;
    } else {
     $39 = Math_imul($3, $30)|0;
     $40 = (($39) + ($0))|0;
     $$2 = $40;
     break;
    }
   }
   $41 = (1 - ($1))|0;
   $42 = ((gb + (10400) | 0) + ($41<<1)|0);
   $43 = HEAP16[$42>>1]|0;
   $44 = ($43<<16>>16)==(0);
   L21: do {
    if (!($44)) {
     $$16382 = 0;$46 = $43;
     while(1) {
      $45 = $46&65535;
      $47 = ($45|0)==($0|0);
      if ($47) {
       break;
      }
      $51 = (($$16382) + 1)|0;
      $52 = (((gb + (10400) | 0) + ($51<<2)|0) + ($41<<1)|0);
      $53 = HEAP16[$52>>1]|0;
      $54 = ($53<<16>>16)==(0);
      if ($54) {
       break L21;
      } else {
       $$16382 = $51;$46 = $53;
      }
     }
     $48 = (((gb + (10400) | 0) + ($$16382<<2)|0) + ($1<<1)|0);
     $49 = HEAP16[$48>>1]|0;
     $50 = $49&65535;
     $$2 = $50;
     break L1;
    }
   } while(0);
   $$neg77 = ($1*40)|0;
   $$neg78 = (($0) + -66600)|0;
   $55 = (($$neg78) + ($$neg77))|0;
   $56 = ($55>>>0)<(40);
   $57 = (($0) + -40)|0;
   $58 = ($1*80)|0;
   $59 = (($57) + ($58))|0;
   $spec$select = $56 ? $59 : $0;
   return ($spec$select|0);
  }
 } while(0);
 return ($$2|0);
}
function _iswalpha($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(131072);
 if ($1) {
  $2 = $0 >>> 8;
  $3 = ((gb + (10896) | 0) + ($2)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = $5 << 5;
  $7 = $0 >>> 3;
  $8 = $7 & 31;
  $9 = $6 | $8;
  $10 = ((gb + (10896) | 0) + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = $0 & 7;
  $14 = $12 >>> $13;
  $15 = $14 & 1;
  $$0 = $15;
 } else {
  $16 = ($0>>>0)<(196606);
  $$ = $16&1;
  $$0 = $$;
 }
 return ($$0|0);
}
function _islower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_islower($0)|0);
 return ($2|0);
}
function _islower($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -97)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 return ($3|0);
}
function _iswspace_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswspace($0)|0);
 return ($2|0);
}
function _iswspace($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (_wcschr((gb + (13872) | 0),$0)|0);
  $3 = ($2|0)!=(0|0);
  $phitmp = $3&1;
  $4 = $phitmp;
 }
 return ($4|0);
}
function _wcschr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$09 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (_wcslen($0)|0);
  $4 = (($0) + ($3<<2)|0);
  $$0 = $4;
 } else {
  $$09 = $0;
  while(1) {
   $5 = HEAP32[$$09>>2]|0;
   $6 = ($5|0)==(0);
   $7 = ($5|0)==($1|0);
   $or$cond = $6 | $7;
   $8 = ((($$09)) + 4|0);
   if ($or$cond) {
    break;
   } else {
    $$09 = $8;
   }
  }
  $9 = $6 ? 0 : $$09;
  $$0 = $9;
 }
 return ($$0|0);
}
function _wcslen($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $0;
 while(1) {
  $1 = HEAP32[$$0>>2]|0;
  $2 = ($1|0)==(0);
  $3 = ((($$0)) + 4|0);
  if ($2) {
   break;
  } else {
   $$0 = $3;
  }
 }
 $4 = $$0;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 return ($7|0);
}
function _isblank_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isblank($0)|0);
 return ($2|0);
}
function _isblank($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(32);
 $2 = ($0|0)==(9);
 $3 = $1 | $2;
 $4 = $3&1;
 return ($4|0);
}
function ___strcoll_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strcmp($0,$1)|0);
 return ($3|0);
}
function _strcoll($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (___pthread_self_168()|0);
 $2 = (___strcoll_l($0,$1,0)|0);
 return ($2|0);
}
function ___pthread_self_168() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _iswdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswdigit($0)|0);
 return ($2|0);
}
function _iswdigit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -48)|0;
 $2 = ($1>>>0)<(10);
 $3 = $2&1;
 return ($3|0);
}
function _catgets($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ($3|0);
}
function _setlocale($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04956 = 0, $$05055 = 0, $$05253 = 0, $$151 = 0, $$154 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond57 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($0>>>0)>(6);
 do {
  if ($3) {
   $$0 = 0;
  } else {
   ___lock(((gb + (171288) | 0)|0));
   $4 = ($0|0)==(6);
   if (!($4)) {
    $27 = (_setlocale_one_unlocked($0,$1)|0);
    ___unlock(((gb + (171288) | 0)|0));
    $$0 = $27;
    break;
   }
   $5 = ($1|0)==(0|0);
   if (!($5)) {
    ;HEAP32[$2>>2]=HEAP32[(gb + (13968) | 0)>>2]|0;HEAP32[$2+4>>2]=HEAP32[(gb + (13968) | 0)+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[(gb + (13968) | 0)+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[(gb + (13968) | 0)+12>>2]|0;
    $$04956 = 0;$$05055 = $1;
    while(1) {
     $6 = (___strchrnul($$05055,59)|0);
     $7 = $6;
     $8 = $$05055;
     $9 = (($7) - ($8))|0;
     $10 = ($9|0)<(16);
     if ($10) {
      (_memcpy(($2|0),($$05055|0),($9|0))|0);
      $11 = (($2) + ($9)|0);
      HEAP8[$11>>0] = 0;
      $12 = HEAP8[$6>>0]|0;
      $13 = ($12<<24>>24)==(0);
      $14 = ((($6)) + 1|0);
      $spec$select = $13 ? $$05055 : $14;
      $$151 = $spec$select;
     } else {
      $$151 = $$05055;
     }
     (_setlocale_one_unlocked($$04956,$2)|0);
     $15 = (($$04956) + 1)|0;
     $exitcond57 = ($15|0)==(6);
     if ($exitcond57) {
      break;
     } else {
      $$04956 = $15;$$05055 = $$151;
     }
    }
   }
   $$05253 = (gb + (169952) | 0);$$154 = 0;
   while(1) {
    $16 = ((((gb + (171204) | 0)) + 40|0) + ($$154<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    $19 = ((($17)) + 8|0);
    $20 = $18 ? (gb + (166525) | 0) : $19;
    $21 = (_strlen($20)|0);
    (_memcpy(($$05253|0),($20|0),($21|0))|0);
    $22 = (($$05253) + ($21)|0);
    HEAP8[$22>>0] = 59;
    $23 = (($21) + 1)|0;
    $24 = (($$05253) + ($23)|0);
    $25 = (($$154) + 1)|0;
    $exitcond = ($25|0)==(6);
    if ($exitcond) {
     break;
    } else {
     $$05253 = $24;$$154 = $25;
    }
   }
   $26 = (($$05253) + ($21)|0);
   HEAP8[$26>>0] = 0;
   ___unlock(((gb + (171288) | 0)|0));
   $$0 = (gb + (169952) | 0);
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___strchrnul($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$029$lcssa = 0, $$02936 = 0, $$030$lcssa = 0, $$03039 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 & 255;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $4 = (_strlen($0)|0);
   $5 = (($0) + ($4)|0);
   $$0 = $5;
  } else {
   $6 = $0;
   $7 = $6 & 3;
   $8 = ($7|0)==(0);
   if ($8) {
    $$030$lcssa = $0;
   } else {
    $9 = $1&255;
    $$03039 = $0;
    while(1) {
     $10 = HEAP8[$$03039>>0]|0;
     $11 = ($10<<24>>24)==(0);
     $12 = ($10<<24>>24)==($9<<24>>24);
     $or$cond = $11 | $12;
     if ($or$cond) {
      $$0 = $$03039;
      break L1;
     }
     $13 = ((($$03039)) + 1|0);
     $14 = $13;
     $15 = $14 & 3;
     $16 = ($15|0)==(0);
     if ($16) {
      $$030$lcssa = $13;
      break;
     } else {
      $$03039 = $13;
     }
    }
   }
   $17 = Math_imul($2, 16843009)|0;
   $18 = HEAP32[$$030$lcssa>>2]|0;
   $19 = (($18) + -16843009)|0;
   $20 = $18 & -2139062144;
   $21 = $20 ^ -2139062144;
   $22 = $21 & $19;
   $23 = ($22|0)==(0);
   L10: do {
    if ($23) {
     $$02936 = $$030$lcssa;$25 = $18;
     while(1) {
      $24 = $25 ^ $17;
      $26 = (($24) + -16843009)|0;
      $27 = $24 & -2139062144;
      $28 = $27 ^ -2139062144;
      $29 = $28 & $26;
      $30 = ($29|0)==(0);
      if (!($30)) {
       $$029$lcssa = $$02936;
       break L10;
      }
      $31 = ((($$02936)) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + -16843009)|0;
      $34 = $32 & -2139062144;
      $35 = $34 ^ -2139062144;
      $36 = $35 & $33;
      $37 = ($36|0)==(0);
      if ($37) {
       $$02936 = $31;$25 = $32;
      } else {
       $$029$lcssa = $31;
       break;
      }
     }
    } else {
     $$029$lcssa = $$030$lcssa;
    }
   } while(0);
   $38 = $1&255;
   $$1 = $$029$lcssa;
   while(1) {
    $39 = HEAP8[$$1>>0]|0;
    $40 = ($39<<24>>24)==(0);
    $41 = ($39<<24>>24)==($38<<24>>24);
    $or$cond33 = $40 | $41;
    $42 = ((($$1)) + 1|0);
    if ($or$cond33) {
     $$0 = $$1;
     break;
    } else {
     $$1 = $42;
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _setlocale_one_unlocked($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = ((((gb + (171204) | 0)) + 40|0) + ($0<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $$0 = $6;
 } else {
  $3 = (___get_locale($0,$1)|0);
  $4 = ((((gb + (171204) | 0)) + 40|0) + ($0<<2)|0);
  HEAP32[$4>>2] = $3;
  $$0 = $3;
 }
 $7 = ($$0|0)==(0|0);
 $8 = ((($$0)) + 8|0);
 $9 = $7 ? (gb + (166525) | 0) : $8;
 return ($9|0);
}
function ___get_locale($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$093$lcssa = 0, $$093118 = 0, $$094114 = 0, $$1 = 0, $$1100111 = 0, $$195112 = 0, $$2122 = 0, $$2123 = 0, $$2124 = 0, $$4 = 0, $$neg = 0, $$pre121 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $2 = sp;
 $3 = sp + 256|0;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = (_getenv(((gb + (166527) | 0)|0))|0);
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = HEAP8[$6>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if (!($9)) {
     $$1 = $6;
     break;
    }
   }
   $10 = ((gb + (13984) | 0) + (($0*12)|0)|0);
   $11 = (_getenv(($10|0))|0);
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = HEAP8[$11>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     $$1 = $11;
     break;
    }
   }
   $15 = (_getenv(((gb + (166534) | 0)|0))|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = HEAP8[$15>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if (!($18)) {
     $$1 = $15;
     break;
    }
   }
   $$1 = (gb + (166539) | 0);
  } else {
   $$1 = $1;
  }
 } while(0);
 $$093118 = 0;
 L13: while(1) {
  $19 = (($$1) + ($$093118)|0);
  $20 = HEAP8[$19>>0]|0;
  switch ($20<<24>>24) {
  case 47: case 0:  {
   $$093$lcssa = $$093118;
   break L13;
   break;
  }
  default: {
  }
  }
  $21 = (($$093118) + 1)|0;
  $22 = ($21>>>0)<(15);
  if ($22) {
   $$093118 = $21;
  } else {
   $$093$lcssa = 15;
   break;
  }
 }
 $23 = HEAP8[$$1>>0]|0;
 $24 = ($23<<24>>24)==(46);
 if ($24) {
  $$2122 = (gb + (166539) | 0);
  label = 15;
 } else {
  $25 = (($$1) + ($$093$lcssa)|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $28 = ($23<<24>>24)==(67);
   if ($28) {
    $$2122 = $$1;
    label = 15;
   } else {
    $$2123 = $$1;
    label = 16;
   }
  } else {
   $$2122 = (gb + (166539) | 0);
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $29 = ((($$2122)) + 1|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $$2124 = $$2122;
   label = 18;
  } else {
   $$2123 = $$2122;
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $32 = (_strcmp($$2123,(gb + (166539) | 0))|0);
   $33 = ($32|0)==(0);
   if ($33) {
    $$2124 = $$2123;
    label = 18;
   } else {
    $34 = (_strcmp($$2123,(gb + (166547) | 0))|0);
    $35 = ($34|0)==(0);
    if ($35) {
     $$2124 = $$2123;
     label = 18;
    } else {
     $40 = HEAP32[(gb + (171296) | 0)>>2]|0;
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      $$094114 = $40;
      while(1) {
       $42 = ((($$094114)) + 8|0);
       $43 = (_strcmp($$2123,$42)|0);
       $44 = ($43|0)==(0);
       if ($44) {
        $$0 = $$094114;
        break L22;
       }
       $45 = ((($$094114)) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==(0|0);
       if ($47) {
        break;
       } else {
        $$094114 = $46;
       }
      }
     }
     ___lock(((gb + (171300) | 0)|0));
     $48 = HEAP32[(gb + (171296) | 0)>>2]|0;
     $49 = ($48|0)==(0|0);
     L32: do {
      if (!($49)) {
       $$195112 = $48;
       while(1) {
        $50 = ((($$195112)) + 8|0);
        $51 = (_strcmp($$2123,$50)|0);
        $52 = ($51|0)==(0);
        if ($52) {
         break;
        }
        $53 = ((($$195112)) + 24|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)==(0|0);
        if ($55) {
         break L32;
        } else {
         $$195112 = $54;
        }
       }
       ___unlock(((gb + (171300) | 0)|0));
       $$0 = $$195112;
       break L22;
      }
     } while(0);
     $56 = HEAP32[((((gb + (171204) | 0)) + 8|0))>>2]|0;
     $57 = ($56|0)==(0);
     L39: do {
      if ($57) {
       $58 = (_getenv(((gb + (166553) | 0)|0))|0);
       $59 = ($58|0)==(0|0);
       if ($59) {
        label = 41;
       } else {
        $60 = HEAP8[$58>>0]|0;
        $61 = ($60<<24>>24)==(0);
        if ($61) {
         label = 41;
        } else {
         $62 = (254 - ($$093$lcssa))|0;
         $63 = (($$093$lcssa) + 1)|0;
         $$1100111 = $58;
         while(1) {
          $64 = (___strchrnul($$1100111,58)|0);
          $65 = $64;
          $66 = $$1100111;
          $67 = (($65) - ($66))|0;
          $68 = HEAP8[$64>>0]|0;
          $69 = ($68<<24>>24)!=(0);
          $$neg = $69 << 31 >> 31;
          $70 = (($67) + ($$neg))|0;
          $71 = ($70>>>0)<($62>>>0);
          if ($71) {
           (_memcpy(($2|0),($$1100111|0),($70|0))|0);
           $72 = (($2) + ($70)|0);
           HEAP8[$72>>0] = 47;
           $73 = ((($72)) + 1|0);
           (_memcpy(($73|0),($$2123|0),($$093$lcssa|0))|0);
           $74 = (($63) + ($70))|0;
           $75 = (($2) + ($74)|0);
           HEAP8[$75>>0] = 0;
           $76 = (___map_file(($2|0),($3|0))|0);
           $77 = ($76|0)==(0|0);
           if (!($77)) {
            break;
           }
           $$pre121 = HEAP8[$64>>0]|0;
           $87 = $$pre121;
          } else {
           $87 = $68;
          }
          $86 = ($87<<24>>24)!=(0);
          $88 = $86&1;
          $89 = (($64) + ($88)|0);
          $90 = HEAP8[$89>>0]|0;
          $91 = ($90<<24>>24)==(0);
          if ($91) {
           label = 41;
           break L39;
          } else {
           $$1100111 = $89;
          }
         }
         $78 = (_malloc(28)|0);
         $79 = ($78|0)==(0|0);
         if ($79) {
          $92 = HEAP32[$3>>2]|0;
          (___munmap($76,$92)|0);
          label = 41;
          break;
         } else {
          HEAP32[$78>>2] = $76;
          $80 = HEAP32[$3>>2]|0;
          $81 = ((($78)) + 4|0);
          HEAP32[$81>>2] = $80;
          $82 = ((($78)) + 8|0);
          (_memcpy(($82|0),($$2123|0),($$093$lcssa|0))|0);
          $83 = (($82) + ($$093$lcssa)|0);
          HEAP8[$83>>0] = 0;
          $84 = HEAP32[(gb + (171296) | 0)>>2]|0;
          $85 = ((($78)) + 24|0);
          HEAP32[$85>>2] = $84;
          HEAP32[(gb + (171296) | 0)>>2] = $78;
          $$4 = $78;
          break;
         }
        }
       }
      } else {
       label = 41;
      }
     } while(0);
     if ((label|0) == 41) {
      $93 = (_malloc(28)|0);
      $94 = ($93|0)==(0|0);
      if ($94) {
       $$4 = $93;
      } else {
       $95 = HEAP32[(gb + (161232) | 0)>>2]|0;
       HEAP32[$93>>2] = $95;
       $96 = HEAP32[((((gb + (161232) | 0)) + 4|0))>>2]|0;
       $97 = ((($93)) + 4|0);
       HEAP32[$97>>2] = $96;
       $98 = ((($93)) + 8|0);
       (_memcpy(($98|0),($$2123|0),($$093$lcssa|0))|0);
       $99 = (($98) + ($$093$lcssa)|0);
       HEAP8[$99>>0] = 0;
       $100 = HEAP32[(gb + (171296) | 0)>>2]|0;
       $101 = ((($93)) + 24|0);
       HEAP32[$101>>2] = $100;
       HEAP32[(gb + (171296) | 0)>>2] = $93;
       $$4 = $93;
      }
     }
     $102 = ($$4|0)==(0|0);
     $103 = ($0|0)==(0);
     $or$cond = $103 & $102;
     $spec$select = $or$cond ? (gb + (161232) | 0) : $$4;
     ___unlock(((gb + (171300) | 0)|0));
     $$0 = $spec$select;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $36 = ($0|0)==(0);
   if ($36) {
    $37 = ((($$2124)) + 1|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)==(46);
    if ($39) {
     $$0 = (gb + (161232) | 0);
     break;
    }
   }
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___munmap($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 mftCall_v((fb + (10) | 0)|0);
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall91(91,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _dummy_284() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _catclose($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _isxdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isxdigit($0)|0);
 return ($2|0);
}
function _isxdigit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $narrow = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isdigit($0)|0);
 $2 = ($1|0)!=(0);
 $3 = $0 | 32;
 $4 = (($3) + -97)|0;
 $5 = ($4>>>0)<(6);
 $narrow = $5 | $2;
 $spec$select = $narrow&1;
 return ($spec$select|0);
}
function _isdigit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -48)|0;
 $2 = ($1>>>0)<(10);
 $3 = $2&1;
 return ($3|0);
}
function ___duplocale($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_malloc(24)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = ($0|0)==((-1)|0);
  $4 = $3 ? ((((gb + (171204) | 0)) + 40|0)) : $0;
  ;HEAP32[$1>>2]=HEAP32[$4>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$4+20>>2]|0;
  $$0 = $1;
 }
 return ($$0|0);
}
function _isdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isdigit($0)|0);
 return ($2|0);
}
function _ispunct_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_ispunct($0)|0);
 return ($2|0);
}
function _ispunct($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isgraph($0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = (_isalnum($0)|0);
  $4 = ($3|0)==(0);
  $phitmp = $4&1;
  $5 = $phitmp;
 }
 return ($5|0);
}
function _isgraph($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -33)|0;
 $2 = ($1>>>0)<(94);
 $3 = $2&1;
 return ($3|0);
}
function _isalnum($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isalpha($0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (_isdigit($0)|0);
  $4 = ($3|0)!=(0);
  $phitmp = $4&1;
  $5 = $phitmp;
 } else {
  $5 = 1;
 }
 return ($5|0);
}
function _isalpha($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 | 32;
 $2 = (($1) + -97)|0;
 $3 = ($2>>>0)<(26);
 $4 = $3&1;
 return ($4|0);
}
function _iswprint_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswprint($0)|0);
 return ($2|0);
}
function _iswprint($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$or$cond11 = 0, $or$cond = 0, $or$cond9 = 0, $spec$select = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(255);
 if ($1) {
  $2 = (($0) + 1)|0;
  $3 = $2 & 127;
  $4 = ($3>>>0)>(32);
  $5 = $4&1;
  $$0 = $5;
 } else {
  $6 = ($0>>>0)<(8232);
  $7 = (($0) + -8234)|0;
  $8 = ($7>>>0)<(47062);
  $or$cond = $6 | $8;
  $9 = (($0) + -57344)|0;
  $10 = ($9>>>0)<(8185);
  $or$cond9 = $10 | $or$cond;
  if ($or$cond9) {
   $$0 = 1;
  } else {
   $11 = (($0) + -65532)|0;
   $12 = ($11>>>0)<(1048580);
   $13 = $0 & 65534;
   $14 = ($13|0)!=(65534);
   $not$or$cond11 = $14 & $12;
   $spec$select = $not$or$cond11&1;
   return ($spec$select|0);
  }
 }
 return ($$0|0);
}
function _strfmon_l($0,$1,$2,$3,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $varargs = $varargs|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 HEAP32[$4>>2] = $varargs;
 $5 = (_vstrfmon_l($0,$1,$3,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function _vstrfmon_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$075$be = 0, $$075$lcssa = 0, $$07521 = 0, $$076$lcssa = 0, $$0763 = 0, $$077 = 0, $$07813 = 0, $$079$lcssa = 0, $$0796 = 0, $$081$be = 0, $$08120 = 0, $$082 = 0, $$084$be = 0, $$08419 = 0, $$1 = 0, $$180 = 0, $$183 = 0, $$185 = 0, $$185$pn = 0;
 var $$2 = 0, $$3 = 0, $$4$lcssa = 0, $$42 = 0, $$5 = 0, $$5$lcssa = 0, $$55 = 0, $$57 = 0, $$6 = 0, $$7 = 0, $$712 = 0, $$714 = 0, $$8 = 0, $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded3 = 0, $expanded5 = 0, $expanded6 = 0, $expanded7 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = ($1|0)==(0);
 L1: do {
  if ($4) {
   $$075$lcssa = $0;
   label = 27;
  } else {
   $$07521 = $0;$$08120 = $1;$$08419 = $2;
   L3: while(1) {
    $5 = HEAP8[$$08419>>0]|0;
    switch ($5<<24>>24) {
    case 0:  {
     $$075$lcssa = $$07521;
     label = 27;
     break L1;
     break;
    }
    case 37:  {
     $10 = ((($$08419)) + 1|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(37);
     if ($12) {
      $$185 = $10;$7 = 37;
      label = 4;
     } else {
      $$082 = 0;$$2 = $10;$14 = $11;
      L8: while(1) {
       $13 = $14 << 24 >> 24;
       switch ($13|0) {
       case 61:  {
        $15 = ((($$2)) + 1|0);
        $$183 = $$082;$$3 = $15;
        break;
       }
       case 33: case 43: case 40: case 94:  {
        $$183 = $$082;$$3 = $$2;
        break;
       }
       case 45:  {
        $$183 = 1;$$3 = $$2;
        break;
       }
       default: {
        break L8;
       }
       }
       $16 = ((($$3)) + 1|0);
       $$pre = HEAP8[$16>>0]|0;
       $$082 = $$183;$$2 = $16;$14 = $$pre;
      }
      $17 = (_isdigit($13)|0);
      $18 = ($17|0)==(0);
      if ($18) {
       $$076$lcssa = 0;$$4$lcssa = $$2;
      } else {
       $$0763 = 0;$$42 = $$2;
       while(1) {
        $19 = ($$0763*10)|0;
        $20 = HEAP8[$$42>>0]|0;
        $21 = $20 << 24 >> 24;
        $22 = (($19) + -48)|0;
        $23 = (($22) + ($21))|0;
        $24 = ((($$42)) + 1|0);
        $25 = HEAP8[$24>>0]|0;
        $26 = $25 << 24 >> 24;
        $27 = (_isdigit($26)|0);
        $28 = ($27|0)==(0);
        if ($28) {
         $$076$lcssa = $23;$$4$lcssa = $24;
         break;
        } else {
         $$0763 = $23;$$42 = $24;
        }
       }
      }
      $29 = HEAP8[$$4$lcssa>>0]|0;
      $30 = ($29<<24>>24)==(35);
      if ($30) {
       $$55 = ((($$4$lcssa)) + 1|0);
       $31 = HEAP8[$$55>>0]|0;
       $32 = $31 << 24 >> 24;
       $33 = (_isdigit($32)|0);
       $34 = ($33|0)==(0);
       if ($34) {
        $$079$lcssa = 0;$$5$lcssa = $$55;
       } else {
        $$0796 = 0;$$57 = $$55;
        while(1) {
         $35 = ($$0796*10)|0;
         $36 = HEAP8[$$57>>0]|0;
         $37 = $36 << 24 >> 24;
         $38 = (($35) + -48)|0;
         $39 = (($38) + ($37))|0;
         $$5 = ((($$57)) + 1|0);
         $40 = HEAP8[$$5>>0]|0;
         $41 = $40 << 24 >> 24;
         $42 = (_isdigit($41)|0);
         $43 = ($42|0)==(0);
         if ($43) {
          $$079$lcssa = $39;$$5$lcssa = $$5;
          break;
         } else {
          $$0796 = $39;$$57 = $$5;
         }
        }
       }
       $$pr = HEAP8[$$5$lcssa>>0]|0;
       $$180 = $$079$lcssa;$$6 = $$5$lcssa;$45 = $$pr;
      } else {
       $$180 = 0;$$6 = $$4$lcssa;$45 = $29;
      }
      $44 = ($45<<24>>24)==(46);
      if ($44) {
       $$712 = ((($$6)) + 1|0);
       $46 = HEAP8[$$712>>0]|0;
       $47 = $46 << 24 >> 24;
       $48 = (_isdigit($47)|0);
       $49 = ($48|0)==(0);
       if ($49) {
        $$1 = 0;$$8 = $$712;
       } else {
        $$07813 = 0;$$714 = $$712;
        while(1) {
         $50 = ($$07813*10)|0;
         $51 = HEAP8[$$714>>0]|0;
         $52 = $51 << 24 >> 24;
         $53 = (($50) + -48)|0;
         $54 = (($53) + ($52))|0;
         $$7 = ((($$714)) + 1|0);
         $55 = HEAP8[$$7>>0]|0;
         $56 = $55 << 24 >> 24;
         $57 = (_isdigit($56)|0);
         $58 = ($57|0)==(0);
         if ($58) {
          $$1 = $54;$$8 = $$7;
          break;
         } else {
          $$07813 = $54;$$714 = $$7;
         }
        }
       }
      } else {
       $$1 = 2;$$8 = $$6;
      }
      $59 = (($$180) + 1)|0;
      $60 = (($59) + ($$1))|0;
      $61 = ($$082|0)==(0);
      $62 = ($$076$lcssa|0)>($60|0);
      $or$cond = $61 & $62;
      $$077 = $or$cond ? $$076$lcssa : $60;
      $arglist_current = HEAP32[$3>>2]|0;
      $63 = $arglist_current;
      $64 = ((0) + 8|0);
      $expanded3 = $64;
      $expanded = (($expanded3) - 1)|0;
      $65 = (($63) + ($expanded))|0;
      $66 = ((0) + 8|0);
      $expanded7 = $66;
      $expanded6 = (($expanded7) - 1)|0;
      $expanded5 = $expanded6 ^ -1;
      $67 = $65 & $expanded5;
      $68 = $67;
      $69 = +HEAPF64[$68>>3];
      $arglist_next = ((($68)) + 8|0);
      HEAP32[$3>>2] = $arglist_next;
      HEAP32[$vararg_buffer>>2] = $$077;
      $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
      HEAP32[$vararg_ptr1>>2] = $$1;
      $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
      HEAPF64[$vararg_ptr2>>3] = $69;
      $70 = (_snprintf($$07521,$$08120,(gb + (166566) | 0),$vararg_buffer)|0);
      $71 = ($$08120>>>0)>($70>>>0);
      if (!($71)) {
       break L3;
      }
      $73 = (($$07521) + ($70)|0);
      $74 = (($$08120) - ($70))|0;
      $$075$be = $73;$$081$be = $74;$$185$pn = $$8;
     }
     break;
    }
    default: {
     $$185 = $$08419;$7 = $5;
     label = 4;
    }
    }
    if ((label|0) == 4) {
     label = 0;
     $6 = ((($$07521)) + 1|0);
     HEAP8[$$07521>>0] = $7;
     $8 = (($$08120) + -1)|0;
     $$075$be = $6;$$081$be = $8;$$185$pn = $$185;
    }
    $$084$be = ((($$185$pn)) + 1|0);
    $9 = ($$081$be|0)==(0);
    if ($9) {
     $$075$lcssa = $$075$be;
     label = 27;
     break L1;
    } else {
     $$07521 = $$075$be;$$08120 = $$081$be;$$08419 = $$084$be;
    }
   }
   $72 = (___errno_location()|0);
   HEAP32[$72>>2] = 7;
   $$0 = -1;
  }
 } while(0);
 if ((label|0) == 27) {
  $75 = $$075$lcssa;
  $76 = $0;
  $77 = (($75) - ($76))|0;
  $$0 = $77;
 }
 STACKTOP = sp;return ($$0|0);
}
function _snprintf($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = (_vsnprintf($0,$1,$2,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function _vsnprintf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$014 = 0, $$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $4 = sp + 124|0;
 $5 = sp;
 dest=$5; src=(gb + (161960) | 0); stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($1) + -1)|0;
 $7 = ($6>>>0)>(2147483646);
 if ($7) {
  $8 = ($1|0)==(0);
  if ($8) {
   $$014 = $4;$$015 = 1;
   label = 4;
  } else {
   $9 = (___errno_location()|0);
   HEAP32[$9>>2] = 75;
   $$0 = -1;
  }
 } else {
  $$014 = $0;$$015 = $1;
  label = 4;
 }
 if ((label|0) == 4) {
  $10 = $$014;
  $11 = (-2 - ($10))|0;
  $12 = ($$015>>>0)>($11>>>0);
  $spec$select = $12 ? $11 : $$015;
  $13 = ((($5)) + 48|0);
  HEAP32[$13>>2] = $spec$select;
  $14 = ((($5)) + 20|0);
  HEAP32[$14>>2] = $$014;
  $15 = ((($5)) + 44|0);
  HEAP32[$15>>2] = $$014;
  $16 = (($$014) + ($spec$select)|0);
  $17 = ((($5)) + 16|0);
  HEAP32[$17>>2] = $16;
  $18 = ((($5)) + 28|0);
  HEAP32[$18>>2] = $16;
  $19 = (_vfprintf($5,$2,$3)|0);
  $20 = ($spec$select|0)==(0);
  if ($20) {
   $$0 = $19;
  } else {
   $21 = HEAP32[$14>>2]|0;
   $22 = HEAP32[$17>>2]|0;
   $23 = ($21|0)==($22|0);
   $24 = $23 << 31 >> 31;
   $25 = (($21) + ($24)|0);
   HEAP8[$25>>0] = 0;
   $$0 = $19;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _vfprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $spec$select = 0, $spec$select41 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(224|0);
 $3 = sp + 208|0;
 $4 = sp + 160|0;
 $5 = sp + 80|0;
 $6 = sp;
 dest=$4; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $vacopy_currentptr;
 $7 = (_printf_core(0,$1,$3,$5,$4)|0);
 $8 = ($7|0)<(0);
 if ($8) {
  $$0 = -1;
 } else {
  $9 = ((($0)) + 76|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)>(-1);
  if ($11) {
   $12 = (___lockfile($0)|0);
   $40 = $12;
  } else {
   $40 = 0;
  }
  $13 = HEAP32[$0>>2]|0;
  $14 = $13 & 32;
  $15 = ((($0)) + 74|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)<(1);
  if ($17) {
   $18 = $13 & -33;
   HEAP32[$0>>2] = $18;
  }
  $19 = ((($0)) + 48|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $23 = ((($0)) + 44|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$23>>2] = $6;
   $25 = ((($0)) + 28|0);
   HEAP32[$25>>2] = $6;
   $26 = ((($0)) + 20|0);
   HEAP32[$26>>2] = $6;
   HEAP32[$19>>2] = 80;
   $27 = ((($6)) + 80|0);
   $28 = ((($0)) + 16|0);
   HEAP32[$28>>2] = $27;
   $29 = (_printf_core($0,$1,$3,$5,$4)|0);
   $30 = ($24|0)==(0|0);
   if ($30) {
    $$1 = $29;
   } else {
    $31 = ((($0)) + 36|0);
    $32 = HEAP32[$31>>2]|0;
    (mftCall_iiii($32|0,($0|0),(0|0),0)|0);
    $33 = HEAP32[$26>>2]|0;
    $34 = ($33|0)==(0|0);
    $spec$select = $34 ? -1 : $29;
    HEAP32[$23>>2] = $24;
    HEAP32[$19>>2] = 0;
    HEAP32[$28>>2] = 0;
    HEAP32[$25>>2] = 0;
    HEAP32[$26>>2] = 0;
    $$1 = $spec$select;
   }
  } else {
   $22 = (_printf_core($0,$1,$3,$5,$4)|0);
   $$1 = $22;
  }
  $35 = HEAP32[$0>>2]|0;
  $36 = $35 & 32;
  $37 = ($36|0)==(0);
  $spec$select41 = $37 ? $$1 : -1;
  $38 = $35 | $14;
  HEAP32[$0>>2] = $38;
  $39 = ($40|0)==(0);
  if (!($39)) {
   ___unlockfile($0);
  }
  $$0 = $spec$select41;
 }
 STACKTOP = sp;return ($$0|0);
}
function _printf_core($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$0 = 0, $$0228 = 0, $$0229334 = 0, $$0232 = 0, $$0235 = 0, $$0237 = 0, $$0240313 = 0, $$0240313371 = 0, $$0240333 = 0, $$0243 = 0, $$0243$ph = 0, $$0243$ph$be = 0, $$0247 = 0, $$0247$ph = 0, $$0249$lcssa = 0, $$0249321 = 0, $$0252 = 0, $$0253 = 0, $$0254 = 0;
 var $$0259 = 0, $$0262$lcssa = 0, $$0262328 = 0, $$0269$ph = 0, $$1 = 0, $$1230340 = 0, $$1233 = 0, $$1236 = 0, $$1238 = 0, $$1241339 = 0, $$1248 = 0, $$1250 = 0, $$1255 = 0, $$1260 = 0, $$1263 = 0, $$1270 = 0, $$2 = 0, $$2234 = 0, $$2239 = 0, $$2242320 = 0;
 var $$2256 = 0, $$2256$ = 0, $$2261 = 0, $$2271 = 0, $$3257 = 0, $$3265 = 0, $$3272 = 0, $$3317 = 0, $$4258370 = 0, $$4266 = 0, $$5 = 0, $$6268 = 0, $$lcssa308 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre360 = 0, $$pre362 = 0, $$pre363 = 0, $$pre363$pre = 0, $$pre364 = 0;
 var $$pre368 = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0.0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0;
 var $arglist_next3 = 0, $brmerge = 0, $brmerge326 = 0, $expanded = 0, $expanded10 = 0, $expanded11 = 0, $expanded13 = 0, $expanded14 = 0, $expanded15 = 0, $expanded4 = 0, $expanded6 = 0, $expanded7 = 0, $expanded8 = 0, $or$cond = 0, $or$cond276 = 0, $or$cond278 = 0, $or$cond283 = 0, $spec$select = 0, $spec$select281 = 0, $spec$select284 = 0;
 var $spec$select291 = 0, $spec$select292 = 0, $spec$select293 = 0, $spec$select294 = 0, $spec$select295 = 0, $spec$select296 = 0, $spec$select297 = 0, $spec$select298 = 0, $spec$select299 = 0, $storemerge273$lcssa = 0, $storemerge273327 = 0, $storemerge274 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 56|0;
 $6 = sp + 40|0;
 $7 = sp;
 $8 = sp + 48|0;
 $9 = sp + 60|0;
 HEAP32[$5>>2] = $1;
 $10 = ($0|0)!=(0|0);
 $11 = ((($7)) + 40|0);
 $12 = $11;
 $13 = ((($7)) + 39|0);
 $14 = ((($8)) + 4|0);
 $$0243$ph = 0;$$0247$ph = 0;$$0269$ph = 0;
 L1: while(1) {
  $$0243 = $$0243$ph;$$0247 = $$0247$ph;
  while(1) {
   $15 = ($$0247|0)>(-1);
   do {
    if ($15) {
     $16 = (2147483647 - ($$0247))|0;
     $17 = ($$0243|0)>($16|0);
     if ($17) {
      $18 = (___errno_location()|0);
      HEAP32[$18>>2] = 75;
      $$1248 = -1;
      break;
     } else {
      $19 = (($$0243) + ($$0247))|0;
      $$1248 = $19;
      break;
     }
    } else {
     $$1248 = $$0247;
    }
   } while(0);
   $20 = HEAP32[$5>>2]|0;
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 94;
    break L1;
   }
   $23 = $21;$25 = $20;
   L12: while(1) {
    switch ($23<<24>>24) {
    case 37:  {
     label = 10;
     break L12;
     break;
    }
    case 0:  {
     $$0249$lcssa = $25;
     break L12;
     break;
    }
    default: {
    }
    }
    $24 = ((($25)) + 1|0);
    HEAP32[$5>>2] = $24;
    $$pre = HEAP8[$24>>0]|0;
    $23 = $$pre;$25 = $24;
   }
   L15: do {
    if ((label|0) == 10) {
     label = 0;
     $$0249321 = $25;$27 = $25;
     while(1) {
      $26 = ((($27)) + 1|0);
      $28 = HEAP8[$26>>0]|0;
      $29 = ($28<<24>>24)==(37);
      if (!($29)) {
       $$0249$lcssa = $$0249321;
       break L15;
      }
      $30 = ((($$0249321)) + 1|0);
      $31 = ((($27)) + 2|0);
      HEAP32[$5>>2] = $31;
      $32 = HEAP8[$31>>0]|0;
      $33 = ($32<<24>>24)==(37);
      if ($33) {
       $$0249321 = $30;$27 = $31;
      } else {
       $$0249$lcssa = $30;
       break;
      }
     }
    }
   } while(0);
   $34 = $$0249$lcssa;
   $35 = $20;
   $36 = (($34) - ($35))|0;
   if ($10) {
    _out_374($0,$20,$36);
   }
   $37 = ($36|0)==(0);
   if ($37) {
    break;
   } else {
    $$0243 = $36;$$0247 = $$1248;
   }
  }
  $38 = HEAP32[$5>>2]|0;
  $39 = ((($38)) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40 << 24 >> 24;
  $42 = (_isdigit($41)|0);
  $43 = ($42|0)==(0);
  $$pre360 = HEAP32[$5>>2]|0;
  if ($43) {
   $$0253 = -1;$$1270 = $$0269$ph;$$sink = 1;
  } else {
   $44 = ((($$pre360)) + 2|0);
   $45 = HEAP8[$44>>0]|0;
   $46 = ($45<<24>>24)==(36);
   if ($46) {
    $47 = ((($$pre360)) + 1|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48 << 24 >> 24;
    $50 = (($49) + -48)|0;
    $$0253 = $50;$$1270 = 1;$$sink = 3;
   } else {
    $$0253 = -1;$$1270 = $$0269$ph;$$sink = 1;
   }
  }
  $51 = (($$pre360) + ($$sink)|0);
  HEAP32[$5>>2] = $51;
  $52 = HEAP8[$51>>0]|0;
  $53 = $52 << 24 >> 24;
  $54 = (($53) + -32)|0;
  $55 = ($54>>>0)>(31);
  $56 = 1 << $54;
  $57 = $56 & 75913;
  $58 = ($57|0)==(0);
  $brmerge326 = $55 | $58;
  if ($brmerge326) {
   $$0262$lcssa = 0;$$lcssa308 = $52;$storemerge273$lcssa = $51;
  } else {
   $$0262328 = 0;$60 = $54;$storemerge273327 = $51;
   while(1) {
    $59 = 1 << $60;
    $61 = $59 | $$0262328;
    $62 = ((($storemerge273327)) + 1|0);
    HEAP32[$5>>2] = $62;
    $63 = HEAP8[$62>>0]|0;
    $64 = $63 << 24 >> 24;
    $65 = (($64) + -32)|0;
    $66 = ($65>>>0)>(31);
    $67 = 1 << $65;
    $68 = $67 & 75913;
    $69 = ($68|0)==(0);
    $brmerge = $66 | $69;
    if ($brmerge) {
     $$0262$lcssa = $61;$$lcssa308 = $63;$storemerge273$lcssa = $62;
     break;
    } else {
     $$0262328 = $61;$60 = $65;$storemerge273327 = $62;
    }
   }
  }
  $70 = ($$lcssa308<<24>>24)==(42);
  if ($70) {
   $71 = ((($storemerge273$lcssa)) + 1|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = $72 << 24 >> 24;
   $74 = (_isdigit($73)|0);
   $75 = ($74|0)==(0);
   if ($75) {
    label = 27;
   } else {
    $76 = HEAP32[$5>>2]|0;
    $77 = ((($76)) + 2|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = ($78<<24>>24)==(36);
    if ($79) {
     $80 = ((($76)) + 1|0);
     $81 = HEAP8[$80>>0]|0;
     $82 = $81 << 24 >> 24;
     $83 = (($82) + -48)|0;
     $84 = (($4) + ($83<<2)|0);
     HEAP32[$84>>2] = 10;
     $85 = HEAP8[$80>>0]|0;
     $86 = $85 << 24 >> 24;
     $87 = (($86) + -48)|0;
     $88 = (($3) + ($87<<3)|0);
     $89 = $88;
     $90 = $89;
     $91 = HEAP32[$90>>2]|0;
     $92 = (($89) + 4)|0;
     $93 = $92;
     $94 = HEAP32[$93>>2]|0;
     $95 = ((($76)) + 3|0);
     $$0259 = $91;$$2271 = 1;$storemerge274 = $95;
    } else {
     label = 27;
    }
   }
   if ((label|0) == 27) {
    label = 0;
    $96 = ($$1270|0)==(0);
    if (!($96)) {
     $$0 = -1;
     break;
    }
    if ($10) {
     $arglist_current = HEAP32[$2>>2]|0;
     $97 = $arglist_current;
     $98 = ((0) + 4|0);
     $expanded4 = $98;
     $expanded = (($expanded4) - 1)|0;
     $99 = (($97) + ($expanded))|0;
     $100 = ((0) + 4|0);
     $expanded8 = $100;
     $expanded7 = (($expanded8) - 1)|0;
     $expanded6 = $expanded7 ^ -1;
     $101 = $99 & $expanded6;
     $102 = $101;
     $103 = HEAP32[$102>>2]|0;
     $arglist_next = ((($102)) + 4|0);
     HEAP32[$2>>2] = $arglist_next;
     $358 = $103;
    } else {
     $358 = 0;
    }
    $104 = HEAP32[$5>>2]|0;
    $105 = ((($104)) + 1|0);
    $$0259 = $358;$$2271 = 0;$storemerge274 = $105;
   }
   HEAP32[$5>>2] = $storemerge274;
   $106 = ($$0259|0)<(0);
   $107 = $$0262$lcssa | 8192;
   $108 = (0 - ($$0259))|0;
   $spec$select291 = $106 ? $107 : $$0262$lcssa;
   $spec$select292 = $106 ? $108 : $$0259;
   $$1260 = $spec$select292;$$1263 = $spec$select291;$$3272 = $$2271;$112 = $storemerge274;
  } else {
   $109 = (_getint_375($5)|0);
   $110 = ($109|0)<(0);
   if ($110) {
    $$0 = -1;
    break;
   }
   $$pre362 = HEAP32[$5>>2]|0;
   $$1260 = $109;$$1263 = $$0262$lcssa;$$3272 = $$1270;$112 = $$pre362;
  }
  $111 = HEAP8[$112>>0]|0;
  $113 = ($111<<24>>24)==(46);
  do {
   if ($113) {
    $114 = ((($112)) + 1|0);
    $115 = HEAP8[$114>>0]|0;
    $116 = ($115<<24>>24)==(42);
    if (!($116)) {
     HEAP32[$5>>2] = $114;
     $152 = (_getint_375($5)|0);
     $$pre363$pre = HEAP32[$5>>2]|0;
     $$0254 = $152;$$pre363 = $$pre363$pre;
     break;
    }
    $117 = ((($112)) + 2|0);
    $118 = HEAP8[$117>>0]|0;
    $119 = $118 << 24 >> 24;
    $120 = (_isdigit($119)|0);
    $121 = ($120|0)==(0);
    if (!($121)) {
     $122 = HEAP32[$5>>2]|0;
     $123 = ((($122)) + 3|0);
     $124 = HEAP8[$123>>0]|0;
     $125 = ($124<<24>>24)==(36);
     if ($125) {
      $126 = ((($122)) + 2|0);
      $127 = HEAP8[$126>>0]|0;
      $128 = $127 << 24 >> 24;
      $129 = (($128) + -48)|0;
      $130 = (($4) + ($129<<2)|0);
      HEAP32[$130>>2] = 10;
      $131 = HEAP8[$126>>0]|0;
      $132 = $131 << 24 >> 24;
      $133 = (($132) + -48)|0;
      $134 = (($3) + ($133<<3)|0);
      $135 = $134;
      $136 = $135;
      $137 = HEAP32[$136>>2]|0;
      $138 = (($135) + 4)|0;
      $139 = $138;
      $140 = HEAP32[$139>>2]|0;
      $141 = ((($122)) + 4|0);
      HEAP32[$5>>2] = $141;
      $$0254 = $137;$$pre363 = $141;
      break;
     }
    }
    $142 = ($$3272|0)==(0);
    if (!($142)) {
     $$0 = -1;
     break L1;
    }
    if ($10) {
     $arglist_current2 = HEAP32[$2>>2]|0;
     $143 = $arglist_current2;
     $144 = ((0) + 4|0);
     $expanded11 = $144;
     $expanded10 = (($expanded11) - 1)|0;
     $145 = (($143) + ($expanded10))|0;
     $146 = ((0) + 4|0);
     $expanded15 = $146;
     $expanded14 = (($expanded15) - 1)|0;
     $expanded13 = $expanded14 ^ -1;
     $147 = $145 & $expanded13;
     $148 = $147;
     $149 = HEAP32[$148>>2]|0;
     $arglist_next3 = ((($148)) + 4|0);
     HEAP32[$2>>2] = $arglist_next3;
     $359 = $149;
    } else {
     $359 = 0;
    }
    $150 = HEAP32[$5>>2]|0;
    $151 = ((($150)) + 2|0);
    HEAP32[$5>>2] = $151;
    $$0254 = $359;$$pre363 = $151;
   } else {
    $$0254 = -1;$$pre363 = $112;
   }
  } while(0);
  $$0252 = 0;$154 = $$pre363;
  while(1) {
   $153 = HEAP8[$154>>0]|0;
   $155 = $153 << 24 >> 24;
   $156 = (($155) + -65)|0;
   $157 = ($156>>>0)>(57);
   if ($157) {
    $$0 = -1;
    break L1;
   }
   $158 = ((($154)) + 1|0);
   HEAP32[$5>>2] = $158;
   $159 = HEAP8[$154>>0]|0;
   $160 = $159 << 24 >> 24;
   $161 = (($160) + -65)|0;
   $162 = (((gb + (14064) | 0) + (($$0252*58)|0)|0) + ($161)|0);
   $163 = HEAP8[$162>>0]|0;
   $164 = $163&255;
   $165 = (($164) + -1)|0;
   $166 = ($165>>>0)<(8);
   if ($166) {
    $$0252 = $164;$154 = $158;
   } else {
    break;
   }
  }
  $167 = ($163<<24>>24)==(0);
  if ($167) {
   $$0 = -1;
   break;
  }
  $168 = ($163<<24>>24)==(19);
  $169 = ($$0253|0)>(-1);
  do {
   if ($168) {
    if ($169) {
     $$0 = -1;
     break L1;
    } else {
     label = 54;
    }
   } else {
    if ($169) {
     $170 = (($4) + ($$0253<<2)|0);
     HEAP32[$170>>2] = $164;
     $171 = (($3) + ($$0253<<3)|0);
     $172 = $171;
     $173 = $172;
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + 4)|0;
     $176 = $175;
     $177 = HEAP32[$176>>2]|0;
     $178 = $6;
     $179 = $178;
     HEAP32[$179>>2] = $174;
     $180 = (($178) + 4)|0;
     $181 = $180;
     HEAP32[$181>>2] = $177;
     label = 54;
     break;
    }
    if (!($10)) {
     $$0 = 0;
     break L1;
    }
    _pop_arg_377($6,$164,$2);
    $$pre364 = HEAP32[$5>>2]|0;
    $183 = $$pre364;
    label = 55;
   }
  } while(0);
  if ((label|0) == 54) {
   label = 0;
   if ($10) {
    $183 = $158;
    label = 55;
   } else {
    $$0243$ph$be = 0;
   }
  }
  L77: do {
   if ((label|0) == 55) {
    label = 0;
    $182 = ((($183)) + -1|0);
    $184 = HEAP8[$182>>0]|0;
    $185 = $184 << 24 >> 24;
    $186 = ($$0252|0)!=(0);
    $187 = $185 & 15;
    $188 = ($187|0)==(3);
    $or$cond276 = $186 & $188;
    $189 = $185 & -33;
    $$0235 = $or$cond276 ? $189 : $185;
    $190 = $$1263 & 8192;
    $191 = ($190|0)==(0);
    $192 = $$1263 & -65537;
    $spec$select = $191 ? $$1263 : $192;
    L79: do {
     switch ($$0235|0) {
     case 110:  {
      $trunc = $$0252&255;
      switch ($trunc<<24>>24) {
      case 0:  {
       $199 = HEAP32[$6>>2]|0;
       HEAP32[$199>>2] = $$1248;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 1:  {
       $200 = HEAP32[$6>>2]|0;
       HEAP32[$200>>2] = $$1248;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 2:  {
       $201 = ($$1248|0)<(0);
       $202 = $201 << 31 >> 31;
       $203 = HEAP32[$6>>2]|0;
       $204 = $203;
       $205 = $204;
       HEAP32[$205>>2] = $$1248;
       $206 = (($204) + 4)|0;
       $207 = $206;
       HEAP32[$207>>2] = $202;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 3:  {
       $208 = $$1248&65535;
       $209 = HEAP32[$6>>2]|0;
       HEAP16[$209>>1] = $208;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 4:  {
       $210 = $$1248&255;
       $211 = HEAP32[$6>>2]|0;
       HEAP8[$211>>0] = $210;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 6:  {
       $212 = HEAP32[$6>>2]|0;
       HEAP32[$212>>2] = $$1248;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      case 7:  {
       $213 = ($$1248|0)<(0);
       $214 = $213 << 31 >> 31;
       $215 = HEAP32[$6>>2]|0;
       $216 = $215;
       $217 = $216;
       HEAP32[$217>>2] = $$1248;
       $218 = (($216) + 4)|0;
       $219 = $218;
       HEAP32[$219>>2] = $214;
       $$0243$ph$be = 0;
       break L77;
       break;
      }
      default: {
       $$0243$ph$be = 0;
       break L77;
      }
      }
      break;
     }
     case 112:  {
      $220 = ($$0254>>>0)>(8);
      $221 = $220 ? $$0254 : 8;
      $222 = $spec$select | 8;
      $$1236 = 120;$$1255 = $221;$$3265 = $222;
      label = 67;
      break;
     }
     case 88: case 120:  {
      $$1236 = $$0235;$$1255 = $$0254;$$3265 = $spec$select;
      label = 67;
      break;
     }
     case 111:  {
      $238 = $6;
      $239 = $238;
      $240 = HEAP32[$239>>2]|0;
      $241 = (($238) + 4)|0;
      $242 = $241;
      $243 = HEAP32[$242>>2]|0;
      $244 = (_fmt_o($240,$243,$11)|0);
      $245 = $spec$select & 8;
      $246 = ($245|0)==(0);
      $247 = $244;
      $248 = (($12) - ($247))|0;
      $249 = ($$0254|0)>($248|0);
      $250 = (($248) + 1)|0;
      $251 = $246 | $249;
      $spec$select295 = $251 ? $$0254 : $250;
      $$0228 = $244;$$1233 = 0;$$1238 = (gb + (166572) | 0);$$2256 = $spec$select295;$$4266 = $spec$select;$277 = $240;$279 = $243;
      label = 73;
      break;
     }
     case 105: case 100:  {
      $252 = $6;
      $253 = $252;
      $254 = HEAP32[$253>>2]|0;
      $255 = (($252) + 4)|0;
      $256 = $255;
      $257 = HEAP32[$256>>2]|0;
      $258 = ($257|0)<(0);
      if ($258) {
       $259 = (_i64Subtract(0,0,($254|0),($257|0))|0);
       $260 = (getTempRet0() | 0);
       $261 = $6;
       $262 = $261;
       HEAP32[$262>>2] = $259;
       $263 = (($261) + 4)|0;
       $264 = $263;
       HEAP32[$264>>2] = $260;
       $$0232 = 1;$$0237 = (gb + (166572) | 0);$271 = $259;$272 = $260;
       label = 72;
       break L79;
      } else {
       $265 = $spec$select & 2048;
       $266 = ($265|0)==(0);
       $267 = $spec$select & 1;
       $268 = ($267|0)==(0);
       $$ = $268 ? (gb + (166572) | 0) : ((((gb + (166572) | 0)) + 2|0));
       $spec$select296 = $266 ? $$ : ((((gb + (166572) | 0)) + 1|0));
       $269 = $spec$select & 2049;
       $270 = ($269|0)!=(0);
       $spec$select297 = $270&1;
       $$0232 = $spec$select297;$$0237 = $spec$select296;$271 = $254;$272 = $257;
       label = 72;
       break L79;
      }
      break;
     }
     case 117:  {
      $193 = $6;
      $194 = $193;
      $195 = HEAP32[$194>>2]|0;
      $196 = (($193) + 4)|0;
      $197 = $196;
      $198 = HEAP32[$197>>2]|0;
      $$0232 = 0;$$0237 = (gb + (166572) | 0);$271 = $195;$272 = $198;
      label = 72;
      break;
     }
     case 99:  {
      $288 = $6;
      $289 = $288;
      $290 = HEAP32[$289>>2]|0;
      $291 = (($288) + 4)|0;
      $292 = $291;
      $293 = HEAP32[$292>>2]|0;
      $294 = $290&255;
      HEAP8[$13>>0] = $294;
      $$2 = $13;$$2234 = 0;$$2239 = (gb + (166572) | 0);$$5 = 1;$$6268 = $192;$$pre$phiZ2D = $12;
      break;
     }
     case 109:  {
      $295 = (___errno_location()|0);
      $296 = HEAP32[$295>>2]|0;
      $297 = (_strerror($296)|0);
      $$1 = $297;
      label = 77;
      break;
     }
     case 115:  {
      $298 = HEAP32[$6>>2]|0;
      $299 = ($298|0)==(0|0);
      $300 = $299 ? (gb + (167291) | 0) : $298;
      $$1 = $300;
      label = 77;
      break;
     }
     case 67:  {
      $307 = $6;
      $308 = $307;
      $309 = HEAP32[$308>>2]|0;
      $310 = (($307) + 4)|0;
      $311 = $310;
      $312 = HEAP32[$311>>2]|0;
      HEAP32[$8>>2] = $309;
      HEAP32[$14>>2] = 0;
      HEAP32[$6>>2] = $8;
      $$4258370 = -1;
      label = 81;
      break;
     }
     case 83:  {
      $313 = ($$0254|0)==(0);
      if ($313) {
       _pad_380($0,32,$$1260,0,$spec$select);
       $$0240313371 = 0;
       label = 91;
      } else {
       $$4258370 = $$0254;
       label = 81;
      }
      break;
     }
     case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
      $336 = +HEAPF64[$6>>3];
      $337 = (_fmt_fp($0,$336,$$1260,$$0254,$spec$select,$$0235)|0);
      $$0243$ph$be = $337;
      break L77;
      break;
     }
     default: {
      $$2 = $20;$$2234 = 0;$$2239 = (gb + (166572) | 0);$$5 = $$0254;$$6268 = $spec$select;$$pre$phiZ2D = $12;
     }
     }
    } while(0);
    L103: do {
     if ((label|0) == 67) {
      label = 0;
      $223 = $6;
      $224 = $223;
      $225 = HEAP32[$224>>2]|0;
      $226 = (($223) + 4)|0;
      $227 = $226;
      $228 = HEAP32[$227>>2]|0;
      $229 = $$1236 & 32;
      $230 = (_fmt_x($225,$228,$11,$229)|0);
      $231 = ($225|0)==(0);
      $232 = ($228|0)==(0);
      $233 = $231 & $232;
      $234 = $$3265 & 8;
      $235 = ($234|0)==(0);
      $or$cond278 = $235 | $233;
      $236 = $$1236 >>> 4;
      $237 = ((gb + (166572) | 0) + ($236)|0);
      $spec$select293 = $or$cond278 ? (gb + (166572) | 0) : $237;
      $spec$select294 = $or$cond278 ? 0 : 2;
      $$0228 = $230;$$1233 = $spec$select294;$$1238 = $spec$select293;$$2256 = $$1255;$$4266 = $$3265;$277 = $225;$279 = $228;
      label = 73;
     }
     else if ((label|0) == 72) {
      label = 0;
      $273 = (_fmt_u($271,$272,$11)|0);
      $$0228 = $273;$$1233 = $$0232;$$1238 = $$0237;$$2256 = $$0254;$$4266 = $spec$select;$277 = $271;$279 = $272;
      label = 73;
     }
     else if ((label|0) == 77) {
      label = 0;
      $301 = (_memchr($$1,0,$$0254)|0);
      $302 = ($301|0)==(0|0);
      $303 = $301;
      $304 = $$1;
      $305 = (($303) - ($304))|0;
      $306 = (($$1) + ($$0254)|0);
      $$3257 = $302 ? $$0254 : $305;
      $$1250 = $302 ? $306 : $301;
      $$pre368 = $$1250;
      $$2 = $$1;$$2234 = 0;$$2239 = (gb + (166572) | 0);$$5 = $$3257;$$6268 = $192;$$pre$phiZ2D = $$pre368;
     }
     else if ((label|0) == 81) {
      label = 0;
      $314 = HEAP32[$6>>2]|0;
      $$0229334 = $314;$$0240333 = 0;
      while(1) {
       $315 = HEAP32[$$0229334>>2]|0;
       $316 = ($315|0)==(0);
       if ($316) {
        $$0240313 = $$0240333;
        break;
       }
       $317 = (_wctomb($9,$315)|0);
       $318 = ($317|0)<(0);
       $319 = (($$4258370) - ($$0240333))|0;
       $320 = ($317>>>0)>($319>>>0);
       $or$cond283 = $318 | $320;
       if ($or$cond283) {
        label = 85;
        break;
       }
       $321 = ((($$0229334)) + 4|0);
       $322 = (($317) + ($$0240333))|0;
       $323 = ($$4258370>>>0)>($322>>>0);
       if ($323) {
        $$0229334 = $321;$$0240333 = $322;
       } else {
        $$0240313 = $322;
        break;
       }
      }
      if ((label|0) == 85) {
       label = 0;
       if ($318) {
        $$0 = -1;
        break L1;
       } else {
        $$0240313 = $$0240333;
       }
      }
      _pad_380($0,32,$$1260,$$0240313,$spec$select);
      $324 = ($$0240313|0)==(0);
      if ($324) {
       $$0240313371 = 0;
       label = 91;
      } else {
       $325 = HEAP32[$6>>2]|0;
       $$1230340 = $325;$$1241339 = 0;
       while(1) {
        $326 = HEAP32[$$1230340>>2]|0;
        $327 = ($326|0)==(0);
        if ($327) {
         $$0240313371 = $$0240313;
         label = 91;
         break L103;
        }
        $328 = (_wctomb($9,$326)|0);
        $329 = (($328) + ($$1241339))|0;
        $330 = ($329|0)>($$0240313|0);
        if ($330) {
         $$0240313371 = $$0240313;
         label = 91;
         break L103;
        }
        $331 = ((($$1230340)) + 4|0);
        _out_374($0,$9,$328);
        $332 = ($329>>>0)<($$0240313>>>0);
        if ($332) {
         $$1230340 = $331;$$1241339 = $329;
        } else {
         $$0240313371 = $$0240313;
         label = 91;
         break;
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 73) {
     label = 0;
     $274 = ($$2256|0)>(-1);
     $275 = $$4266 & -65537;
     $spec$select281 = $274 ? $275 : $$4266;
     $276 = ($277|0)!=(0);
     $278 = ($279|0)!=(0);
     $280 = $276 | $278;
     $281 = ($$2256|0)!=(0);
     $or$cond = $281 | $280;
     $282 = $$0228;
     $283 = (($12) - ($282))|0;
     $284 = $280 ^ 1;
     $285 = $284&1;
     $286 = (($283) + ($285))|0;
     $287 = ($$2256|0)>($286|0);
     $$2256$ = $287 ? $$2256 : $286;
     $spec$select298 = $or$cond ? $$2256$ : 0;
     $spec$select299 = $or$cond ? $$0228 : $11;
     $$2 = $spec$select299;$$2234 = $$1233;$$2239 = $$1238;$$5 = $spec$select298;$$6268 = $spec$select281;$$pre$phiZ2D = $12;
    }
    else if ((label|0) == 91) {
     label = 0;
     $333 = $spec$select ^ 8192;
     _pad_380($0,32,$$1260,$$0240313371,$333);
     $334 = ($$1260|0)>($$0240313371|0);
     $335 = $334 ? $$1260 : $$0240313371;
     $$0243$ph$be = $335;
     break;
    }
    $338 = $$2;
    $339 = (($$pre$phiZ2D) - ($338))|0;
    $340 = ($$5|0)<($339|0);
    $spec$select284 = $340 ? $339 : $$5;
    $341 = (($spec$select284) + ($$2234))|0;
    $342 = ($$1260|0)<($341|0);
    $$2261 = $342 ? $341 : $$1260;
    _pad_380($0,32,$$2261,$341,$$6268);
    _out_374($0,$$2239,$$2234);
    $343 = $$6268 ^ 65536;
    _pad_380($0,48,$$2261,$341,$343);
    _pad_380($0,48,$spec$select284,$339,0);
    _out_374($0,$$2,$339);
    $344 = $$6268 ^ 8192;
    _pad_380($0,32,$$2261,$341,$344);
    $$0243$ph$be = $$2261;
   }
  } while(0);
  $$0243$ph = $$0243$ph$be;$$0247$ph = $$1248;$$0269$ph = $$3272;
 }
 L125: do {
  if ((label|0) == 94) {
   $345 = ($0|0)==(0|0);
   if ($345) {
    $346 = ($$0269$ph|0)==(0);
    if ($346) {
     $$0 = 0;
    } else {
     $$2242320 = 1;
     while(1) {
      $347 = (($4) + ($$2242320<<2)|0);
      $348 = HEAP32[$347>>2]|0;
      $349 = ($348|0)==(0);
      if ($349) {
       break;
      }
      $350 = (($3) + ($$2242320<<3)|0);
      _pop_arg_377($350,$348,$2);
      $351 = (($$2242320) + 1)|0;
      $352 = ($351>>>0)<(10);
      if ($352) {
       $$2242320 = $351;
      } else {
       $$0 = 1;
       break L125;
      }
     }
     $$3317 = $$2242320;
     while(1) {
      $355 = (($4) + ($$3317<<2)|0);
      $356 = HEAP32[$355>>2]|0;
      $357 = ($356|0)==(0);
      $354 = (($$3317) + 1)|0;
      if (!($357)) {
       $$0 = -1;
       break L125;
      }
      $353 = ($354>>>0)<(10);
      if ($353) {
       $$3317 = $354;
      } else {
       $$0 = 1;
       break;
      }
     }
    }
   } else {
    $$0 = $$1248;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___lockfile($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 1;
}
function ___unlockfile($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _out_374($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3 & 32;
 $5 = ($4|0)==(0);
 if ($5) {
  (___fwritex($1,$2,$0)|0);
 }
 return;
}
function _getint_375($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$04 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (_isdigit($3)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$0$lcssa = 0;
 } else {
  $$04 = 0;
  while(1) {
   $6 = ($$04*10)|0;
   $7 = HEAP32[$0>>2]|0;
   $8 = HEAP8[$7>>0]|0;
   $9 = $8 << 24 >> 24;
   $10 = (($6) + -48)|0;
   $11 = (($10) + ($9))|0;
   $12 = ((($7)) + 1|0);
   HEAP32[$0>>2] = $12;
   $13 = HEAP8[$12>>0]|0;
   $14 = $13 << 24 >> 24;
   $15 = (_isdigit($14)|0);
   $16 = ($15|0)==(0);
   if ($16) {
    $$0$lcssa = $11;
    break;
   } else {
    $$04 = $11;
   }
  }
 }
 return ($$0$lcssa|0);
}
function _pop_arg_377($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$mask = 0, $$mask31 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0;
 var $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0, $arglist_current26 = 0, $arglist_current5 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0, $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next6 = 0, $arglist_next9 = 0, $expanded = 0, $expanded28 = 0, $expanded30 = 0, $expanded31 = 0;
 var $expanded32 = 0, $expanded34 = 0, $expanded35 = 0, $expanded37 = 0, $expanded38 = 0, $expanded39 = 0, $expanded41 = 0, $expanded42 = 0, $expanded44 = 0, $expanded45 = 0, $expanded46 = 0, $expanded48 = 0, $expanded49 = 0, $expanded51 = 0, $expanded52 = 0, $expanded53 = 0, $expanded55 = 0, $expanded56 = 0, $expanded58 = 0, $expanded59 = 0;
 var $expanded60 = 0, $expanded62 = 0, $expanded63 = 0, $expanded65 = 0, $expanded66 = 0, $expanded67 = 0, $expanded69 = 0, $expanded70 = 0, $expanded72 = 0, $expanded73 = 0, $expanded74 = 0, $expanded76 = 0, $expanded77 = 0, $expanded79 = 0, $expanded80 = 0, $expanded81 = 0, $expanded83 = 0, $expanded84 = 0, $expanded86 = 0, $expanded87 = 0;
 var $expanded88 = 0, $expanded90 = 0, $expanded91 = 0, $expanded93 = 0, $expanded94 = 0, $expanded95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(20);
 L1: do {
  if (!($3)) {
   do {
    switch ($1|0) {
    case 9:  {
     $arglist_current = HEAP32[$2>>2]|0;
     $4 = $arglist_current;
     $5 = ((0) + 4|0);
     $expanded28 = $5;
     $expanded = (($expanded28) - 1)|0;
     $6 = (($4) + ($expanded))|0;
     $7 = ((0) + 4|0);
     $expanded32 = $7;
     $expanded31 = (($expanded32) - 1)|0;
     $expanded30 = $expanded31 ^ -1;
     $8 = $6 & $expanded30;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $arglist_next = ((($9)) + 4|0);
     HEAP32[$2>>2] = $arglist_next;
     HEAP32[$0>>2] = $10;
     break L1;
     break;
    }
    case 10:  {
     $arglist_current2 = HEAP32[$2>>2]|0;
     $11 = $arglist_current2;
     $12 = ((0) + 4|0);
     $expanded35 = $12;
     $expanded34 = (($expanded35) - 1)|0;
     $13 = (($11) + ($expanded34))|0;
     $14 = ((0) + 4|0);
     $expanded39 = $14;
     $expanded38 = (($expanded39) - 1)|0;
     $expanded37 = $expanded38 ^ -1;
     $15 = $13 & $expanded37;
     $16 = $15;
     $17 = HEAP32[$16>>2]|0;
     $arglist_next3 = ((($16)) + 4|0);
     HEAP32[$2>>2] = $arglist_next3;
     $18 = ($17|0)<(0);
     $19 = $18 << 31 >> 31;
     $20 = $0;
     $21 = $20;
     HEAP32[$21>>2] = $17;
     $22 = (($20) + 4)|0;
     $23 = $22;
     HEAP32[$23>>2] = $19;
     break L1;
     break;
    }
    case 11:  {
     $arglist_current5 = HEAP32[$2>>2]|0;
     $24 = $arglist_current5;
     $25 = ((0) + 4|0);
     $expanded42 = $25;
     $expanded41 = (($expanded42) - 1)|0;
     $26 = (($24) + ($expanded41))|0;
     $27 = ((0) + 4|0);
     $expanded46 = $27;
     $expanded45 = (($expanded46) - 1)|0;
     $expanded44 = $expanded45 ^ -1;
     $28 = $26 & $expanded44;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $arglist_next6 = ((($29)) + 4|0);
     HEAP32[$2>>2] = $arglist_next6;
     $31 = $0;
     $32 = $31;
     HEAP32[$32>>2] = $30;
     $33 = (($31) + 4)|0;
     $34 = $33;
     HEAP32[$34>>2] = 0;
     break L1;
     break;
    }
    case 12:  {
     $arglist_current8 = HEAP32[$2>>2]|0;
     $35 = $arglist_current8;
     $36 = ((0) + 8|0);
     $expanded49 = $36;
     $expanded48 = (($expanded49) - 1)|0;
     $37 = (($35) + ($expanded48))|0;
     $38 = ((0) + 8|0);
     $expanded53 = $38;
     $expanded52 = (($expanded53) - 1)|0;
     $expanded51 = $expanded52 ^ -1;
     $39 = $37 & $expanded51;
     $40 = $39;
     $41 = $40;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = (($41) + 4)|0;
     $45 = $44;
     $46 = HEAP32[$45>>2]|0;
     $arglist_next9 = ((($40)) + 8|0);
     HEAP32[$2>>2] = $arglist_next9;
     $47 = $0;
     $48 = $47;
     HEAP32[$48>>2] = $43;
     $49 = (($47) + 4)|0;
     $50 = $49;
     HEAP32[$50>>2] = $46;
     break L1;
     break;
    }
    case 13:  {
     $arglist_current11 = HEAP32[$2>>2]|0;
     $51 = $arglist_current11;
     $52 = ((0) + 4|0);
     $expanded56 = $52;
     $expanded55 = (($expanded56) - 1)|0;
     $53 = (($51) + ($expanded55))|0;
     $54 = ((0) + 4|0);
     $expanded60 = $54;
     $expanded59 = (($expanded60) - 1)|0;
     $expanded58 = $expanded59 ^ -1;
     $55 = $53 & $expanded58;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $arglist_next12 = ((($56)) + 4|0);
     HEAP32[$2>>2] = $arglist_next12;
     $58 = $57&65535;
     $59 = $58 << 16 >> 16;
     $60 = ($59|0)<(0);
     $61 = $60 << 31 >> 31;
     $62 = $0;
     $63 = $62;
     HEAP32[$63>>2] = $59;
     $64 = (($62) + 4)|0;
     $65 = $64;
     HEAP32[$65>>2] = $61;
     break L1;
     break;
    }
    case 14:  {
     $arglist_current14 = HEAP32[$2>>2]|0;
     $66 = $arglist_current14;
     $67 = ((0) + 4|0);
     $expanded63 = $67;
     $expanded62 = (($expanded63) - 1)|0;
     $68 = (($66) + ($expanded62))|0;
     $69 = ((0) + 4|0);
     $expanded67 = $69;
     $expanded66 = (($expanded67) - 1)|0;
     $expanded65 = $expanded66 ^ -1;
     $70 = $68 & $expanded65;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $arglist_next15 = ((($71)) + 4|0);
     HEAP32[$2>>2] = $arglist_next15;
     $$mask31 = $72 & 65535;
     $73 = $0;
     $74 = $73;
     HEAP32[$74>>2] = $$mask31;
     $75 = (($73) + 4)|0;
     $76 = $75;
     HEAP32[$76>>2] = 0;
     break L1;
     break;
    }
    case 15:  {
     $arglist_current17 = HEAP32[$2>>2]|0;
     $77 = $arglist_current17;
     $78 = ((0) + 4|0);
     $expanded70 = $78;
     $expanded69 = (($expanded70) - 1)|0;
     $79 = (($77) + ($expanded69))|0;
     $80 = ((0) + 4|0);
     $expanded74 = $80;
     $expanded73 = (($expanded74) - 1)|0;
     $expanded72 = $expanded73 ^ -1;
     $81 = $79 & $expanded72;
     $82 = $81;
     $83 = HEAP32[$82>>2]|0;
     $arglist_next18 = ((($82)) + 4|0);
     HEAP32[$2>>2] = $arglist_next18;
     $84 = $83&255;
     $85 = $84 << 24 >> 24;
     $86 = ($85|0)<(0);
     $87 = $86 << 31 >> 31;
     $88 = $0;
     $89 = $88;
     HEAP32[$89>>2] = $85;
     $90 = (($88) + 4)|0;
     $91 = $90;
     HEAP32[$91>>2] = $87;
     break L1;
     break;
    }
    case 16:  {
     $arglist_current20 = HEAP32[$2>>2]|0;
     $92 = $arglist_current20;
     $93 = ((0) + 4|0);
     $expanded77 = $93;
     $expanded76 = (($expanded77) - 1)|0;
     $94 = (($92) + ($expanded76))|0;
     $95 = ((0) + 4|0);
     $expanded81 = $95;
     $expanded80 = (($expanded81) - 1)|0;
     $expanded79 = $expanded80 ^ -1;
     $96 = $94 & $expanded79;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $arglist_next21 = ((($97)) + 4|0);
     HEAP32[$2>>2] = $arglist_next21;
     $$mask = $98 & 255;
     $99 = $0;
     $100 = $99;
     HEAP32[$100>>2] = $$mask;
     $101 = (($99) + 4)|0;
     $102 = $101;
     HEAP32[$102>>2] = 0;
     break L1;
     break;
    }
    case 17:  {
     $arglist_current23 = HEAP32[$2>>2]|0;
     $103 = $arglist_current23;
     $104 = ((0) + 8|0);
     $expanded84 = $104;
     $expanded83 = (($expanded84) - 1)|0;
     $105 = (($103) + ($expanded83))|0;
     $106 = ((0) + 8|0);
     $expanded88 = $106;
     $expanded87 = (($expanded88) - 1)|0;
     $expanded86 = $expanded87 ^ -1;
     $107 = $105 & $expanded86;
     $108 = $107;
     $109 = +HEAPF64[$108>>3];
     $arglist_next24 = ((($108)) + 8|0);
     HEAP32[$2>>2] = $arglist_next24;
     HEAPF64[$0>>3] = $109;
     break L1;
     break;
    }
    case 18:  {
     $arglist_current26 = HEAP32[$2>>2]|0;
     $110 = $arglist_current26;
     $111 = ((0) + 8|0);
     $expanded91 = $111;
     $expanded90 = (($expanded91) - 1)|0;
     $112 = (($110) + ($expanded90))|0;
     $113 = ((0) + 8|0);
     $expanded95 = $113;
     $expanded94 = (($expanded95) - 1)|0;
     $expanded93 = $expanded94 ^ -1;
     $114 = $112 & $expanded93;
     $115 = $114;
     $116 = +HEAPF64[$115>>3];
     $arglist_next27 = ((($115)) + 8|0);
     HEAP32[$2>>2] = $arglist_next27;
     HEAPF64[$0>>3] = $116;
     break L1;
     break;
    }
    default: {
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 return;
}
function _fmt_x($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$05$lcssa = 0, $$056 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0);
 $5 = ($1|0)==(0);
 $6 = $4 & $5;
 if ($6) {
  $$05$lcssa = $2;
 } else {
  $$056 = $2;$15 = $1;$8 = $0;
  while(1) {
   $7 = $8 & 15;
   $9 = ((gb + (14528) | 0) + ($7)|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10&255;
   $12 = $11 | $3;
   $13 = $12&255;
   $14 = ((($$056)) + -1|0);
   HEAP8[$14>>0] = $13;
   $16 = (_bitshift64Lshr(($8|0),($15|0),4)|0);
   $17 = (getTempRet0() | 0);
   $18 = ($16|0)==(0);
   $19 = ($17|0)==(0);
   $20 = $18 & $19;
   if ($20) {
    $$05$lcssa = $14;
    break;
   } else {
    $$056 = $14;$15 = $17;$8 = $16;
   }
  }
 }
 return ($$05$lcssa|0);
}
function _fmt_o($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$06 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0);
 $4 = ($1|0)==(0);
 $5 = $3 & $4;
 if ($5) {
  $$0$lcssa = $2;
 } else {
  $$06 = $2;$11 = $1;$7 = $0;
  while(1) {
   $6 = $7&255;
   $8 = $6 & 7;
   $9 = $8 | 48;
   $10 = ((($$06)) + -1|0);
   HEAP8[$10>>0] = $9;
   $12 = (_bitshift64Lshr(($7|0),($11|0),3)|0);
   $13 = (getTempRet0() | 0);
   $14 = ($12|0)==(0);
   $15 = ($13|0)==(0);
   $16 = $14 & $15;
   if ($16) {
    $$0$lcssa = $10;
    break;
   } else {
    $$06 = $10;$11 = $13;$7 = $12;
   }
  }
 }
 return ($$0$lcssa|0);
}
function _fmt_u($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$010$lcssa$off0 = 0, $$012 = 0, $$09$lcssa = 0, $$0914 = 0, $$1$lcssa = 0, $$111 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(0);
 $4 = ($0>>>0)>(4294967295);
 $5 = ($1|0)==(0);
 $6 = $5 & $4;
 $7 = $3 | $6;
 if ($7) {
  $$0914 = $2;$8 = $0;$9 = $1;
  while(1) {
   $10 = (___udivdi3(($8|0),($9|0),10,0)|0);
   $11 = (getTempRet0() | 0);
   $12 = (___muldi3(($10|0),($11|0),10,0)|0);
   $13 = (getTempRet0() | 0);
   $14 = (_i64Subtract(($8|0),($9|0),($12|0),($13|0))|0);
   $15 = (getTempRet0() | 0);
   $16 = $14&255;
   $17 = $16 | 48;
   $18 = ((($$0914)) + -1|0);
   HEAP8[$18>>0] = $17;
   $19 = ($9>>>0)>(9);
   $20 = ($8>>>0)>(4294967295);
   $21 = ($9|0)==(9);
   $22 = $21 & $20;
   $23 = $19 | $22;
   if ($23) {
    $$0914 = $18;$8 = $10;$9 = $11;
   } else {
    break;
   }
  }
  $$010$lcssa$off0 = $10;$$09$lcssa = $18;
 } else {
  $$010$lcssa$off0 = $0;$$09$lcssa = $2;
 }
 $24 = ($$010$lcssa$off0|0)==(0);
 if ($24) {
  $$1$lcssa = $$09$lcssa;
 } else {
  $$012 = $$010$lcssa$off0;$$111 = $$09$lcssa;
  while(1) {
   $25 = (($$012>>>0) / 10)&-1;
   $26 = ($25*10)|0;
   $27 = (($$012) - ($26))|0;
   $28 = $27 | 48;
   $29 = $28&255;
   $30 = ((($$111)) + -1|0);
   HEAP8[$30>>0] = $29;
   $31 = ($$012>>>0)<(10);
   if ($31) {
    $$1$lcssa = $30;
    break;
   } else {
    $$012 = $25;$$111 = $30;
   }
  }
 }
 return ($$1$lcssa|0);
}
function _memchr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$035$lcssa = 0, $$035$lcssa65 = 0, $$03555 = 0, $$036$lcssa = 0, $$036$lcssa64 = 0, $$03654 = 0, $$046 = 0, $$137$lcssa = 0, $$137$lcssa66 = 0, $$13745 = 0, $$140 = 0, $$23839 = 0, $$in = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond53 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1 & 255;
 $4 = $0;
 $5 = $4 & 3;
 $6 = ($5|0)!=(0);
 $7 = ($2|0)!=(0);
 $or$cond53 = $7 & $6;
 L1: do {
  if ($or$cond53) {
   $8 = $1&255;
   $$03555 = $0;$$03654 = $2;
   while(1) {
    $9 = HEAP8[$$03555>>0]|0;
    $10 = ($9<<24>>24)==($8<<24>>24);
    if ($10) {
     $$035$lcssa65 = $$03555;$$036$lcssa64 = $$03654;
     label = 6;
     break L1;
    }
    $11 = ((($$03555)) + 1|0);
    $12 = (($$03654) + -1)|0;
    $13 = $11;
    $14 = $13 & 3;
    $15 = ($14|0)!=(0);
    $16 = ($12|0)!=(0);
    $or$cond = $16 & $15;
    if ($or$cond) {
     $$03555 = $11;$$03654 = $12;
    } else {
     $$035$lcssa = $11;$$036$lcssa = $12;$$lcssa = $16;
     label = 5;
     break;
    }
   }
  } else {
   $$035$lcssa = $0;$$036$lcssa = $2;$$lcssa = $7;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$035$lcssa65 = $$035$lcssa;$$036$lcssa64 = $$036$lcssa;
   label = 6;
  } else {
   label = 16;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $17 = HEAP8[$$035$lcssa65>>0]|0;
   $18 = $1&255;
   $19 = ($17<<24>>24)==($18<<24>>24);
   if ($19) {
    $38 = ($$036$lcssa64|0)==(0);
    if ($38) {
     label = 16;
     break;
    } else {
     $39 = $$035$lcssa65;
     break;
    }
   }
   $20 = Math_imul($3, 16843009)|0;
   $21 = ($$036$lcssa64>>>0)>(3);
   L13: do {
    if ($21) {
     $$046 = $$035$lcssa65;$$13745 = $$036$lcssa64;
     while(1) {
      $22 = HEAP32[$$046>>2]|0;
      $23 = $22 ^ $20;
      $24 = (($23) + -16843009)|0;
      $25 = $23 & -2139062144;
      $26 = $25 ^ -2139062144;
      $27 = $26 & $24;
      $28 = ($27|0)==(0);
      if (!($28)) {
       $$137$lcssa66 = $$13745;$$in = $$046;
       break L13;
      }
      $29 = ((($$046)) + 4|0);
      $30 = (($$13745) + -4)|0;
      $31 = ($30>>>0)>(3);
      if ($31) {
       $$046 = $29;$$13745 = $30;
      } else {
       $$0$lcssa = $29;$$137$lcssa = $30;
       label = 11;
       break;
      }
     }
    } else {
     $$0$lcssa = $$035$lcssa65;$$137$lcssa = $$036$lcssa64;
     label = 11;
    }
   } while(0);
   if ((label|0) == 11) {
    $32 = ($$137$lcssa|0)==(0);
    if ($32) {
     label = 16;
     break;
    } else {
     $$137$lcssa66 = $$137$lcssa;$$in = $$0$lcssa;
    }
   }
   $$140 = $$in;$$23839 = $$137$lcssa66;
   while(1) {
    $33 = HEAP8[$$140>>0]|0;
    $34 = ($33<<24>>24)==($18<<24>>24);
    if ($34) {
     $39 = $$140;
     break L8;
    }
    $35 = ((($$140)) + 1|0);
    $36 = (($$23839) + -1)|0;
    $37 = ($36|0)==(0);
    if ($37) {
     label = 16;
     break;
    } else {
     $$140 = $35;$$23839 = $36;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $39 = 0;
 }
 return ($39|0);
}
function _pad_380($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $5 = sp;
 $6 = $4 & 73728;
 $7 = ($6|0)==(0);
 $8 = ($2|0)>($3|0);
 $or$cond = $8 & $7;
 if ($or$cond) {
  $9 = (($2) - ($3))|0;
  $10 = $1 << 24 >> 24;
  $11 = ($9>>>0)<(256);
  $12 = $11 ? $9 : 256;
  (_memset(($5|0),($10|0),($12|0))|0);
  $13 = ($9>>>0)>(255);
  if ($13) {
   $14 = (($2) - ($3))|0;
   $$011 = $9;
   while(1) {
    _out_374($0,$5,256);
    $15 = (($$011) + -256)|0;
    $16 = ($15>>>0)>(255);
    if ($16) {
     $$011 = $15;
    } else {
     break;
    }
   }
   $17 = $14 & 255;
   $$0$lcssa = $17;
  } else {
   $$0$lcssa = $9;
  }
  _out_374($0,$5,$$0$lcssa);
 }
 STACKTOP = sp;return;
}
function _wctomb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (_wcrtomb($0,$1,0)|0);
  $$0 = $3;
 }
 return ($$0|0);
}
function _fmt_fp($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = +$1;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$0 = 0, $$0463$lcssa = 0, $$0463588 = 0, $$0464599 = 0, $$0471 = 0.0, $$0479 = 0, $$0487657 = 0, $$0488 = 0, $$0488669 = 0, $$0488671 = 0, $$0497670 = 0, $$0498 = 0, $$0511586 = 0.0, $$0512 = 0, $$0513 = 0, $$0516652 = 0, $$0522 = 0, $$0523 = 0, $$0525 = 0;
 var $$0527 = 0, $$0529 = 0, $$0529$in646 = 0, $$0532651 = 0, $$1465 = 0, $$1467 = 0.0, $$1469 = 0.0, $$1472 = 0.0, $$1480 = 0, $$1482$lcssa = 0, $$1482683 = 0, $$1489656 = 0, $$1499 = 0, $$1510587 = 0, $$1514$lcssa = 0, $$1514614 = 0, $$1517 = 0, $$1526 = 0, $$1528 = 0, $$1530621 = 0;
 var $$1533$lcssa = 0, $$1533645 = 0, $$1604 = 0, $$2 = 0, $$2473 = 0.0, $$2476 = 0, $$2483 = 0, $$2490$lcssa = 0, $$2490638 = 0, $$2500$lcssa = 0, $$2500682 = 0, $$2515 = 0, $$2518634 = 0, $$2531 = 0, $$2534633 = 0, $$3 = 0.0, $$3477 = 0, $$3484$lcssa = 0, $$3484663 = 0, $$3501$lcssa = 0;
 var $$3501676 = 0, $$3535620 = 0, $$4 = 0.0, $$4478$lcssa = 0, $$4478594 = 0, $$4492 = 0, $$4502$lcssa = 0, $$4502662 = 0, $$4520 = 0, $$5$lcssa = 0, $$5486$lcssa = 0, $$5486639 = 0, $$5493603 = 0, $$5503 = 0, $$5521 = 0, $$560 = 0, $$5609 = 0, $$6 = 0, $$6494593 = 0, $$7495608 = 0;
 var $$8 = 0, $$8506 = 0, $$9 = 0, $$9507$lcssa = 0, $$9507625 = 0, $$lcssa583 = 0, $$lobit = 0, $$neg = 0, $$neg571 = 0, $$not = 0, $$pn = 0, $$pr = 0, $$pr564 = 0, $$pre = 0, $$pre$phi717Z2D = 0, $$pre$phi718Z2D = 0, $$pre720 = 0, $$sink757 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0.0;
 var $247 = 0.0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0.0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, $or$cond3$not = 0, $or$cond543 = 0, $or$cond546 = 0, $or$cond556 = 0, $or$cond559 = 0, $or$cond6 = 0, $scevgep711 = 0, $scevgep711712 = 0, $spec$select = 0, $spec$select539 = 0, $spec$select540 = 0, $spec$select540722 = 0, $spec$select540723 = 0;
 var $spec$select541 = 0, $spec$select544 = 0.0, $spec$select547 = 0, $spec$select548 = 0, $spec$select549 = 0, $spec$select551 = 0, $spec$select554 = 0, $spec$select557 = 0, $spec$select561 = 0.0, $spec$select562 = 0, $spec$select563 = 0, $spec$select565 = 0, $spec$select566 = 0, $spec$select567 = 0.0, $spec$select568 = 0.0, $spec$select569 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(560|0);
 $6 = sp + 32|0;
 $7 = sp + 536|0;
 $8 = sp;
 $9 = $8;
 $10 = sp + 540|0;
 HEAP32[$7>>2] = 0;
 $11 = ((($10)) + 12|0);
 $12 = (___DOUBLE_BITS_381($1)|0);
 $13 = (getTempRet0() | 0);
 $14 = ($13|0)<(0);
 if ($14) {
  $15 = - $1;
  $16 = (___DOUBLE_BITS_381($15)|0);
  $17 = (getTempRet0() | 0);
  $$0471 = $15;$$0522 = 1;$$0523 = (gb + (166582) | 0);$25 = $17;$412 = $16;
 } else {
  $18 = $4 & 2048;
  $19 = ($18|0)==(0);
  $20 = $4 & 1;
  $21 = ($20|0)==(0);
  $$ = $21 ? ((((gb + (166582) | 0)) + 1|0)) : ((((gb + (166582) | 0)) + 6|0));
  $spec$select565 = $19 ? $$ : ((((gb + (166582) | 0)) + 3|0));
  $22 = $4 & 2049;
  $23 = ($22|0)!=(0);
  $spec$select566 = $23&1;
  $$0471 = $1;$$0522 = $spec$select566;$$0523 = $spec$select565;$25 = $13;$412 = $12;
 }
 $24 = $25 & 2146435072;
 $26 = (0)==(0);
 $27 = ($24|0)==(2146435072);
 $28 = $26 & $27;
 do {
  if ($28) {
   $29 = $5 & 32;
   $30 = ($29|0)!=(0);
   $31 = $30 ? (gb + (166601) | 0) : (gb + (166605) | 0);
   $32 = ($$0471 != $$0471) | (0.0 != 0.0);
   $33 = $30 ? (gb + (167252) | 0) : (gb + (166609) | 0);
   $$0512 = $32 ? $33 : $31;
   $34 = (($$0522) + 3)|0;
   $35 = $4 & -65537;
   _pad_380($0,32,$2,$34,$35);
   _out_374($0,$$0523,$$0522);
   _out_374($0,$$0512,3);
   $36 = $4 ^ 8192;
   _pad_380($0,32,$2,$34,$36);
   $$sink757 = $34;
  } else {
   $37 = (+_frexpl($$0471,$7));
   $38 = $37 * 2.0;
   $39 = $38 != 0.0;
   if ($39) {
    $40 = HEAP32[$7>>2]|0;
    $41 = (($40) + -1)|0;
    HEAP32[$7>>2] = $41;
   }
   $42 = $5 | 32;
   $43 = ($42|0)==(97);
   if ($43) {
    $44 = $5 & 32;
    $45 = ($44|0)==(0);
    $46 = ((($$0523)) + 9|0);
    $spec$select = $45 ? $$0523 : $46;
    $47 = $$0522 | 2;
    $48 = ($3>>>0)>(11);
    $49 = (12 - ($3))|0;
    $50 = ($49|0)==(0);
    $51 = $48 | $50;
    do {
     if ($51) {
      $$1472 = $38;
     } else {
      $$0511586 = 8.0;$$1510587 = $49;
      while(1) {
       $52 = (($$1510587) + -1)|0;
       $53 = $$0511586 * 16.0;
       $54 = ($52|0)==(0);
       if ($54) {
        break;
       } else {
        $$0511586 = $53;$$1510587 = $52;
       }
      }
      $55 = HEAP8[$spec$select>>0]|0;
      $56 = ($55<<24>>24)==(45);
      if ($56) {
       $57 = - $38;
       $58 = $57 - $53;
       $59 = $53 + $58;
       $60 = - $59;
       $$1472 = $60;
       break;
      } else {
       $61 = $38 + $53;
       $62 = $61 - $53;
       $$1472 = $62;
       break;
      }
     }
    } while(0);
    $63 = HEAP32[$7>>2]|0;
    $64 = ($63|0)<(0);
    $65 = (0 - ($63))|0;
    $66 = $64 ? $65 : $63;
    $67 = ($66|0)<(0);
    $68 = $67 << 31 >> 31;
    $69 = (_fmt_u($66,$68,$11)|0);
    $70 = ($69|0)==($11|0);
    if ($70) {
     $71 = ((($10)) + 11|0);
     HEAP8[$71>>0] = 48;
     $$0513 = $71;
    } else {
     $$0513 = $69;
    }
    $72 = $63 >> 31;
    $73 = $72 & 2;
    $74 = (($73) + 43)|0;
    $75 = $74&255;
    $76 = ((($$0513)) + -1|0);
    HEAP8[$76>>0] = $75;
    $77 = (($5) + 15)|0;
    $78 = $77&255;
    $79 = ((($$0513)) + -2|0);
    HEAP8[$79>>0] = $78;
    $80 = ($3|0)<(1);
    $81 = $4 & 8;
    $82 = ($81|0)==(0);
    $$0525 = $8;$$2473 = $$1472;
    while(1) {
     $83 = (~~(($$2473)));
     $84 = ((gb + (14528) | 0) + ($83)|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     $87 = $44 | $86;
     $88 = $87&255;
     $89 = ((($$0525)) + 1|0);
     HEAP8[$$0525>>0] = $88;
     $90 = (+($83|0));
     $91 = $$2473 - $90;
     $92 = $91 * 16.0;
     $93 = $89;
     $94 = (($93) - ($9))|0;
     $95 = ($94|0)==(1);
     if ($95) {
      $96 = $92 == 0.0;
      $or$cond3$not = $80 & $96;
      $or$cond = $82 & $or$cond3$not;
      if ($or$cond) {
       $$1526 = $89;
      } else {
       $97 = ((($$0525)) + 2|0);
       HEAP8[$89>>0] = 46;
       $$1526 = $97;
      }
     } else {
      $$1526 = $89;
     }
     $98 = $92 != 0.0;
     if ($98) {
      $$0525 = $$1526;$$2473 = $92;
     } else {
      break;
     }
    }
    $99 = ($3|0)==(0);
    $$pre720 = $$1526;
    if ($99) {
     label = 25;
    } else {
     $100 = (-2 - ($9))|0;
     $101 = (($100) + ($$pre720))|0;
     $102 = ($101|0)<($3|0);
     if ($102) {
      $103 = $11;
      $104 = $79;
      $105 = (($3) + 2)|0;
      $106 = (($105) + ($103))|0;
      $107 = (($106) - ($104))|0;
      $$0527 = $107;$$pre$phi717Z2D = $103;$$pre$phi718Z2D = $104;
     } else {
      label = 25;
     }
    }
    if ((label|0) == 25) {
     $108 = $11;
     $109 = $79;
     $110 = (($108) - ($9))|0;
     $111 = (($110) - ($109))|0;
     $112 = (($111) + ($$pre720))|0;
     $$0527 = $112;$$pre$phi717Z2D = $108;$$pre$phi718Z2D = $109;
    }
    $113 = (($$0527) + ($47))|0;
    _pad_380($0,32,$2,$113,$4);
    _out_374($0,$spec$select,$47);
    $114 = $4 ^ 65536;
    _pad_380($0,48,$2,$113,$114);
    $115 = (($$pre720) - ($9))|0;
    _out_374($0,$8,$115);
    $116 = (($$pre$phi717Z2D) - ($$pre$phi718Z2D))|0;
    $117 = (($115) + ($116))|0;
    $118 = (($$0527) - ($117))|0;
    _pad_380($0,48,$118,0,0);
    _out_374($0,$79,$116);
    $119 = $4 ^ 8192;
    _pad_380($0,32,$2,$113,$119);
    $$sink757 = $113;
    break;
   }
   $120 = ($3|0)<(0);
   $spec$select539 = $120 ? 6 : $3;
   if ($39) {
    $121 = $38 * 268435456.0;
    $122 = HEAP32[$7>>2]|0;
    $123 = (($122) + -28)|0;
    HEAP32[$7>>2] = $123;
    $$3 = $121;$$pr = $123;
   } else {
    $$pre = HEAP32[$7>>2]|0;
    $$3 = $38;$$pr = $$pre;
   }
   $124 = ($$pr|0)<(0);
   $125 = ((($6)) + 288|0);
   $$0498 = $124 ? $6 : $125;
   $$1499 = $$0498;$$4 = $$3;
   while(1) {
    $126 = (~~(($$4))>>>0);
    HEAP32[$$1499>>2] = $126;
    $127 = ((($$1499)) + 4|0);
    $128 = (+($126>>>0));
    $129 = $$4 - $128;
    $130 = $129 * 1.0E+9;
    $131 = $130 != 0.0;
    if ($131) {
     $$1499 = $127;$$4 = $130;
    } else {
     break;
    }
   }
   $132 = $$0498;
   $133 = ($$pr|0)>(0);
   if ($133) {
    $$1482683 = $$0498;$$2500682 = $127;$135 = $$pr;
    while(1) {
     $134 = ($135|0)<(29);
     $136 = $134 ? $135 : 29;
     $$0488669 = ((($$2500682)) + -4|0);
     $137 = ($$0488669>>>0)<($$1482683>>>0);
     if ($137) {
      $$2483 = $$1482683;
     } else {
      $$0488671 = $$0488669;$$0497670 = 0;
      while(1) {
       $138 = HEAP32[$$0488671>>2]|0;
       $139 = (_bitshift64Shl(($138|0),0,($136|0))|0);
       $140 = (getTempRet0() | 0);
       $141 = (_i64Add(($139|0),($140|0),($$0497670|0),0)|0);
       $142 = (getTempRet0() | 0);
       $143 = (___udivdi3(($141|0),($142|0),1000000000,0)|0);
       $144 = (getTempRet0() | 0);
       $145 = (___muldi3(($143|0),($144|0),1000000000,0)|0);
       $146 = (getTempRet0() | 0);
       $147 = (_i64Subtract(($141|0),($142|0),($145|0),($146|0))|0);
       $148 = (getTempRet0() | 0);
       HEAP32[$$0488671>>2] = $147;
       $$0488 = ((($$0488671)) + -4|0);
       $149 = ($$0488>>>0)<($$1482683>>>0);
       if ($149) {
        break;
       } else {
        $$0488671 = $$0488;$$0497670 = $143;
       }
      }
      $150 = ($143|0)==(0);
      if ($150) {
       $$2483 = $$1482683;
      } else {
       $151 = ((($$1482683)) + -4|0);
       HEAP32[$151>>2] = $143;
       $$2483 = $151;
      }
     }
     $152 = ($$2500682>>>0)>($$2483>>>0);
     L57: do {
      if ($152) {
       $$3501676 = $$2500682;
       while(1) {
        $154 = ((($$3501676)) + -4|0);
        $155 = HEAP32[$154>>2]|0;
        $156 = ($155|0)==(0);
        if (!($156)) {
         $$3501$lcssa = $$3501676;
         break L57;
        }
        $153 = ($154>>>0)>($$2483>>>0);
        if ($153) {
         $$3501676 = $154;
        } else {
         $$3501$lcssa = $154;
         break;
        }
       }
      } else {
       $$3501$lcssa = $$2500682;
      }
     } while(0);
     $157 = HEAP32[$7>>2]|0;
     $158 = (($157) - ($136))|0;
     HEAP32[$7>>2] = $158;
     $159 = ($158|0)>(0);
     if ($159) {
      $$1482683 = $$2483;$$2500682 = $$3501$lcssa;$135 = $158;
     } else {
      $$1482$lcssa = $$2483;$$2500$lcssa = $$3501$lcssa;$$pr564 = $158;
      break;
     }
    }
   } else {
    $$1482$lcssa = $$0498;$$2500$lcssa = $127;$$pr564 = $$pr;
   }
   $160 = ($$pr564|0)<(0);
   if ($160) {
    $161 = (($spec$select539) + 25)|0;
    $162 = (($161|0) / 9)&-1;
    $163 = (($162) + 1)|0;
    $164 = ($42|0)==(102);
    $$3484663 = $$1482$lcssa;$$4502662 = $$2500$lcssa;$166 = $$pr564;
    while(1) {
     $165 = (0 - ($166))|0;
     $167 = ($165|0)<(9);
     $168 = $167 ? $165 : 9;
     $169 = ($$3484663>>>0)<($$4502662>>>0);
     if ($169) {
      $173 = 1 << $168;
      $174 = (($173) + -1)|0;
      $175 = 1000000000 >>> $168;
      $$0487657 = 0;$$1489656 = $$3484663;
      while(1) {
       $176 = HEAP32[$$1489656>>2]|0;
       $177 = $176 & $174;
       $178 = $176 >>> $168;
       $179 = (($178) + ($$0487657))|0;
       HEAP32[$$1489656>>2] = $179;
       $180 = Math_imul($177, $175)|0;
       $181 = ((($$1489656)) + 4|0);
       $182 = ($181>>>0)<($$4502662>>>0);
       if ($182) {
        $$0487657 = $180;$$1489656 = $181;
       } else {
        break;
       }
      }
      $183 = HEAP32[$$3484663>>2]|0;
      $184 = ($183|0)==(0);
      $185 = ((($$3484663)) + 4|0);
      $spec$select540 = $184 ? $185 : $$3484663;
      $186 = ($180|0)==(0);
      if ($186) {
       $$5503 = $$4502662;$spec$select540723 = $spec$select540;
      } else {
       $187 = ((($$4502662)) + 4|0);
       HEAP32[$$4502662>>2] = $180;
       $$5503 = $187;$spec$select540723 = $spec$select540;
      }
     } else {
      $170 = HEAP32[$$3484663>>2]|0;
      $171 = ($170|0)==(0);
      $172 = ((($$3484663)) + 4|0);
      $spec$select540722 = $171 ? $172 : $$3484663;
      $$5503 = $$4502662;$spec$select540723 = $spec$select540722;
     }
     $188 = $164 ? $$0498 : $spec$select540723;
     $189 = $$5503;
     $190 = $188;
     $191 = (($189) - ($190))|0;
     $192 = $191 >> 2;
     $193 = ($192|0)>($163|0);
     $194 = (($188) + ($163<<2)|0);
     $spec$select541 = $193 ? $194 : $$5503;
     $195 = HEAP32[$7>>2]|0;
     $196 = (($195) + ($168))|0;
     HEAP32[$7>>2] = $196;
     $197 = ($196|0)<(0);
     if ($197) {
      $$3484663 = $spec$select540723;$$4502662 = $spec$select541;$166 = $196;
     } else {
      $$3484$lcssa = $spec$select540723;$$4502$lcssa = $spec$select541;
      break;
     }
    }
   } else {
    $$3484$lcssa = $$1482$lcssa;$$4502$lcssa = $$2500$lcssa;
   }
   $198 = ($$3484$lcssa>>>0)<($$4502$lcssa>>>0);
   if ($198) {
    $199 = $$3484$lcssa;
    $200 = (($132) - ($199))|0;
    $201 = $200 >> 2;
    $202 = ($201*9)|0;
    $203 = HEAP32[$$3484$lcssa>>2]|0;
    $204 = ($203>>>0)<(10);
    if ($204) {
     $$1517 = $202;
    } else {
     $$0516652 = $202;$$0532651 = 10;
     while(1) {
      $205 = ($$0532651*10)|0;
      $206 = (($$0516652) + 1)|0;
      $207 = ($203>>>0)<($205>>>0);
      if ($207) {
       $$1517 = $206;
       break;
      } else {
       $$0516652 = $206;$$0532651 = $205;
      }
     }
    }
   } else {
    $$1517 = 0;
   }
   $208 = ($42|0)==(102);
   $209 = $208 ? 0 : $$1517;
   $210 = (($spec$select539) - ($209))|0;
   $211 = ($42|0)==(103);
   $212 = ($spec$select539|0)!=(0);
   $213 = $212 & $211;
   $$neg = $213 << 31 >> 31;
   $214 = (($210) + ($$neg))|0;
   $215 = $$4502$lcssa;
   $216 = (($215) - ($132))|0;
   $217 = $216 >> 2;
   $218 = ($217*9)|0;
   $219 = (($218) + -9)|0;
   $220 = ($214|0)<($219|0);
   if ($220) {
    $221 = ((($$0498)) + 4|0);
    $222 = (($214) + 9216)|0;
    $223 = (($222|0) / 9)&-1;
    $224 = (($223) + -1024)|0;
    $225 = (($221) + ($224<<2)|0);
    $226 = ($223*9)|0;
    $227 = (($222) - ($226))|0;
    $228 = ($227|0)<(8);
    if ($228) {
     $$0529$in646 = $227;$$1533645 = 10;
     while(1) {
      $$0529 = (($$0529$in646) + 1)|0;
      $229 = ($$1533645*10)|0;
      $230 = ($$0529$in646|0)<(7);
      if ($230) {
       $$0529$in646 = $$0529;$$1533645 = $229;
      } else {
       $$1533$lcssa = $229;
       break;
      }
     }
    } else {
     $$1533$lcssa = 10;
    }
    $231 = HEAP32[$225>>2]|0;
    $232 = (($231>>>0) / ($$1533$lcssa>>>0))&-1;
    $233 = Math_imul($232, $$1533$lcssa)|0;
    $234 = (($231) - ($233))|0;
    $235 = ($234|0)==(0);
    $236 = ((($225)) + 4|0);
    $237 = ($236|0)==($$4502$lcssa|0);
    $or$cond543 = $237 & $235;
    if ($or$cond543) {
     $$4492 = $225;$$4520 = $$1517;$$8 = $$3484$lcssa;
    } else {
     $238 = $232 & 1;
     $239 = ($238|0)==(0);
     $spec$select544 = $239 ? 9007199254740992.0 : 9007199254740994.0;
     $240 = $$1533$lcssa >>> 1;
     $241 = ($234>>>0)<($240>>>0);
     $242 = ($234|0)==($240|0);
     $or$cond546 = $237 & $242;
     $spec$select561 = $or$cond546 ? 1.0 : 1.5;
     $spec$select567 = $241 ? 0.5 : $spec$select561;
     $243 = ($$0522|0)==(0);
     if ($243) {
      $$1467 = $spec$select567;$$1469 = $spec$select544;
     } else {
      $244 = HEAP8[$$0523>>0]|0;
      $245 = ($244<<24>>24)==(45);
      $246 = - $spec$select544;
      $247 = - $spec$select567;
      $spec$select568 = $245 ? $246 : $spec$select544;
      $spec$select569 = $245 ? $247 : $spec$select567;
      $$1467 = $spec$select569;$$1469 = $spec$select568;
     }
     $248 = (($231) - ($234))|0;
     HEAP32[$225>>2] = $248;
     $249 = $$1469 + $$1467;
     $250 = $249 != $$1469;
     if ($250) {
      $251 = (($248) + ($$1533$lcssa))|0;
      HEAP32[$225>>2] = $251;
      $252 = ($251>>>0)>(999999999);
      if ($252) {
       $$2490638 = $225;$$5486639 = $$3484$lcssa;
       while(1) {
        $253 = ((($$2490638)) + -4|0);
        HEAP32[$$2490638>>2] = 0;
        $254 = ($253>>>0)<($$5486639>>>0);
        if ($254) {
         $255 = ((($$5486639)) + -4|0);
         HEAP32[$255>>2] = 0;
         $$6 = $255;
        } else {
         $$6 = $$5486639;
        }
        $256 = HEAP32[$253>>2]|0;
        $257 = (($256) + 1)|0;
        HEAP32[$253>>2] = $257;
        $258 = ($257>>>0)>(999999999);
        if ($258) {
         $$2490638 = $253;$$5486639 = $$6;
        } else {
         $$2490$lcssa = $253;$$5486$lcssa = $$6;
         break;
        }
       }
      } else {
       $$2490$lcssa = $225;$$5486$lcssa = $$3484$lcssa;
      }
      $259 = $$5486$lcssa;
      $260 = (($132) - ($259))|0;
      $261 = $260 >> 2;
      $262 = ($261*9)|0;
      $263 = HEAP32[$$5486$lcssa>>2]|0;
      $264 = ($263>>>0)<(10);
      if ($264) {
       $$4492 = $$2490$lcssa;$$4520 = $262;$$8 = $$5486$lcssa;
      } else {
       $$2518634 = $262;$$2534633 = 10;
       while(1) {
        $265 = ($$2534633*10)|0;
        $266 = (($$2518634) + 1)|0;
        $267 = ($263>>>0)<($265>>>0);
        if ($267) {
         $$4492 = $$2490$lcssa;$$4520 = $266;$$8 = $$5486$lcssa;
         break;
        } else {
         $$2518634 = $266;$$2534633 = $265;
        }
       }
      }
     } else {
      $$4492 = $225;$$4520 = $$1517;$$8 = $$3484$lcssa;
     }
    }
    $268 = ((($$4492)) + 4|0);
    $269 = ($$4502$lcssa>>>0)>($268>>>0);
    $spec$select547 = $269 ? $268 : $$4502$lcssa;
    $$5521 = $$4520;$$8506 = $spec$select547;$$9 = $$8;
   } else {
    $$5521 = $$1517;$$8506 = $$4502$lcssa;$$9 = $$3484$lcssa;
   }
   $270 = (0 - ($$5521))|0;
   $271 = ($$8506>>>0)>($$9>>>0);
   L109: do {
    if ($271) {
     $$9507625 = $$8506;
     while(1) {
      $273 = ((($$9507625)) + -4|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(0);
      if (!($275)) {
       $$9507$lcssa = $$9507625;$$lcssa583 = 1;
       break L109;
      }
      $272 = ($273>>>0)>($$9>>>0);
      if ($272) {
       $$9507625 = $273;
      } else {
       $$9507$lcssa = $273;$$lcssa583 = 0;
       break;
      }
     }
    } else {
     $$9507$lcssa = $$8506;$$lcssa583 = 0;
    }
   } while(0);
   do {
    if ($211) {
     $not$ = $212 ^ 1;
     $276 = $not$&1;
     $spec$select548 = (($spec$select539) + ($276))|0;
     $277 = ($spec$select548|0)>($$5521|0);
     $278 = ($$5521|0)>(-5);
     $or$cond6 = $277 & $278;
     if ($or$cond6) {
      $279 = (($5) + -1)|0;
      $$neg571 = (($spec$select548) + -1)|0;
      $280 = (($$neg571) - ($$5521))|0;
      $$0479 = $279;$$2476 = $280;
     } else {
      $281 = (($5) + -2)|0;
      $282 = (($spec$select548) + -1)|0;
      $$0479 = $281;$$2476 = $282;
     }
     $283 = $4 & 8;
     $284 = ($283|0)==(0);
     if ($284) {
      if ($$lcssa583) {
       $285 = ((($$9507$lcssa)) + -4|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = ($286|0)==(0);
       if ($287) {
        $$2531 = 9;
       } else {
        $288 = (($286>>>0) % 10)&-1;
        $289 = ($288|0)==(0);
        if ($289) {
         $$1530621 = 0;$$3535620 = 10;
         while(1) {
          $290 = ($$3535620*10)|0;
          $291 = (($$1530621) + 1)|0;
          $292 = (($286>>>0) % ($290>>>0))&-1;
          $293 = ($292|0)==(0);
          if ($293) {
           $$1530621 = $291;$$3535620 = $290;
          } else {
           $$2531 = $291;
           break;
          }
         }
        } else {
         $$2531 = 0;
        }
       }
      } else {
       $$2531 = 9;
      }
      $294 = $$0479 | 32;
      $295 = ($294|0)==(102);
      $296 = $$9507$lcssa;
      $297 = (($296) - ($132))|0;
      $298 = $297 >> 2;
      $299 = ($298*9)|0;
      $300 = (($299) + -9)|0;
      if ($295) {
       $301 = (($300) - ($$2531))|0;
       $302 = ($301|0)>(0);
       $spec$select549 = $302 ? $301 : 0;
       $303 = ($$2476|0)<($spec$select549|0);
       $spec$select562 = $303 ? $$2476 : $spec$select549;
       $$1480 = $$0479;$$3477 = $spec$select562;
       break;
      } else {
       $304 = (($300) + ($$5521))|0;
       $305 = (($304) - ($$2531))|0;
       $306 = ($305|0)>(0);
       $spec$select551 = $306 ? $305 : 0;
       $307 = ($$2476|0)<($spec$select551|0);
       $spec$select563 = $307 ? $$2476 : $spec$select551;
       $$1480 = $$0479;$$3477 = $spec$select563;
       break;
      }
     } else {
      $$1480 = $$0479;$$3477 = $$2476;
     }
    } else {
     $$1480 = $5;$$3477 = $spec$select539;
    }
   } while(0);
   $308 = ($$3477|0)!=(0);
   $309 = $4 >>> 3;
   $$lobit = $309 & 1;
   $310 = $308 ? 1 : $$lobit;
   $311 = $$1480 | 32;
   $312 = ($311|0)==(102);
   if ($312) {
    $313 = ($$5521|0)>(0);
    $314 = $313 ? $$5521 : 0;
    $$2515 = 0;$$pn = $314;
   } else {
    $315 = ($$5521|0)<(0);
    $316 = $315 ? $270 : $$5521;
    $317 = ($316|0)<(0);
    $318 = $317 << 31 >> 31;
    $319 = (_fmt_u($316,$318,$11)|0);
    $320 = $11;
    $321 = $319;
    $322 = (($320) - ($321))|0;
    $323 = ($322|0)<(2);
    if ($323) {
     $$1514614 = $319;
     while(1) {
      $324 = ((($$1514614)) + -1|0);
      HEAP8[$324>>0] = 48;
      $325 = $324;
      $326 = (($320) - ($325))|0;
      $327 = ($326|0)<(2);
      if ($327) {
       $$1514614 = $324;
      } else {
       $$1514$lcssa = $324;
       break;
      }
     }
    } else {
     $$1514$lcssa = $319;
    }
    $328 = $$5521 >> 31;
    $329 = $328 & 2;
    $330 = (($329) + 43)|0;
    $331 = $330&255;
    $332 = ((($$1514$lcssa)) + -1|0);
    HEAP8[$332>>0] = $331;
    $333 = $$1480&255;
    $334 = ((($$1514$lcssa)) + -2|0);
    HEAP8[$334>>0] = $333;
    $335 = $334;
    $336 = (($320) - ($335))|0;
    $$2515 = $334;$$pn = $336;
   }
   $337 = (($$0522) + 1)|0;
   $338 = (($337) + ($$3477))|0;
   $$1528 = (($338) + ($310))|0;
   $339 = (($$1528) + ($$pn))|0;
   _pad_380($0,32,$2,$339,$4);
   _out_374($0,$$0523,$$0522);
   $340 = $4 ^ 65536;
   _pad_380($0,48,$2,$339,$340);
   if ($312) {
    $341 = ($$9>>>0)>($$0498>>>0);
    $spec$select554 = $341 ? $$0498 : $$9;
    $342 = ((($8)) + 9|0);
    $343 = $342;
    $344 = ((($8)) + 8|0);
    $$5493603 = $spec$select554;
    while(1) {
     $345 = HEAP32[$$5493603>>2]|0;
     $346 = (_fmt_u($345,0,$342)|0);
     $347 = ($$5493603|0)==($spec$select554|0);
     if ($347) {
      $353 = ($346|0)==($342|0);
      if ($353) {
       HEAP8[$344>>0] = 48;
       $$1465 = $344;
      } else {
       $$1465 = $346;
      }
     } else {
      $348 = ($346>>>0)>($8>>>0);
      if ($348) {
       $349 = $346;
       $350 = (($349) - ($9))|0;
       _memset(($8|0),48,($350|0))|0;
       $$0464599 = $346;
       while(1) {
        $351 = ((($$0464599)) + -1|0);
        $352 = ($351>>>0)>($8>>>0);
        if ($352) {
         $$0464599 = $351;
        } else {
         $$1465 = $351;
         break;
        }
       }
      } else {
       $$1465 = $346;
      }
     }
     $354 = $$1465;
     $355 = (($343) - ($354))|0;
     _out_374($0,$$1465,$355);
     $356 = ((($$5493603)) + 4|0);
     $357 = ($356>>>0)>($$0498>>>0);
     if ($357) {
      break;
     } else {
      $$5493603 = $356;
     }
    }
    $$not = $308 ^ 1;
    $358 = $4 & 8;
    $359 = ($358|0)==(0);
    $or$cond556 = $359 & $$not;
    if (!($or$cond556)) {
     _out_374($0,(gb + (167711) | 0),1);
    }
    $360 = ($356>>>0)<($$9507$lcssa>>>0);
    $361 = ($$3477|0)>(0);
    $362 = $360 & $361;
    if ($362) {
     $$4478594 = $$3477;$$6494593 = $356;
     while(1) {
      $363 = HEAP32[$$6494593>>2]|0;
      $364 = (_fmt_u($363,0,$342)|0);
      $365 = ($364>>>0)>($8>>>0);
      if ($365) {
       $366 = $364;
       $367 = (($366) - ($9))|0;
       _memset(($8|0),48,($367|0))|0;
       $$0463588 = $364;
       while(1) {
        $368 = ((($$0463588)) + -1|0);
        $369 = ($368>>>0)>($8>>>0);
        if ($369) {
         $$0463588 = $368;
        } else {
         $$0463$lcssa = $368;
         break;
        }
       }
      } else {
       $$0463$lcssa = $364;
      }
      $370 = ($$4478594|0)<(9);
      $371 = $370 ? $$4478594 : 9;
      _out_374($0,$$0463$lcssa,$371);
      $372 = ((($$6494593)) + 4|0);
      $373 = (($$4478594) + -9)|0;
      $374 = ($372>>>0)<($$9507$lcssa>>>0);
      $375 = ($$4478594|0)>(9);
      $376 = $374 & $375;
      if ($376) {
       $$4478594 = $373;$$6494593 = $372;
      } else {
       $$4478$lcssa = $373;
       break;
      }
     }
    } else {
     $$4478$lcssa = $$3477;
    }
    $377 = (($$4478$lcssa) + 9)|0;
    _pad_380($0,48,$377,9,0);
   } else {
    $378 = ((($$9)) + 4|0);
    $spec$select557 = $$lcssa583 ? $$9507$lcssa : $378;
    $379 = ($$9>>>0)<($spec$select557>>>0);
    $380 = ($$3477|0)>(-1);
    $381 = $379 & $380;
    if ($381) {
     $382 = ((($8)) + 9|0);
     $383 = $4 & 8;
     $384 = ($383|0)==(0);
     $385 = $382;
     $386 = (0 - ($9))|0;
     $387 = ((($8)) + 8|0);
     $$5609 = $$3477;$$7495608 = $$9;
     while(1) {
      $388 = HEAP32[$$7495608>>2]|0;
      $389 = (_fmt_u($388,0,$382)|0);
      $390 = ($389|0)==($382|0);
      if ($390) {
       HEAP8[$387>>0] = 48;
       $$0 = $387;
      } else {
       $$0 = $389;
      }
      $391 = ($$7495608|0)==($$9|0);
      do {
       if ($391) {
        $395 = ((($$0)) + 1|0);
        _out_374($0,$$0,1);
        $396 = ($$5609|0)<(1);
        $or$cond559 = $384 & $396;
        if ($or$cond559) {
         $$2 = $395;
         break;
        }
        _out_374($0,(gb + (167711) | 0),1);
        $$2 = $395;
       } else {
        $392 = ($$0>>>0)>($8>>>0);
        if (!($392)) {
         $$2 = $$0;
         break;
        }
        $scevgep711 = (($$0) + ($386)|0);
        $scevgep711712 = $scevgep711;
        _memset(($8|0),48,($scevgep711712|0))|0;
        $$1604 = $$0;
        while(1) {
         $393 = ((($$1604)) + -1|0);
         $394 = ($393>>>0)>($8>>>0);
         if ($394) {
          $$1604 = $393;
         } else {
          $$2 = $393;
          break;
         }
        }
       }
      } while(0);
      $397 = $$2;
      $398 = (($385) - ($397))|0;
      $399 = ($$5609|0)>($398|0);
      $400 = $399 ? $398 : $$5609;
      _out_374($0,$$2,$400);
      $401 = (($$5609) - ($398))|0;
      $402 = ((($$7495608)) + 4|0);
      $403 = ($402>>>0)<($spec$select557>>>0);
      $404 = ($401|0)>(-1);
      $405 = $403 & $404;
      if ($405) {
       $$5609 = $401;$$7495608 = $402;
      } else {
       $$5$lcssa = $401;
       break;
      }
     }
    } else {
     $$5$lcssa = $$3477;
    }
    $406 = (($$5$lcssa) + 18)|0;
    _pad_380($0,48,$406,18,0);
    $407 = $11;
    $408 = $$2515;
    $409 = (($407) - ($408))|0;
    _out_374($0,$$2515,$409);
   }
   $410 = $4 ^ 8192;
   _pad_380($0,32,$2,$339,$410);
   $$sink757 = $339;
  }
 } while(0);
 $411 = ($$sink757|0)<($2|0);
 $$560 = $411 ? $2 : $$sink757;
 STACKTOP = sp;return ($$560|0);
}
function ___DOUBLE_BITS_381($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _wcrtomb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0|0);
 do {
  if ($3) {
   $$0 = 1;
  } else {
   $4 = ($1>>>0)<(128);
   if ($4) {
    $5 = $1&255;
    HEAP8[$0>>0] = $5;
    $$0 = 1;
    break;
   }
   $6 = (___pthread_self_495()|0);
   $7 = ((($6)) + 188|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $11 = $1 & -128;
    $12 = ($11|0)==(57216);
    if ($12) {
     $14 = $1&255;
     HEAP8[$0>>0] = $14;
     $$0 = 1;
     break;
    } else {
     $13 = (___errno_location()|0);
     HEAP32[$13>>2] = 84;
     $$0 = -1;
     break;
    }
   }
   $15 = ($1>>>0)<(2048);
   if ($15) {
    $16 = $1 >>> 6;
    $17 = $16 | 192;
    $18 = $17&255;
    $19 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $18;
    $20 = $1 & 63;
    $21 = $20 | 128;
    $22 = $21&255;
    HEAP8[$19>>0] = $22;
    $$0 = 2;
    break;
   }
   $23 = ($1>>>0)<(55296);
   $24 = $1 & -8192;
   $25 = ($24|0)==(57344);
   $or$cond = $23 | $25;
   if ($or$cond) {
    $26 = $1 >>> 12;
    $27 = $26 | 224;
    $28 = $27&255;
    $29 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $28;
    $30 = $1 >>> 6;
    $31 = $30 & 63;
    $32 = $31 | 128;
    $33 = $32&255;
    $34 = ((($0)) + 2|0);
    HEAP8[$29>>0] = $33;
    $35 = $1 & 63;
    $36 = $35 | 128;
    $37 = $36&255;
    HEAP8[$34>>0] = $37;
    $$0 = 3;
    break;
   }
   $38 = (($1) + -65536)|0;
   $39 = ($38>>>0)<(1048576);
   if ($39) {
    $40 = $1 >>> 18;
    $41 = $40 | 240;
    $42 = $41&255;
    $43 = ((($0)) + 1|0);
    HEAP8[$0>>0] = $42;
    $44 = $1 >>> 12;
    $45 = $44 & 63;
    $46 = $45 | 128;
    $47 = $46&255;
    $48 = ((($0)) + 2|0);
    HEAP8[$43>>0] = $47;
    $49 = $1 >>> 6;
    $50 = $49 & 63;
    $51 = $50 | 128;
    $52 = $51&255;
    $53 = ((($0)) + 3|0);
    HEAP8[$48>>0] = $52;
    $54 = $1 & 63;
    $55 = $54 | 128;
    $56 = $55&255;
    HEAP8[$53>>0] = $56;
    $$0 = 4;
    break;
   } else {
    $57 = (___errno_location()|0);
    HEAP32[$57>>2] = 84;
    $$0 = -1;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function ___pthread_self_495() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___fwritex($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03846 = 0, $$042 = 0, $$1 = 0, $$139 = 0, $$141 = 0, $$143 = 0, $$pre = 0, $$pre48 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $7 = (___towrite($2)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$pre = HEAP32[$3>>2]|0;
   $12 = $$pre;
   label = 5;
  } else {
   $$1 = 0;
  }
 } else {
  $6 = $4;
  $12 = $6;
  label = 5;
 }
 L5: do {
  if ((label|0) == 5) {
   $9 = ((($2)) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($12) - ($10))|0;
   $13 = ($11>>>0)<($1>>>0);
   $14 = $10;
   if ($13) {
    $15 = ((($2)) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (mftCall_iiii($16|0,($2|0),($0|0),($1|0))|0);
    $$1 = $17;
    break;
   }
   $18 = ((($2)) + 75|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)<(0);
   $21 = ($1|0)==(0);
   $or$cond = $20 | $21;
   L10: do {
    if ($or$cond) {
     $$139 = 0;$$141 = $0;$$143 = $1;$32 = $14;
    } else {
     $$03846 = $1;
     while(1) {
      $23 = (($$03846) + -1)|0;
      $24 = (($0) + ($23)|0);
      $25 = HEAP8[$24>>0]|0;
      $26 = ($25<<24>>24)==(10);
      if ($26) {
       break;
      }
      $22 = ($23|0)==(0);
      if ($22) {
       $$139 = 0;$$141 = $0;$$143 = $1;$32 = $14;
       break L10;
      } else {
       $$03846 = $23;
      }
     }
     $27 = ((($2)) + 36|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (mftCall_iiii($28|0,($2|0),($0|0),($$03846|0))|0);
     $30 = ($29>>>0)<($$03846>>>0);
     if ($30) {
      $$1 = $29;
      break L5;
     }
     $31 = (($0) + ($$03846)|0);
     $$042 = (($1) - ($$03846))|0;
     $$pre48 = HEAP32[$9>>2]|0;
     $$139 = $$03846;$$141 = $31;$$143 = $$042;$32 = $$pre48;
    }
   } while(0);
   (_memcpy(($32|0),($$141|0),($$143|0))|0);
   $33 = HEAP32[$9>>2]|0;
   $34 = (($33) + ($$143)|0);
   HEAP32[$9>>2] = $34;
   $35 = (($$139) + ($$143))|0;
   $$1 = $35;
  }
 } while(0);
 return ($$1|0);
}
function ___towrite($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (($3) + 255)|0;
 $5 = $4 | $3;
 $6 = $5&255;
 HEAP8[$1>>0] = $6;
 $7 = HEAP32[$0>>2]|0;
 $8 = $7 & 8;
 $9 = ($8|0)==(0);
 if ($9) {
  $11 = ((($0)) + 8|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($0)) + 4|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($0)) + 44|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($0)) + 28|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($0)) + 20|0);
  HEAP32[$16>>2] = $14;
  $17 = $14;
  $18 = ((($0)) + 48|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + ($19)|0);
  $21 = ((($0)) + 16|0);
  HEAP32[$21>>2] = $20;
  $$0 = 0;
 } else {
  $10 = $7 | 32;
  HEAP32[$0>>2] = $10;
  $$0 = -1;
 }
 return ($$0|0);
}
function _sn_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$cast = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = ($7>>>0)>($2>>>0);
 $spec$select = $8 ? $2 : $7;
 $$cast = $6;
 (_memcpy(($$cast|0),($1|0),($spec$select|0))|0);
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + ($spec$select)|0);
 HEAP32[$5>>2] = $10;
 return ($2|0);
}
function _strfmon($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 (___pthread_self_174()|0);
 $4 = (_vstrfmon_l($0,$1,$2,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function ___pthread_self_174() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _iswctype_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_iswctype($0,$1)|0);
 return ($3|0);
}
function _iswctype($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($1|0) {
  case 1:  {
   $2 = (_iswalnum($0)|0);
   $$0 = $2;
   break;
  }
  case 2:  {
   $3 = (_iswalpha($0)|0);
   $$0 = $3;
   break;
  }
  case 3:  {
   $4 = (_iswblank($0)|0);
   $$0 = $4;
   break;
  }
  case 4:  {
   $5 = (_iswcntrl($0)|0);
   $$0 = $5;
   break;
  }
  case 5:  {
   $6 = (_iswdigit($0)|0);
   $$0 = $6;
   break;
  }
  case 6:  {
   $7 = (_iswgraph($0)|0);
   $$0 = $7;
   break;
  }
  case 7:  {
   $8 = (_iswlower($0)|0);
   $$0 = $8;
   break;
  }
  case 8:  {
   $9 = (_iswprint($0)|0);
   $$0 = $9;
   break;
  }
  case 9:  {
   $10 = (_iswpunct($0)|0);
   $$0 = $10;
   break;
  }
  case 10:  {
   $11 = (_iswspace($0)|0);
   $$0 = $11;
   break;
  }
  case 11:  {
   $12 = (_iswupper($0)|0);
   $$0 = $12;
   break;
  }
  case 12:  {
   $13 = (_iswxdigit($0)|0);
   $$0 = $13;
   break;
  }
  default: {
   $$0 = 0;
  }
  }
 } while(0);
 return ($$0|0);
}
function _iswalnum($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_iswdigit($0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (_iswalpha($0)|0);
  $4 = ($3|0)!=(0);
  $phitmp = $4&1;
  $5 = $phitmp;
 } else {
  $5 = 1;
 }
 return ($5|0);
}
function _iswblank($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isblank($0)|0);
 return ($1|0);
}
function _iswcntrl($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $narrow = 0, $or$cond = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(32);
 $2 = (($0) + -127)|0;
 $3 = ($2>>>0)<(33);
 $or$cond = $1 | $3;
 $4 = $0 & -2;
 $5 = ($4|0)==(8232);
 $or$cond6 = $5 | $or$cond;
 $6 = (($0) + -65529)|0;
 $7 = ($6>>>0)<(3);
 $narrow = $7 | $or$cond6;
 $8 = $narrow&1;
 return ($8|0);
}
function _iswgraph($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_iswspace($0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (_iswprint($0)|0);
  $4 = ($3|0)!=(0);
  $phitmp = $4&1;
  $5 = $phitmp;
 } else {
  $5 = 0;
 }
 return ($5|0);
}
function _iswlower($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_towupper($0)|0);
 $2 = ($1|0)!=($0|0);
 $3 = $2&1;
 return ($3|0);
}
function _iswpunct($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(131072);
 if ($1) {
  $2 = $0 >>> 8;
  $3 = ((gb + (14544) | 0) + ($2)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = $5 << 5;
  $7 = $0 >>> 3;
  $8 = $7 & 31;
  $9 = $6 | $8;
  $10 = ((gb + (14544) | 0) + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = $0 & 7;
  $14 = $12 >>> $13;
  $15 = $14 & 1;
  $$0 = $15;
 } else {
  $$0 = 0;
 }
 return ($$0|0);
}
function _iswupper($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_towlower($0)|0);
 $2 = ($1|0)!=($0|0);
 $3 = $2&1;
 return ($3|0);
}
function _iswxdigit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $narrow = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -48)|0;
 $2 = ($1>>>0)<(10);
 $3 = $0 | 32;
 $4 = (($3) + -97)|0;
 $5 = ($4>>>0)<(6);
 $narrow = $2 | $5;
 $spec$select = $narrow&1;
 return ($spec$select|0);
}
function ___uselocale($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_175()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($0|0)==(0|0);
 if (!($4)) {
  $5 = ($0|0)==((-1)|0);
  $6 = $5 ? ((((gb + (171204) | 0)) + 40|0)) : $0;
  HEAP32[$2>>2] = $6;
 }
 $7 = ($3|0)==(((((gb + (171204) | 0)) + 40|0))|0);
 $8 = $7 ? (-1) : $3;
 return ($8|0);
}
function ___pthread_self_175() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _toupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_toupper($0)|0);
 return ($2|0);
}
function _toupper($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_islower($0)|0);
 $2 = ($1|0)==(0);
 $3 = $0 & 95;
 $$0 = $2 ? $0 : $3;
 return ($$0|0);
}
function ___wcsxfrm_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_wcslen($1)|0);
 $5 = ($4>>>0)<($2>>>0);
 if ($5) {
  $6 = (($4) + 1)|0;
  (_wmemcpy($0,$1,$6)|0);
 } else {
  $7 = ($2|0)==(0);
  $8 = (($2) + -1)|0;
  if (!($7)) {
   $9 = (($0) + ($8<<2)|0);
   (_wmemcpy($0,$1,$8)|0);
   HEAP32[$9>>2] = 0;
  }
 }
 return ($4|0);
}
function _wmemcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$058 = 0, $$067 = 0, $$09 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$058 = $2;$$067 = $1;$$09 = $0;
  while(1) {
   $4 = (($$058) + -1)|0;
   $5 = ((($$067)) + 4|0);
   $6 = HEAP32[$$067>>2]|0;
   $7 = ((($$09)) + 4|0);
   HEAP32[$$09>>2] = $6;
   $8 = ($4|0)==(0);
   if ($8) {
    break;
   } else {
    $$058 = $4;$$067 = $5;$$09 = $7;
   }
  }
 }
 return ($0|0);
}
function _wcsxfrm($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (___pthread_self_176()|0);
 $3 = (___wcsxfrm_l($0,$1,$2,0)|0);
 return ($3|0);
}
function ___pthread_self_176() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___gettextdomain() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(gb + (171308) | 0)>>2]|0;
 $1 = ($0|0)==(0|0);
 $2 = $1 ? (gb + (166613) | 0) : $0;
 return ($2|0);
}
function _textdomain($0) {
 $0 = $0|0;
 var $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $2 = (___gettextdomain()|0);
   $$1 = $2;
  } else {
   $3 = (_strlen($0)|0);
   $4 = ($3>>>0)>(255);
   if ($4) {
    $5 = (___errno_location()|0);
    HEAP32[$5>>2] = 22;
    $$1 = 0;
    break;
   }
   $6 = HEAP32[(gb + (171308) | 0)>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $8 = (_malloc(256)|0);
    HEAP32[(gb + (171308) | 0)>>2] = $8;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $$1 = 0;
     break;
    } else {
     $11 = $8;
    }
   } else {
    $11 = $6;
   }
   $10 = (($3) + 1)|0;
   (_memcpy(($11|0),($0|0),($10|0))|0);
   $12 = HEAP32[(gb + (171308) | 0)>>2]|0;
   $$1 = $12;
  }
 } while(0);
 return ($$1|0);
}
function _gettext($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_dgettext(0,$0)|0);
 return ($1|0);
}
function _dgettext($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_dcngettext($0,$1,0,1,5)|0);
 return ($2|0);
}
function _dcngettext($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$ph = 0, $$0150 = 0, $$0152186 = 0, $$0154 = 0, $$0156 = 0, $$0157185 = 0, $$0161190 = 0, $$1 = 0, $$1153 = 0, $$1155 = 0, $$2 = 0, $$2163 = 0, $$3 = 0, $$3$pn = 0, $$4 = 0, $$alloca_mul = 0, $$in = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = (___pthread_self_180()|0);
 $9 = ((($8)) + 188|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($4>>>0)>(5);
 L1: do {
  if ($11) {
   label = 7;
  } else {
   $12 = ($0|0)==(0|0);
   if ($12) {
    $13 = (___gettextdomain()|0);
    $$0150 = $13;
   } else {
    $$0150 = $0;
   }
   $14 = (_strlen($$0150)|0);
   $15 = ($14>>>0)>(255);
   if ($15) {
    label = 7;
   } else {
    $16 = (_gettextdir($$0150,$5)|0);
    $17 = ($16|0)==(0|0);
    if ($17) {
     label = 7;
    } else {
     $18 = (($10) + ($4<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      label = 7;
     } else {
      $23 = ((($19)) + 8|0);
      $24 = ((gb + (17712) | 0) + (($4*12)|0)|0);
      $25 = ((gb + (166622) | 0) + ($4)|0);
      $26 = HEAP8[$25>>0]|0;
      $27 = $26 << 24 >> 24;
      $28 = (_strlen($23)|0);
      $29 = HEAP32[$5>>2]|0;
      $30 = (($29) + 1)|0;
      $31 = (($14) + 2)|0;
      $32 = (($31) + ($28))|0;
      $33 = (($32) + ($27))|0;
      $34 = (($33) + ($30))|0;
      $35 = (($34) + 4)|0;
      $36 = (_llvm_stacksave()|0);
      $$alloca_mul = $35;
      $37 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
      (_memcpy(($37|0),($16|0),($29|0))|0);
      $38 = (($37) + ($29)|0);
      HEAP8[$38>>0] = 47;
      $39 = (($37) + ($30)|0);
      (_memcpy(($39|0),($23|0),($28|0))|0);
      $40 = (($39) + ($28)|0);
      HEAP8[$40>>0] = 47;
      $41 = (($28) + 1)|0;
      $42 = (($39) + ($41)|0);
      (_memcpy(($42|0),($24|0),($27|0))|0);
      $43 = (($42) + ($27)|0);
      HEAP8[$43>>0] = 47;
      $44 = (($27) + 1)|0;
      $45 = (($42) + ($44)|0);
      (_memcpy(($45|0),($$0150|0),($14|0))|0);
      $46 = (($45) + ($14)|0);
      HEAP8[$46>>0] = 46;
      $47 = (($14) + 1)|0;
      $48 = (($45) + ($47)|0);
      HEAP8[$48>>0] = 109;
      $49 = (($45) + ($31)|0);
      HEAP8[$49>>0] = 111;
      $50 = (($14) + 3)|0;
      $51 = (($45) + ($50)|0);
      HEAP8[$51>>0] = 0;
      $52 = HEAP32[(gb + (171312) | 0)>>2]|0;
      $53 = ($52|0)==(0|0);
      L9: do {
       if ($53) {
        label = 12;
       } else {
        $$0161190 = $52;
        while(1) {
         $54 = ((($$0161190)) + 20|0);
         $55 = (_strcmp($54,$37)|0);
         $56 = ($55|0)==(0);
         if ($56) {
          $$2163 = $$0161190;
          label = 17;
          break L9;
         }
         $57 = HEAP32[$$0161190>>2]|0;
         $58 = ($57|0)==(0|0);
         if ($58) {
          label = 12;
          break;
         } else {
          $$0161190 = $57;
         }
        }
       }
      } while(0);
      L14: do {
       if ((label|0) == 12) {
        $59 = (___map_file(($37|0),($6|0))|0);
        $60 = ($59|0)==(0|0);
        do {
         if (!($60)) {
          $61 = (($34) + 24)|0;
          $62 = (_malloc($61)|0);
          $63 = ($62|0)==(0|0);
          if ($63) {
           $64 = HEAP32[$6>>2]|0;
           (___munmap($59,$64)|0);
           break;
          } else {
           $65 = ((($62)) + 4|0);
           HEAP32[$65>>2] = $59;
           $66 = HEAP32[$6>>2]|0;
           $67 = ((($62)) + 8|0);
           HEAP32[$67>>2] = $66;
           $68 = ((($62)) + 20|0);
           (_memcpy(($68|0),($37|0),($35|0))|0);
           $69 = HEAP32[(gb + (171312) | 0)>>2]|0;
           HEAP32[$62>>2] = $69;
           (_a_cas_p((gb + (171312) | 0),$69,$62)|0);
           $$2163 = $62;
           label = 17;
           break L14;
          }
         }
        } while(0);
       }
      } while(0);
      L22: do {
       if ((label|0) == 17) {
        $70 = ((($$2163)) + 4|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ((($$2163)) + 8|0);
        $73 = HEAP32[$72>>2]|0;
        $74 = (___mo_lookup($71,$73,$1)|0);
        $75 = ($74|0)==(0|0);
        if (!($75)) {
         $76 = ($2|0)==(0|0);
         L25: do {
          if ($76) {
           $$0$ph = $74;
          } else {
           $77 = ((($$2163)) + 12|0);
           $78 = HEAP32[$77>>2]|0;
           $79 = ($78|0)==(0|0);
           if ($79) {
            $80 = HEAP32[$70>>2]|0;
            $81 = HEAP32[$72>>2]|0;
            $82 = (___mo_lookup($80,$81,(gb + (172139) | 0))|0);
            $83 = ($82|0)==(0|0);
            do {
             if ($83) {
              $$0156 = (gb + (166660) | 0);$$1155 = 2;
             } else {
              $$0152186 = $82;$89 = 0;
              while(1) {
               $84 = (_strncmp($$0152186,(gb + (166628) | 0),13)|0);
               $85 = ($84|0)==(0);
               if ($85) {
                break;
               }
               $86 = (_strchr($$0152186,10)|0);
               $87 = ($86|0)==(0|0);
               $88 = ((($86)) + 1|0);
               if ($87) {
                label = 36;
                break;
               } else {
                $$0152186 = $88;$89 = $86;
               }
              }
              if ((label|0) == 36) {
               HEAP32[$7>>2] = 0;
               $$0156 = (gb + (166660) | 0);$$1155 = 2;
               break;
              }
              HEAP32[$7>>2] = $89;
              $90 = ((($$0152186)) + 13|0);
              $$1153 = $90;
              while(1) {
               $91 = HEAP8[$$1153>>0]|0;
               $92 = $91 << 24 >> 24;
               $93 = (_isspace($92)|0);
               $94 = ($93|0)==(0);
               $95 = ((($$1153)) + 1|0);
               if ($94) {
                break;
               } else {
                $$1153 = $95;
               }
              }
              $96 = (_strncmp($$1153,(gb + (166642) | 0),9)|0);
              $97 = ($96|0)==(0);
              if ($97) {
               $98 = ((($$1153)) + 9|0);
               $99 = (_strtoul($98,$7,10)|0);
               $100 = HEAP32[$7>>2]|0;
               $$0154 = $99;$$2 = $100;
              } else {
               $$0154 = 2;$$2 = $$1153;
              }
              $$3 = $$2;
              while(1) {
               $101 = HEAP8[$$3>>0]|0;
               $102 = ($101<<24>>24)==(0);
               $103 = ($101<<24>>24)!=(59);
               $spec$select = $102 ^ $103;
               $104 = ((($$3)) + 1|0);
               if ($spec$select) {
                $$3 = $104;
               } else {
                break;
               }
              }
              if ($102) {
               $$0156 = (gb + (166660) | 0);$$1155 = $$0154;
              } else {
               $$3$pn = $$3;
               while(1) {
                $$4 = ((($$3$pn)) + 1|0);
                $105 = HEAP8[$$4>>0]|0;
                $106 = $105 << 24 >> 24;
                $107 = (_isspace($106)|0);
                $108 = ($107|0)==(0);
                if ($108) {
                 break;
                } else {
                 $$3$pn = $$4;
                }
               }
               $109 = (_strncmp($$4,(gb + (166652) | 0),7)|0);
               $110 = ($109|0)==(0);
               if ($110) {
                $111 = ((($$3$pn)) + 8|0);
                $$0156 = $111;$$1155 = $$0154;
               } else {
                $$0156 = (gb + (166660) | 0);$$1155 = $$0154;
               }
              }
             }
            } while(0);
            $112 = ((($$2163)) + 16|0);
            _a_store($112,$$1155);
            (_a_cas_p($77,0,$$0156)|0);
            $$pre$phiZ2D = $112;
           } else {
            $$pre = ((($$2163)) + 16|0);
            $$pre$phiZ2D = $$pre;
           }
           $113 = HEAP32[$$pre$phiZ2D>>2]|0;
           $114 = ($113|0)==(0);
           if ($114) {
            $$0$ph = $74;
           } else {
            $115 = HEAP32[$77>>2]|0;
            $116 = (___pleval($115,$3)|0);
            $117 = HEAP32[$$pre$phiZ2D>>2]|0;
            $118 = ($116>>>0)>($117>>>0);
            if ($118) {
             break L22;
            }
            $119 = ($116|0)==(0);
            if ($119) {
             $$0$ph = $74;
            } else {
             $$0157185 = $74;$$in = $116;
             while(1) {
              $120 = (($$in) + -1)|0;
              $121 = HEAP32[$72>>2]|0;
              $122 = HEAP32[$70>>2]|0;
              $123 = $$0157185;
              $124 = (($122) - ($123))|0;
              $125 = (($124) + ($121))|0;
              $126 = (_strnlen($$0157185,$125)|0);
              $127 = (($126) + 1)|0;
              $128 = ($127>>>0)<($125>>>0);
              if (!($128)) {
               break;
              }
              $129 = (($$0157185) + ($127)|0);
              $130 = ($120|0)==(0);
              if ($130) {
               $$0$ph = $129;
               break L25;
              } else {
               $$0157185 = $129;$$in = $120;
              }
             }
             _llvm_stackrestore(($36|0));
             label = 7;
             break L1;
            }
           }
          }
         } while(0);
         _llvm_stackrestore(($36|0));
         $$1 = $$0$ph;
         break L1;
        }
       }
      } while(0);
      _llvm_stackrestore(($36|0));
      label = 7;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $21 = ($3|0)==(1);
  $22 = $21 ? $1 : $2;
  $$1 = $22;
 }
 STACKTOP = sp;return ($$1|0);
}
function ___pthread_self_180() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _gettextdir($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$010 = 0, $$012 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(gb + (171316) | 0)>>2]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if ($3) {
   $$010 = 0;
  } else {
   $$012 = $2;
   while(1) {
    $4 = ((($$012)) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_strcmp($5,$0)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $8 = ((($$012)) + 8|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)==(0);
     if (!($10)) {
      break;
     }
    }
    $15 = HEAP32[$$012>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     $$010 = 0;
     break L1;
    } else {
     $$012 = $15;
    }
   }
   $11 = ((($$012)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$1>>2] = $12;
   $13 = ((($$012)) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $$010 = $14;
  }
 } while(0);
 return ($$010|0);
}
function _a_cas_p($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $5 = $2;
  HEAP32[$0>>2] = $5;
 }
 return ($1|0);
}
function _strncmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$01823 = 0, $$01925 = 0, $$01925$in = 0, $$020 = 0, $$024 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$020 = 0;
 } else {
  $4 = HEAP8[$0>>0]|0;
  $5 = ($4<<24>>24)==(0);
  L3: do {
   if ($5) {
    $$0$lcssa = $1;$$lcssa = 0;
   } else {
    $$01823 = $0;$$01925$in = $2;$$024 = $1;$10 = $4;
    while(1) {
     $$01925 = (($$01925$in) + -1)|0;
     $6 = HEAP8[$$024>>0]|0;
     $7 = ($6<<24>>24)!=(0);
     $8 = ($$01925|0)!=(0);
     $or$cond = $8 & $7;
     $9 = ($10<<24>>24)==($6<<24>>24);
     $or$cond21 = $9 & $or$cond;
     if (!($or$cond21)) {
      $$0$lcssa = $$024;$$lcssa = $10;
      break L3;
     }
     $11 = ((($$01823)) + 1|0);
     $12 = ((($$024)) + 1|0);
     $13 = HEAP8[$11>>0]|0;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      $$0$lcssa = $12;$$lcssa = 0;
      break;
     } else {
      $$01823 = $11;$$01925$in = $$01925;$$024 = $12;$10 = $13;
     }
    }
   }
  } while(0);
  $15 = $$lcssa&255;
  $16 = HEAP8[$$0$lcssa>>0]|0;
  $17 = $16&255;
  $18 = (($15) - ($17))|0;
  $$020 = $18;
 }
 return ($$020|0);
}
function _strchr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___strchrnul($0,$1)|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $1&255;
 $5 = ($3<<24>>24)==($4<<24>>24);
 $6 = $5 ? $2 : 0;
 return ($6|0);
}
function _isspace($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $narrow = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(32);
 $2 = (($0) + -9)|0;
 $3 = ($2>>>0)<(5);
 $narrow = $1 | $3;
 $4 = $narrow&1;
 return ($4|0);
}
function _strtoul($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox_327($0,$1,$2,-1,0)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _a_store($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = $1;
 return;
}
function ___pleval($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $1;
 $4 = (_evalexpr($2,$0,100)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(59);
 $7 = HEAP32[$2>>2]|0;
 $8 = $6 ? $7 : -1;
 STACKTOP = sp;return ($8|0);
}
function _strnlen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_memchr($0,0,$1)|0);
 $3 = ($2|0)==(0|0);
 $4 = $2;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $3 ? $1 : $6;
 return ($7|0);
}
function _evalexpr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($2) + -1)|0;
 $4 = ($2|0)<(1);
 if ($4) {
  $$0 = (gb + (172139) | 0);
 } else {
  $5 = (_evalbinop($0,$1,0,$3)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(63);
  if ($7) {
   $8 = HEAP32[$0>>2]|0;
   $9 = ((($5)) + 1|0);
   $10 = (_evalexpr($0,$9,$3)|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(58);
   if ($12) {
    $13 = HEAP32[$0>>2]|0;
    $14 = ((($10)) + 1|0);
    $15 = (_evalexpr($0,$14,$3)|0);
    $16 = ($8|0)==(0);
    if ($16) {
     $17 = HEAP32[$0>>2]|0;
     $18 = $17;
    } else {
     $18 = $13;
    }
    HEAP32[$0>>2] = $18;
    $$0 = $15;
   } else {
    $$0 = (gb + (172139) | 0);
   }
  } else {
   $$0 = $5;
  }
 }
 return ($$0|0);
}
function _evalbinop($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$02122 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($3) + -1)|0;
 $5 = (_evalprim($0,$1,$4)|0);
 $6 = (_parseop($0,$5)|0);
 $7 = ((($0)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((gb + (166666) | 0) + ($8)|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10 << 24 >> 24;
 $12 = ($11|0)>($2|0);
 L1: do {
  if ($12) {
   $$02122 = $6;$19 = $11;$21 = $8;
   while(1) {
    $18 = HEAP32[$0>>2]|0;
    $20 = (_evalbinop($0,$$02122,$19,$4)|0);
    $22 = (_binop($0,$21,$18)|0);
    $23 = ($22|0)==(0);
    if (!($23)) {
     $$0 = (gb + (172139) | 0);
     break L1;
    }
    $13 = HEAP32[$7>>2]|0;
    $14 = ((gb + (166666) | 0) + ($13)|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15 << 24 >> 24;
    $17 = ($16|0)>($2|0);
    if ($17) {
     $$02122 = $20;$19 = $16;$21 = $13;
    } else {
     $$0 = $20;
     break;
    }
   }
  } else {
   $$0 = $6;
  }
 } while(0);
 return ($$0|0);
}
function _evalprim($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = (($2) + -1)|0;
 $5 = ($2|0)<(1);
 L1: do {
  if ($5) {
   $$0 = (gb + (172139) | 0);
  } else {
   $6 = (_skipspace($1)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = $7 << 24 >> 24;
   $9 = (_isdigit($8)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = (_strtoul($6,$3,10)|0);
    HEAP32[$0>>2] = $11;
    $12 = HEAP32[$3>>2]|0;
    $13 = ($12|0)==($6|0);
    $14 = ($11|0)==(-1);
    $or$cond = $14 | $13;
    if ($or$cond) {
     $$0 = (gb + (172139) | 0);
     break;
    }
    $15 = (_skipspace($12)|0);
    $$0 = $15;
    break;
   }
   $16 = HEAP8[$6>>0]|0;
   switch ($16<<24>>24) {
   case 110:  {
    $17 = ((($0)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$0>>2] = $18;
    $19 = ((($6)) + 1|0);
    $20 = (_skipspace($19)|0);
    $$0 = $20;
    break L1;
    break;
   }
   case 40:  {
    $21 = ((($6)) + 1|0);
    $22 = (_evalexpr($0,$21,$4)|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = ($23<<24>>24)==(41);
    if (!($24)) {
     $$0 = (gb + (172139) | 0);
     break L1;
    }
    $25 = ((($22)) + 1|0);
    $26 = (_skipspace($25)|0);
    $$0 = $26;
    break L1;
    break;
   }
   case 33:  {
    $27 = ((($6)) + 1|0);
    $28 = (_evalprim($0,$27,$4)|0);
    $29 = HEAP32[$0>>2]|0;
    $30 = ($29|0)==(0);
    $31 = $30&1;
    HEAP32[$0>>2] = $31;
    $$0 = $28;
    break L1;
    break;
   }
   default: {
    $$0 = (gb + (172139) | 0);
    break L1;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _parseop($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016 = 0, $$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $$018 = 0;
 while(1) {
  $3 = ((gb + (166680) | 0) + ($$018)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($2<<24>>24)==($4<<24>>24);
  if ($5) {
   label = 3;
   break;
  }
  $17 = (($$018) + 1)|0;
  $18 = ($17>>>0)<(11);
  if ($18) {
   $$018 = $17;
  } else {
   label = 9;
   break;
  }
 }
 L4: do {
  if ((label|0) == 3) {
   $6 = ($$018>>>0)<(6);
   $7 = ((($1)) + 1|0);
   do {
    if ($6) {
     $8 = HEAP8[$7>>0]|0;
     $9 = ((gb + (166691) | 0) + ($$018)|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = ($8<<24>>24)==($10<<24>>24);
     if ($11) {
      $12 = ((($0)) + 8|0);
      HEAP32[$12>>2] = $$018;
      $13 = ((($1)) + 2|0);
      $$016 = $13;
      break L4;
     } else {
      $14 = ($$018>>>0)>(3);
      if ($14) {
       break;
      } else {
       label = 9;
       break L4;
      }
     }
    }
   } while(0);
   $15 = (($$018) + 2)|0;
   $16 = ((($0)) + 8|0);
   HEAP32[$16>>2] = $15;
   $$016 = $7;
  }
 } while(0);
 if ((label|0) == 9) {
  $19 = ((($0)) + 8|0);
  HEAP32[$19>>2] = 13;
  $$016 = $1;
 }
 return ($$016|0);
}
function _binop($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 do {
  switch ($1|0) {
  case 0:  {
   $4 = $3 | $2;
   $5 = ($4|0)!=(0);
   $6 = $5&1;
   HEAP32[$0>>2] = $6;
   $$0 = 0;
   break;
  }
  case 1:  {
   $7 = ($2|0)!=(0);
   $8 = ($3|0)!=(0);
   $9 = $7 & $8;
   $10 = $9&1;
   HEAP32[$0>>2] = $10;
   $$0 = 0;
   break;
  }
  case 2:  {
   $11 = ($3|0)==($2|0);
   $12 = $11&1;
   HEAP32[$0>>2] = $12;
   $$0 = 0;
   break;
  }
  case 3:  {
   $13 = ($3|0)!=($2|0);
   $14 = $13&1;
   HEAP32[$0>>2] = $14;
   $$0 = 0;
   break;
  }
  case 4:  {
   $15 = ($3>>>0)<=($2>>>0);
   $16 = $15&1;
   HEAP32[$0>>2] = $16;
   $$0 = 0;
   break;
  }
  case 5:  {
   $17 = ($3>>>0)>=($2>>>0);
   $18 = $17&1;
   HEAP32[$0>>2] = $18;
   $$0 = 0;
   break;
  }
  case 6:  {
   $19 = ($3>>>0)<($2>>>0);
   $20 = $19&1;
   HEAP32[$0>>2] = $20;
   $$0 = 0;
   break;
  }
  case 7:  {
   $21 = ($3>>>0)>($2>>>0);
   $22 = $21&1;
   HEAP32[$0>>2] = $22;
   $$0 = 0;
   break;
  }
  case 8:  {
   $23 = (($3) + ($2))|0;
   HEAP32[$0>>2] = $23;
   $$0 = 0;
   break;
  }
  case 9:  {
   $24 = (($2) - ($3))|0;
   HEAP32[$0>>2] = $24;
   $$0 = 0;
   break;
  }
  case 10:  {
   $25 = Math_imul($3, $2)|0;
   HEAP32[$0>>2] = $25;
   $$0 = 0;
   break;
  }
  case 11:  {
   $26 = ($3|0)==(0);
   if ($26) {
    $$0 = 1;
   } else {
    $27 = (($2>>>0) % ($3>>>0))&-1;
    HEAP32[$0>>2] = $27;
    $$0 = 0;
   }
   break;
  }
  case 12:  {
   $28 = ($3|0)==(0);
   if ($28) {
    $$0 = 1;
   } else {
    $29 = (($2>>>0) / ($3>>>0))&-1;
    HEAP32[$0>>2] = $29;
    $$0 = 0;
   }
   break;
  }
  default: {
   $$0 = 1;
  }
  }
 } while(0);
 return ($$0|0);
}
function _skipspace($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $0;
 while(1) {
  $1 = HEAP8[$$0>>0]|0;
  $2 = $1 << 24 >> 24;
  $3 = (_isspace($2)|0);
  $4 = ($3|0)==(0);
  $5 = ((($$0)) + 1|0);
  if ($4) {
   break;
  } else {
   $$0 = $5;
  }
 }
 return ($$0|0);
}
function _strtox_327($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $5 = sp;
 HEAP32[$5>>2] = 0;
 $6 = ((($5)) + 4|0);
 HEAP32[$6>>2] = $0;
 $7 = ((($5)) + 44|0);
 HEAP32[$7>>2] = $0;
 $8 = ($0|0)<(0|0);
 $9 = ((($0)) + 2147483647|0);
 $$sink = $8 ? (-1) : $9;
 $10 = ((($5)) + 8|0);
 HEAP32[$10>>2] = $$sink;
 $11 = ((($5)) + 76|0);
 HEAP32[$11>>2] = -1;
 ___shlim($5,0);
 $12 = (___intscan($5,$2,1,$3,$4)|0);
 $13 = (getTempRet0() | 0);
 $14 = ($1|0)==(0|0);
 if (!($14)) {
  $15 = ((($5)) + 108|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$6>>2]|0;
  $18 = HEAP32[$10>>2]|0;
  $19 = (($17) + ($16))|0;
  $20 = (($19) - ($18))|0;
  $21 = (($0) + ($20)|0);
  HEAP32[$1>>2] = $21;
 }
 setTempRet0(($13) | 0);
 STACKTOP = sp;return ($12|0);
}
function ___shlim($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 104|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = ((($0)) + 108|0);
 HEAP32[$8>>2] = $7;
 $9 = ($1|0)!=(0);
 $10 = ($7|0)>($1|0);
 $or$cond = $9 & $10;
 if ($or$cond) {
  $11 = $6;
  $12 = (($11) + ($1)|0);
  $13 = ((($0)) + 100|0);
  HEAP32[$13>>2] = $12;
 } else {
  $14 = ((($0)) + 100|0);
  HEAP32[$14>>2] = $4;
 }
 return;
}
function ___intscan($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0154215 = 0, $$0157 = 0, $$0159 = 0, $$1155184 = 0, $$1158 = 0, $$1160 = 0, $$1160170 = 0, $$1165 = 0, $$1165168 = 0, $$1165169 = 0, $$2156202 = 0, $$3162208 = 0, $$4163$lcssa = 0, $$6$lcssa = 0, $$7190 = 0, $$8 = 0, $$pre$phi237Z2D = 0, $$pre$phi239Z2D = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond12 = 0, $or$cond179 = 0, $or$cond5 = 0, $or$cond7 = 0, $spec$select166 = 0, $spec$select167 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $5 = ($1>>>0)>(36);
 L1: do {
  if ($5) {
   $6 = (___errno_location()|0);
   HEAP32[$6>>2] = 22;
   $291 = 0;$292 = 0;
  } else {
   $7 = ((($0)) + 4|0);
   $8 = ((($0)) + 100|0);
   while(1) {
    $9 = HEAP32[$7>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($9>>>0)<($10>>>0);
    if ($11) {
     $12 = ((($9)) + 1|0);
     HEAP32[$7>>2] = $12;
     $13 = HEAP8[$9>>0]|0;
     $14 = $13&255;
     $16 = $14;
    } else {
     $15 = (___shgetc($0)|0);
     $16 = $15;
    }
    $17 = (_isspace($16)|0);
    $18 = ($17|0)==(0);
    if ($18) {
     break;
    }
   }
   L11: do {
    switch ($16|0) {
    case 43: case 45:  {
     $19 = ($16|0)==(45);
     $20 = $19 << 31 >> 31;
     $21 = HEAP32[$7>>2]|0;
     $22 = HEAP32[$8>>2]|0;
     $23 = ($21>>>0)<($22>>>0);
     if ($23) {
      $24 = ((($21)) + 1|0);
      HEAP32[$7>>2] = $24;
      $25 = HEAP8[$21>>0]|0;
      $26 = $25&255;
      $$0157 = $20;$$0159 = $26;
      break L11;
     } else {
      $27 = (___shgetc($0)|0);
      $$0157 = $20;$$0159 = $27;
      break L11;
     }
     break;
    }
    default: {
     $$0157 = 0;$$0159 = $16;
    }
    }
   } while(0);
   $28 = ($1|0)==(0);
   $29 = $1 | 16;
   $30 = ($29|0)==(16);
   $31 = ($$0159|0)==(48);
   $or$cond5 = $30 & $31;
   do {
    if ($or$cond5) {
     $32 = HEAP32[$7>>2]|0;
     $33 = HEAP32[$8>>2]|0;
     $34 = ($32>>>0)<($33>>>0);
     if ($34) {
      $35 = ((($32)) + 1|0);
      HEAP32[$7>>2] = $35;
      $36 = HEAP8[$32>>0]|0;
      $37 = $36&255;
      $40 = $37;
     } else {
      $38 = (___shgetc($0)|0);
      $40 = $38;
     }
     $39 = $40 | 32;
     $41 = ($39|0)==(120);
     if (!($41)) {
      if ($28) {
       $$1160170 = $40;$$1165168 = 8;
       label = 47;
       break;
      } else {
       $$1160 = $40;$$1165 = $1;
       label = 32;
       break;
      }
     }
     $42 = HEAP32[$7>>2]|0;
     $43 = HEAP32[$8>>2]|0;
     $44 = ($42>>>0)<($43>>>0);
     if ($44) {
      $45 = ((($42)) + 1|0);
      HEAP32[$7>>2] = $45;
      $46 = HEAP8[$42>>0]|0;
      $47 = $46&255;
      $50 = $47;
     } else {
      $48 = (___shgetc($0)|0);
      $50 = $48;
     }
     $49 = (((((gb + (17792) | 0)) + 1|0)) + ($50)|0);
     $51 = HEAP8[$49>>0]|0;
     $52 = ($51&255)>(15);
     if ($52) {
      $53 = HEAP32[$8>>2]|0;
      $54 = ($53|0)==(0|0);
      if (!($54)) {
       $55 = HEAP32[$7>>2]|0;
       $56 = ((($55)) + -1|0);
       HEAP32[$7>>2] = $56;
      }
      $57 = ($2|0)==(0);
      if ($57) {
       ___shlim($0,0);
       $291 = 0;$292 = 0;
       break L1;
      }
      if ($54) {
       $291 = 0;$292 = 0;
       break L1;
      }
      $58 = HEAP32[$7>>2]|0;
      $59 = ((($58)) + -1|0);
      HEAP32[$7>>2] = $59;
      $291 = 0;$292 = 0;
      break L1;
     } else {
      $$1160170 = $50;$$1165168 = 16;
      label = 47;
     }
    } else {
     $spec$select166 = $28 ? 10 : $1;
     $60 = (((((gb + (17792) | 0)) + 1|0)) + ($$0159)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61&255;
     $63 = ($spec$select166>>>0)>($62>>>0);
     if ($63) {
      $$1160 = $$0159;$$1165 = $spec$select166;
      label = 32;
     } else {
      $64 = HEAP32[$8>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $66 = HEAP32[$7>>2]|0;
       $67 = ((($66)) + -1|0);
       HEAP32[$7>>2] = $67;
      }
      ___shlim($0,0);
      $68 = (___errno_location()|0);
      HEAP32[$68>>2] = 22;
      $291 = 0;$292 = 0;
      break L1;
     }
    }
   } while(0);
   L43: do {
    if ((label|0) == 32) {
     $69 = ($$1165|0)==(10);
     if ($69) {
      $70 = (($$1160) + -48)|0;
      $71 = ($70>>>0)<(10);
      if ($71) {
       $$0154215 = 0;$74 = $70;
       while(1) {
        $72 = ($$0154215*10)|0;
        $73 = (($72) + ($74))|0;
        $75 = HEAP32[$7>>2]|0;
        $76 = HEAP32[$8>>2]|0;
        $77 = ($75>>>0)<($76>>>0);
        if ($77) {
         $78 = ((($75)) + 1|0);
         HEAP32[$7>>2] = $78;
         $79 = HEAP8[$75>>0]|0;
         $80 = $79&255;
         $83 = $80;
        } else {
         $81 = (___shgetc($0)|0);
         $83 = $81;
        }
        $82 = (($83) + -48)|0;
        $84 = ($82>>>0)<(10);
        $85 = ($73>>>0)<(429496729);
        $86 = $84 & $85;
        if ($86) {
         $$0154215 = $73;$74 = $82;
        } else {
         break;
        }
       }
       $87 = ($82>>>0)<(10);
       if ($87) {
        $$3162208 = $83;$88 = $73;$89 = 0;$93 = $82;
        while(1) {
         $90 = (___muldi3(($88|0),($89|0),10,0)|0);
         $91 = (getTempRet0() | 0);
         $92 = ($93|0)<(0);
         $94 = $92 << 31 >> 31;
         $95 = $93 ^ -1;
         $96 = $94 ^ -1;
         $97 = ($91>>>0)>($96>>>0);
         $98 = ($90>>>0)>($95>>>0);
         $99 = ($91|0)==($96|0);
         $100 = $99 & $98;
         $101 = $97 | $100;
         if ($101) {
          $$1165169 = 10;$$8 = $$3162208;$293 = $88;$294 = $89;
          label = 76;
          break L43;
         }
         $102 = (_i64Add(($90|0),($91|0),($93|0),($94|0))|0);
         $103 = (getTempRet0() | 0);
         $104 = HEAP32[$7>>2]|0;
         $105 = HEAP32[$8>>2]|0;
         $106 = ($104>>>0)<($105>>>0);
         if ($106) {
          $107 = ((($104)) + 1|0);
          HEAP32[$7>>2] = $107;
          $108 = HEAP8[$104>>0]|0;
          $109 = $108&255;
          $112 = $109;
         } else {
          $110 = (___shgetc($0)|0);
          $112 = $110;
         }
         $111 = (($112) + -48)|0;
         $113 = ($111>>>0)<(10);
         $114 = ($103>>>0)<(429496729);
         $115 = ($102>>>0)<(2576980378);
         $116 = ($103|0)==(429496729);
         $117 = $116 & $115;
         $118 = $114 | $117;
         $or$cond7 = $113 & $118;
         if ($or$cond7) {
          $$3162208 = $112;$88 = $102;$89 = $103;$93 = $111;
         } else {
          break;
         }
        }
        $119 = ($111>>>0)>(9);
        if ($119) {
         $$1158 = $$0157;$265 = $103;$267 = $102;
        } else {
         $$1165169 = 10;$$8 = $112;$293 = $102;$294 = $103;
         label = 76;
        }
       } else {
        $$1158 = $$0157;$265 = 0;$267 = $73;
       }
      } else {
       $$1158 = $$0157;$265 = 0;$267 = 0;
      }
     } else {
      $$1160170 = $$1160;$$1165168 = $$1165;
      label = 47;
     }
    }
   } while(0);
   L63: do {
    if ((label|0) == 47) {
     $120 = (($$1165168) + -1)|0;
     $121 = $120 & $$1165168;
     $122 = ($121|0)==(0);
     if ($122) {
      $123 = ($$1165168*23)|0;
      $124 = $123 >>> 5;
      $125 = $124 & 7;
      $126 = ((gb + (166697) | 0) + ($125)|0);
      $127 = HEAP8[$126>>0]|0;
      $128 = $127 << 24 >> 24;
      $129 = (((((gb + (17792) | 0)) + 1|0)) + ($$1160170)|0);
      $130 = HEAP8[$129>>0]|0;
      $131 = $130&255;
      $132 = ($$1165168>>>0)>($131>>>0);
      if ($132) {
       $$1155184 = 0;$135 = $131;
       while(1) {
        $133 = $$1155184 << $128;
        $134 = $135 | $133;
        $136 = HEAP32[$7>>2]|0;
        $137 = HEAP32[$8>>2]|0;
        $138 = ($136>>>0)<($137>>>0);
        if ($138) {
         $139 = ((($136)) + 1|0);
         HEAP32[$7>>2] = $139;
         $140 = HEAP8[$136>>0]|0;
         $141 = $140&255;
         $144 = $141;
        } else {
         $142 = (___shgetc($0)|0);
         $144 = $142;
        }
        $143 = (((((gb + (17792) | 0)) + 1|0)) + ($144)|0);
        $145 = HEAP8[$143>>0]|0;
        $146 = $145&255;
        $147 = ($$1165168>>>0)>($146>>>0);
        $148 = ($134>>>0)<(134217728);
        $149 = $148 & $147;
        if ($149) {
         $$1155184 = $134;$135 = $146;
        } else {
         break;
        }
       }
       $$4163$lcssa = $144;$$pre$phi237Z2D = $146;$154 = 0;$156 = $134;$295 = $145;
      } else {
       $$4163$lcssa = $$1160170;$$pre$phi237Z2D = $131;$154 = 0;$156 = 0;$295 = $130;
      }
      $150 = (_bitshift64Lshr(-1,-1,($128|0))|0);
      $151 = (getTempRet0() | 0);
      $152 = ($$1165168>>>0)<=($$pre$phi237Z2D>>>0);
      $153 = ($151>>>0)<($154>>>0);
      $155 = ($150>>>0)<($156>>>0);
      $157 = ($151|0)==($154|0);
      $158 = $157 & $155;
      $159 = $153 | $158;
      $or$cond179 = $152 | $159;
      if ($or$cond179) {
       $$1165169 = $$1165168;$$8 = $$4163$lcssa;$293 = $156;$294 = $154;
       label = 76;
       break;
      }
      $160 = $156;$161 = $154;$165 = $295;
      while(1) {
       $162 = (_bitshift64Shl(($160|0),($161|0),($128|0))|0);
       $163 = (getTempRet0() | 0);
       $164 = $165&255;
       $166 = $162 | $164;
       $167 = HEAP32[$7>>2]|0;
       $168 = HEAP32[$8>>2]|0;
       $169 = ($167>>>0)<($168>>>0);
       if ($169) {
        $170 = ((($167)) + 1|0);
        HEAP32[$7>>2] = $170;
        $171 = HEAP8[$167>>0]|0;
        $172 = $171&255;
        $175 = $172;
       } else {
        $173 = (___shgetc($0)|0);
        $175 = $173;
       }
       $174 = (((((gb + (17792) | 0)) + 1|0)) + ($175)|0);
       $176 = HEAP8[$174>>0]|0;
       $177 = $176&255;
       $178 = ($$1165168>>>0)<=($177>>>0);
       $179 = ($163>>>0)>($151>>>0);
       $180 = ($166>>>0)>($150>>>0);
       $181 = ($163|0)==($151|0);
       $182 = $181 & $180;
       $183 = $179 | $182;
       $or$cond = $178 | $183;
       if ($or$cond) {
        $$1165169 = $$1165168;$$8 = $175;$293 = $166;$294 = $163;
        label = 76;
        break L63;
       } else {
        $160 = $166;$161 = $163;$165 = $176;
       }
      }
     }
     $184 = (((((gb + (17792) | 0)) + 1|0)) + ($$1160170)|0);
     $185 = HEAP8[$184>>0]|0;
     $186 = $185&255;
     $187 = ($$1165168>>>0)>($186>>>0);
     if ($187) {
      $$2156202 = 0;$190 = $186;
      while(1) {
       $188 = Math_imul($$2156202, $$1165168)|0;
       $189 = (($190) + ($188))|0;
       $191 = HEAP32[$7>>2]|0;
       $192 = HEAP32[$8>>2]|0;
       $193 = ($191>>>0)<($192>>>0);
       if ($193) {
        $194 = ((($191)) + 1|0);
        HEAP32[$7>>2] = $194;
        $195 = HEAP8[$191>>0]|0;
        $196 = $195&255;
        $199 = $196;
       } else {
        $197 = (___shgetc($0)|0);
        $199 = $197;
       }
       $198 = (((((gb + (17792) | 0)) + 1|0)) + ($199)|0);
       $200 = HEAP8[$198>>0]|0;
       $201 = $200&255;
       $202 = ($$1165168>>>0)>($201>>>0);
       $203 = ($189>>>0)<(119304647);
       $204 = $203 & $202;
       if ($204) {
        $$2156202 = $189;$190 = $201;
       } else {
        break;
       }
      }
      $$6$lcssa = $199;$$pre$phi239Z2D = $201;$296 = $200;$297 = $189;$298 = 0;
     } else {
      $$6$lcssa = $$1160170;$$pre$phi239Z2D = $186;$296 = $185;$297 = 0;$298 = 0;
     }
     $205 = ($$1165168>>>0)>($$pre$phi239Z2D>>>0);
     if ($205) {
      $206 = (___udivdi3(-1,-1,($$1165168|0),0)|0);
      $207 = (getTempRet0() | 0);
      $$7190 = $$6$lcssa;$209 = $298;$211 = $297;$218 = $296;
      while(1) {
       $208 = ($209>>>0)>($207>>>0);
       $210 = ($211>>>0)>($206>>>0);
       $212 = ($209|0)==($207|0);
       $213 = $212 & $210;
       $214 = $208 | $213;
       if ($214) {
        $$1165169 = $$1165168;$$8 = $$7190;$293 = $211;$294 = $209;
        label = 76;
        break L63;
       }
       $215 = (___muldi3(($211|0),($209|0),($$1165168|0),0)|0);
       $216 = (getTempRet0() | 0);
       $217 = $218&255;
       $219 = $217 ^ -1;
       $220 = ($216>>>0)>(4294967295);
       $221 = ($215>>>0)>($219>>>0);
       $222 = ($216|0)==(-1);
       $223 = $222 & $221;
       $224 = $220 | $223;
       if ($224) {
        $$1165169 = $$1165168;$$8 = $$7190;$293 = $211;$294 = $209;
        label = 76;
        break L63;
       }
       $225 = (_i64Add(($215|0),($216|0),($217|0),0)|0);
       $226 = (getTempRet0() | 0);
       $227 = HEAP32[$7>>2]|0;
       $228 = HEAP32[$8>>2]|0;
       $229 = ($227>>>0)<($228>>>0);
       if ($229) {
        $230 = ((($227)) + 1|0);
        HEAP32[$7>>2] = $230;
        $231 = HEAP8[$227>>0]|0;
        $232 = $231&255;
        $235 = $232;
       } else {
        $233 = (___shgetc($0)|0);
        $235 = $233;
       }
       $234 = (((((gb + (17792) | 0)) + 1|0)) + ($235)|0);
       $236 = HEAP8[$234>>0]|0;
       $237 = $236&255;
       $238 = ($$1165168>>>0)>($237>>>0);
       if ($238) {
        $$7190 = $235;$209 = $226;$211 = $225;$218 = $236;
       } else {
        $$1165169 = $$1165168;$$8 = $235;$293 = $225;$294 = $226;
        label = 76;
        break;
       }
      }
     } else {
      $$1165169 = $$1165168;$$8 = $$6$lcssa;$293 = $297;$294 = $298;
      label = 76;
     }
    }
   } while(0);
   if ((label|0) == 76) {
    $239 = (((((gb + (17792) | 0)) + 1|0)) + ($$8)|0);
    $240 = HEAP8[$239>>0]|0;
    $241 = $240&255;
    $242 = ($$1165169>>>0)>($241>>>0);
    if ($242) {
     while(1) {
      $243 = HEAP32[$7>>2]|0;
      $244 = HEAP32[$8>>2]|0;
      $245 = ($243>>>0)<($244>>>0);
      if ($245) {
       $246 = ((($243)) + 1|0);
       HEAP32[$7>>2] = $246;
       $247 = HEAP8[$243>>0]|0;
       $248 = $247&255;
       $251 = $248;
      } else {
       $249 = (___shgetc($0)|0);
       $251 = $249;
      }
      $250 = (((((gb + (17792) | 0)) + 1|0)) + ($251)|0);
      $252 = HEAP8[$250>>0]|0;
      $253 = $252&255;
      $254 = ($$1165169>>>0)>($253>>>0);
      if (!($254)) {
       break;
      }
     }
     $255 = (___errno_location()|0);
     HEAP32[$255>>2] = 34;
     $256 = $3 & 1;
     $257 = ($256|0)==(0);
     $258 = (0)==(0);
     $259 = $257 & $258;
     $spec$select167 = $259 ? $$0157 : 0;
     $$1158 = $spec$select167;$265 = $4;$267 = $3;
    } else {
     $$1158 = $$0157;$265 = $294;$267 = $293;
    }
   }
   $260 = HEAP32[$8>>2]|0;
   $261 = ($260|0)==(0|0);
   if (!($261)) {
    $262 = HEAP32[$7>>2]|0;
    $263 = ((($262)) + -1|0);
    HEAP32[$7>>2] = $263;
   }
   $264 = ($265>>>0)<($4>>>0);
   $266 = ($267>>>0)<($3>>>0);
   $268 = ($265|0)==($4|0);
   $269 = $268 & $266;
   $270 = $264 | $269;
   if (!($270)) {
    $271 = $3 & 1;
    $272 = ($271|0)!=(0);
    $273 = (0)!=(0);
    $274 = $272 | $273;
    $275 = ($$1158|0)!=(0);
    $or$cond12 = $274 | $275;
    if (!($or$cond12)) {
     $276 = (___errno_location()|0);
     HEAP32[$276>>2] = 34;
     $277 = (_i64Add(($3|0),($4|0),-1,-1)|0);
     $278 = (getTempRet0() | 0);
     $291 = $278;$292 = $277;
     break;
    }
    $279 = ($265>>>0)>($4>>>0);
    $280 = ($267>>>0)>($3>>>0);
    $281 = ($265|0)==($4|0);
    $282 = $281 & $280;
    $283 = $279 | $282;
    if ($283) {
     $284 = (___errno_location()|0);
     HEAP32[$284>>2] = 34;
     $291 = $4;$292 = $3;
     break;
    }
   }
   $285 = ($$1158|0)<(0);
   $286 = $285 << 31 >> 31;
   $287 = $267 ^ $$1158;
   $288 = $265 ^ $286;
   $289 = (_i64Subtract(($287|0),($288|0),($$1158|0),($286|0))|0);
   $290 = (getTempRet0() | 0);
   $291 = $290;$292 = $289;
  }
 } while(0);
 setTempRet0(($291) | 0);
 return ($292|0);
}
function ___shgetc($0) {
 $0 = $0|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert28 = 0, $$pre = 0, $$pre29 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  label = 3;
 } else {
  $4 = ((($0)) + 108|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)<($2|0);
  if ($6) {
   label = 3;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 3) {
  $7 = (___uflow($0)|0);
  $8 = ($7|0)<(0);
  if ($8) {
   label = 4;
  } else {
   $10 = HEAP32[$1>>2]|0;
   $11 = ($10|0)==(0);
   $$phi$trans$insert = ((($0)) + 8|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if ($11) {
    $12 = $$pre;
    $42 = $12;
    label = 9;
   } else {
    $13 = ((($0)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14;
    $16 = (($$pre) - ($15))|0;
    $17 = ((($0)) + 108|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($10) - ($18))|0;
    $20 = ($16|0)<($19|0);
    $21 = $$pre;
    if ($20) {
     $42 = $21;
     label = 9;
    } else {
     $22 = (($19) + -1)|0;
     $23 = (($14) + ($22)|0);
     $24 = ((($0)) + 100|0);
     HEAP32[$24>>2] = $23;
     $27 = $21;
    }
   }
   if ((label|0) == 9) {
    $25 = ((($0)) + 100|0);
    HEAP32[$25>>2] = $$pre;
    $27 = $42;
   }
   $26 = ($27|0)==(0|0);
   $$phi$trans$insert28 = ((($0)) + 4|0);
   if ($26) {
    $$pre29 = HEAP32[$$phi$trans$insert28>>2]|0;
    $37 = $$pre29;
   } else {
    $28 = HEAP32[$$phi$trans$insert28>>2]|0;
    $29 = $27;
    $30 = ((($0)) + 108|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + 1)|0;
    $33 = (($32) - ($28))|0;
    $34 = (($33) + ($31))|0;
    HEAP32[$30>>2] = $34;
    $35 = $28;
    $37 = $35;
   }
   $36 = ((($37)) + -1|0);
   $38 = HEAP8[$36>>0]|0;
   $39 = $38&255;
   $40 = ($7|0)==($39|0);
   if ($40) {
    $$0 = $7;
   } else {
    $41 = $7&255;
    HEAP8[$36>>0] = $41;
    $$0 = $7;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = ((($0)) + 100|0);
  HEAP32[$9>>2] = 0;
  $$0 = -1;
 }
 return ($$0|0);
}
function ___uflow($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (___toread($0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = ((($0)) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (mftCall_iiii($5|0,($0|0),($1|0),1)|0);
  $7 = ($6|0)==(1);
  if ($7) {
   $8 = HEAP8[$1>>0]|0;
   $9 = $8&255;
   $$0 = $9;
  } else {
   $$0 = -1;
  }
 } else {
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___toread($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (($3) + 255)|0;
 $5 = $4 | $3;
 $6 = $5&255;
 HEAP8[$1>>0] = $6;
 $7 = ((($0)) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = ((($0)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  (mftCall_iiii($13|0,($0|0),(0|0),0)|0);
 }
 $14 = ((($0)) + 16|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$9>>2] = 0;
 HEAP32[$7>>2] = 0;
 $15 = HEAP32[$0>>2]|0;
 $16 = $15 & 4;
 $17 = ($16|0)==(0);
 if ($17) {
  $19 = ((($0)) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($0)) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + ($22)|0);
  $24 = ((($0)) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = ((($0)) + 4|0);
  HEAP32[$25>>2] = $23;
  $26 = $15 << 27;
  $sext = $26 >> 31;
  $$0 = $sext;
 } else {
  $18 = $15 | 32;
  HEAP32[$0>>2] = $18;
  $$0 = -1;
 }
 return ($$0|0);
}
function _ngettext($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_dngettext(0,$0,$1,$2)|0);
 return ($3|0);
}
function _dngettext($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_dcngettext($0,$1,$2,$3,5)|0);
 return ($4|0);
}
function _catopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((-1)|0);
}
function _strncasecmp_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strncasecmp($0,$1,$2)|0);
 return ($4|0);
}
function _strncasecmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$02125 = 0, $$02227 = 0, $$02227$in = 0, $$023 = 0, $$026 = 0, $$pre$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$023 = 0;
 } else {
  $4 = HEAP8[$0>>0]|0;
  $5 = ($4<<24>>24)==(0);
  L3: do {
   if ($5) {
    $$0$lcssa = $1;$24 = 0;
   } else {
    $6 = $4&255;
    $$02125 = $0;$$02227$in = $2;$$026 = $1;$11 = $4;$12 = $6;
    while(1) {
     $$02227 = (($$02227$in) + -1)|0;
     $7 = HEAP8[$$026>>0]|0;
     $8 = ($7<<24>>24)!=(0);
     $9 = ($$02227|0)!=(0);
     $or$cond = $9 & $8;
     if (!($or$cond)) {
      $$0$lcssa = $$026;$24 = $11;
      break L3;
     }
     $10 = ($11<<24>>24)==($7<<24>>24);
     if (!($10)) {
      $13 = (_tolower($12)|0);
      $14 = HEAP8[$$026>>0]|0;
      $15 = $14&255;
      $16 = (_tolower($15)|0);
      $17 = ($13|0)==($16|0);
      if (!($17)) {
       break;
      }
     }
     $18 = ((($$02125)) + 1|0);
     $19 = ((($$026)) + 1|0);
     $20 = HEAP8[$18>>0]|0;
     $21 = $20&255;
     $22 = ($20<<24>>24)==(0);
     if ($22) {
      $$0$lcssa = $19;$24 = 0;
      break L3;
     } else {
      $$02125 = $18;$$02227$in = $$02227;$$026 = $19;$11 = $20;$12 = $21;
     }
    }
    $$pre$pre = HEAP8[$$02125>>0]|0;
    $$0$lcssa = $$026;$24 = $$pre$pre;
   }
  } while(0);
  $23 = $24&255;
  $25 = (_tolower($23)|0);
  $26 = HEAP8[$$0$lcssa>>0]|0;
  $27 = $26&255;
  $28 = (_tolower($27)|0);
  $29 = (($25) - ($28))|0;
  $$023 = $29;
 }
 return ($$023|0);
}
function _tolower($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_isupper($0)|0);
 $2 = ($1|0)==(0);
 $3 = $0 | 32;
 $$0 = $2 ? $0 : $3;
 return ($$0|0);
}
function _isupper($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -65)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 return ($3|0);
}
function _iscntrl_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iscntrl($0)|0);
 return ($2|0);
}
function _iscntrl($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(32);
 $2 = ($0|0)==(127);
 $3 = $1 | $2;
 $4 = $3&1;
 return ($4|0);
}
function _iswblank_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswblank($0)|0);
 return ($2|0);
}
function _bindtextdomain($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$04955 = 0, $$05154 = 0, $$1 = 0, $$150 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond52 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ($0|0)==(0|0);
 L1: do {
  if ($3) {
   $$1 = 0;
  } else {
   $4 = ($1|0)==(0|0);
   if ($4) {
    HEAP32[$2>>2] = 0;
    $5 = (_gettextdir($0,$2)|0);
    $$1 = $5;
    break;
   }
   $6 = (_strlen($0)|0);
   $7 = (_strlen($1)|0);
   $8 = ($6>>>0)>(255);
   $9 = ($7>>>0)>(4095);
   $or$cond = $8 | $9;
   if ($or$cond) {
    $10 = (___errno_location()|0);
    HEAP32[$10>>2] = 22;
    $$1 = 0;
    break;
   }
   ___lock(((gb + (171320) | 0)|0));
   $11 = HEAP32[(gb + (171316) | 0)>>2]|0;
   $12 = ($11|0)==(0|0);
   L9: do {
    if ($12) {
     label = 11;
    } else {
     $$04955 = $11;
     while(1) {
      $13 = ((($$04955)) + 12|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (_strcmp($14,$0)|0);
      $16 = ($15|0)==(0);
      if ($16) {
       $17 = ((($$04955)) + 16|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (_strcmp($18,$1)|0);
       $20 = ($19|0)==(0);
       if ($20) {
        $$150 = $$04955;
        break L9;
       }
      }
      $21 = HEAP32[$$04955>>2]|0;
      $22 = ($21|0)==(0|0);
      if ($22) {
       label = 11;
       break;
      } else {
       $$04955 = $21;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 11) {
     $23 = (($6) + 22)|0;
     $24 = (($23) + ($7))|0;
     $25 = (_malloc($24)|0);
     $26 = ($25|0)==(0|0);
     if ($26) {
      ___unlock(((gb + (171320) | 0)|0));
      $$1 = 0;
      break L1;
     } else {
      $27 = HEAP32[(gb + (171316) | 0)>>2]|0;
      HEAP32[$25>>2] = $27;
      $28 = ((($25)) + 4|0);
      HEAP32[$28>>2] = $7;
      $29 = ((($25)) + 20|0);
      $30 = ((($25)) + 12|0);
      HEAP32[$30>>2] = $29;
      $31 = (($29) + ($6)|0);
      $32 = ((($31)) + 1|0);
      $33 = ((($25)) + 16|0);
      HEAP32[$33>>2] = $32;
      $34 = (($6) + 1)|0;
      (_memcpy(($29|0),($0|0),($34|0))|0);
      $35 = HEAP32[$33>>2]|0;
      $36 = (($7) + 1)|0;
      (_memcpy(($35|0),($1|0),($36|0))|0);
      $37 = HEAP32[(gb + (171316) | 0)>>2]|0;
      (_a_cas_p((gb + (171316) | 0),$37,$25)|0);
      $$150 = $25;
      break;
     }
    }
   } while(0);
   $38 = ((($$150)) + 8|0);
   _a_store($38,1);
   $39 = HEAP32[(gb + (171316) | 0)>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = ((($$150)) + 12|0);
    $$05154 = $39;
    while(1) {
     $42 = HEAP32[$41>>2]|0;
     $43 = (_strcmp($42,$0)|0);
     $44 = ($43|0)!=(0);
     $45 = ($$05154|0)==($$150|0);
     $or$cond52 = $45 | $44;
     if (!($or$cond52)) {
      $46 = ((($$05154)) + 8|0);
      _a_store($46,0);
     }
     $47 = HEAP32[$$05154>>2]|0;
     $48 = ($47|0)==(0|0);
     if ($48) {
      break;
     } else {
      $$05154 = $47;
     }
    }
   }
   ___unlock(((gb + (171320) | 0)|0));
   $49 = ((($$150)) + 16|0);
   $50 = HEAP32[$49>>2]|0;
   $$1 = $50;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _dcgettext($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_dcngettext($0,$1,0,1,$2)|0);
 return ($3|0);
}
function _strerror_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strerror($0)|0);
 return ($2|0);
}
function _isalnum_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isalnum($0)|0);
 return ($2|0);
}
function _strcasecmp_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strcasecmp($0,$1)|0);
 return ($3|0);
}
function _strcasecmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$01718 = 0, $$019 = 0, $$pre$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $$0$lcssa = $1;$21 = 0;
  } else {
   $4 = $2&255;
   $$01718 = $0;$$019 = $1;$8 = $2;$9 = $4;
   while(1) {
    $5 = HEAP8[$$019>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     $$0$lcssa = $$019;$21 = $8;
     break L1;
    }
    $7 = ($8<<24>>24)==($5<<24>>24);
    if (!($7)) {
     $10 = (_tolower($9)|0);
     $11 = HEAP8[$$019>>0]|0;
     $12 = $11&255;
     $13 = (_tolower($12)|0);
     $14 = ($10|0)==($13|0);
     if (!($14)) {
      break;
     }
    }
    $15 = ((($$01718)) + 1|0);
    $16 = ((($$019)) + 1|0);
    $17 = HEAP8[$15>>0]|0;
    $18 = $17&255;
    $19 = ($17<<24>>24)==(0);
    if ($19) {
     $$0$lcssa = $16;$21 = 0;
     break L1;
    } else {
     $$01718 = $15;$$019 = $16;$8 = $17;$9 = $18;
    }
   }
   $$pre$pre = HEAP8[$$01718>>0]|0;
   $$0$lcssa = $$019;$21 = $$pre$pre;
  }
 } while(0);
 $20 = $21&255;
 $22 = (_tolower($20)|0);
 $23 = HEAP8[$$0$lcssa>>0]|0;
 $24 = $23&255;
 $25 = (_tolower($24)|0);
 $26 = (($22) - ($25))|0;
 return ($26|0);
}
function _iswgraph_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswgraph($0)|0);
 return ($2|0);
}
function ___lctrans_cur($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_194()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (___lctrans_impl($0,$5)|0);
 return ($6|0);
}
function ___pthread_self_194() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___wcscoll_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcscmp($0,$1)|0);
 return ($3|0);
}
function _wcscmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$015 = 0, $$0914 = 0, $$lcssa = 0, $$lcssa11 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond1013 = 0;
 var $or$cond12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($2|0)!=($3|0);
 $5 = ($2|0)==(0);
 $or$cond12 = $5 | $4;
 $6 = ($3|0)==(0);
 $or$cond1013 = $6 | $or$cond12;
 if ($or$cond1013) {
  $$lcssa = $3;$$lcssa11 = $2;
 } else {
  $$015 = $1;$$0914 = $0;
  while(1) {
   $7 = ((($$0914)) + 4|0);
   $8 = ((($$015)) + 4|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = HEAP32[$8>>2]|0;
   $11 = ($9|0)!=($10|0);
   $12 = ($9|0)==(0);
   $or$cond = $12 | $11;
   $13 = ($10|0)==(0);
   $or$cond10 = $13 | $or$cond;
   if ($or$cond10) {
    $$lcssa = $10;$$lcssa11 = $9;
    break;
   } else {
    $$015 = $8;$$0914 = $7;
   }
  }
 }
 $14 = (($$lcssa11) - ($$lcssa))|0;
 return ($14|0);
}
function _wcscoll($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (___pthread_self_195()|0);
 $2 = (___wcscoll_l($0,$1,0)|0);
 return ($2|0);
}
function ___pthread_self_195() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _isprint_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isprint($0)|0);
 return ($2|0);
}
function _isprint($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -32)|0;
 $2 = ($1>>>0)<(95);
 $3 = $2&1;
 return ($3|0);
}
function _isupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isupper($0)|0);
 return ($2|0);
}
function _bind_textdomain_codeset($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (_strcasecmp($1,(gb + (166739) | 0))|0);
  $4 = ($3|0)==(0);
  if (!($4)) {
   $5 = (___errno_location()|0);
   HEAP32[$5>>2] = 22;
  }
 }
 return (0|0);
}
function _wctype_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wctype($0)|0);
 return ($2|0);
}
function _wctype($0) {
 $0 = $0|0;
 var $$01113 = 0, $$012 = 0, $$014 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $$01113 = 1;$$014 = (gb + (18064) | 0);$3 = 97;
 while(1) {
  $2 = ($1<<24>>24)==($3<<24>>24);
  if ($2) {
   $4 = (_strcmp($0,$$014)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $$012 = $$01113;
    break;
   }
  }
  $6 = (($$01113) + 1)|0;
  $7 = ((($$014)) + 6|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $$012 = 0;
   break;
  } else {
   $$01113 = $6;$$014 = $7;$3 = $8;
  }
 }
 return ($$012|0);
}
function _iswalnum_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswalnum($0)|0);
 return ($2|0);
}
function _iconv_open($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_find_charmap($0)|0);
 $3 = ($2|0)==(-1);
 if ($3) {
  label = 4;
 } else {
  $4 = (_find_charmap($1)|0);
  $5 = ($4|0)==(-1);
  if ($5) {
   label = 4;
  } else {
   $6 = ((gb + (18144) | 0) + ($2)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7&255)>(207);
   if ($8) {
    label = 4;
   } else {
    $10 = $4 << 16;
    $11 = $10 | $2;
    $12 = $11;
    $$0 = $12;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = (___errno_location()|0);
  HEAP32[$9>>2] = 22;
  $$0 = (-1);
 }
 return ($$0|0);
}
function _find_charmap($0) {
 $0 = $0|0;
 var $$015 = 0, $$018 = 0, $$1$lcssa = 0, $$117 = 0, $$2 = 0, $$pr = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $spec$select = $2 ? (gb + (18144) | 0) : $0;
 $$018 = (gb + (18144) | 0);
 while(1) {
  $3 = (_fuzzycmp($spec$select,$$018)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   label = 3;
   break;
  }
  $15 = (_strlen($$018)|0);
  $16 = (($15) + 1)|0;
  $17 = (($$018) + ($16)|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $20 = ((($17)) + 1|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21&255)>(128);
   if ($22) {
    $$sink = 2;
   } else {
    $23 = $21&255;
    $24 = (128 - ($23))|0;
    $25 = $24 >>> 2;
    $26 = ($25*5)|0;
    $27 = (($26) + 2)|0;
    $$sink = $27;
   }
   $28 = (($17) + ($$sink)|0);
   $$pr = HEAP8[$28>>0]|0;
   $$2 = $28;$30 = $$pr;
  } else {
   $$2 = $17;$30 = $18;
  }
  $29 = ($30<<24>>24)==(0);
  if ($29) {
   $$015 = -1;
   break;
  } else {
   $$018 = $$2;
  }
 }
 if ((label|0) == 3) {
  $5 = HEAP8[$$018>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $$1$lcssa = $$018;
  } else {
   $$117 = $$018;
   while(1) {
    $7 = (_strlen($$117)|0);
    $8 = (($7) + 1)|0;
    $9 = (($$117) + ($8)|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $$1$lcssa = $9;
     break;
    } else {
     $$117 = $9;
    }
   }
  }
  $12 = ((($$1$lcssa)) + 1|0);
  $13 = $12;
  $14 = (($13) - ((gb + (18144) | 0)))|0;
  $$015 = $14;
 }
 return ($$015|0);
}
function _fuzzycmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$01124 = 0, $$012 = 0, $$025 = 0, $$1$lcssa = 0, $$119 = 0, $$lcssa = 0, $$lcssa16 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $$0$lcssa = $1;$$lcssa16 = 0;
   label = 9;
  } else {
   $$01124 = $0;$$025 = $1;$7 = $2;
   while(1) {
    $4 = HEAP8[$$025>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     $$0$lcssa = $$025;$$lcssa16 = $7;
     label = 9;
     break L1;
    }
    $6 = $7&255;
    $$119 = $$01124;$27 = $7;$9 = $6;
    while(1) {
     $8 = $9 | 32;
     $10 = (($8) + -97)|0;
     $11 = ($10>>>0)>(26);
     $12 = (($9) + -48)|0;
     $13 = ($12>>>0)>(10);
     $or$cond = $13 & $11;
     if (!($or$cond)) {
      $$1$lcssa = $$119;$$lcssa = $27;
      break;
     }
     $14 = ((($$119)) + 1|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = $15&255;
     $17 = ($15<<24>>24)==(0);
     if ($17) {
      $$1$lcssa = $14;$$lcssa = 0;
      break;
     } else {
      $$119 = $14;$27 = $15;$9 = $16;
     }
    }
    $18 = $$lcssa | 32;
    $19 = ($18<<24>>24)==($4<<24>>24);
    if (!($19)) {
     $$012 = 1;
     break L1;
    }
    $20 = ((($$1$lcssa)) + 1|0);
    $21 = ((($$025)) + 1|0);
    $22 = HEAP8[$20>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     $$0$lcssa = $21;$$lcssa16 = 0;
     label = 9;
     break;
    } else {
     $$01124 = $20;$$025 = $21;$7 = $22;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $24 = HEAP8[$$0$lcssa>>0]|0;
  $25 = ($$lcssa16<<24>>24)!=($24<<24>>24);
  $26 = $25&1;
  $$012 = $26;
 }
 return ($$012|0);
}
function _iconv_close($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _iconv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0318375 = 0, $$0319379 = 0, $$0320381 = 0, $$0322 = 0, $$0323386 = 0, $$0324 = 0, $$0337 = 0, $$0337$ph = 0, $$0338 = 0, $$0342380 = 0, $$0373 = 0, $$1 = 0, $$10 = 0, $$11 = 0, $$12384 = 0, $$1325 = 0, $$1331 = 0, $$1343378 = 0, $$2326 = 0, $$2332382 = 0;
 var $$2340 = 0, $$3 = 0, $$3327383 = 0, $$3341 = 0, $$3345 = 0, $$4 = 0, $$4328 = 0, $$4346374 = 0, $$5329 = 0, $$5335 = 0, $$5347372 = 0, $$6336376 = 0, $$6377 = 0, $$7349 = 0, $$8 = 0, $$in = 0, $$lobit = 0, $$mask = 0, $$pn = 0, $$pre = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond = 0, $exitcond393 = 0, $exitcond394 = 0, $exitcond395 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond3 = 0, $or$cond352 = 0, $or$cond353 = 0;
 var $or$cond357 = 0, $or$cond361 = 0, $or$cond5 = 0, $or$cond9 = 0, $spec$select350 = 0, $spec$select351 = 0, $spec$select354 = 0, $spec$select355 = 0, $spec$select358 = 0, $spec$select359 = 0, $spec$select362 = 0, $spec$select364 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp;
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 20|0;
 $10 = $0;
 $11 = $10 & 65535;
 $12 = $10 >>> 16;
 $13 = ((gb + (18144) | 0) + ($12)|0);
 $14 = ((($13)) + 1|0);
 $15 = ((gb + (18144) | 0) + ($11)|0);
 $16 = ((($15)) + 1|0);
 $17 = $5;
 $18 = $17;
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = HEAP8[$13>>0]|0;
 $22 = HEAP8[$15>>0]|0;
 $23 = (___pthread_self_200()|0);
 $24 = ((($23)) + 188|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($1|0)==(0|0);
 do {
  if ($26) {
   $$0322 = 0;
  } else {
   $27 = HEAP32[$1>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $$0322 = 0;
   } else {
    $29 = HEAP32[$2>>2]|0;
    $30 = ($29|0)==(0);
    if ($30) {
     $$0322 = 0;
    } else {
     HEAP32[$24>>2] = (gb + (161260) | 0);
     $31 = $21&255;
     $32 = $22&255;
     $33 = (($31) + -192)|0;
     $34 = ($33>>>0)<(7);
     $35 = (($31) + 128)|0;
     $36 = $21 & -2;
     $37 = ($36<<24>>24)==(-60);
     $38 = (($32) + 128)|0;
     $39 = $31 & 254;
     $40 = ($39|0)==(196);
     $41 = ($21<<24>>24)==(-38);
     $42 = (128 - ($32))|0;
     $43 = ($42|0)==(0);
     $44 = ($21<<24>>24)==(-40);
     $45 = (($32) + -192)|0;
     $46 = ($45>>>0)>(8);
     $47 = ((gb + (166706) | 0) + ($45)|0);
     $48 = $11;
     $$pre = HEAP32[$1>>2]|0;
     $$0323386 = 0;$$in = $$pre;$52 = $29;
     L5: while(1) {
      $49 = HEAP8[$$in>>0]|0;
      $50 = $49&255;
      $51 = ($49<<24>>24)<(0);
      $brmerge = $51 | $34;
      L7: do {
       if ($brmerge) {
        do {
         switch ($21<<24>>24) {
         case -57:  {
          $$0337$ph = 84;
          label = 115;
          break L5;
          break;
         }
         case -56:  {
          $53 = (_mbrtowc($6,$$in,$52,$5)|0);
          switch ($53|0) {
          case -1:  {
           $$0337$ph = 84;
           label = 115;
           break L5;
           break;
          }
          case -2:  {
           $$0337 = 22;
           break L5;
           break;
          }
          case 0:  {
           $$0338 = 1;
           break;
          }
          default: {
           $$0338 = $53;
          }
          }
          $54 = HEAP32[$6>>2]|0;
          $$2340 = $$0338;$$8 = $54;
          label = 87;
          break L7;
          break;
         }
         case -58:  {
          $55 = ($52>>>0)<(4);
          if ($55) {
           $$0337 = 22;
           break L5;
          }
          $56 = HEAP32[$$in>>2]|0;
          $$0324 = $56;
          label = 14;
          break;
         }
         case -61: case -64:  {
          $57 = ($52>>>0)<(4);
          if ($57) {
           $$0337 = 22;
           break L5;
          }
          $58 = (_get_32($$in,$31)|0);
          $$0324 = $58;
          label = 14;
          break;
         }
         case -63: case -62: case -59: case -60:  {
          $62 = ($52>>>0)<(2);
          if ($62) {
           $$0337 = 22;
           break L5;
          }
          $63 = (_get_16($$in,$31)|0);
          $64 = $63 & -1024;
          switch ($64|0) {
          case 56320:  {
           $$0337$ph = 84;
           label = 115;
           break L5;
           break;
          }
          case 55296:  {
           break;
          }
          default: {
           $$2340 = 2;$$8 = $63;
           label = 87;
           break L7;
          }
          }
          if ($40) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $65 = ($52>>>0)<(4);
          if ($65) {
           $$0337 = 22;
           break L5;
          }
          $66 = ((($$in)) + 2|0);
          $67 = (_get_16($66,$31)|0);
          $68 = (($67) + -56320)|0;
          $69 = ($68>>>0)>(1023);
          if ($69) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $70 = $63 << 10;
          $71 = (($70) + -56557568)|0;
          $72 = (($71) + ($68))|0;
          $$2340 = 4;$$8 = $72;
          label = 87;
          break L7;
          break;
         }
         case -47:  {
          $73 = (($50) + -161)|0;
          $74 = ($73>>>0)<(63);
          if ($74) {
           $75 = (($50) + 65216)|0;
           $$2340 = 1;$$8 = $75;
           label = 87;
           break L7;
          }
          $76 = ($52>>>0)<(2);
          if ($76) {
           $$0337 = 22;
           break L5;
          }
          $77 = ((($$in)) + 1|0);
          $78 = HEAP8[$77>>0]|0;
          $79 = $78&255;
          $80 = (($50) + -129)|0;
          $81 = ($80>>>0)<(31);
          if ($81) {
           $$1325 = $80;
          } else {
           $82 = $50 & 240;
           $83 = ($82|0)==(224);
           if (!($83)) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           }
           $84 = (($50) + -193)|0;
           $$1325 = $84;
          }
          $85 = $$1325 << 1;
          $86 = (($79) + -64)|0;
          $87 = ($86>>>0)<(95);
          if ($87) {
           $88 = ($78<<24>>24)==(127);
           if ($88) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           }
           $$lobit = ($78<<24>>24) >> 7;
           $89 = $$lobit << 24 >> 24;
           $90 = (($86) + ($89))|0;
           $$1331 = $90;$$2326 = $85;
          } else {
           $91 = (($79) + -159)|0;
           $92 = ($91>>>0)<(94);
           $spec$select350 = $92 ? $91 : $79;
           $93 = $92&1;
           $spec$select351 = $85 | $93;
           $$1331 = $spec$select350;$$2326 = $spec$select351;
          }
          $94 = (((gb + (22512) | 0) + (($$2326*188)|0)|0) + ($$1331<<1)|0);
          $95 = HEAP16[$94>>1]|0;
          $96 = $95&65535;
          $97 = ($95<<16>>16)==(0);
          if ($97) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          } else {
           $$2340 = 2;$$8 = $96;
           label = 87;
           break L7;
          }
          break;
         }
         case -48:  {
          $98 = ($52>>>0)<(2);
          if ($98) {
           $$0337 = 22;
           break L5;
          }
          $99 = ((($$in)) + 1|0);
          $100 = HEAP8[$99>>0]|0;
          $101 = $100&255;
          $102 = ($49<<24>>24)==(-114);
          if ($102) {
           $103 = (($101) + -161)|0;
           $104 = ($103>>>0)>(62);
           if ($104) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           }
           $105 = (($101) + 65216)|0;
           $$2340 = 2;$$8 = $105;
           label = 87;
           break L7;
          } else {
           $106 = (($50) + -161)|0;
           $107 = (($101) + -161)|0;
           $108 = ($106>>>0)>(83);
           $109 = ($107>>>0)>(93);
           $or$cond3 = $108 | $109;
           if ($or$cond3) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           }
           $110 = (((gb + (22512) | 0) + (($106*188)|0)|0) + ($107<<1)|0);
           $111 = HEAP16[$110>>1]|0;
           $112 = $111&65535;
           $113 = ($111<<16>>16)==(0);
           if ($113) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           } else {
            $$2340 = 2;$$8 = $112;
            label = 87;
            break L7;
           }
          }
          break;
         }
         case -38:  {
          $114 = ($49&255)<(161);
          if ($114) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          break;
         }
         case -40: case -39:  {
          break;
         }
         case -32:  {
          $162 = ($52>>>0)<(2);
          if ($162) {
           $$0337 = 22;
           break L5;
          }
          $163 = ((($$in)) + 1|0);
          $164 = HEAP8[$163>>0]|0;
          $165 = $164&255;
          $166 = (($165) + -64)|0;
          $167 = ($166>>>0)>(190);
          $168 = (($165) + -127)|0;
          $169 = ($168>>>0)<(34);
          $or$cond357 = $167 | $169;
          if ($or$cond357) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $170 = ($166>>>0)>(62);
          $171 = (($165) + -98)|0;
          $spec$select358 = $170 ? $171 : $166;
          $172 = (($50) + -161)|0;
          $173 = ($172>>>0)>(88);
          if (!($173)) {
           $203 = (((gb + (96544) | 0) + (($172*314)|0)|0) + ($spec$select358<<1)|0);
           $204 = HEAP16[$203>>1]|0;
           $205 = $204&65535;
           $206 = ($172|0)==(39);
           L53: do {
            if ($206) {
             switch ($spec$select358|0) {
             case 66: case 58: case 60:  {
              $208 = 131072;
              break L53;
              break;
             }
             default: {
             }
             }
             $208 = 0;
            } else {
             $208 = 0;
            }
           } while(0);
           $207 = $208 | $205;
           $209 = ($207|0)==(0);
           if ($209) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           } else {
            $$2340 = 2;$$8 = $207;
            label = 87;
            break L7;
           }
          }
          $174 = (($50) + -135)|0;
          $175 = ($174>>>0)>(119);
          if ($175) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $176 = ($49&255)<(161);
          $177 = (($50) + -224)|0;
          $$4328 = $176 ? $174 : $177;
          $178 = ($$4328*157)|0;
          $179 = (($spec$select358) + ($178))|0;
          $180 = $179 >>> 4;
          $181 = (($180) + 4867)|0;
          $182 = ((gb + (86192) | 0) + ($181<<1)|0);
          $183 = HEAP16[$182>>1]|0;
          $184 = $183&65535;
          $185 = $179 & 15;
          $186 = $184 >>> $185;
          $187 = $186 << 17;
          $188 = $187 & 131072;
          $189 = ((gb + (86192) | 0) + ($179<<1)|0);
          $190 = HEAP16[$189>>1]|0;
          $191 = $190&65535;
          $192 = $188 | $191;
          $$mask = $192 & 196352;
          $193 = ($$mask|0)==(56320);
          if (!($193)) {
           $202 = ($192|0)==(0);
           if ($202) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           } else {
            $$2340 = 2;$$8 = $192;
            label = 87;
            break L7;
           }
          }
          if ($46) {
           $$3345 = 2;
          } else {
           $194 = HEAP8[$47>>0]|0;
           $195 = $194 << 24 >> 24;
           $$3345 = $195;
          }
          $196 = HEAP32[$4>>2]|0;
          $197 = ($$3345>>>0)>($196>>>0);
          if ($197) {
           $$0337$ph = 7;
           label = 115;
           break L5;
          }
          $198 = $191 & 255;
          $199 = ((gb + (166716) | 0) + ($198)|0);
          HEAP32[$7>>2] = $199;
          HEAP32[$8>>2] = 4;
          $200 = (_iconv($48,$7,$8,$3,$4)|0);
          $201 = (($200) + ($$0323386))|0;
          $$3341 = 2;$$4 = $201;
          break L7;
          break;
         }
         case -24:  {
          $210 = ($52>>>0)<(2);
          if ($210) {
           $$0337 = 22;
           break L5;
          }
          $211 = ((($$in)) + 1|0);
          $212 = HEAP8[$211>>0]|0;
          $213 = $212&255;
          $214 = (($50) + -161)|0;
          $215 = (($213) + -161)|0;
          $216 = ($214>>>0)>(92);
          $217 = ($215>>>0)>(93);
          $or$cond9 = $216 | $217;
          if (!($or$cond9)) {
           $248 = (((gb + (124496) | 0) + (($214*188)|0)|0) + ($215<<1)|0);
           $249 = HEAP16[$248>>1]|0;
           $250 = $249&65535;
           $251 = ($249<<16>>16)==(0);
           if ($251) {
            $$0337$ph = 84;
            label = 115;
            break L5;
           } else {
            $$2340 = 2;$$8 = $250;
            label = 87;
            break L7;
           }
          }
          $218 = (($50) + -129)|0;
          $219 = ($218>>>0)>(92);
          if ($219) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $220 = ($218>>>0)>(68);
          $221 = ($212&255)>(82);
          $or$cond11 = $220 & $221;
          if ($or$cond11) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          }
          $222 = (($213) + -65)|0;
          $223 = ($222>>>0)<(26);
          do {
           if ($223) {
            $$5335 = $222;
           } else {
            $224 = (($213) + -97)|0;
            $225 = ($224>>>0)<(26);
            if ($225) {
             $226 = (($213) + -71)|0;
             $$5335 = $226;
             break;
            }
            $227 = (($213) + -129)|0;
            $228 = ($227>>>0)<(126);
            if (!($228)) {
             $$0337$ph = 84;
             label = 115;
             break L5;
            }
            $229 = (($213) + -77)|0;
            $$5335 = $229;
           }
          } while(0);
          $230 = ($218>>>0)<(32);
          $231 = ($218*178)|0;
          $232 = ($214*84)|0;
          $233 = (($232) + 5696)|0;
          $$pn = $230 ? $231 : $233;
          $$5329 = (($$pn) + 44032)|0;
          $234 = (($$5329) + ($$5335))|0;
          $235 = ($234>>>0)<(44032);
          if ($235) {
           $$2340 = 2;$$8 = $234;
           label = 87;
           break L7;
          }
          $$6336376 = 44032;$$6377 = $234;
          while(1) {
           $236 = (($$6377) - ($$6336376))|0;
           $$0318375 = 0;$$4346374 = 0;
           while(1) {
            $$0373 = 0;$$5347372 = $$4346374;
            while(1) {
             $241 = (((gb + (124496) | 0) + (($$0318375*188)|0)|0) + ($$0373<<1)|0);
             $242 = HEAP16[$241>>1]|0;
             $243 = $242&65535;
             $244 = (($243) - ($$6336376))|0;
             $245 = ($244>>>0)<=($236>>>0);
             $246 = $245&1;
             $spec$select359 = (($$5347372) + ($246))|0;
             $247 = (($$0373) + 1)|0;
             $exitcond = ($247|0)==(94);
             if ($exitcond) {
              break;
             } else {
              $$0373 = $247;$$5347372 = $spec$select359;
             }
            }
            $240 = (($$0318375) + 1)|0;
            $exitcond393 = ($240|0)==(93);
            if ($exitcond393) {
             break;
            } else {
             $$0318375 = $240;$$4346374 = $spec$select359;
            }
           }
           $237 = (($$6377) + 1)|0;
           $238 = (($spec$select359) + ($$6377))|0;
           $239 = ($238>>>0)<($237>>>0);
           if ($239) {
            $$2340 = 2;$$8 = $238;
            label = 87;
            break L7;
           } else {
            $$6336376 = $237;$$6377 = $238;
           }
          }
          break;
         }
         default: {
          $252 = ($35>>>0)>($50>>>0);
          if ($252) {
           $$2340 = 1;$$8 = $50;
           label = 87;
           break L7;
          }
          $253 = (($50) - ($35))|0;
          $254 = ($253*5)|0;
          $255 = $254 >>> 2;
          $256 = (($14) + ($255)|0);
          $257 = HEAP8[$256>>0]|0;
          $258 = $257&255;
          $259 = $253 << 1;
          $260 = $259 & 6;
          $261 = $258 >>> $260;
          $262 = (($255) + 1)|0;
          $263 = (($14) + ($262)|0);
          $264 = HEAP8[$263>>0]|0;
          $265 = $264&255;
          $266 = (8 - ($260))|0;
          $267 = $265 << $266;
          $268 = $267 & 1023;
          $269 = $268 | $261;
          $270 = ((gb + (141984) | 0) + ($269<<1)|0);
          $271 = HEAP16[$270>>1]|0;
          $272 = $271&65535;
          $273 = ($269|0)==(0);
          $spec$select364 = $273 ? $50 : $272;
          $274 = ($spec$select364|0)==(1);
          if ($274) {
           $$0337$ph = 84;
           label = 115;
           break L5;
          } else {
           $$2340 = 1;$$8 = $spec$select364;
           label = 87;
           break L7;
          }
         }
         }
        } while(0);
        if ((label|0) == 14) {
         label = 0;
         $59 = $$0324 & -2048;
         $60 = ($59|0)==(55296);
         $61 = ($$0324>>>0)>(1114111);
         $or$cond = $61 | $60;
         if ($or$cond) {
          $$0337$ph = 84;
          label = 115;
          break L5;
         } else {
          $$2340 = 4;$$8 = $$0324;
          label = 87;
          break;
         }
        }
        $115 = (($50) + -129)|0;
        $116 = ($115>>>0)>(125);
        if ($116) {
         $$0337$ph = 84;
         label = 115;
         break L5;
        }
        $117 = ($52>>>0)<(2);
        if ($117) {
         $$0337 = 22;
         break L5;
        }
        $118 = ((($$in)) + 1|0);
        $119 = HEAP8[$118>>0]|0;
        $120 = $119&255;
        $121 = ($119&255)<(161);
        $or$cond352 = $41 & $121;
        if ($or$cond352) {
         $$0337$ph = 84;
         label = 115;
         break L5;
        }
        $122 = (($120) + -64)|0;
        $123 = ($122>>>0)>(190);
        $124 = ($119<<24>>24)==(127);
        $or$cond5 = $124 | $123;
        if (!($or$cond5)) {
         $157 = ($122>>>0)>(63);
         $158 = (($120) + -65)|0;
         $spec$select355 = $157 ? $158 : $122;
         $159 = (((gb + (38304) | 0) + (($115*380)|0)|0) + ($spec$select355<<1)|0);
         $160 = HEAP16[$159>>1]|0;
         $161 = $160&65535;
         $$2340 = 2;$$8 = $161;
         label = 87;
         break;
        }
        $125 = (($120) + -48)|0;
        $126 = ($125>>>0)<(10);
        $or$cond353 = $44 & $126;
        if (!($or$cond353)) {
         $$0337$ph = 84;
         label = 115;
         break L5;
        }
        $127 = ($52>>>0)<(4);
        if ($127) {
         $$0337 = 22;
         break L5;
        }
        $128 = ((($$in)) + 2|0);
        $129 = HEAP8[$128>>0]|0;
        $130 = $129&255;
        $131 = (($130) + -129)|0;
        $132 = ($131>>>0)>(126);
        if ($132) {
         $$0337$ph = 84;
         label = 115;
         break L5;
        }
        $133 = ((($$in)) + 3|0);
        $134 = HEAP8[$133>>0]|0;
        $135 = $134&255;
        $136 = (($135) + -48)|0;
        $137 = ($136>>>0)>(9);
        if ($137) {
         $$0337$ph = 84;
         label = 115;
         break L5;
        }
        $138 = ($115*10)|0;
        $139 = (($138) + ($120))|0;
        $140 = ($139*1260)|0;
        $141 = ($131*10)|0;
        $142 = (($140) + -60352)|0;
        $143 = (($142) + ($141))|0;
        $144 = (($143) + ($136))|0;
        $$2332382 = 0;$$3327383 = $144;
        while(1) {
         $145 = (($$3327383) - ($$2332382))|0;
         $$0320381 = 0;$$0342380 = 0;
         while(1) {
          $$0319379 = 0;$$1343378 = $$0342380;
          while(1) {
           $150 = (((gb + (38304) | 0) + (($$0320381*380)|0)|0) + ($$0319379<<1)|0);
           $151 = HEAP16[$150>>1]|0;
           $152 = $151&65535;
           $153 = (($152) - ($$2332382))|0;
           $154 = ($153>>>0)<=($145>>>0);
           $155 = $154&1;
           $spec$select354 = (($$1343378) + ($155))|0;
           $156 = (($$0319379) + 1)|0;
           $exitcond394 = ($156|0)==(190);
           if ($exitcond394) {
            break;
           } else {
            $$0319379 = $156;$$1343378 = $spec$select354;
           }
          }
          $149 = (($$0320381) + 1)|0;
          $exitcond395 = ($149|0)==(126);
          if ($exitcond395) {
           break;
          } else {
           $$0320381 = $149;$$0342380 = $spec$select354;
          }
         }
         $146 = (($$3327383) + 1)|0;
         $147 = (($spec$select354) + ($$3327383))|0;
         $148 = ($147>>>0)<($146>>>0);
         if ($148) {
          $$2340 = 4;$$8 = $147;
          label = 87;
          break;
         } else {
          $$2332382 = $146;$$3327383 = $147;
         }
        }
       } else {
        $$2340 = 1;$$8 = $50;
        label = 87;
       }
      } while(0);
      L110: do {
       if ((label|0) == 87) {
        label = 0;
        switch ($22<<24>>24) {
        case -58:  {
         $275 = HEAP32[$4>>2]|0;
         $276 = ($275>>>0)<(4);
         if ($276) {
          $$0337$ph = 7;
          label = 115;
          break L5;
         }
         $277 = HEAP32[$3>>2]|0;
         HEAP32[$277>>2] = $$8;
         $278 = ((($277)) + 4|0);
         HEAP32[$3>>2] = $278;
         $279 = (($275) + -4)|0;
         HEAP32[$4>>2] = $279;
         $$3341 = $$2340;$$4 = $$0323386;
         break L110;
         break;
        }
        case -56:  {
         $280 = HEAP32[$4>>2]|0;
         $281 = ($280>>>0)<(4);
         if ($281) {
          $282 = (_wctomb($9,$$8)|0);
          $283 = HEAP32[$4>>2]|0;
          $284 = ($283>>>0)<($282>>>0);
          if ($284) {
           label = 93;
           break L5;
          }
          $285 = HEAP32[$3>>2]|0;
          (_memcpy(($285|0),($9|0),($282|0))|0);
          $$7349 = $282;$289 = $285;
         } else {
          $286 = HEAP32[$3>>2]|0;
          $287 = (_wctomb($286,$$8)|0);
          $$7349 = $287;$289 = $286;
         }
         $288 = (($289) + ($$7349)|0);
         HEAP32[$3>>2] = $288;
         $290 = HEAP32[$4>>2]|0;
         $291 = (($290) - ($$7349))|0;
         HEAP32[$4>>2] = $291;
         $$3341 = $$2340;$$4 = $$0323386;
         break L110;
         break;
        }
        case -57:  {
         $292 = ($$8>>>0)>(127);
         if ($292) {
          $$1 = $$0323386;
          label = 97;
         } else {
          $$10 = $$8;$$3 = $$0323386;
         }
         break;
        }
        case -63: case -62: case -59: case -60:  {
         $325 = ($$8>>>0)<(65536);
         $or$cond361 = $37 | $325;
         $326 = HEAP32[$4>>2]|0;
         if ($or$cond361) {
          $327 = ($326>>>0)<(2);
          if ($327) {
           $$0337$ph = 7;
           label = 115;
           break L5;
          }
          $328 = ($$8>>>0)>(65535);
          $spec$select362 = $328 ? 65533 : $$8;
          $329 = HEAP32[$3>>2]|0;
          _put_16($329,$spec$select362,$32);
          $330 = ((($329)) + 2|0);
          HEAP32[$3>>2] = $330;
          $331 = HEAP32[$4>>2]|0;
          $332 = (($331) + -2)|0;
          HEAP32[$4>>2] = $332;
          $$3341 = $$2340;$$4 = $$0323386;
          break L110;
         } else {
          $333 = ($326>>>0)<(4);
          if ($333) {
           $$0337$ph = 7;
           label = 115;
           break L5;
          }
          $334 = (($$8) + -65536)|0;
          $335 = HEAP32[$3>>2]|0;
          $336 = $334 >>> 10;
          $337 = $336 | 55296;
          _put_16($335,$337,$32);
          $338 = ((($335)) + 2|0);
          $339 = $334 & 1023;
          $340 = $339 | 56320;
          _put_16($338,$340,$32);
          $341 = ((($335)) + 4|0);
          HEAP32[$3>>2] = $341;
          $342 = HEAP32[$4>>2]|0;
          $343 = (($342) + -4)|0;
          HEAP32[$4>>2] = $343;
          $$3341 = $$2340;$$4 = $$0323386;
          break L110;
         }
         break;
        }
        case -61: case -64:  {
         $344 = HEAP32[$4>>2]|0;
         $345 = ($344>>>0)<(4);
         if ($345) {
          $$0337$ph = 7;
          label = 115;
          break L5;
         }
         $346 = HEAP32[$3>>2]|0;
         _put_32($346,$$8,$32);
         $347 = ((($346)) + 4|0);
         HEAP32[$3>>2] = $347;
         $348 = HEAP32[$4>>2]|0;
         $349 = (($348) + -4)|0;
         HEAP32[$4>>2] = $349;
         $$3341 = $$2340;$$4 = $$0323386;
         break L110;
         break;
        }
        default: {
         $$10 = $$8;$$3 = $$0323386;
        }
        }
        L130: while(1) {
         if ((label|0) == 97) {
          label = 0;
          $293 = (($$1) + 1)|0;
          $$10 = 42;$$3 = $293;
         }
         $294 = HEAP32[$4>>2]|0;
         $295 = ($294|0)==(0);
         if ($295) {
          $$0337$ph = 7;
          label = 115;
          break L5;
         }
         $296 = ($$10>>>0)<($38>>>0);
         if ($296) {
          $$11 = $$10;
          break;
         }
         if ($43) {
          $$1 = $$3;
          label = 97;
          continue;
         }
         $$12384 = 0;
         while(1) {
          $302 = ($$12384*5)|0;
          $303 = $302 >>> 2;
          $304 = (($16) + ($303)|0);
          $305 = HEAP8[$304>>0]|0;
          $306 = $305&255;
          $307 = $$12384 << 1;
          $308 = $307 & 6;
          $309 = $306 >>> $308;
          $310 = (($303) + 1)|0;
          $311 = (($16) + ($310)|0);
          $312 = HEAP8[$311>>0]|0;
          $313 = $312&255;
          $314 = (8 - ($308))|0;
          $315 = $313 << $314;
          $316 = $315 & 1023;
          $317 = $316 | $309;
          $318 = ((gb + (141984) | 0) + ($317<<1)|0);
          $319 = HEAP16[$318>>1]|0;
          $320 = $319&65535;
          $321 = ($$10|0)==($320|0);
          if ($321) {
           label = 104;
           break L130;
          }
          $323 = (($$12384) + 1)|0;
          $324 = ($323>>>0)<($42>>>0);
          if ($324) {
           $$12384 = $323;
          } else {
           $$1 = $$3;
           label = 97;
           continue L130;
          }
         }
        }
        if ((label|0) == 104) {
         label = 0;
         $322 = (($$12384) + 128)|0;
         $$11 = $322;
        }
        $297 = $$11&255;
        $298 = HEAP32[$3>>2]|0;
        $299 = ((($298)) + 1|0);
        HEAP32[$3>>2] = $299;
        HEAP8[$298>>0] = $297;
        $300 = HEAP32[$4>>2]|0;
        $301 = (($300) + -1)|0;
        HEAP32[$4>>2] = $301;
        $$3341 = $$2340;$$4 = $$3;
       }
      } while(0);
      $350 = HEAP32[$1>>2]|0;
      $351 = (($350) + ($$3341)|0);
      HEAP32[$1>>2] = $351;
      $352 = (($52) - ($$3341))|0;
      HEAP32[$2>>2] = $352;
      $353 = ($352|0)==(0);
      if ($353) {
       label = 114;
       break;
      } else {
       $$0323386 = $$4;$$in = $351;$52 = $352;
      }
     }
     if ((label|0) == 93) {
      $$0337 = 7;
     }
     else if ((label|0) == 114) {
      HEAP32[$24>>2] = $25;
      $$0322 = $$4;
      break;
     }
     else if ((label|0) == 115) {
      $$0337 = $$0337$ph;
     }
     $354 = (___errno_location()|0);
     HEAP32[$354>>2] = $$0337;
     HEAP32[$24>>2] = $25;
     $$0322 = -1;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0322|0);
}
function ___pthread_self_200() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _mbrtowc($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$03952 = 0, $$03952$pn = 0, $$04051 = 0, $$04350 = 0, $$2 = 0, $$lcssa = 0, $$lcssa56 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $spec$select47 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($3|0)==(0|0);
 $spec$select = $5 ? (gb + (171328) | 0) : $3;
 $6 = HEAP32[$spec$select>>2]|0;
 $7 = ($1|0)==(0|0);
 L1: do {
  if ($7) {
   $8 = ($6|0)==(0);
   if ($8) {
    $$0 = 0;
   } else {
    label = 19;
   }
  } else {
   $9 = ($0|0)==(0|0);
   $spec$select47 = $9 ? $4 : $0;
   $10 = ($2|0)==(0);
   if ($10) {
    $$0 = -2;
   } else {
    $11 = ($6|0)==(0);
    if ($11) {
     $12 = HEAP8[$1>>0]|0;
     $13 = ($12<<24>>24)>(-1);
     if ($13) {
      $14 = $12&255;
      HEAP32[$spec$select47>>2] = $14;
      $15 = ($12<<24>>24)!=(0);
      $16 = $15&1;
      $$0 = $16;
      break;
     }
     $17 = (___pthread_self_509()|0);
     $18 = ((($17)) + 188|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0|0);
     $22 = HEAP8[$1>>0]|0;
     if ($21) {
      $23 = $22 << 24 >> 24;
      $24 = $23 & 57343;
      HEAP32[$spec$select47>>2] = $24;
      $$0 = 1;
      break;
     }
     $25 = $22&255;
     $26 = (($25) + -194)|0;
     $27 = ($26>>>0)>(50);
     if ($27) {
      label = 19;
      break;
     }
     $28 = ((($1)) + 1|0);
     $29 = ((gb + (160) | 0) + ($26<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($2) + -1)|0;
     $32 = ($31|0)==(0);
     if ($32) {
      $$2 = $30;
     } else {
      $$03952 = $28;$$04051 = $30;$$04350 = $31;
      label = 11;
     }
    } else {
     $$03952 = $1;$$04051 = $6;$$04350 = $2;
     label = 11;
    }
    L14: do {
     if ((label|0) == 11) {
      $33 = HEAP8[$$03952>>0]|0;
      $34 = $33&255;
      $35 = $34 >>> 3;
      $36 = (($35) + -16)|0;
      $37 = $$04051 >> 26;
      $38 = (($35) + ($37))|0;
      $39 = $36 | $38;
      $40 = ($39>>>0)>(7);
      if ($40) {
       label = 19;
       break L1;
      }
      $41 = $$04051 << 6;
      $42 = (($34) + -128)|0;
      $43 = $42 | $41;
      $44 = (($$04350) + -1)|0;
      $45 = ($43|0)<(0);
      if ($45) {
       $$03952$pn = $$03952;$47 = $43;$53 = $44;
       while(1) {
        $56 = ((($$03952$pn)) + 1|0);
        $57 = ($53|0)==(0);
        if ($57) {
         $$2 = $47;
         break L14;
        }
        $49 = HEAP8[$56>>0]|0;
        $58 = $49 & -64;
        $59 = ($58<<24>>24)==(-128);
        if (!($59)) {
         label = 19;
         break L1;
        }
        $46 = $47 << 6;
        $48 = $49&255;
        $50 = (($48) + -128)|0;
        $51 = $50 | $46;
        $52 = (($53) + -1)|0;
        $54 = ($51|0)<(0);
        if ($54) {
         $$03952$pn = $56;$47 = $51;$53 = $52;
        } else {
         $$lcssa = $52;$$lcssa56 = $51;
         break;
        }
       }
      } else {
       $$lcssa = $44;$$lcssa56 = $43;
      }
      HEAP32[$spec$select>>2] = 0;
      HEAP32[$spec$select47>>2] = $$lcssa56;
      $55 = (($2) - ($$lcssa))|0;
      $$0 = $55;
      break L1;
     }
    } while(0);
    HEAP32[$spec$select>>2] = $$2;
    $$0 = -2;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  HEAP32[$spec$select>>2] = 0;
  $60 = (___errno_location()|0);
  HEAP32[$60>>2] = 84;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _get_32($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 & 3;
 $3 = (($0) + ($2)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = $2 ^ 1;
 $8 = (($0) + ($7)|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $6;
 $13 = $2 ^ 2;
 $14 = (($0) + ($13)|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = $16 << 8;
 $18 = $12 | $17;
 $19 = $2 ^ 3;
 $20 = (($0) + ($19)|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = $18 | $22;
 return ($23|0);
}
function _get_16($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 & 1;
 $3 = (($0) + ($2)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = $2 ^ 1;
 $8 = (($0) + ($7)|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $6 | $10;
 return ($11|0);
}
function _put_16($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 & 1;
 $4 = $1 >>> 8;
 $5 = $4&255;
 $6 = (($0) + ($3)|0);
 HEAP8[$6>>0] = $5;
 $7 = $1&255;
 $8 = $3 ^ 1;
 $9 = (($0) + ($8)|0);
 HEAP8[$9>>0] = $7;
 return;
}
function _put_32($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 & 3;
 $4 = $1 >>> 24;
 $5 = $4&255;
 $6 = (($0) + ($3)|0);
 HEAP8[$6>>0] = $5;
 $7 = $1 >>> 16;
 $8 = $7&255;
 $9 = $3 ^ 1;
 $10 = (($0) + ($9)|0);
 HEAP8[$10>>0] = $8;
 $11 = $1 >>> 8;
 $12 = $11&255;
 $13 = $3 ^ 2;
 $14 = (($0) + ($13)|0);
 HEAP8[$14>>0] = $12;
 $15 = $1&255;
 $16 = $3 ^ 3;
 $17 = (($0) + ($16)|0);
 HEAP8[$17>>0] = $15;
 return;
}
function ___pthread_self_509() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _iswcntrl_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswcntrl($0)|0);
 return ($2|0);
}
function ___loc_is_allocated($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $narrow = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)!=(0|0);
 $2 = ($0|0)!=((gb + (171132) | 0)|0);
 $or$cond = $1 & $2;
 $3 = ($0|0)!=((gb + (161260) | 0)|0);
 $narrow = $3 & $or$cond;
 $4 = $narrow&1;
 return ($4|0);
}
function ___newlocale($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$03338 = 0, $$03439 = 0, $$036 = 0, $$13537 = 0, $$pre = 0, $$pre41 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond40 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 $4 = (___loc_is_allocated($2)|0);
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $12 = ($2|0)!=(0|0);
   $$03338 = 0;$$13537 = 0;
   while(1) {
    $$pre = 1 << $$13537;
    $$pre41 = $$pre & $0;
    $13 = ($$pre41|0)==(0);
    $or$cond = $12 & $13;
    if ($or$cond) {
     $14 = (($2) + ($$13537<<2)|0);
     $15 = HEAP32[$14>>2]|0;
     $$0 = $15;
    } else {
     $16 = ($$pre41|0)==(0);
     $17 = $16 ? (gb + (172139) | 0) : $1;
     $18 = (___get_locale($$13537,$17)|0);
     $$0 = $18;
    }
    $19 = ($$0|0)!=(0|0);
    $20 = $19&1;
    $trunc = (($$03338) + ($20))|0;
    $21 = (($3) + ($$13537<<2)|0);
    HEAP32[$21>>2] = $$0;
    $22 = (($$13537) + 1)|0;
    $exitcond = ($22|0)==(6);
    if ($exitcond) {
     break;
    } else {
     $$03338 = $trunc;$$13537 = $22;
    }
   }
   $trunc$clear = $trunc & 2147483647;
   switch ($trunc$clear|0) {
   case 0:  {
    $$036 = (gb + (171132) | 0);
    break L1;
    break;
   }
   case 1:  {
    $23 = HEAP32[$3>>2]|0;
    $24 = ($23|0)==((gb + (161232) | 0)|0);
    if ($24) {
     $$036 = (gb + (161260) | 0);
     break L1;
    }
    break;
   }
   default: {
   }
   }
   $$036 = $2;
  } else {
   $$03439 = 0;
   while(1) {
    $6 = 1 << $$03439;
    $7 = $6 & $0;
    $8 = ($7|0)==(0);
    if (!($8)) {
     $9 = (($2) + ($$03439<<2)|0);
     $10 = (___get_locale($$03439,$1)|0);
     HEAP32[$9>>2] = $10;
    }
    $11 = (($$03439) + 1)|0;
    $exitcond40 = ($11|0)==(6);
    if ($exitcond40) {
     $$036 = $2;
     break;
    } else {
     $$03439 = $11;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$036|0);
}
function ___strxfrm_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strlen($1)|0);
 $5 = ($4>>>0)<($2>>>0);
 if ($5) {
  (_strcpy($0,$1)|0);
 }
 return ($4|0);
}
function _strxfrm($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (___pthread_self_204()|0);
 $3 = (___strxfrm_l($0,$1,$2,0)|0);
 return ($3|0);
}
function ___pthread_self_204() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _isalpha_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isalpha($0)|0);
 return ($2|0);
}
function _iswxdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswxdigit($0)|0);
 return ($2|0);
}
function _towupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_towupper($0)|0);
 return ($2|0);
}
function _iswlower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswlower($0)|0);
 return ($2|0);
}
function _iswpunct_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswpunct($0)|0);
 return ($2|0);
}
function _isspace_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isspace($0)|0);
 return ($2|0);
}
function _freelocale($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___loc_is_allocated($0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  _free($0);
 }
 return;
}
function _iswalpha_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswalpha($0)|0);
 return ($2|0);
}
function ___nl_langinfo_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$02426 = 0, $$025 = 0, $$1$lcssa = 0, $$1$lcssa28 = 0, $$127 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 >> 16;
 $3 = $0 & 65535;
 $4 = ($0|0)==(14);
 L1: do {
  if ($4) {
   $5 = (___pthread_self_205()|0);
   $6 = ((($5)) + 188|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   $10 = $9 ? (gb + (166733) | 0) : (gb + (166739) | 0);
   $$025 = $10;
  } else {
   switch ($2|0) {
   case 1:  {
    $11 = ($3>>>0)>(1);
    if ($11) {
     $$025 = (gb + (172139) | 0);
     break L1;
    } else {
     $$0 = (gb + (166745) | 0);
     label = 8;
    }
    break;
   }
   case 2:  {
    $12 = ($3>>>0)>(49);
    if ($12) {
     $$025 = (gb + (172139) | 0);
     break L1;
    } else {
     $$0 = (gb + (143312) | 0);
     label = 8;
    }
    break;
   }
   case 4:  {
    $13 = ($3|0)==(0);
    if ($13) {
     $$1$lcssa28 = (gb + (172139) | 0);
    } else {
     $$025 = (gb + (172139) | 0);
     break L1;
    }
    break;
   }
   case 5:  {
    $14 = ($3>>>0)>(3);
    if ($14) {
     $$025 = (gb + (172139) | 0);
     break L1;
    } else {
     $$0 = (gb + (143632) | 0);
     label = 8;
    }
    break;
   }
   default: {
    $$025 = (gb + (172139) | 0);
    break L1;
   }
   }
   if ((label|0) == 8) {
    $15 = ($3|0)==(0);
    if ($15) {
     $$1$lcssa = $$0;
    } else {
     $$02426 = $3;$$127 = $$0;
     while(1) {
      $$2 = $$127;
      while(1) {
       $16 = HEAP8[$$2>>0]|0;
       $17 = ($16<<24>>24)==(0);
       $18 = ((($$2)) + 1|0);
       if ($17) {
        break;
       } else {
        $$2 = $18;
       }
      }
      $19 = (($$02426) + -1)|0;
      $20 = ($19|0)==(0);
      if ($20) {
       $$1$lcssa = $18;
       break;
      } else {
       $$02426 = $19;$$127 = $18;
      }
     }
    }
    $21 = ($2|0)==(1);
    if ($21) {
     $$025 = $$1$lcssa;
     break;
    } else {
     $$1$lcssa28 = $$1$lcssa;
    }
   }
   $22 = HEAP8[$$1$lcssa28>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $$025 = $$1$lcssa28;
   } else {
    $24 = (($1) + ($2<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (___lctrans($$1$lcssa28,$25)|0);
    $$025 = $26;
   }
  }
 } while(0);
 return ($$025|0);
}
function ___pthread_self_205() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___nl_langinfo($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_205()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (___nl_langinfo_l($0,$3)|0);
 return ($4|0);
}
function _isgraph_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isgraph($0)|0);
 return ($2|0);
}
function _towlower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_towlower($0)|0);
 return ($2|0);
}
function _tolower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_tolower($0)|0);
 return ($2|0);
}
function _iswupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswupper($0)|0);
 return ($2|0);
}
function _wctrans_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wctrans($0)|0);
 return ($2|0);
}
function _wctrans($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strcmp($0,(gb + (166748) | 0))|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = (1);
 } else {
  $3 = (_strcmp($0,(gb + (166756) | 0))|0);
  $4 = ($3|0)==(0);
  $$ = $4 ? (2) : 0;
  $$0 = $$;
 }
 return ($$0|0);
}
function _localeconv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (162084) | 0)|0);
}
function _shutdown($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $2 = sp + 8|0;
 HEAP32[$2>>2] = $0;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($2)) + 8|0);
 $5 = $2;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$vararg_buffer>>2] = 13;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $6 = (___syscall102(102,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function ___rtnetlink_enumerate($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$015 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = (_socket(16,524291,0)|0);
 $5 = ($4|0)<(0);
 if ($5) {
  $$015 = -1;
 } else {
  $6 = (___netlink_enumerate($4,1,18,$0,$2,$3)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (___netlink_enumerate($4,2,22,$1,$2,$3)|0);
   $$0 = $8;
  } else {
   $$0 = $6;
  }
  HEAP32[$vararg_buffer>>2] = $4;
  (___syscall6(6,($vararg_buffer|0))|0);
  $$015 = $$0;
 }
 STACKTOP = sp;return ($$015|0);
}
function _socket($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$017 = 0, $$old = 0, $$old18 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer11 = 0, $vararg_buffer2 = 0;
 var $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $vararg_buffer11 = sp + 32|0;
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 72|0;
 $4 = sp + 48|0;
 HEAP32[$3>>2] = $0;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = $1;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = $3;
 HEAP32[$vararg_buffer>>2] = 1;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $11 = (___syscall102(102,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 $13 = ($12|0)<(0);
 do {
  if ($13) {
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(22);
   if ($16) {
    $$old = $1 & 526336;
    $$old18 = ($$old|0)==(0);
    if ($$old18) {
     $$017 = $12;
     break;
    }
   } else {
    $17 = (___errno_location()|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)!=(93);
    $20 = $1 & 526336;
    $21 = ($20|0)==(0);
    $or$cond = $21 | $19;
    if ($or$cond) {
     $$017 = $12;
     break;
    }
   }
   HEAP32[$4>>2] = $0;
   $22 = ((($4)) + 4|0);
   $23 = $1 & -526337;
   HEAP32[$22>>2] = $23;
   $24 = ((($4)) + 8|0);
   HEAP32[$24>>2] = $2;
   $25 = ((($4)) + 12|0);
   HEAP32[$25>>2] = 0;
   $26 = ((($4)) + 16|0);
   HEAP32[$26>>2] = 0;
   $27 = ((($4)) + 20|0);
   HEAP32[$27>>2] = 0;
   $28 = $4;
   HEAP32[$vararg_buffer2>>2] = 1;
   $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
   HEAP32[$vararg_ptr5>>2] = $28;
   $29 = (___syscall102(102,($vararg_buffer2|0))|0);
   $30 = (___syscall_ret($29)|0);
   $31 = ($30|0)<(0);
   if ($31) {
    $$017 = $30;
   } else {
    $32 = $1 & 524288;
    $33 = ($32|0)==(0);
    if (!($33)) {
     HEAP32[$vararg_buffer6>>2] = $30;
     $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
     HEAP32[$vararg_ptr9>>2] = 2;
     $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
     HEAP32[$vararg_ptr10>>2] = 1;
     (___syscall221(221,($vararg_buffer6|0))|0);
    }
    $34 = $1 & 2048;
    $35 = ($34|0)==(0);
    if ($35) {
     $$017 = $30;
    } else {
     HEAP32[$vararg_buffer11>>2] = $30;
     $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
     HEAP32[$vararg_ptr14>>2] = 4;
     $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
     HEAP32[$vararg_ptr15>>2] = 2048;
     (___syscall221(221,($vararg_buffer11|0))|0);
     $$017 = $30;
    }
   }
  } else {
   $$017 = $12;
  }
 } while(0);
 STACKTOP = sp;return ($$017|0);
}
function ___netlink_enumerate($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$0$ph = 0, $$02426 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 8192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(8192|0);
 $6 = sp;
 (_memset(($6|0),0,20)|0);
 HEAP32[$6>>2] = 20;
 $7 = $2&65535;
 $8 = ((($6)) + 4|0);
 HEAP16[$8>>1] = $7;
 $9 = ((($6)) + 6|0);
 HEAP16[$9>>1] = 769;
 $10 = ((($6)) + 8|0);
 HEAP32[$10>>2] = $1;
 $11 = $3&255;
 $12 = ((($6)) + 16|0);
 HEAP8[$12>>0] = $11;
 $13 = (_send($0,$6,20,0)|0);
 $14 = ($13|0)<(0);
 L1: do {
  if ($14) {
   $$0 = $13;
  } else {
   $15 = (_recv($0,$6,8192,64)|0);
   $16 = ($15|0)<(1);
   if ($16) {
    $$0 = -1;
   } else {
    $17 = $6;
    $19 = $15;
    L4: while(1) {
     $18 = (($6) + ($19)|0);
     $20 = $18;
     $21 = (($20) - ($17))|0;
     $22 = ($21>>>0)>(15);
     L6: do {
      if ($22) {
       $$02426 = $6;$31 = $6;
       while(1) {
        $23 = ((($$02426)) + 4|0);
        $24 = HEAP16[$23>>1]|0;
        switch ($24<<16>>16) {
        case 2:  {
         $$0 = -1;
         break L1;
         break;
        }
        case 3:  {
         $$0$ph = 0;
         break L4;
         break;
        }
        default: {
        }
        }
        $25 = (mftCall_iii($4|0,($5|0),($$02426|0))|0);
        $26 = ($25|0)==(0);
        if (!($26)) {
         $$0$ph = $25;
         break L4;
        }
        $27 = HEAP32[$$02426>>2]|0;
        $28 = (($27) + 3)|0;
        $29 = $28 & -4;
        $30 = (($31) + ($29)|0);
        $32 = $30;
        $33 = (($20) - ($32))|0;
        $34 = ($33>>>0)>(15);
        if ($34) {
         $$02426 = $30;$31 = $30;
        } else {
         break L6;
        }
       }
      }
     } while(0);
     $35 = (_recv($0,$6,8192,64)|0);
     $36 = ($35|0)<(1);
     if ($36) {
      $$0 = -1;
      break L1;
     } else {
      $19 = $35;
     }
    }
    $$0 = $$0$ph;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _send($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_sendto($0,$1,$2,$3,0,0)|0);
 return ($4|0);
}
function _recv($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_recvfrom($0,$1,$2,$3,0,0)|0);
 return ($4|0);
}
function _recvfrom($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $6 = sp + 8|0;
 HEAP32[$6>>2] = $0;
 $7 = ((($6)) + 4|0);
 $8 = $1;
 HEAP32[$7>>2] = $8;
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $2;
 $10 = ((($6)) + 12|0);
 HEAP32[$10>>2] = $3;
 $11 = ((($6)) + 16|0);
 $12 = $4;
 HEAP32[$11>>2] = $12;
 $13 = ((($6)) + 20|0);
 $14 = $5;
 HEAP32[$13>>2] = $14;
 $15 = $6;
 HEAP32[$vararg_buffer>>2] = 12;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $15;
 $16 = (___syscall102(102,($vararg_buffer|0))|0);
 $17 = (___syscall_ret($16)|0);
 STACKTOP = sp;return ($17|0);
}
function _sendto($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $6 = sp + 8|0;
 HEAP32[$6>>2] = $0;
 $7 = ((($6)) + 4|0);
 $8 = $1;
 HEAP32[$7>>2] = $8;
 $9 = ((($6)) + 8|0);
 HEAP32[$9>>2] = $2;
 $10 = ((($6)) + 12|0);
 HEAP32[$10>>2] = $3;
 $11 = ((($6)) + 16|0);
 $12 = $4;
 HEAP32[$11>>2] = $12;
 $13 = ((($6)) + 20|0);
 HEAP32[$13>>2] = $5;
 $14 = $6;
 HEAP32[$vararg_buffer>>2] = 11;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $14;
 $15 = (___syscall102(102,($vararg_buffer|0))|0);
 $16 = (___syscall_ret($15)|0);
 STACKTOP = sp;return ($16|0);
}
function _if_indextoname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $2 = sp + 16|0;
 $3 = (_socket(1,524290,0)|0);
 $4 = ($3|0)<(0);
 if ($4) {
  $$0 = 0;
 } else {
  $5 = ((($2)) + 16|0);
  HEAP32[$5>>2] = $0;
  HEAP32[$vararg_buffer>>2] = $2;
  $6 = (_ioctl($3,35088,$vararg_buffer)|0);
  HEAP32[$vararg_buffer1>>2] = $3;
  (___syscall6(6,($vararg_buffer1|0))|0);
  $7 = ($6|0)<(0);
  if ($7) {
   $$0 = 0;
  } else {
   $8 = (_strncpy($1,$2,16)|0);
   $$0 = $1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _strncpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___stpncpy($0,$1,$2)|0);
 return ($0|0);
}
function ___stpncpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$037$lcssa = 0, $$03754 = 0, $$038$lcssa = 0, $$03867 = 0, $$039$lcssa = 0, $$03966 = 0, $$042$lcssa = 0, $$04265 = 0, $$055 = 0, $$1$lcssa = 0, $$140 = 0, $$143 = 0, $$153 = 0, $$2 = 0, $$24147 = 0, $$24446 = 0, $$345 = 0, $$348 = 0, $$4 = 0;
 var $$lcssa = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond64 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $4 = $0;
 $5 = $3 ^ $4;
 $6 = $5 & 3;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $8 = $3 & 3;
   $9 = ($8|0)!=(0);
   $10 = ($2|0)!=(0);
   $or$cond64 = $10 & $9;
   if ($or$cond64) {
    $$03867 = $2;$$03966 = $1;$$04265 = $0;
    while(1) {
     $11 = HEAP8[$$03966>>0]|0;
     HEAP8[$$04265>>0] = $11;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $$345 = $$04265;$$4 = $$03867;
      break L1;
     }
     $13 = (($$03867) + -1)|0;
     $14 = ((($$03966)) + 1|0);
     $15 = ((($$04265)) + 1|0);
     $16 = $14;
     $17 = $16 & 3;
     $18 = ($17|0)!=(0);
     $19 = ($13|0)!=(0);
     $or$cond = $19 & $18;
     if ($or$cond) {
      $$03867 = $13;$$03966 = $14;$$04265 = $15;
     } else {
      $$038$lcssa = $13;$$039$lcssa = $14;$$042$lcssa = $15;$$lcssa = $19;
      break;
     }
    }
   } else {
    $$038$lcssa = $2;$$039$lcssa = $1;$$042$lcssa = $0;$$lcssa = $10;
   }
   if ($$lcssa) {
    $$pr = HEAP8[$$039$lcssa>>0]|0;
    $20 = ($$pr<<24>>24)==(0);
    if ($20) {
     $$345 = $$042$lcssa;$$4 = $$038$lcssa;
    } else {
     $21 = ($$038$lcssa>>>0)>(3);
     L11: do {
      if ($21) {
       $$03754 = $$042$lcssa;$$055 = $$039$lcssa;$$153 = $$038$lcssa;
       while(1) {
        $22 = HEAP32[$$055>>2]|0;
        $23 = (($22) + -16843009)|0;
        $24 = $22 & -2139062144;
        $25 = $24 ^ -2139062144;
        $26 = $25 & $23;
        $27 = ($26|0)==(0);
        if (!($27)) {
         $$0$lcssa = $$055;$$037$lcssa = $$03754;$$1$lcssa = $$153;
         break L11;
        }
        HEAP32[$$03754>>2] = $22;
        $28 = (($$153) + -4)|0;
        $29 = ((($$055)) + 4|0);
        $30 = ((($$03754)) + 4|0);
        $31 = ($28>>>0)>(3);
        if ($31) {
         $$03754 = $30;$$055 = $29;$$153 = $28;
        } else {
         $$0$lcssa = $29;$$037$lcssa = $30;$$1$lcssa = $28;
         break;
        }
       }
      } else {
       $$0$lcssa = $$039$lcssa;$$037$lcssa = $$042$lcssa;$$1$lcssa = $$038$lcssa;
      }
     } while(0);
     $$140 = $$0$lcssa;$$143 = $$037$lcssa;$$2 = $$1$lcssa;
     label = 13;
    }
   } else {
    $$345 = $$042$lcssa;$$4 = 0;
   }
  } else {
   $$140 = $1;$$143 = $0;$$2 = $2;
   label = 13;
  }
 } while(0);
 L17: do {
  if ((label|0) == 13) {
   $32 = ($$2|0)==(0);
   if ($32) {
    $$345 = $$143;$$4 = 0;
   } else {
    $$24147 = $$140;$$24446 = $$143;$$348 = $$2;
    while(1) {
     $33 = HEAP8[$$24147>>0]|0;
     HEAP8[$$24446>>0] = $33;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $$345 = $$24446;$$4 = $$348;
      break L17;
     }
     $35 = (($$348) + -1)|0;
     $36 = ((($$24147)) + 1|0);
     $37 = ((($$24446)) + 1|0);
     $38 = ($35|0)==(0);
     if ($38) {
      $$345 = $37;$$4 = 0;
      break;
     } else {
      $$24147 = $36;$$24446 = $37;$$348 = $35;
     }
    }
   }
  }
 } while(0);
 (_memset(($$345|0),0,($$4|0))|0);
 return ($$345|0);
}
function ___res_send($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 HEAP32[$4>>2] = $0;
 HEAP32[$5>>2] = $1;
 HEAP32[$6>>2] = $2;
 HEAP32[$7>>2] = $3;
 $8 = (___res_msend(1,$4,$5,$6,$7,$3)|0);
 $9 = ($8|0)<(0);
 $10 = HEAP32[$7>>2]|0;
 $11 = $9 ? $8 : $10;
 STACKTOP = sp;return ($11|0);
}
function ___res_msend($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $6 = sp;
 $7 = (___get_resolv_conf($6,0,0)|0);
 $8 = ($7|0)<(0);
 if ($8) {
  $$0 = -1;
 } else {
  $9 = (___res_msend_rc($0,$1,$2,$3,$4,$5,$6)|0);
  $$0 = $9;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___get_resolv_conf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$07381 = 0, $$076 = 0, $$177 = 0, $$2 = 0, $$4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $spec$select = 0;
 var $storemerge$lcssa = 0, $storemerge78 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(640|0);
 $3 = sp + 256|0;
 $4 = sp;
 $5 = sp + 516|0;
 $6 = sp + 512|0;
 $7 = ((($0)) + 92|0);
 HEAP32[$7>>2] = 1;
 $8 = ((($0)) + 96|0);
 HEAP32[$8>>2] = 5;
 $9 = ((($0)) + 88|0);
 HEAP32[$9>>2] = 2;
 $10 = ($1|0)!=(0|0);
 if ($10) {
  HEAP8[$1>>0] = 0;
 }
 $11 = (___fopen_rb_ca((gb + (166846) | 0),$5,$4,256)|0);
 $12 = ($11|0)==(0|0);
 do {
  if ($12) {
   $13 = (___errno_location()|0);
   $14 = HEAP32[$13>>2]|0;
   switch ($14|0) {
   case 13: case 20: case 2:  {
    label = 47;
    break;
   }
   default: {
    $$0 = -1;
   }
   }
  } else {
   $15 = (_fgets($3,256,$11)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    (___fclose_ca($11)|0);
    label = 47;
    break;
   }
   $17 = ((($3)) + 7|0);
   $18 = ((($3)) + 10|0);
   $19 = ((($3)) + 11|0);
   $20 = ((($3)) + 6|0);
   $$07381 = 0;
   while(1) {
    $21 = (_strchr($3,10)|0);
    $22 = ($21|0)==(0|0);
    L12: do {
     if ($22) {
      $23 = HEAP32[$11>>2]|0;
      $24 = $23 & 16;
      $25 = ($24|0)==(0);
      if ($25) {
       while(1) {
        $26 = (_getc($11)|0);
        switch ($26|0) {
        case 10: case -1:  {
         $$2 = $$07381;
         break L12;
         break;
        }
        default: {
        }
        }
       }
      } else {
       label = 12;
      }
     } else {
      label = 12;
     }
    } while(0);
    do {
     if ((label|0) == 12) {
      label = 0;
      $27 = (_strncmp($3,(gb + (166764) | 0),7)|0);
      $28 = ($27|0)==(0);
      if ($28) {
       $29 = HEAP8[$17>>0]|0;
       $30 = $29 << 24 >> 24;
       $31 = (_isspace($30)|0);
       $32 = ($31|0)==(0);
       if (!($32)) {
        $33 = (_strstr($3,(gb + (166772) | 0))|0);
        $34 = ($33|0)==(0|0);
        if (!($34)) {
         $35 = ((($33)) + 6|0);
         $36 = HEAP8[$35>>0]|0;
         $37 = $36 << 24 >> 24;
         $38 = (_isdigit($37)|0);
         $39 = ($38|0)==(0);
         if (!($39)) {
          $40 = (_strtoul($35,$6,10)|0);
          $41 = HEAP32[$6>>2]|0;
          $42 = ($41|0)==($35|0);
          if (!($42)) {
           $43 = ($40>>>0)<(15);
           $44 = $43 ? $40 : 15;
           HEAP32[$7>>2] = $44;
          }
         }
        }
        $45 = (_strstr($3,(gb + (166779) | 0))|0);
        $46 = ($45|0)==(0|0);
        if (!($46)) {
         $47 = ((($45)) + 6|0);
         $48 = HEAP8[$47>>0]|0;
         $49 = $48 << 24 >> 24;
         $50 = (_isdigit($49)|0);
         $51 = ($50|0)==(0);
         if (!($51)) {
          $52 = (_strtoul($47,$6,10)|0);
          $53 = HEAP32[$6>>2]|0;
          $54 = ($53|0)==($47|0);
          if (!($54)) {
           $55 = ($52>>>0)<(10);
           $56 = $55 ? $52 : 10;
           HEAP32[$9>>2] = $56;
          }
         }
        }
        $57 = (_strstr($3,(gb + (166789) | 0))|0);
        $58 = ($57|0)==(0|0);
        if ($58) {
         $$2 = $$07381;
         break;
        }
        $59 = ((($57)) + 8|0);
        $60 = HEAP8[$59>>0]|0;
        $61 = $60 << 24 >> 24;
        $62 = (_isdigit($61)|0);
        $63 = ($62|0)==(0);
        if ($63) {
         $64 = HEAP8[$59>>0]|0;
         $65 = ($64<<24>>24)==(46);
         if (!($65)) {
          $$2 = $$07381;
          break;
         }
        }
        $66 = (_strtoul($59,$6,10)|0);
        $67 = HEAP32[$6>>2]|0;
        $68 = ($67|0)==($59|0);
        if ($68) {
         $$2 = $$07381;
         break;
        }
        $69 = ($66>>>0)<(60);
        $70 = $69 ? $66 : 60;
        HEAP32[$8>>2] = $70;
        $$2 = $$07381;
        break;
       }
      }
      $71 = (_strncmp($3,(gb + (166863) | 0),10)|0);
      $72 = ($71|0)==(0);
      if ($72) {
       $73 = HEAP8[$18>>0]|0;
       $74 = $73 << 24 >> 24;
       $75 = (_isspace($74)|0);
       $76 = ($75|0)==(0);
       if (!($76)) {
        $77 = ($$07381|0)>(2);
        if ($77) {
         $$2 = $$07381;
         break;
        }
        $$076 = $19;
        while(1) {
         $78 = HEAP8[$$076>>0]|0;
         $79 = $78 << 24 >> 24;
         $80 = (_isspace($79)|0);
         $81 = ($80|0)==(0);
         $82 = ((($$076)) + 1|0);
         if ($81) {
          break;
         } else {
          $$076 = $82;
         }
        }
        HEAP32[$6>>2] = $$076;
        $83 = HEAP8[$$076>>0]|0;
        $84 = ($83<<24>>24)==(0);
        L45: do {
         if ($84) {
          $storemerge$lcssa = $$076;
         } else {
          $86 = $83;$storemerge78 = $$076;
          while(1) {
           $85 = $86 << 24 >> 24;
           $87 = (_isspace($85)|0);
           $88 = ($87|0)==(0);
           if (!($88)) {
            $storemerge$lcssa = $storemerge78;
            break L45;
           }
           $89 = ((($storemerge78)) + 1|0);
           HEAP32[$6>>2] = $89;
           $90 = HEAP8[$89>>0]|0;
           $91 = ($90<<24>>24)==(0);
           if ($91) {
            $storemerge$lcssa = $89;
            break;
           } else {
            $86 = $90;$storemerge78 = $89;
           }
          }
         }
        } while(0);
        HEAP8[$storemerge$lcssa>>0] = 0;
        $92 = (($0) + (($$07381*28)|0)|0);
        $93 = (___lookup_ipliteral($92,$$076,0)|0);
        $94 = ($93|0)>(0);
        $95 = $94&1;
        $spec$select = (($$07381) + ($95))|0;
        $$2 = $spec$select;
        break;
       }
      }
      if ($10) {
       $96 = (_strncmp($3,(gb + (166798) | 0),6)|0);
       $97 = ($96|0)==(0);
       if (!($97)) {
        $98 = (_strncmp($3,(gb + (166805) | 0),6)|0);
        $99 = ($98|0)==(0);
        if (!($99)) {
         $$2 = $$07381;
         break;
        }
       }
       $100 = HEAP8[$20>>0]|0;
       $101 = $100 << 24 >> 24;
       $102 = (_isspace($101)|0);
       $103 = ($102|0)==(0);
       if ($103) {
        $$2 = $$07381;
       } else {
        $$177 = $17;
        while(1) {
         $104 = HEAP8[$$177>>0]|0;
         $105 = $104 << 24 >> 24;
         $106 = (_isspace($105)|0);
         $107 = ($106|0)==(0);
         $108 = ((($$177)) + 1|0);
         if ($107) {
          break;
         } else {
          $$177 = $108;
         }
        }
        $109 = (_strlen($$177)|0);
        $110 = ($109>>>0)<($2>>>0);
        if ($110) {
         $111 = (($109) + 1)|0;
         (_memcpy(($1|0),($$177|0),($111|0))|0);
         $$2 = $$07381;
        } else {
         $$2 = $$07381;
        }
       }
      } else {
       $$2 = $$07381;
      }
     }
    } while(0);
    $112 = (_fgets($3,256,$11)|0);
    $113 = ($112|0)==(0|0);
    if ($113) {
     break;
    } else {
     $$07381 = $$2;
    }
   }
   (___fclose_ca($11)|0);
   $114 = ($$2|0)==(0);
   if ($114) {
    label = 47;
   } else {
    $$4 = $$2;
    label = 48;
   }
  }
 } while(0);
 if ((label|0) == 47) {
  (___lookup_ipliteral($0,(gb + (166812) | 0),0)|0);
  $$4 = 1;
  label = 48;
 }
 if ((label|0) == 48) {
  $115 = ((($0)) + 84|0);
  HEAP32[$115>>2] = $$4;
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___res_msend_rc($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$0163242 = 0, $$0164241 = 0, $$0164241$mux = 0, $$0165 = 0, $$0166205 = 0, $$0168245 = 0, $$0170240 = 0, $$0173239 = 0, $$0173239$mux = 0, $$0178$lcssa = 0, $$0178250 = 0, $$0181$lcssa = 0, $$0181249 = 0, $$0182$lcssa = 0, $$0182248 = 0, $$1 = 0, $$1167$lcssa = 0, $$1167208 = 0, $$1169206 = 0;
 var $$1171$ph188230 = 0, $$1171$ph236 = 0, $$1174 = 0, $$1179 = 0, $$1183 = 0, $$2$lcssa = 0, $$2172224 = 0, $$2175$ph235 = 0, $$2180 = 0, $$2213 = 0, $$3 = 0, $$3176 = 0, $$4 = 0, $$4177 = 0, $$sink = 0, $$sink283 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $brmerge = 0, $brmerge259 = 0, $exitcond = 0, $exitcond281 = 0, $exitcond282 = 0, $or$cond = 0, $trunc = 0, $trunc$clear = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $7 = sp + 108|0;
 $8 = sp;
 $9 = sp + 104|0;
 $10 = sp + 96|0;
 $11 = sp + 88|0;
 $12 = sp + 84|0;
 ;HEAP32[$7>>2]=HEAP32[(gb + (171356) | 0)>>2]|0;HEAP32[$7+4>>2]=HEAP32[(gb + (171356) | 0)+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[(gb + (171356) | 0)+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[(gb + (171356) | 0)+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[(gb + (171356) | 0)+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[(gb + (171356) | 0)+20>>2]|0;HEAP32[$7+24>>2]=HEAP32[(gb + (171356) | 0)+24>>2]|0;
 dest=$8; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 (_pthread_setcancelstate(1,($9|0))|0);
 $13 = ((($6)) + 96|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14*1000)|0;
 $16 = ((($6)) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($6)) + 84|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0178$lcssa = 2;$$0181$lcssa = 0;$$0182$lcssa = 16;
 } else {
  $$0178250 = 2;$$0181249 = 0;$$0182248 = 16;
  while(1) {
   $21 = (($6) + (($$0181249*28)|0)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(2);
   if ($23) {
    $24 = (((($8) + (($$0181249*28)|0)|0)) + 4|0);
    $25 = (((($6) + (($$0181249*28)|0)|0)) + 8|0);
    (_memcpy(($24|0),($25|0),4)|0);
    $26 = (_htons(53)|0);
    $$1179 = $$0178250;$$1183 = $$0182248;$$sink = 2;$$sink283 = $26;
   } else {
    $27 = (((($8) + (($$0181249*28)|0)|0)) + 8|0);
    $28 = (((($6) + (($$0181249*28)|0)|0)) + 8|0);
    (_memcpy(($27|0),($28|0),16)|0);
    $29 = (_htons(53)|0);
    $30 = (((($6) + (($$0181249*28)|0)|0)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (((($8) + (($$0181249*28)|0)|0)) + 24|0);
    HEAP32[$32>>2] = $31;
    $$1179 = 10;$$1183 = 28;$$sink = 10;$$sink283 = $29;
   }
   $33 = (((($8) + (($$0181249*28)|0)|0)) + 2|0);
   HEAP16[$33>>1] = $$sink283;
   $34 = (($8) + (($$0181249*28)|0)|0);
   HEAP16[$34>>1] = $$sink;
   $35 = (($$0181249) + 1)|0;
   $36 = HEAP32[$18>>2]|0;
   $37 = ($35>>>0)<($36>>>0);
   if ($37) {
    $$0178250 = $$1179;$$0181249 = $35;$$0182248 = $$1183;
   } else {
    $$0178$lcssa = $$1179;$$0181$lcssa = $35;$$0182$lcssa = $$1183;
    break;
   }
  }
 }
 $38 = $$0178$lcssa&65535;
 HEAP16[$7>>1] = $38;
 $39 = (_socket($$0178$lcssa,526338,0)|0);
 $40 = ($39|0)<(0);
 $41 = ($$0178$lcssa|0)==(10);
 $or$cond = $41 & $40;
 if ($or$cond) {
  $42 = (___errno_location()|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(97);
  if ($44) {
   $45 = (_socket(2,526338,0)|0);
   $$0165 = $45;$$2180 = 2;
   label = 10;
  } else {
   $$0 = -1;
  }
 } else {
  $$0165 = $39;$$2180 = $$0178$lcssa;
  label = 10;
 }
 if ((label|0) == 10) {
  $46 = ($$0165|0)<(0);
  if ($46) {
   $$0 = -1;
  } else {
   $47 = (_bind($$0165,$7,$$0182$lcssa)|0);
   $48 = ($47|0)<(0);
   if ($48) {
    $$0 = -1;
   } else {
    $49 = $$0165;
    _pthread_cleanup_push(((fb + (11) | 0)|0),($49|0));
    $50 = HEAP32[$9>>2]|0;
    (_pthread_setcancelstate(($50|0),(0|0))|0);
    $51 = ($$2180|0)==(10);
    if ($51) {
     HEAP32[$11>>2] = 0;
     (_setsockopt($$0165,41,26,$11,4)|0);
     $52 = ($$0181$lcssa|0)==(0);
     if (!($52)) {
      $$0168245 = 0;
      while(1) {
       $53 = (($8) + (($$0168245*28)|0)|0);
       $54 = HEAP16[$53>>1]|0;
       $55 = ($54<<16>>16)==(2);
       if ($55) {
        $56 = (((($8) + (($$0168245*28)|0)|0)) + 8|0);
        $57 = (((($8) + (($$0168245*28)|0)|0)) + 20|0);
        $58 = (((($8) + (($$0168245*28)|0)|0)) + 4|0);
        (_memcpy(($57|0),($58|0),4)|0);
        (_memcpy(($56|0),((gb + (166957) | 0)|0),12)|0);
        HEAP16[$53>>1] = 10;
        HEAP32[$58>>2] = 0;
        $59 = (((($8) + (($$0168245*28)|0)|0)) + 24|0);
        HEAP32[$59>>2] = 0;
       }
       $60 = (($$0168245) + 1)|0;
       $exitcond282 = ($60|0)==($$0181$lcssa|0);
       if ($exitcond282) {
        break;
       } else {
        $$0168245 = $60;
       }
      }
     }
    }
    $61 = $0 << 2;
    (_memset(($4|0),0,($61|0))|0);
    HEAP32[$10>>2] = $$0165;
    $62 = ((($10)) + 4|0);
    HEAP16[$62>>1] = 1;
    $63 = (($15|0) / ($17|0))&-1;
    $64 = (_mtime()|0);
    $65 = ($15|0)==(0);
    L26: do {
     if (!($65)) {
      $66 = (($64) - ($63))|0;
      $67 = ($0|0)<(1);
      $68 = $0 << 1;
      $69 = ($$0181$lcssa|0)==(0);
      $$0163242 = $64;$$0164241 = $66;$$0170240 = 0;$$0173239 = 0;
      while(1) {
       $70 = (($$0163242) - ($$0164241))|0;
       $71 = ($70>>>0)<($63>>>0);
       $brmerge = $71 | $67;
       $$0173239$mux = $71 ? $$0173239 : $68;
       $$0164241$mux = $71 ? $$0164241 : $$0163242;
       if ($brmerge) {
        $$1 = $$0164241$mux;$$1174 = $$0173239$mux;
       } else {
        $$1169206 = 0;
        while(1) {
         $72 = (($4) + ($$1169206<<2)|0);
         $73 = HEAP32[$72>>2]|0;
         $74 = ($73|0)!=(0);
         $brmerge259 = $74 | $69;
         if (!($brmerge259)) {
          $75 = (($1) + ($$1169206<<2)|0);
          $76 = (($2) + ($$1169206<<2)|0);
          $$0166205 = 0;
          while(1) {
           $77 = HEAP32[$75>>2]|0;
           $78 = HEAP32[$76>>2]|0;
           $79 = (($8) + (($$0166205*28)|0)|0);
           (_sendto($$0165,$77,$78,16384,$79,$$0182$lcssa)|0);
           $80 = (($$0166205) + 1)|0;
           $exitcond = ($80|0)==($$0181$lcssa|0);
           if ($exitcond) {
            break;
           } else {
            $$0166205 = $80;
           }
          }
         }
         $81 = (($$1169206) + 1)|0;
         $exitcond281 = ($81|0)==($0|0);
         if ($exitcond281) {
          $$1 = $$0163242;$$1174 = $68;
          break;
         } else {
          $$1169206 = $81;
         }
        }
       }
       $82 = (($63) - ($$0163242))|0;
       $83 = (($82) + ($$1))|0;
       $84 = (_poll($10,1,$83)|0);
       $85 = ($84|0)<(1);
       L40: do {
        if ($85) {
         $$4 = $$0170240;$$4177 = $$1174;
        } else {
         $86 = (($3) + ($$0170240<<2)|0);
         $87 = HEAP32[$86>>2]|0;
         HEAP32[$12>>2] = $$0182$lcssa;
         $88 = (_recvfrom($$0165,$87,$5,0,$7,$12)|0);
         $89 = ($88|0)>(-1);
         if ($89) {
          $$1171$ph236 = $$0170240;$$2175$ph235 = $$1174;$149 = $88;$150 = $86;
          while(1) {
           $$1171$ph188230 = $$1171$ph236;$151 = $149;$98 = $150;
           L45: while(1) {
            $94 = ($$1171$ph188230|0)<($0|0);
            $96 = $151;
            L47: while(1) {
             $95 = ($96|0)<(4);
             do {
              if (!($95)) {
               L51: do {
                if ($69) {
                 $$1167$lcssa = 0;
                } else {
                 $$1167208 = 0;
                 while(1) {
                  $101 = (($8) + (($$1167208*28)|0)|0);
                  $102 = (_memcmp($101,$7,$$0182$lcssa)|0);
                  $103 = ($102|0)==(0);
                  if ($103) {
                   $$1167$lcssa = $$1167208;
                   break L51;
                  }
                  $104 = (($$1167208) + 1)|0;
                  $105 = ($104>>>0)<($$0181$lcssa>>>0);
                  if ($105) {
                   $$1167208 = $104;
                  } else {
                   $$1167$lcssa = $104;
                   break;
                  }
                 }
                }
               } while(0);
               $106 = ($$1167$lcssa|0)==($$0181$lcssa|0);
               if (!($106)) {
                L58: do {
                 if ($94) {
                  $107 = HEAP32[$98>>2]|0;
                  $108 = HEAP8[$107>>0]|0;
                  $109 = ((($107)) + 1|0);
                  $$2213 = $$1171$ph188230;
                  while(1) {
                   $110 = (($1) + ($$2213<<2)|0);
                   $111 = HEAP32[$110>>2]|0;
                   $112 = HEAP8[$111>>0]|0;
                   $113 = ($108<<24>>24)==($112<<24>>24);
                   if ($113) {
                    $114 = HEAP8[$109>>0]|0;
                    $115 = ((($111)) + 1|0);
                    $116 = HEAP8[$115>>0]|0;
                    $117 = ($114<<24>>24)==($116<<24>>24);
                    if ($117) {
                     $$2$lcssa = $$2213;
                     break L58;
                    }
                   }
                   $118 = (($$2213) + 1)|0;
                   $119 = ($118|0)<($0|0);
                   if ($119) {
                    $$2213 = $118;
                   } else {
                    $$2$lcssa = $118;
                    break;
                   }
                  }
                 } else {
                  $$2$lcssa = $$1171$ph188230;
                 }
                } while(0);
                $120 = ($$2$lcssa|0)==($0|0);
                if ($120) {
                 break;
                }
                $121 = (($4) + ($$2$lcssa<<2)|0);
                $122 = HEAP32[$121>>2]|0;
                $123 = ($122|0)==(0);
                if ($123) {
                 break L47;
                }
               }
              }
             } while(0);
             $97 = HEAP32[$98>>2]|0;
             HEAP32[$12>>2] = $$0182$lcssa;
             $99 = (_recvfrom($$0165,$97,$5,0,$7,$12)|0);
             $100 = ($99|0)>(-1);
             if ($100) {
              $96 = $99;
             } else {
              $$4 = $$1171$ph188230;$$4177 = $$2175$ph235;
              break L40;
             }
            }
            $124 = HEAP32[$98>>2]|0;
            $125 = ((($124)) + 3|0);
            $trunc = HEAP8[$125>>0]|0;
            $trunc$clear = $trunc & 15;
            switch ($trunc$clear<<24>>24) {
            case 2:  {
             label = 47;
             break L45;
             break;
            }
            case 3: case 0:  {
             break;
            }
            default: {
             $$3176 = $$2175$ph235;
             break L45;
            }
            }
            HEAP32[$121>>2] = $96;
            $137 = ($$2$lcssa|0)==($$1171$ph188230|0);
            L70: do {
             if ($137) {
              if ($94) {
               $$2172224 = $$1171$ph188230;
               while(1) {
                $138 = (($4) + ($$2172224<<2)|0);
                $139 = HEAP32[$138>>2]|0;
                $140 = ($139|0)==(0);
                if ($140) {
                 $$3 = $$2172224;
                 break L70;
                }
                $141 = (($$2172224) + 1)|0;
                $142 = ($141|0)<($0|0);
                if ($142) {
                 $$2172224 = $141;
                } else {
                 $$3 = $141;
                 break;
                }
               }
              } else {
               $$3 = $$1171$ph188230;
              }
             } else {
              $143 = (($3) + ($$2$lcssa<<2)|0);
              $144 = HEAP32[$143>>2]|0;
              (_memcpy(($144|0),($124|0),($96|0))|0);
              $$3 = $$1171$ph188230;
             }
            } while(0);
            $145 = ($$3|0)==($0|0);
            if ($145) {
             break L26;
            }
            $90 = (($3) + ($$3<<2)|0);
            $91 = HEAP32[$90>>2]|0;
            HEAP32[$12>>2] = $$0182$lcssa;
            $92 = (_recvfrom($$0165,$91,$5,0,$7,$12)|0);
            $93 = ($92|0)>(-1);
            if ($93) {
             $$1171$ph188230 = $$3;$151 = $92;$98 = $90;
            } else {
             $$4 = $$3;$$4177 = $$2175$ph235;
             break L40;
            }
           }
           if ((label|0) == 47) {
            label = 0;
            $126 = ($$2175$ph235|0)==(0);
            if ($126) {
             $$3176 = 0;
            } else {
             $127 = (($8) + (($$1167$lcssa*28)|0)|0);
             $128 = (($2) + ($$2$lcssa<<2)|0);
             $129 = (($1) + ($$2$lcssa<<2)|0);
             $130 = (($$2175$ph235) + -1)|0;
             $131 = HEAP32[$129>>2]|0;
             $132 = HEAP32[$128>>2]|0;
             (_sendto($$0165,$131,$132,16384,$127,$$0182$lcssa)|0);
             $$3176 = $130;
            }
           }
           $133 = (($3) + ($$1171$ph188230<<2)|0);
           $134 = HEAP32[$133>>2]|0;
           HEAP32[$12>>2] = $$0182$lcssa;
           $135 = (_recvfrom($$0165,$134,$5,0,$7,$12)|0);
           $136 = ($135|0)>(-1);
           if ($136) {
            $$1171$ph236 = $$1171$ph188230;$$2175$ph235 = $$3176;$149 = $135;$150 = $133;
           } else {
            $$4 = $$1171$ph188230;$$4177 = $$3176;
            break;
           }
          }
         } else {
          $$4 = $$0170240;$$4177 = $$1174;
         }
        }
       } while(0);
       $146 = (_mtime()|0);
       $147 = (($146) - ($64))|0;
       $148 = ($147>>>0)<($15>>>0);
       if ($148) {
        $$0163242 = $146;$$0164241 = $$1;$$0170240 = $$4;$$0173239 = $$4177;
       } else {
        break;
       }
      }
     }
    } while(0);
    _pthread_cleanup_pop(1);
    $$0 = 0;
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _htons($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___bswap_16($0)|0);
 return ($1|0);
}
function _bind($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = $3;
 HEAP32[$vararg_buffer>>2] = 2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $11 = (___syscall102(102,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function _cleanup_241($0) {
 $0 = $0|0;
 var $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 (___syscall6(6,($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function _setsockopt($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = sp + 8|0;
 HEAP32[$5>>2] = $0;
 $6 = ((($5)) + 4|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($5)) + 8|0);
 HEAP32[$7>>2] = $2;
 $8 = ((($5)) + 12|0);
 $9 = $3;
 HEAP32[$8>>2] = $9;
 $10 = ((($5)) + 16|0);
 HEAP32[$10>>2] = $4;
 $11 = ((($5)) + 20|0);
 HEAP32[$11>>2] = 0;
 $12 = $5;
 HEAP32[$vararg_buffer>>2] = 14;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $12;
 $13 = (___syscall102(102,($vararg_buffer|0))|0);
 $14 = (___syscall_ret($13)|0);
 STACKTOP = sp;return ($14|0);
}
function _mtime() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 (_clock_gettime(0,($0|0))|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1*1000)|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4|0) / 1000000)&-1;
 $6 = (($5) + ($2))|0;
 STACKTOP = sp;return ($6|0);
}
function _poll($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall168(168,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___bswap_16($0) {
 $0 = $0|0;
 var $rev = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $rev = (_llvm_bswap_i16(($0|0))|0);
 return ($rev|0);
}
function ___fopen_rb_ca($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 (_memset(($1|0),0,124)|0);
 $4 = $0;
 HEAP32[$vararg_buffer>>2] = $4;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 557056;
 $5 = (___syscall5(5,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 $7 = ((($1)) + 60|0);
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)<(0);
 if ($8) {
  $$0 = 0;
 } else {
  HEAP32[$vararg_buffer2>>2] = $6;
  $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
  HEAP32[$vararg_ptr5>>2] = 2;
  $vararg_ptr6 = ((($vararg_buffer2)) + 8|0);
  HEAP32[$vararg_ptr6>>2] = 1;
  (___syscall221(221,($vararg_buffer2|0))|0);
  HEAP32[$1>>2] = 9;
  $9 = ((($2)) + 8|0);
  $10 = ((($1)) + 44|0);
  HEAP32[$10>>2] = $9;
  $11 = (($3) + -8)|0;
  $12 = ((($1)) + 48|0);
  HEAP32[$12>>2] = $11;
  $13 = ((($1)) + 32|0);
  HEAP32[$13>>2] = (fb + (4) | 0);
  $14 = ((($1)) + 40|0);
  HEAP32[$14>>2] = (fb + (3) | 0);
  $15 = ((($1)) + 12|0);
  HEAP32[$15>>2] = (fb + (1) | 0);
  $16 = ((($1)) + 76|0);
  HEAP32[$16>>2] = -1;
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _fgets($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$05963 = 0, $$06065 = 0, $$06164 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond72 = 0, $sext$mask = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($2)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $6 = (___lockfile($2)|0);
  $16 = $6;
 } else {
  $16 = 0;
 }
 $7 = (($1) + -1)|0;
 $8 = ($1|0)<(2);
 if ($8) {
  $9 = ((($2)) + 74|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10 << 24 >> 24;
  $12 = (($11) + 255)|0;
  $13 = $12 | $11;
  $14 = $13&255;
  HEAP8[$9>>0] = $14;
  $15 = ($16|0)==(0);
  if (!($15)) {
   ___unlockfile($2);
  }
  $17 = ($7|0)==(0);
  if ($17) {
   HEAP8[$0>>0] = 0;
   $$0 = $0;
  } else {
   $$0 = 0;
  }
 } else {
  $18 = ($7|0)==(0);
  L11: do {
   if ($18) {
    $$1 = $0;
    label = 17;
   } else {
    $19 = ((($2)) + 4|0);
    $20 = ((($2)) + 8|0);
    $$06065 = $7;$$06164 = $0;
    while(1) {
     $21 = HEAP32[$19>>2]|0;
     $22 = HEAP32[$20>>2]|0;
     $23 = $21;
     $24 = (($22) - ($23))|0;
     $25 = (_memchr($21,10,$24)|0);
     $26 = ($25|0)==(0|0);
     $27 = $25;
     $28 = (1 - ($23))|0;
     $29 = (($28) + ($27))|0;
     $30 = $26 ? $24 : $29;
     $31 = ($30>>>0)<($$06065>>>0);
     $32 = $31 ? $30 : $$06065;
     (_memcpy(($$06164|0),($21|0),($32|0))|0);
     $33 = HEAP32[$19>>2]|0;
     $34 = (($33) + ($32)|0);
     HEAP32[$19>>2] = $34;
     $35 = (($$06164) + ($32)|0);
     $36 = (($$06065) - ($32))|0;
     $37 = ($36|0)!=(0);
     $or$cond = $26 & $37;
     if (!($or$cond)) {
      $$1 = $35;
      label = 17;
      break L11;
     }
     $38 = HEAP32[$20>>2]|0;
     $39 = ($34>>>0)<($38>>>0);
     if ($39) {
      $40 = ((($34)) + 1|0);
      HEAP32[$19>>2] = $40;
      $41 = HEAP8[$34>>0]|0;
      $42 = $41&255;
      $50 = $42;
     } else {
      $43 = (___uflow($2)|0);
      $44 = ($43|0)<(0);
      if ($44) {
       break;
      } else {
       $50 = $43;
      }
     }
     $49 = $50&255;
     $51 = ((($35)) + 1|0);
     HEAP8[$35>>0] = $49;
     $sext$mask = $50 & 255;
     $52 = ($sext$mask|0)==(10);
     $53 = (($36) + -1)|0;
     $54 = ($53|0)==(0);
     $or$cond72 = $52 | $54;
     if ($or$cond72) {
      $$1 = $51;
      label = 17;
      break L11;
     } else {
      $$06065 = $53;$$06164 = $51;
     }
    }
    $45 = ($35|0)==($0|0);
    if ($45) {
     $$05963 = 0;
    } else {
     $46 = HEAP32[$2>>2]|0;
     $47 = $46 & 16;
     $48 = ($47|0)==(0);
     if ($48) {
      $$05963 = 0;
     } else {
      $$1 = $35;
      label = 17;
     }
    }
   }
  } while(0);
  if ((label|0) == 17) {
   $55 = ($0|0)==(0|0);
   if ($55) {
    $$05963 = 0;
   } else {
    HEAP8[$$1>>0] = 0;
    $$05963 = $0;
   }
  }
  $56 = ($16|0)==(0);
  if ($56) {
   $$0 = $$05963;
  } else {
   ___unlockfile($2);
   $$0 = $$05963;
  }
 }
 return ($$0|0);
}
function ___fclose_ca($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (mftCall_ii($2|0,($0|0))|0);
 return ($3|0);
}
function _getc($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(0);
 if ($3) {
  label = 3;
 } else {
  $4 = (___lockfile($0)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   label = 3;
  } else {
   $15 = ((($0)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($0)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16>>>0)<($18>>>0);
   if ($19) {
    $20 = ((($16)) + 1|0);
    HEAP32[$15>>2] = $20;
    $21 = HEAP8[$16>>0]|0;
    $22 = $21&255;
    $24 = $22;
   } else {
    $23 = (___uflow($0)|0);
    $24 = $23;
   }
   $$0 = $24;
  }
 }
 do {
  if ((label|0) == 3) {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7>>>0)<($9>>>0);
   if ($10) {
    $11 = ((($7)) + 1|0);
    HEAP32[$6>>2] = $11;
    $12 = HEAP8[$7>>0]|0;
    $13 = $12&255;
    $$0 = $13;
    break;
   } else {
    $14 = (___uflow($0)|0);
    $$0 = $14;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 do {
  if ($3) {
   $$0 = $0;
  } else {
   $4 = $2 << 24 >> 24;
   $5 = (_strchr($0,$4)|0);
   $6 = ($5|0)==(0|0);
   if ($6) {
    $$0 = 0;
   } else {
    $7 = ((($1)) + 1|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $$0 = $5;
    } else {
     $10 = ((($5)) + 1|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $$0 = 0;
     } else {
      $13 = ((($1)) + 2|0);
      $14 = HEAP8[$13>>0]|0;
      $15 = ($14<<24>>24)==(0);
      if ($15) {
       $16 = (_twobyte_strstr($5,$1)|0);
       $$0 = $16;
       break;
      }
      $17 = ((($5)) + 2|0);
      $18 = HEAP8[$17>>0]|0;
      $19 = ($18<<24>>24)==(0);
      if ($19) {
       $$0 = 0;
      } else {
       $20 = ((($1)) + 3|0);
       $21 = HEAP8[$20>>0]|0;
       $22 = ($21<<24>>24)==(0);
       if ($22) {
        $23 = (_threebyte_strstr($5,$1)|0);
        $$0 = $23;
        break;
       }
       $24 = ((($5)) + 3|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = ($25<<24>>24)==(0);
       if ($26) {
        $$0 = 0;
       } else {
        $27 = ((($1)) + 4|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         $30 = (_fourbyte_strstr($5,$1)|0);
         $$0 = $30;
         break;
        } else {
         $31 = (_twoway_strstr($5,$1)|0);
         $$0 = $31;
         break;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function ___lookup_ipliteral($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$029 = 0, $$031 = 0, $$130 = 0, $$2$off0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $3 = sp + 88|0;
 $4 = sp + 72|0;
 $5 = sp;
 $6 = sp + 64|0;
 $7 = (___inet_aton($1,$3)|0);
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = ($2|0)==(10);
  if ($9) {
   $$130 = -2;
  } else {
   $10 = ((($0)) + 8|0);
   (_memcpy(($10|0),($3|0),4)|0);
   HEAP32[$0>>2] = 2;
   $11 = ((($0)) + 4|0);
   HEAP32[$11>>2] = 0;
   $$130 = 1;
  }
 } else {
  $12 = (_strchr($1,37)|0);
  $13 = ($12|0)!=(0|0);
  if ($13) {
   $14 = $12;
   $15 = $1;
   $16 = (($14) - ($15))|0;
   $17 = ($16|0)<(64);
   if ($17) {
    (_memcpy(($5|0),($1|0),($16|0))|0);
    $18 = (($5) + ($16)|0);
    HEAP8[$18>>0] = 0;
    $$031 = $5;
   } else {
    $$031 = $1;
   }
  } else {
   $$031 = $1;
  }
  $19 = (_inet_pton(10,$$031,$4)|0);
  $20 = ($19|0)<(1);
  L9: do {
   if ($20) {
    $$029 = 0;
   } else {
    $21 = ($2|0)==(2);
    if ($21) {
     $$029 = -2;
    } else {
     $22 = ((($0)) + 8|0);
     (_memcpy(($22|0),($4|0),16)|0);
     HEAP32[$0>>2] = 10;
     do {
      if ($13) {
       $23 = ((($12)) + 1|0);
       $24 = HEAP8[$23>>0]|0;
       $25 = $24 << 24 >> 24;
       $26 = (_isdigit($25)|0);
       $27 = ($26|0)==(0);
       if ($27) {
        HEAP32[$6>>2] = $12;
        $31 = $12;$45 = 0;$47 = 0;
       } else {
        $28 = (_strtoull($23,$6,10)|0);
        $29 = (getTempRet0() | 0);
        $$pre = HEAP32[$6>>2]|0;
        $31 = $$pre;$45 = $29;$47 = $28;
       }
       $30 = HEAP8[$31>>0]|0;
       $32 = ($30<<24>>24)==(0);
       if ($32) {
        $44 = ($45>>>0)>(0);
        $46 = ($47>>>0)>(4294967295);
        $48 = ($45|0)==(0);
        $49 = $48 & $46;
        $50 = $44 | $49;
        if ($50) {
         $$029 = -2;
         break L9;
        } else {
         $$2$off0 = $47;
         break;
        }
       }
       $33 = HEAP8[$4>>0]|0;
       switch ($33<<24>>24) {
       case -2:  {
        $34 = ((($4)) + 1|0);
        $35 = HEAP8[$34>>0]|0;
        $36 = $35 & -64;
        $37 = ($36<<24>>24)==(-128);
        if (!($37)) {
         $$029 = -2;
         break L9;
        }
        break;
       }
       case -1:  {
        $38 = ((($4)) + 1|0);
        $39 = HEAP8[$38>>0]|0;
        $40 = $39 & 15;
        $41 = ($40<<24>>24)==(2);
        if (!($41)) {
         $$029 = -2;
         break L9;
        }
        break;
       }
       default: {
        $$029 = -2;
        break L9;
       }
       }
       $42 = (_if_nametoindex($23)|0);
       $43 = ($42|0)==(0);
       if ($43) {
        $$029 = -2;
        break L9;
       } else {
        $$2$off0 = $42;
       }
      } else {
       $$2$off0 = 0;
      }
     } while(0);
     $51 = ((($0)) + 4|0);
     HEAP32[$51>>2] = $$2$off0;
     $$029 = 1;
    }
   }
  } while(0);
  $$130 = $$029;
 }
 STACKTOP = sp;return ($$130|0);
}
function ___inet_aton($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$021 = 0, $$02228 = 0, $$127 = 0, $$phi$trans$insert = 0, $$phi$trans$insert34 = 0, $$pre = 0, $$pre$phi36Z2D = 0, $$pre$phiZ2D = 0, $$pre35 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = sp + 16|0;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $$02228 = $0;$trunc = 0;
 L1: while(1) {
  $4 = (_strtoul($$02228,$3,0)|0);
  $5 = (($2) + ($trunc<<2)|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$3>>2]|0;
  $7 = ($6|0)==($$02228|0);
  if ($7) {
   $$021 = 0;
   break;
  }
  $8 = HEAP8[$6>>0]|0;
  switch ($8<<24>>24) {
  case 46: case 0:  {
   break;
  }
  default: {
   $$021 = 0;
   break L1;
  }
  }
  $9 = HEAP8[$$02228>>0]|0;
  $10 = $9 << 24 >> 24;
  $11 = (_isdigit($10)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $$021 = 0;
   break;
  }
  $13 = HEAP8[$6>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   label = 7;
   break;
  }
  $15 = ((($6)) + 1|0);
  $16 = (($trunc) + 1)|0;
  $17 = ($16>>>0)<(4);
  if ($17) {
   $$02228 = $15;$trunc = $16;
  } else {
   $$021 = 0;
   break;
  }
 }
 L7: do {
  if ((label|0) == 7) {
   $trunc$clear = $trunc & 2147483647;
   switch ($trunc$clear|0) {
   case 0:  {
    $18 = HEAP32[$2>>2]|0;
    $19 = $18 & 16777215;
    $20 = ((($2)) + 4|0);
    HEAP32[$20>>2] = $19;
    $21 = $18 >>> 24;
    HEAP32[$2>>2] = $21;
    $$pre$phiZ2D = $20;$23 = $19;
    label = 11;
    break;
   }
   case 1:  {
    $$phi$trans$insert = ((($2)) + 4|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$pre$phiZ2D = $$phi$trans$insert;$23 = $$pre;
    label = 11;
    break;
   }
   case 2:  {
    $$phi$trans$insert34 = ((($2)) + 8|0);
    $$pre35 = HEAP32[$$phi$trans$insert34>>2]|0;
    $$pre$phi36Z2D = $$phi$trans$insert34;$27 = $$pre35;
    label = 12;
    break;
   }
   default: {
   }
   }
   if ((label|0) == 11) {
    $22 = $23 & 65535;
    $24 = ((($2)) + 8|0);
    HEAP32[$24>>2] = $22;
    $25 = $23 >>> 16;
    HEAP32[$$pre$phiZ2D>>2] = $25;
    $$pre$phi36Z2D = $24;$27 = $22;
    label = 12;
   }
   if ((label|0) == 12) {
    $26 = $27 & 255;
    $28 = ((($2)) + 12|0);
    HEAP32[$28>>2] = $26;
    $29 = $27 >>> 8;
    HEAP32[$$pre$phi36Z2D>>2] = $29;
   }
   $$127 = 0;
   while(1) {
    $30 = (($2) + ($$127<<2)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31>>>0)>(255);
    if ($32) {
     $$021 = 0;
     break L7;
    }
    $33 = $31&255;
    $34 = (($1) + ($$127)|0);
    HEAP8[$34>>0] = $33;
    $35 = (($$127) + 1)|0;
    $36 = ($35>>>0)<(4);
    if ($36) {
     $$127 = $35;
    } else {
     $$021 = 1;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$021|0);
}
function _inet_pton($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0106 = 0, $$0107 = 0, $$0108$lcssa = 0, $$0108142 = 0, $$0110141 = 0, $$0113144 = 0, $$0116145 = 0, $$0117143 = 0, $$1 = 0, $$1109125 = 0, $$1109149$lcssa = 0, $$1109149210 = 0, $$1111148$lcssa = 0, $$1111148211 = 0, $$1114 = 0, $$2 = 0, $$2115 = 0, $$2119 = 0, $$2119$ph = 0;
 var $$3120 = 0, $$3146 = 0, $$4 = 0, $$old1 = 0, $$ph = 0, $$phi$trans$insert = 0, $$pn = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre171 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $exitcond = 0, $or$cond = 0, $or$cond11 = 0, $or$cond14 = 0, $or$cond4 = 0, $or$cond7 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 L1: do {
  switch ($0|0) {
  case 2:  {
   $$0113144 = 0;$$0117143 = $1;
   while(1) {
    $$0108142 = 0;$$0110141 = 0;
    while(1) {
     $4 = (($$0117143) + ($$0110141)|0);
     $5 = HEAP8[$4>>0]|0;
     $6 = $5 << 24 >> 24;
     $7 = (_isdigit($6)|0);
     $8 = ($7|0)==(0);
     if ($8) {
      $$0108$lcssa = $$0108142;$trunc = $$0110141;
      break;
     }
     $9 = ($$0108142*10)|0;
     $10 = HEAP8[$4>>0]|0;
     $11 = $10 << 24 >> 24;
     $12 = (($9) + -48)|0;
     $13 = (($12) + ($11))|0;
     $14 = (($$0110141) + 1)|0;
     $15 = ($14>>>0)<(3);
     if ($15) {
      $$0108142 = $13;$$0110141 = $14;
     } else {
      $$0108$lcssa = $13;$trunc = 3;
      break;
     }
    }
    $trunc$clear = $trunc & 2147483647;
    switch ($trunc$clear|0) {
    case 0:  {
     $$0107 = 0;
     break L1;
     break;
    }
    case 1:  {
     $$old1 = ($$0108$lcssa|0)>(255);
     if ($$old1) {
      $$0107 = 0;
      break L1;
     }
     break;
    }
    default: {
     $16 = HEAP8[$$0117143>>0]|0;
     $17 = ($16<<24>>24)==(48);
     $18 = ($$0108$lcssa|0)>(255);
     $or$cond = $18 | $17;
     if ($or$cond) {
      $$0107 = 0;
      break L1;
     }
    }
    }
    $19 = $$0108$lcssa&255;
    $20 = (($2) + ($$0113144)|0);
    HEAP8[$20>>0] = $19;
    $21 = (($$0117143) + ($trunc)|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)==(0);
    $24 = ($$0113144|0)==(3);
    $or$cond4 = $24 & $23;
    if ($or$cond4) {
     $$0107 = 1;
     break L1;
    }
    $25 = ($22<<24>>24)==(46);
    if (!($25)) {
     $$0107 = 0;
     break L1;
    }
    $26 = (($trunc) + 1)|0;
    $27 = (($$0117143) + ($26)|0);
    $28 = (($$0113144) + 1)|0;
    $29 = ($28>>>0)<(4);
    if ($29) {
     $$0113144 = $28;$$0117143 = $27;
    } else {
     $$0107 = 0;
     break L1;
    }
   }
   break;
  }
  case 10:  {
   $31 = HEAP8[$1>>0]|0;
   $32 = ($31<<24>>24)==(58);
   if ($32) {
    $33 = ((($1)) + 1|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(58);
    if ($35) {
     $$2119$ph = $33;$$ph = 58;
    } else {
     $$0107 = 0;
     break L1;
    }
   } else {
    $$2119$ph = $1;$$ph = $31;
   }
   $$0106 = -1;$$1114 = 0;$$2119 = $$2119$ph;$37 = $$ph;
   L20: while(1) {
    $36 = ($37<<24>>24)==(58);
    $38 = ($$0106|0)<(0);
    $or$cond7 = $38 & $36;
    if ($or$cond7) {
     $39 = $$1114 & 7;
     $40 = (($3) + ($39<<1)|0);
     HEAP16[$40>>1] = 0;
     $41 = ((($$2119)) + 1|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = ($42<<24>>24)==(0);
     if ($43) {
      $$0 = 0;$$2 = $$1114;$$2115 = $$1114;$$4 = $41;
      break;
     }
     $44 = ($$1114|0)==(7);
     if ($44) {
      $$0107 = 0;
      break L1;
     } else {
      $$1 = $$1114;$$3120 = $41;$$pre = $42;
     }
    } else {
     $45 = $37 << 24 >> 24;
     $46 = (_hexval($45)|0);
     $47 = ($46|0)>(-1);
     L26: do {
      if ($47) {
       $$1109149210 = 0;$$1111148211 = 0;$50 = $46;
       while(1) {
        $48 = $$1109149210 << 4;
        $49 = (($50) + ($48))|0;
        $51 = (($$1111148211) + 1)|0;
        $52 = ($51>>>0)<(4);
        if (!($52)) {
         $$1109125 = $49;$$pn = $51;
         break L26;
        }
        $$phi$trans$insert = (($$2119) + ($51)|0);
        $$pre171 = HEAP8[$$phi$trans$insert>>0]|0;
        $53 = $$pre171 << 24 >> 24;
        $54 = (_hexval($53)|0);
        $55 = ($54|0)>(-1);
        if ($55) {
         $$1109149210 = $49;$$1111148211 = $51;$50 = $54;
        } else {
         $$1109149$lcssa = $49;$$1111148$lcssa = $51;
         label = 23;
         break;
        }
       }
      } else {
       $$1109149$lcssa = 0;$$1111148$lcssa = 0;
       label = 23;
      }
     } while(0);
     if ((label|0) == 23) {
      label = 0;
      $56 = ($$1111148$lcssa|0)==(0);
      if ($56) {
       $$0107 = 0;
       break L1;
      } else {
       $$1109125 = $$1109149$lcssa;$$pn = $$1111148$lcssa;
      }
     }
     $$pre$phiZ2D = (($$2119) + ($$pn)|0);
     $57 = $$1109125&65535;
     $58 = $$1114 & 7;
     $59 = (($3) + ($58<<1)|0);
     HEAP16[$59>>1] = $57;
     $60 = HEAP8[$$pre$phiZ2D>>0]|0;
     $61 = ($60<<24>>24)==(0);
     if ($61) {
      label = 25;
      break;
     }
     $64 = ($$1114|0)==(7);
     if ($64) {
      $$0107 = 0;
      break L1;
     }
     switch ($60<<24>>24) {
     case 46:  {
      label = 28;
      break L20;
      break;
     }
     case 58:  {
      break;
     }
     default: {
      $$0107 = 0;
      break L1;
     }
     }
     $67 = (($$pn) + 1)|0;
     $68 = (($$2119) + ($67)|0);
     $$pre$pre = HEAP8[$68>>0]|0;
     $$1 = $$0106;$$3120 = $68;$$pre = $$pre$pre;
    }
    $69 = (($$1114) + 1)|0;
    $$0106 = $$1;$$1114 = $69;$$2119 = $$3120;$37 = $$pre;
   }
   if ((label|0) == 25) {
    $62 = ($$0106|0)>(-1);
    $63 = ($$1114|0)==(7);
    $or$cond11 = $63 | $62;
    if ($or$cond11) {
     $$0 = 0;$$2 = $$0106;$$2115 = $$1114;$$4 = $$2119;
    } else {
     $$0107 = 0;
     break L1;
    }
   }
   else if ((label|0) == 28) {
    $65 = ($$1114>>>0)<(6);
    $or$cond14 = $65 & $38;
    if ($or$cond14) {
     $$0107 = 0;
     break L1;
    }
    $66 = (($$1114) + 1)|0;
    $$0 = 1;$$2 = $$0106;$$2115 = $66;$$4 = $$2119;
   }
   $70 = ($$2|0)>(-1);
   if ($70) {
    $71 = (($3) + ($$2<<1)|0);
    $72 = ((($71)) + 14|0);
    $73 = (0 - ($$2115))|0;
    $74 = (($72) + ($73<<1)|0);
    $75 = (($$2115) + 1)|0;
    $76 = (($75) - ($$2))|0;
    $77 = $76 << 1;
    (_memmove(($74|0),($71|0),($77|0))|0);
    $78 = ($$2115|0)<(7);
    if ($78) {
     $79 = $$2115 << 1;
     $80 = (14 - ($79))|0;
     _memset(($71|0),0,($80|0))|0;
    }
   }
   $$0116145 = $2;$$3146 = 0;
   while(1) {
    $81 = (($3) + ($$3146<<1)|0);
    $82 = HEAP16[$81>>1]|0;
    $83 = ($82&65535) >>> 8;
    $84 = $83&255;
    $85 = ((($$0116145)) + 1|0);
    HEAP8[$$0116145>>0] = $84;
    $86 = HEAP16[$81>>1]|0;
    $87 = $86&255;
    $88 = ((($$0116145)) + 2|0);
    HEAP8[$85>>0] = $87;
    $89 = (($$3146) + 1)|0;
    $exitcond = ($89|0)==(8);
    if ($exitcond) {
     break;
    } else {
     $$0116145 = $88;$$3146 = $89;
    }
   }
   $90 = ($$0|0)==(0);
   if (!($90)) {
    $91 = ((($2)) + 12|0);
    $92 = (_inet_pton(2,$$4,$91)|0);
    $93 = ($92|0)<(1);
    if ($93) {
     $$0107 = 0;
     break L1;
    }
   }
   $$0107 = 1;
   break;
  }
  default: {
   $30 = (___errno_location()|0);
   HEAP32[$30>>2] = 97;
   $$0107 = -1;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0107|0);
}
function _strtoull($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox_327($0,$1,$2,-1,-1)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _if_nametoindex($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = sp + 16|0;
 $2 = (_socket(1,524290,0)|0);
 $3 = ($2|0)<(0);
 if ($3) {
  $$0 = 0;
 } else {
  (_strncpy($1,$0,16)|0);
  HEAP32[$vararg_buffer>>2] = $1;
  $4 = (_ioctl($2,35123,$vararg_buffer)|0);
  HEAP32[$vararg_buffer1>>2] = $2;
  (___syscall6(6,($vararg_buffer1|0))|0);
  $5 = ($4|0)<(0);
  $6 = ((($1)) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $5 ? 0 : $7;
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _hexval($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -48)|0;
 $2 = ($1>>>0)<(10);
 if ($2) {
  return ($1|0);
 } else {
  $3 = $0 | 32;
  $4 = (($3) + -97)|0;
  $5 = ($4>>>0)<(6);
  $6 = (($3) + -87)|0;
  $spec$select = $5 ? $6 : -1;
  return ($spec$select|0);
 }
 return (0)|0;
}
function _twobyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$in16 = 0, $$01415 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 8;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $4 | $7;
 $9 = ((($0)) + 1|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 L1: do {
  if ($11) {
   $26 = 0;
  } else {
   $12 = HEAP8[$0>>0]|0;
   $13 = $12&255;
   $14 = $13 << 8;
   $15 = $10&255;
   $16 = $14 | $15;
   $$0$in16 = $16;$$01415 = $9;
   while(1) {
    $17 = $$0$in16 & 65535;
    $18 = ($17|0)==($8|0);
    if ($18) {
     break;
    }
    $19 = $17 << 8;
    $20 = ((($$01415)) + 1|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21&255;
    $23 = $19 | $22;
    $24 = ($21<<24>>24)==(0);
    if ($24) {
     $26 = 0;
     break L1;
    } else {
     $$0$in16 = $23;$$01415 = $20;
    }
   }
   $25 = ((($$01415)) + -1|0);
   $26 = $25;
  }
 } while(0);
 return ($26|0);
}
function _threebyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016$lcssa = 0, $$01618 = 0, $$019 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = ((($1)) + 2|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = HEAP8[$0>>0]|0;
 $16 = $15&255;
 $17 = $16 << 24;
 $18 = ((($0)) + 1|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $20 << 16;
 $22 = $21 | $17;
 $23 = ((($0)) + 2|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = $25 << 8;
 $27 = $22 | $26;
 $28 = ($24<<24>>24)==(0);
 $29 = ($27|0)==($14|0);
 $or$cond17 = $29 | $28;
 if ($or$cond17) {
  $$016$lcssa = $23;$$lcssa = $28;
 } else {
  $$01618 = $23;$$019 = $27;
  while(1) {
   $30 = ((($$01618)) + 1|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31&255;
   $33 = $$019 | $32;
   $34 = $33 << 8;
   $35 = ($31<<24>>24)==(0);
   $36 = ($34|0)==($14|0);
   $or$cond = $36 | $35;
   if ($or$cond) {
    $$016$lcssa = $30;$$lcssa = $35;
    break;
   } else {
    $$01618 = $30;$$019 = $34;
   }
  }
 }
 $37 = ((($$016$lcssa)) + -2|0);
 $38 = $$lcssa ? 0 : $37;
 return ($38|0);
}
function _fourbyte_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$018$lcssa = 0, $$01820 = 0, $$021 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = ((($1)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = ((($1)) + 2|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = ((($1)) + 3|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $14 | $17;
 $19 = HEAP8[$0>>0]|0;
 $20 = $19&255;
 $21 = $20 << 24;
 $22 = ((($0)) + 1|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 16;
 $26 = $25 | $21;
 $27 = ((($0)) + 2|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = $29 << 8;
 $31 = $26 | $30;
 $32 = ((($0)) + 3|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $31 | $34;
 $36 = ($33<<24>>24)==(0);
 $37 = ($35|0)==($18|0);
 $or$cond19 = $37 | $36;
 if ($or$cond19) {
  $$018$lcssa = $32;$$lcssa = $36;
 } else {
  $$01820 = $32;$$021 = $35;
  while(1) {
   $38 = $$021 << 8;
   $39 = ((($$01820)) + 1|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = $38 | $41;
   $43 = ($40<<24>>24)==(0);
   $44 = ($42|0)==($18|0);
   $or$cond = $44 | $43;
   if ($or$cond) {
    $$018$lcssa = $39;$$lcssa = $43;
    break;
   } else {
    $$01820 = $39;$$021 = $42;
   }
  }
 }
 $45 = ((($$018$lcssa)) + -3|0);
 $46 = $$lcssa ? 0 : $45;
 return ($46|0);
}
function _twoway_strstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0166 = 0, $$0168 = 0, $$0169 = 0, $$0169$be = 0, $$0170 = 0, $$0175$lcssa237 = 0, $$0175219 = 0, $$0179218 = 0, $$0185217 = 0, $$0189$lcssa236 = 0, $$0189216 = 0, $$0193$lcssa234235 = 0, $$0193225 = 0, $$1176 = 0, $$1180 = 0, $$1186 = 0, $$1190 = 0, $$2177$$0175 = 0, $$2177$lcssa = 0, $$2177210 = 0;
 var $$2181209 = 0, $$2187208 = 0, $$2191$$0189 = 0, $$2191$$0189$ = 0, $$2191$lcssa = 0, $$2191207 = 0, $$3 = 0, $$3173 = 0, $$3178 = 0, $$3182 = 0, $$3188 = 0, $$3192 = 0, $$4183 = 0, $$4183$sink = 0, $$5 = 0, $$5184201 = 0, $$6202 = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond194 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1056|0);
 $2 = sp + 1024|0;
 $3 = sp;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($4<<24>>24)==(0);
 L1: do {
  if ($5) {
   $$0175$lcssa237 = 1;$$0189$lcssa236 = -1;$$0193$lcssa234235 = 0;$$2177$lcssa = 1;$$2191$lcssa = -1;
   label = 25;
  } else {
   $$0193225 = 0;$10 = $4;
   while(1) {
    $6 = (($0) + ($$0193225)|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     $$3 = 0;
     break L1;
    }
    $9 = $10&255;
    $11 = $9 & 31;
    $12 = 1 << $11;
    $13 = $9 >>> 5;
    $14 = (($2) + ($13<<2)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 | $12;
    HEAP32[$14>>2] = $16;
    $17 = (($$0193225) + 1)|0;
    $18 = (($3) + ($9<<2)|0);
    HEAP32[$18>>2] = $17;
    $19 = (($1) + ($17)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     break;
    } else {
     $$0193225 = $17;$10 = $20;
    }
   }
   $22 = ($17>>>0)>(1);
   if ($22) {
    $$0175219 = 1;$$0179218 = 1;$$0185217 = 0;$$0189216 = -1;$27 = 1;
    while(1) {
     $23 = (($$0179218) + ($$0189216))|0;
     $24 = (($1) + ($23)|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = (($1) + ($27)|0);
     $28 = HEAP8[$26>>0]|0;
     $29 = ($25<<24>>24)==($28<<24>>24);
     do {
      if ($29) {
       $30 = ($$0179218|0)==($$0175219|0);
       if ($30) {
        $31 = (($$0175219) + ($$0185217))|0;
        $$1176 = $$0175219;$$1180 = 1;$$1186 = $31;$$1190 = $$0189216;
        break;
       } else {
        $32 = (($$0179218) + 1)|0;
        $$1176 = $$0175219;$$1180 = $32;$$1186 = $$0185217;$$1190 = $$0189216;
        break;
       }
      } else {
       $33 = ($25&255)>($28&255);
       if ($33) {
        $34 = (($27) - ($$0189216))|0;
        $$1176 = $34;$$1180 = 1;$$1186 = $27;$$1190 = $$0189216;
        break;
       } else {
        $35 = (($$0185217) + 1)|0;
        $$1176 = 1;$$1180 = 1;$$1186 = $35;$$1190 = $$0185217;
        break;
       }
      }
     } while(0);
     $36 = (($$1180) + ($$1186))|0;
     $37 = ($36>>>0)<($17>>>0);
     if ($37) {
      $$0175219 = $$1176;$$0179218 = $$1180;$$0185217 = $$1186;$$0189216 = $$1190;$27 = $36;
     } else {
      break;
     }
    }
    if ($22) {
     $$2177210 = 1;$$2181209 = 1;$$2187208 = 0;$$2191207 = -1;$42 = 1;
     while(1) {
      $38 = (($$2181209) + ($$2191207))|0;
      $39 = (($1) + ($38)|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = (($1) + ($42)|0);
      $43 = HEAP8[$41>>0]|0;
      $44 = ($40<<24>>24)==($43<<24>>24);
      do {
       if ($44) {
        $45 = ($$2181209|0)==($$2177210|0);
        if ($45) {
         $46 = (($$2177210) + ($$2187208))|0;
         $$3178 = $$2177210;$$3182 = 1;$$3188 = $46;$$3192 = $$2191207;
         break;
        } else {
         $47 = (($$2181209) + 1)|0;
         $$3178 = $$2177210;$$3182 = $47;$$3188 = $$2187208;$$3192 = $$2191207;
         break;
        }
       } else {
        $48 = ($40&255)<($43&255);
        if ($48) {
         $49 = (($42) - ($$2191207))|0;
         $$3178 = $49;$$3182 = 1;$$3188 = $42;$$3192 = $$2191207;
         break;
        } else {
         $50 = (($$2187208) + 1)|0;
         $$3178 = 1;$$3182 = 1;$$3188 = $50;$$3192 = $$2187208;
         break;
        }
       }
      } while(0);
      $51 = (($$3182) + ($$3188))|0;
      $52 = ($51>>>0)<($17>>>0);
      if ($52) {
       $$2177210 = $$3178;$$2181209 = $$3182;$$2187208 = $$3188;$$2191207 = $$3192;$42 = $51;
      } else {
       $$0175$lcssa237 = $$1176;$$0189$lcssa236 = $$1190;$$0193$lcssa234235 = $17;$$2177$lcssa = $$3178;$$2191$lcssa = $$3192;
       label = 25;
       break;
      }
     }
    } else {
     $$0175$lcssa237 = $$1176;$$0189$lcssa236 = $$1190;$$0193$lcssa234235 = $17;$$2177$lcssa = 1;$$2191$lcssa = -1;
     label = 25;
    }
   } else {
    $$0175$lcssa237 = 1;$$0189$lcssa236 = -1;$$0193$lcssa234235 = $17;$$2177$lcssa = 1;$$2191$lcssa = -1;
    label = 25;
   }
  }
 } while(0);
 L34: do {
  if ((label|0) == 25) {
   $53 = (($$2191$lcssa) + 1)|0;
   $54 = (($$0189$lcssa236) + 1)|0;
   $55 = ($53>>>0)>($54>>>0);
   $$2177$$0175 = $55 ? $$2177$lcssa : $$0175$lcssa237;
   $$2191$$0189 = $55 ? $$2191$lcssa : $$0189$lcssa236;
   $56 = (($1) + ($$2177$$0175)|0);
   $57 = (($$2191$$0189) + 1)|0;
   $58 = (_memcmp($1,$56,$57)|0);
   $59 = ($58|0)==(0);
   if ($59) {
    $64 = (($$0193$lcssa234235) - ($$2177$$0175))|0;
    $$0168 = $64;$$5 = $$2177$$0175;$$pre$phiZ2D = $64;
   } else {
    $60 = (($$0193$lcssa234235) - ($$2191$$0189))|0;
    $61 = (($60) + -1)|0;
    $62 = ($$2191$$0189>>>0)>($61>>>0);
    $$2191$$0189$ = $62 ? $$2191$$0189 : $61;
    $63 = (($$2191$$0189$) + 1)|0;
    $$pre = (($$0193$lcssa234235) - ($63))|0;
    $$0168 = 0;$$5 = $63;$$pre$phiZ2D = $$pre;
   }
   $65 = $$0193$lcssa234235 | 63;
   $66 = (($$0193$lcssa234235) + -1)|0;
   $67 = ($$0168|0)!=(0);
   $$0166 = $0;$$0169 = 0;$$0170 = $0;
   while(1) {
    $68 = $$0170;
    $69 = $$0166;
    $70 = (($68) - ($69))|0;
    $71 = ($70>>>0)<($$0193$lcssa234235>>>0);
    do {
     if ($71) {
      $72 = (_memchr($$0170,0,$65)|0);
      $73 = ($72|0)==(0|0);
      if ($73) {
       $77 = (($$0170) + ($65)|0);
       $$3173 = $77;
       break;
      } else {
       $74 = $72;
       $75 = (($74) - ($69))|0;
       $76 = ($75>>>0)<($$0193$lcssa234235>>>0);
       if ($76) {
        $$3 = 0;
        break L34;
       } else {
        $$3173 = $72;
        break;
       }
      }
     } else {
      $$3173 = $$0170;
     }
    } while(0);
    $78 = (($$0166) + ($66)|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = $79&255;
    $81 = $80 >>> 5;
    $82 = (($2) + ($81<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = $80 & 31;
    $85 = 1 << $84;
    $86 = $85 & $83;
    $87 = ($86|0)==(0);
    L48: do {
     if ($87) {
      $$0169$be = 0;$$4183$sink = $$0193$lcssa234235;
     } else {
      $88 = (($3) + ($80<<2)|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($$0193$lcssa234235) - ($89))|0;
      $91 = ($90|0)==(0);
      if (!($91)) {
       $92 = ($$0169|0)!=(0);
       $or$cond = $67 & $92;
       $93 = ($90>>>0)<($$5>>>0);
       $or$cond194 = $or$cond & $93;
       $$4183 = $or$cond194 ? $$pre$phiZ2D : $90;
       $$0169$be = 0;$$4183$sink = $$4183;
       break;
      }
      $95 = ($57>>>0)>($$0169>>>0);
      $96 = $95 ? $57 : $$0169;
      $97 = (($1) + ($96)|0);
      $98 = HEAP8[$97>>0]|0;
      $99 = ($98<<24>>24)==(0);
      L53: do {
       if (!($99)) {
        $$5184201 = $96;$103 = $98;
        while(1) {
         $100 = (($$0166) + ($$5184201)|0);
         $101 = HEAP8[$100>>0]|0;
         $102 = ($103<<24>>24)==($101<<24>>24);
         if (!($102)) {
          break;
         }
         $104 = (($$5184201) + 1)|0;
         $105 = (($1) + ($104)|0);
         $106 = HEAP8[$105>>0]|0;
         $107 = ($106<<24>>24)==(0);
         if ($107) {
          break L53;
         } else {
          $$5184201 = $104;$103 = $106;
         }
        }
        $108 = (($$5184201) - ($$2191$$0189))|0;
        $$0169$be = 0;$$4183$sink = $108;
        break L48;
       }
      } while(0);
      if (!($95)) {
       $$3 = $$0166;
       break L34;
      }
      $$6202 = $57;
      while(1) {
       $110 = (($$6202) + -1)|0;
       $111 = (($1) + ($110)|0);
       $112 = HEAP8[$111>>0]|0;
       $113 = (($$0166) + ($110)|0);
       $114 = HEAP8[$113>>0]|0;
       $115 = ($112<<24>>24)==($114<<24>>24);
       if (!($115)) {
        $$0169$be = $$0168;$$4183$sink = $$5;
        break L48;
       }
       $109 = ($110>>>0)>($$0169>>>0);
       if ($109) {
        $$6202 = $110;
       } else {
        $$3 = $$0166;
        break L34;
       }
      }
     }
    } while(0);
    $94 = (($$0166) + ($$4183$sink)|0);
    $$0166 = $94;$$0169 = $$0169$be;$$0170 = $$3173;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$3|0);
}
function ___dn_comp($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$088 = 0, $$089 = 0, $$089101 = 0, $$089104 = 0, $$090103 = 0, $$093102 = 0, $$096$lcssa = 0, $$096100 = 0, $$09899 = 0, $$1 = 0, $$191 = 0, $$194 = 0, $$197 = 0, $$197$in = 0, $$2 = 0, $$292 = 0, $$295 = 0, $$pre = 0, $$sink = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $5 = sp + 128|0;
 $6 = sp;
 $7 = (_strnlen($0,255)|0);
 $8 = ($7|0)==(0);
 $9 = (($7) + -1)|0;
 if ($8) {
  $$0 = 0;
 } else {
  $10 = (($0) + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(46);
  $spec$select = $12 ? $9 : $7;
  $$0 = $spec$select;
 }
 $13 = ($$0>>>0)>(253);
 $14 = ($2|0)<(1);
 $or$cond = $14 | $13;
 do {
  if ($or$cond) {
   $$088 = -1;
  } else {
   $15 = ($$0|0)==(0);
   if ($15) {
    HEAP8[$1>>0] = 0;
    $$088 = 1;
    break;
   }
   $16 = (($0) + ($$0)|0);
   $17 = (_getlens($6,$0,$$0)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $$088 = -1;
   } else {
    $19 = ($3|0)!=(0|0);
    L10: do {
     if ($19) {
      $20 = HEAP32[$3>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       $$1 = $3;$$292 = 0;$$295 = 0;
      } else {
       $$089101 = ((($3)) + 4|0);
       $22 = HEAP32[$$089101>>2]|0;
       $23 = ($22|0)==(0|0);
       if ($23) {
        $$1 = $$089101;$$292 = 0;$$295 = 0;
       } else {
        $$089104 = $$089101;$$090103 = 0;$$093102 = 0;$24 = $20;$25 = $22;
        while(1) {
         $26 = (_match($5,$24,$25,$16,$6,$17)|0);
         $27 = ($26|0)>($$093102|0);
         if ($27) {
          $28 = HEAP32[$5>>2]|0;
          $29 = ($26|0)==($$0|0);
          if ($29) {
           $$1 = $$089104;$$292 = $28;$$295 = $$0;
           break L10;
          } else {
           $$191 = $28;$$194 = $26;
          }
         } else {
          $$191 = $$090103;$$194 = $$093102;
         }
         $$089 = ((($$089104)) + 4|0);
         $30 = HEAP32[$$089>>2]|0;
         $31 = ($30|0)==(0|0);
         if ($31) {
          $$1 = $$089;$$292 = $$191;$$295 = $$194;
          break L10;
         }
         $$pre = HEAP32[$3>>2]|0;
         $$089104 = $$089;$$090103 = $$191;$$093102 = $$194;$24 = $$pre;$25 = $30;
        }
       }
      }
     } else {
      $$1 = 0;$$292 = 0;$$295 = 0;
     }
    } while(0);
    $32 = (($$0) - ($$295))|0;
    $33 = (($32) + 2)|0;
    $34 = (($$295) + -1)|0;
    $35 = (($$0) + -1)|0;
    $36 = ($34>>>0)<($35>>>0);
    $37 = $36&1;
    $38 = (($33) + ($37))|0;
    $39 = ($38>>>0)>($2>>>0);
    if ($39) {
     $$088 = -1;
    } else {
     $40 = ((($1)) + 1|0);
     (_memcpy(($40|0),($0|0),($32|0))|0);
     $41 = ($32|0)==(0);
     if ($41) {
      $$096$lcssa = 0;
     } else {
      $$096100 = 0;$$09899 = 0;
      while(1) {
       $42 = (($6) + ($$09899)|0);
       $43 = HEAP8[$42>>0]|0;
       $44 = (($1) + ($$096100)|0);
       HEAP8[$44>>0] = $43;
       $45 = (($$09899) + 1)|0;
       $46 = $43&255;
       $47 = (($$096100) + 1)|0;
       $48 = (($47) + ($46))|0;
       $49 = ($48>>>0)<($32>>>0);
       if ($49) {
        $$096100 = $48;$$09899 = $45;
       } else {
        $$096$lcssa = $48;
        break;
       }
      }
     }
     $50 = ($$295|0)==(0);
     if ($50) {
      $$197$in = $$096$lcssa;$$sink = 0;
     } else {
      $51 = $$292 >>> 8;
      $52 = $51 | 192;
      $53 = $52&255;
      $54 = (($$096$lcssa) + 1)|0;
      $55 = $$292&255;
      $56 = (($1) + ($54)|0);
      HEAP8[$56>>0] = $55;
      $$197$in = $54;$$sink = $53;
     }
     $57 = (($1) + ($$096$lcssa)|0);
     HEAP8[$57>>0] = $$sink;
     $$197 = (($$197$in) + 1)|0;
     $58 = ($$197$in|0)>(1);
     $59 = ($4|0)!=(0|0);
     $or$cond3 = $59 & $58;
     $or$cond5 = $19 & $or$cond3;
     if ($or$cond5) {
      $60 = HEAP32[$3>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       $$088 = $$197;
      } else {
       $$2 = $$1;
       while(1) {
        $62 = HEAP32[$$2>>2]|0;
        $63 = ($62|0)==(0|0);
        $64 = ((($$2)) + 4|0);
        if ($63) {
         break;
        } else {
         $$2 = $64;
        }
       }
       $65 = ($64>>>0)<($4>>>0);
       if ($65) {
        HEAP32[$$2>>2] = $1;
        HEAP32[$64>>2] = 0;
        $$088 = $$197;
       } else {
        $$088 = $$197;
       }
      }
     } else {
      $$088 = $$197;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$088|0);
}
function _getlens($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$020 = 0, $$021 = 0, $$022 = 0, $$1$lcssa = 0, $$123 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$020 = 0;$$021 = 0;
 while(1) {
  $3 = ($$020|0)<($2|0);
  L3: do {
   if ($3) {
    $$123 = $$020;
    while(1) {
     $4 = (($1) + ($$123)|0);
     $5 = HEAP8[$4>>0]|0;
     $6 = ($5<<24>>24)==(46);
     if ($6) {
      $$1$lcssa = $$123;
      break L3;
     }
     $7 = (($$123) + 1)|0;
     $8 = ($7|0)<($2|0);
     if ($8) {
      $$123 = $7;
     } else {
      $$1$lcssa = $7;
      break;
     }
    }
   } else {
    $$1$lcssa = $$020;
   }
  } while(0);
  $9 = (($$1$lcssa) - ($$020))|0;
  $10 = (($9) + -1)|0;
  $11 = ($10>>>0)>(62);
  if ($11) {
   $$022 = 0;
   break;
  }
  $12 = $9&255;
  $13 = (($$021) + 1)|0;
  $14 = (($0) + ($$021)|0);
  HEAP8[$14>>0] = $12;
  $15 = ($$1$lcssa|0)==($2|0);
  $16 = (($$1$lcssa) + 1)|0;
  if ($15) {
   $$022 = $13;
   break;
  } else {
   $$020 = $16;$$021 = $13;
  }
 }
 return ($$022|0);
}
function _match($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$03438 = 0, $$035 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $6 = sp;
 $7 = (_getoffs($6,$1,$2)|0);
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   $$035 = 0;
  } else {
   $9 = (($5) + -1)|0;
   $10 = (($4) + ($9)|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11&255;
   $13 = (($7) + -1)|0;
   $14 = (($6) + ($13<<1)|0);
   $15 = HEAP16[$14>>1]|0;
   $16 = $15 << 16 >> 16;
   $17 = (($1) + ($16)|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($11<<24>>24)==($18<<24>>24);
   if ($19) {
    $20 = (0 - ($12))|0;
    $21 = (($3) + ($20)|0);
    $$03438 = 0;$23 = $21;$25 = $9;$30 = $13;$40 = $16;$42 = $12;
    while(1) {
     $39 = (($1) + ($40)|0);
     $41 = ((($39)) + 1|0);
     $43 = (_memcmp($41,$23,$42)|0);
     $44 = ($43|0)==(0);
     if (!($44)) {
      $$035 = $$03438;
      break L1;
     }
     HEAP32[$0>>2] = $40;
     $45 = ($25|0)!=(0);
     $46 = $45&1;
     $47 = (($$03438) + ($46))|0;
     $spec$select = (($47) + ($42))|0;
     $48 = ($30|0)!=(0);
     $or$cond = $45 & $48;
     if (!($or$cond)) {
      $$035 = $spec$select;
      break L1;
     }
     $22 = ((($23)) + -1|0);
     $24 = (($25) + -1)|0;
     $26 = (($4) + ($24)|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = $27&255;
     $29 = (($30) + -1)|0;
     $31 = (($6) + ($29<<1)|0);
     $32 = HEAP16[$31>>1]|0;
     $33 = $32 << 16 >> 16;
     $34 = (0 - ($28))|0;
     $35 = (($22) + ($34)|0);
     $36 = (($1) + ($33)|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = ($27<<24>>24)==($37<<24>>24);
     if ($38) {
      $$03438 = $spec$select;$23 = $35;$25 = $24;$30 = $29;$40 = $33;$42 = $28;
     } else {
      $$035 = $spec$select;
      break;
     }
    }
   } else {
    $$035 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$035|0);
}
function _getoffs($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$015 = 0, $$016 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $1;
 $$0 = 0;$$015 = $2;
 L1: while(1) {
  $$1 = $$015;
  L3: while(1) {
   $4 = HEAP8[$$1>>0]|0;
   $5 = $4&255;
   $6 = $5 & 192;
   $trunc = $6&255;
   switch ($trunc<<24>>24) {
   case 0:  {
    break L3;
    break;
   }
   case -64:  {
    break;
   }
   default: {
    $$016 = 0;
    break L1;
   }
   }
   $7 = $5 << 8;
   $8 = $7 & 16128;
   $9 = ((($$1)) + 1|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10&255;
   $12 = $8 | $11;
   $13 = (($1) + ($12)|0);
   $$1 = $13;
  }
  $14 = ($4<<24>>24)==(0);
  if ($14) {
   $$016 = $$0;
   break;
  }
  $15 = $$1;
  $16 = (($15) - ($3))|0;
  $17 = ($16|0)>(16383);
  if ($17) {
   $$016 = 0;
   break;
  }
  $18 = $16&65535;
  $19 = (($$0) + 1)|0;
  $20 = (($0) + ($$0<<1)|0);
  HEAP16[$20>>1] = $18;
  $21 = HEAP8[$$1>>0]|0;
  $22 = $21&255;
  $23 = (($22) + 1)|0;
  $24 = (($$1) + ($23)|0);
  $$0 = $19;$$015 = $24;
 }
 return ($$016|0);
}
function _getservbyname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $getservbyname$se$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (_getservbyname_r($0,$1,(gb + (171332) | 0),(gb + (171348) | 0),8,$2)|0);
 $4 = ($3|0)==(0);
 $getservbyname$se$ = $4 ? (gb + (171332) | 0) : 0;
 STACKTOP = sp;return ($getservbyname$se$|0);
}
function _getservbyname_r($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$ = 0, $$0 = 0, $$028 = 0, $$cast = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 $7 = $3;
 $8 = (0 - ($7))|0;
 $9 = $8 & 3;
 $10 = $9 | 8;
 $11 = ($10>>>0)>($4>>>0);
 do {
  if ($11) {
   $$0 = 34;
  } else {
   $12 = (($3) + ($9)|0);
   $13 = ($1|0)==(0|0);
   if ($13) {
    $$028 = 0;
   } else {
    $14 = (_strcmp($1,(gb + (166915) | 0))|0);
    $15 = ($14|0)==(0);
    if ($15) {
     $$028 = 6;
    } else {
     $16 = (_strcmp($1,(gb + (166919) | 0))|0);
     $17 = ($16|0)==(0);
     if ($17) {
      $$028 = 17;
     } else {
      $$0 = 22;
      break;
     }
    }
   }
   $18 = (___lookup_serv($6,$0,$$028,0,0)|0);
   $19 = ($18|0)<(0);
   if ($19) {
    $$off = (($18) + 11)|0;
    $switch = ($$off>>>0)<(2);
    $$ = $switch ? 12 : 2;
    $$0 = $$;
    break;
   } else {
    HEAP32[$2>>2] = $0;
    $20 = ((($2)) + 4|0);
    HEAP32[$20>>2] = $12;
    $$cast = $0;
    HEAP32[$12>>2] = $$cast;
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($21)) + 4|0);
    HEAP32[$22>>2] = 0;
    $23 = HEAP16[$6>>1]|0;
    $24 = (_htons($23)|0);
    $25 = $24&65535;
    $26 = ((($2)) + 8|0);
    HEAP32[$26>>2] = $25;
    $27 = ((($6)) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)==(6);
    $30 = $29 ? (gb + (166915) | 0) : (gb + (166919) | 0);
    $31 = ((($2)) + 12|0);
    HEAP32[$31>>2] = $30;
    HEAP32[$5>>2] = $2;
    $$0 = 0;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___lookup_serv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$081 = 0, $$082 = 0, $$1 = 0, $$184$lcssa = 0, $$18491 = 0, $$2$ph$be = 0, $$2$ph$lcssa = 0, $$2$ph98 = 0, $$3 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre105 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1296|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1296|0);
 $5 = sp + 1040|0;
 $6 = sp + 1292|0;
 $7 = sp;
 $8 = sp + 1168|0;
 HEAP32[$6>>2] = (gb + (172139) | 0);
 switch ($3|0) {
 case 1:  {
  switch ($2|0) {
  case 6: case 0:  {
   $$081 = 6;
   label = 6;
   break;
  }
  default: {
   $$1 = -8;
  }
  }
  break;
 }
 case 2:  {
  switch ($2|0) {
  case 17: case 0:  {
   $$081 = 17;
   label = 6;
   break;
  }
  default: {
   $$1 = -8;
  }
  }
  break;
 }
 case 0:  {
  $$081 = $2;
  label = 6;
  break;
 }
 default: {
  $9 = ($1|0)==(0|0);
  if ($9) {
   HEAP16[$0>>1] = 0;
   $10 = $2&255;
   $11 = ((($0)) + 2|0);
   HEAP8[$11>>0] = $10;
   $12 = $3&255;
   $13 = ((($0)) + 3|0);
   HEAP8[$13>>0] = $12;
   $$1 = 1;
  } else {
   $$1 = -8;
  }
 }
 }
 do {
  if ((label|0) == 6) {
   $14 = ($1|0)==(0|0);
   if ($14) {
    $$082 = 0;$19 = (gb + (172139) | 0);
   } else {
    $15 = HEAP8[$1>>0]|0;
    $16 = ($15<<24>>24)==(0);
    if ($16) {
     $$1 = -8;
     break;
    }
    $17 = (_strtoul($1,$6,10)|0);
    $$pre = HEAP32[$6>>2]|0;
    $$082 = $17;$19 = $$pre;
   }
   $18 = HEAP8[$19>>0]|0;
   $20 = ($18<<24>>24)==(0);
   if ($20) {
    $21 = ($$082>>>0)>(65535);
    if ($21) {
     $$1 = -8;
     break;
    }
    $22 = ($$081|0)==(17);
    if ($22) {
     $23 = ((($0)) + 3|0);
     $24 = ((($0)) + 2|0);
     $$pre105 = $$082&65535;
     $$pre$phiZ2D = $$pre105;$101 = 1;$32 = $0;$33 = $23;$34 = $24;
    } else {
     $25 = $$082&65535;
     HEAP16[$0>>1] = $25;
     $26 = ((($0)) + 3|0);
     HEAP8[$26>>0] = 1;
     $27 = ((($0)) + 2|0);
     HEAP8[$27>>0] = 6;
     $28 = ($$081|0)==(6);
     $29 = ((($0)) + 4|0);
     $30 = ((($0)) + 7|0);
     $31 = ((($0)) + 6|0);
     if ($28) {
      $$1 = 1;
      break;
     } else {
      $$pre$phiZ2D = $25;$101 = 2;$32 = $29;$33 = $30;$34 = $31;
     }
    }
    HEAP16[$32>>1] = $$pre$phiZ2D;
    HEAP8[$33>>0] = 2;
    HEAP8[$34>>0] = 17;
    $$1 = $101;
    break;
   }
   $35 = $4 & 1024;
   $36 = ($35|0)==(0);
   if ($36) {
    $37 = (_strlen($1)|0);
    $38 = (___fopen_rb_ca((gb + (166822) | 0),$8,$7,1032)|0);
    $39 = ($38|0)==(0|0);
    L21: do {
     if ($39) {
      $40 = (___errno_location()|0);
      $41 = HEAP32[$40>>2]|0;
      switch ($41|0) {
      case 13: case 20: case 2:  {
       $$0 = -8;
       break L21;
       break;
      }
      default: {
      }
      }
      $$0 = -11;
     } else {
      $42 = (_fgets($5,128,$38)|0);
      $43 = ($42|0)==(0|0);
      if ($43) {
       (___fclose_ca($38)|0);
       $$0 = -8;
       break;
      }
      $44 = ($$081|0)==(6);
      $45 = ($$081|0)==(17);
      $$2$ph98 = 0;
      L28: while(1) {
       L30: while(1) {
        $46 = (_strchr($5,35)|0);
        $47 = ($46|0)==(0|0);
        if (!($47)) {
         $48 = ((($46)) + 1|0);
         HEAP8[$46>>0] = 10;
         HEAP8[$48>>0] = 0;
        }
        $49 = (_strstr($5,$1)|0);
        $50 = ($49|0)==(0|0);
        L35: do {
         if (!($50)) {
          $52 = $49;
          while(1) {
           $51 = ($52>>>0)>($5>>>0);
           if ($51) {
            $53 = ((($52)) + -1|0);
            $54 = HEAP8[$53>>0]|0;
            $55 = $54 << 24 >> 24;
            $56 = (_isspace($55)|0);
            $57 = ($56|0)==(0);
            if (!($57)) {
             label = 29;
            }
           } else {
            label = 29;
           }
           if ((label|0) == 29) {
            label = 0;
            $58 = (($52) + ($37)|0);
            $59 = HEAP8[$58>>0]|0;
            $60 = ($59<<24>>24)==(0);
            if ($60) {
             break;
            }
            $61 = $59 << 24 >> 24;
            $62 = (_isspace($61)|0);
            $63 = ($62|0)==(0);
            if (!($63)) {
             break;
            }
           }
           $64 = ((($52)) + 1|0);
           $65 = (_strstr($64,$1)|0);
           $66 = ($65|0)==(0|0);
           if ($66) {
            break L35;
           } else {
            $52 = $65;
           }
          }
          $69 = HEAP8[$5>>0]|0;
          $70 = ($69<<24>>24)==(0);
          L46: do {
           if ($70) {
            $$184$lcssa = $5;
           } else {
            $$18491 = $5;$72 = $69;
            while(1) {
             $71 = $72 << 24 >> 24;
             $73 = (_isspace($71)|0);
             $74 = ($73|0)==(0);
             if (!($74)) {
              $$184$lcssa = $$18491;
              break L46;
             }
             $75 = ((($$18491)) + 1|0);
             $76 = HEAP8[$75>>0]|0;
             $77 = ($76<<24>>24)==(0);
             if ($77) {
              $$184$lcssa = $75;
              break;
             } else {
              $$18491 = $75;$72 = $76;
             }
            }
           }
          } while(0);
          $78 = (_strtoul($$184$lcssa,$6,10)|0);
          $79 = ($78>>>0)>(65535);
          if (!($79)) {
           $80 = HEAP32[$6>>2]|0;
           $81 = ($80|0)==($$184$lcssa|0);
           if (!($81)) {
            $82 = (_strncmp($80,(gb + (166836) | 0),4)|0);
            $83 = ($82|0)==(0);
            if (!($83)) {
             $$3 = $$2$ph98;
             break L30;
            }
            if (!($44)) {
             label = 41;
             break L30;
            }
           }
          }
         }
        } while(0);
        $67 = (_fgets($5,128,$38)|0);
        $68 = ($67|0)==(0|0);
        if ($68) {
         $$2$ph$lcssa = $$2$ph98;
         break L28;
        }
       }
       if ((label|0) == 41) {
        label = 0;
        $84 = $78&65535;
        $85 = (($0) + ($$2$ph98<<2)|0);
        HEAP16[$85>>1] = $84;
        $86 = (((($0) + ($$2$ph98<<2)|0)) + 3|0);
        HEAP8[$86>>0] = 2;
        $87 = (($$2$ph98) + 1)|0;
        $88 = (((($0) + ($$2$ph98<<2)|0)) + 2|0);
        HEAP8[$88>>0] = 17;
        $$3 = $87;
       }
       $89 = (_strncmp($80,(gb + (166841) | 0),4)|0);
       $90 = ($89|0)!=(0);
       $brmerge = $90 | $45;
       if ($brmerge) {
        $$2$ph$be = $$3;
       } else {
        $91 = $78&65535;
        $92 = (($0) + ($$3<<2)|0);
        HEAP16[$92>>1] = $91;
        $93 = (((($0) + ($$3<<2)|0)) + 3|0);
        HEAP8[$93>>0] = 1;
        $94 = (($$3) + 1)|0;
        $95 = (((($0) + ($$3<<2)|0)) + 2|0);
        HEAP8[$95>>0] = 6;
        $$2$ph$be = $94;
       }
       $96 = (_fgets($5,128,$38)|0);
       $97 = ($96|0)!=(0|0);
       $98 = ($$2$ph$be|0)<(2);
       $99 = $98 & $97;
       if ($99) {
        $$2$ph98 = $$2$ph$be;
       } else {
        $$2$ph$lcssa = $$2$ph$be;
        break;
       }
      }
      (___fclose_ca($38)|0);
      $100 = ($$2$ph$lcssa|0)>(0);
      $spec$select = $100 ? $$2$ph$lcssa : -8;
      $$0 = $spec$select;
     }
    } while(0);
    $$1 = $$0;
   } else {
    $$1 = -8;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _accept4($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 40|0;
 $5 = ($3|0)==(0);
 do {
  if ($5) {
   $6 = (_accept($0,$1,$2)|0);
   $$1 = $6;
  } else {
   HEAP32[$4>>2] = $0;
   $7 = ((($4)) + 4|0);
   $8 = $1;
   HEAP32[$7>>2] = $8;
   $9 = ((($4)) + 8|0);
   $10 = $2;
   HEAP32[$9>>2] = $10;
   $11 = ((($4)) + 12|0);
   HEAP32[$11>>2] = $3;
   $12 = ((($4)) + 16|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($4)) + 20|0);
   HEAP32[$13>>2] = 0;
   $14 = $4;
   HEAP32[$vararg_buffer>>2] = 18;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $14;
   $15 = (___syscall102(102,($vararg_buffer|0))|0);
   $16 = (___syscall_ret($15)|0);
   $17 = ($16|0)>(-1);
   if ($17) {
    $$1 = $16;
   } else {
    $18 = (___errno_location()|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(38);
    if (!($20)) {
     $21 = (___errno_location()|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(22);
     if (!($23)) {
      $$1 = $16;
      break;
     }
    }
    $24 = (_accept($0,$1,$2)|0);
    $25 = ($24|0)<(0);
    if ($25) {
     $$1 = $24;
    } else {
     $26 = $3 & 524288;
     $27 = ($26|0)==(0);
     if (!($27)) {
      HEAP32[$vararg_buffer2>>2] = $24;
      $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
      HEAP32[$vararg_ptr5>>2] = 2;
      $vararg_ptr6 = ((($vararg_buffer2)) + 8|0);
      HEAP32[$vararg_ptr6>>2] = 1;
      (___syscall221(221,($vararg_buffer2|0))|0);
     }
     $28 = $3 & 2048;
     $29 = ($28|0)==(0);
     if ($29) {
      $$1 = $24;
     } else {
      HEAP32[$vararg_buffer7>>2] = $24;
      $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
      HEAP32[$vararg_ptr10>>2] = 4;
      $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
      HEAP32[$vararg_ptr11>>2] = 2048;
      (___syscall221(221,($vararg_buffer7|0))|0);
      $$1 = $24;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _accept($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 $7 = $2;
 HEAP32[$6>>2] = $7;
 $8 = ((($3)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($3)) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = $3;
 HEAP32[$vararg_buffer>>2] = 5;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $11;
 $12 = (___syscall102(102,($vararg_buffer|0))|0);
 $13 = (___syscall_ret($12)|0);
 STACKTOP = sp;return ($13|0);
}
function _if_freenameindex($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($0);
 return;
}
function _ntohl($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___bswap_32($0)|0);
 return ($1|0);
}
function ___bswap_32($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_llvm_bswap_i32(($0|0))|0);
 return ($1|0);
}
function ___dns_doqueries($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0140 = 0, $$0141$lcssa = 0, $$0141262 = 0, $$0143$ph236 = 0, $$0147$ph235 = 0, $$0150$ph234 = 0, $$0154178180 = 0, $$0155 = 0, $$0156$ph233 = 0, $$0158$ph261 = 0, $$0163$ph260 = 0, $$0166$ph259 = 0, $$0170$lcssa = 0, $$0170242 = 0, $$1142239 = 0, $$1144$ph$lcssa = 0, $$1144$ph227 = 0, $$1148$ph$lcssa = 0, $$1148$ph226 = 0;
 var $$1151$ph$lcssa = 0, $$1151$ph225 = 0, $$1157$ph$lcssa = 0, $$1157$ph224 = 0, $$2145 = 0, $$2149 = 0, $$2152 = 0, $$2165 = 0, $$2194 = 0, $$3$lcssa = 0, $$3146 = 0, $$3153 = 0, $$3161 = 0, $$3169 = 0, $$3200 = 0, $$4 = 0, $$4182 = 0, $$lcssa = 0, $$pre = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond = 0, $exitcond286 = 0, $exitcond287 = 0, $exitcond326 = 0, $or$cond = 0, $spec$select = 0, $spec$select171 = 0, $trunc = 0;
 var $trunc$clear = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(896|0);
 $4 = sp + 764|0;
 $5 = sp + 448|0;
 $6 = sp + 384|0;
 $7 = sp + 736|0;
 $8 = sp + 288|0;
 $9 = sp;
 $10 = sp + 728|0;
 $11 = sp + 720|0;
 $12 = sp + 712|0;
 $13 = sp + 708|0;
 $14 = sp + 704|0;
 $15 = (_time((0|0))|0);
 ;HEAP32[$7>>2]=HEAP32[(gb + (171356) | 0)>>2]|0;HEAP32[$7+4>>2]=HEAP32[(gb + (171356) | 0)+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[(gb + (171356) | 0)+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[(gb + (171356) | 0)+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[(gb + (171356) | 0)+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[(gb + (171356) | 0)+20>>2]|0;HEAP32[$7+24>>2]=HEAP32[(gb + (171356) | 0)+24>>2]|0;
 dest=$8; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 _memset(($9|0),0,280)|0;
 (_pthread_setcancelstate(1,($12|0))|0);
 $16 = (_strlen($1)|0);
 $17 = (($16) + -1)|0;
 $18 = ($17>>>0)>(253);
 L1: do {
  if ($18) {
   $$0 = -2;
  } else {
   $19 = ((($9)) + 5|0);
   HEAP8[$19>>0] = 1;
   $20 = ((($9)) + 2|0);
   HEAP8[$20>>0] = 1;
   $21 = ((($9)) + 13|0);
   (_strcpy($21,$1)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $$0141$lcssa = 13;
   } else {
    $$0141262 = 13;
    while(1) {
     $$0140 = $$0141262;
     L7: while(1) {
      $24 = (($9) + ($$0140)|0);
      $25 = HEAP8[$24>>0]|0;
      switch ($25<<24>>24) {
      case 46: case 0:  {
       break L7;
       break;
      }
      default: {
      }
      }
      $26 = (($$0140) + 1)|0;
      $$0140 = $26;
     }
     $27 = (($$0140) - ($$0141262))|0;
     $28 = (($27) + -1)|0;
     $29 = ($28>>>0)>(62);
     if ($29) {
      $$0 = -2;
      break L1;
     }
     $30 = $27&255;
     $31 = (($$0141262) + -1)|0;
     $32 = (($9) + ($31)|0);
     HEAP8[$32>>0] = $30;
     $33 = (($$0140) + 1)|0;
     $34 = (($9) + ($33)|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = ($35<<24>>24)==(0);
     if ($36) {
      $$0141$lcssa = $33;
      break;
     } else {
      $$0141262 = $33;
     }
    }
   }
   $37 = (($$0141$lcssa) + 3)|0;
   $38 = (($9) + ($37)|0);
   HEAP8[$38>>0] = 1;
   $39 = (($$0141$lcssa) + 4)|0;
   (_clock_gettime(0,($10|0))|0);
   $40 = ((($10)) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = $41 >>> 16;
   $43 = (($42) + ($41))|0;
   $44 = $43 & 65535;
   $45 = (___fopen_rb_ca((gb + (166846) | 0),$4,$5,256)|0);
   $46 = ($45|0)==(0|0);
   do {
    if ($46) {
     label = 26;
    } else {
     $47 = ((($6)) + 10|0);
     $48 = ((($6)) + 11|0);
     $$0158$ph261 = 2;$$0163$ph260 = 0;$$0166$ph259 = 16;
     L15: while(1) {
      $49 = (($8) + (($$0163$ph260*28)|0)|0);
      $50 = (_fgets($6,64,$45)|0);
      $51 = ($50|0)==(0|0);
      if ($51) {
       label = 25;
       break;
      }
      while(1) {
       $52 = (_strncmp($6,(gb + (166863) | 0),10)|0);
       $53 = ($52|0)==(0);
       if ($53) {
        $54 = HEAP8[$47>>0]|0;
        $55 = $54 << 24 >> 24;
        $56 = (_isspace($55)|0);
        $57 = ($56|0)==(0);
        if (!($57)) {
         $$0155 = $48;
         while(1) {
          $60 = HEAP8[$$0155>>0]|0;
          $61 = $60 << 24 >> 24;
          $62 = (_isspace($61)|0);
          $63 = ($62|0)==(0);
          $64 = ((($$0155)) + 1|0);
          if ($63) {
           break;
          } else {
           $$0155 = $64;
          }
         }
         $65 = HEAP8[$$0155>>0]|0;
         $66 = ($65<<24>>24)==(0);
         L26: do {
          if ($66) {
           $$0170$lcssa = $$0155;
          } else {
           $$0170242 = $$0155;$68 = $65;
           while(1) {
            $67 = $68 << 24 >> 24;
            $69 = (_isspace($67)|0);
            $70 = ($69|0)==(0);
            if (!($70)) {
             $$0170$lcssa = $$0170242;
             break L26;
            }
            $71 = ((($$0170242)) + 1|0);
            $72 = HEAP8[$71>>0]|0;
            $73 = ($72<<24>>24)==(0);
            if ($73) {
             $$0170$lcssa = $71;
             break;
            } else {
             $$0170242 = $71;$68 = $72;
            }
           }
          }
         } while(0);
         HEAP8[$$0170$lcssa>>0] = 0;
         $74 = (___ipparse($49,0,$$0155)|0);
         $75 = ($74|0)<(0);
         if (!($75)) {
          break;
         }
        }
       }
       $58 = (_fgets($6,64,$45)|0);
       $59 = ($58|0)==(0|0);
       if ($59) {
        label = 25;
        break L15;
       }
      }
      $76 = (_htons(53)|0);
      $77 = (((($8) + (($$0163$ph260*28)|0)|0)) + 2|0);
      HEAP16[$77>>1] = $76;
      $78 = (($$0163$ph260) + 1)|0;
      $79 = (($8) + (($$0163$ph260*28)|0)|0);
      $80 = HEAP16[$79>>1]|0;
      $81 = ($80<<16>>16)==(10);
      $spec$select = $81 ? 28 : $$0166$ph259;
      $spec$select171 = $81 ? 10 : $$0158$ph261;
      $82 = ($78>>>0)<(3);
      if ($82) {
       $$0158$ph261 = $spec$select171;$$0163$ph260 = $78;$$0166$ph259 = $spec$select;
      } else {
       label = 24;
       break;
      }
     }
     if ((label|0) == 24) {
      (___fclose_ca($45)|0);
      $$2165 = $78;$$3161 = $spec$select171;$$3169 = $spec$select;
      break;
     }
     else if ((label|0) == 25) {
      (___fclose_ca($45)|0);
      $83 = ($$0163$ph260|0)==(0);
      if ($83) {
       label = 26;
       break;
      } else {
       $$2165 = $$0163$ph260;$$3161 = $$0158$ph261;$$3169 = $$0166$ph259;
       break;
      }
     }
    }
   } while(0);
   if ((label|0) == 26) {
    HEAP16[$8>>1] = 2;
    $84 = (_htons(53)|0);
    $85 = ((($8)) + 2|0);
    HEAP16[$85>>1] = $84;
    $86 = (_htonl(2130706433)|0);
    $87 = ((($8)) + 4|0);
    HEAP32[$87>>2] = $86;
    $$2165 = 1;$$3161 = 2;$$3169 = 16;
   }
   $88 = $$3161&65535;
   HEAP16[$7>>1] = $88;
   $89 = (_socket($$3161,526338,0)|0);
   $90 = ($89|0)<(0);
   if ($90) {
    $91 = (___errno_location()|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(97);
    $94 = ($$3161|0)==(10);
    $or$cond = $94 & $93;
    if (!($or$cond)) {
     $$0 = -11;
     break;
    }
    $95 = (_socket(2,526338,0)|0);
    $96 = ($95|0)<(0);
    if ($96) {
     $$0 = -11;
     break;
    } else {
     $$0154178180 = $95;
    }
   } else {
    $97 = ($$3161|0)==(10);
    if ($97) {
     HEAP32[$13>>2] = 0;
     (_setsockopt($89,41,26,$13,4)|0);
     $98 = ($$2165|0)>(0);
     if ($98) {
      $$1142239 = 0;
      while(1) {
       $99 = (($8) + (($$1142239*28)|0)|0);
       $100 = HEAP16[$99>>1]|0;
       $101 = ($100<<16>>16)==(2);
       if ($101) {
        $102 = (((($8) + (($$1142239*28)|0)|0)) + 8|0);
        $103 = (((($8) + (($$1142239*28)|0)|0)) + 20|0);
        $104 = (((($8) + (($$1142239*28)|0)|0)) + 4|0);
        (_memcpy(($103|0),($104|0),4)|0);
        (_memcpy(($102|0),((gb + (166957) | 0)|0),12)|0);
        HEAP16[$99>>1] = 10;
        HEAP32[$104>>2] = 0;
        $105 = (((($8) + (($$1142239*28)|0)|0)) + 24|0);
        HEAP32[$105>>2] = 0;
       }
       $106 = (($$1142239) + 1)|0;
       $exitcond287 = ($106|0)==($$2165|0);
       if ($exitcond287) {
        $$0154178180 = $89;
        break;
       } else {
        $$1142239 = $106;
       }
      }
     } else {
      $$0154178180 = $89;
     }
    } else {
     $$0154178180 = $89;
    }
   }
   $107 = $$0154178180;
   _pthread_cleanup_push(((fb + (12) | 0)|0),($107|0));
   $108 = HEAP32[$12>>2]|0;
   (_pthread_setcancelstate(($108|0),(0|0))|0);
   $109 = (_bind($$0154178180,$7,$$3169)|0);
   $110 = ($109|0)<(0);
   do {
    if ($110) {
     _pthread_cleanup_pop(1);
     $$4182 = -11;
    } else {
     HEAP32[$11>>2] = $$0154178180;
     $111 = ((($11)) + 4|0);
     HEAP16[$111>>1] = 1;
     $112 = (_time((0|0))|0);
     $113 = (($112) - ($15))|0;
     $114 = ($113|0)<(5);
     if (!($114)) {
      _pthread_cleanup_pop(1);
      $$4182 = -3;
      break;
     }
     $115 = ($3|0)>(0);
     $116 = ($$2165|0)<(1);
     $117 = ((($9)) + 1|0);
     $118 = (($$0141$lcssa) + 1)|0;
     $119 = (($9) + ($118)|0);
     $120 = ($$2165|0)>(0);
     $exitcond326 = ($$2165|0)==(1);
     $$0143$ph236 = -3;$$0147$ph235 = 0;$$0150$ph234 = 0;$$0156$ph233 = $0;
     L58: while(1) {
      while(1) {
       if ($115) {
        $$2194 = 0;
        while(1) {
         $127 = (($2) + ($$2194<<2)|0);
         $128 = HEAP32[$127>>2]|0;
         $129 = ($128|0)==(0);
         $brmerge = $129 | $116;
         if (!($brmerge)) {
          $130 = (($$2194) + ($44))|0;
          $131 = $130 >>> 8;
          $132 = $131&255;
          $133 = $130&255;
          HEAP8[$9>>0] = $132;
          HEAP8[$117>>0] = $133;
          $134 = $128&255;
          HEAP8[$119>>0] = $134;
          (_sendto($$0154178180,$9,$39,16384,$8,$$3169)|0);
          if (!($exitcond326)) {
           $137 = 1;
           while(1) {
            $$pre = HEAP32[$127>>2]|0;
            HEAP8[$9>>0] = $132;
            HEAP8[$117>>0] = $133;
            $135 = $$pre&255;
            HEAP8[$119>>0] = $135;
            $136 = (($8) + (($137*28)|0)|0);
            (_sendto($$0154178180,$9,$39,16384,$136,$$3169)|0);
            $138 = (($137) + 1)|0;
            $exitcond = ($138|0)==($$2165|0);
            if ($exitcond) {
             break;
            } else {
             $137 = $138;
            }
           }
          }
         }
         $139 = (($$2194) + 1)|0;
         $exitcond286 = ($139|0)==($3|0);
         if ($exitcond286) {
          break;
         } else {
          $$2194 = $139;
         }
        }
       }
       $140 = (_poll($11,1,1000)|0);
       $141 = ($140|0)<(1);
       if (!($141)) {
        break;
       }
       $124 = (_time((0|0))|0);
       $125 = (($124) - ($15))|0;
       $126 = ($125|0)<(5);
       if (!($126)) {
        $$3153 = $$0150$ph234;$$4 = $$0143$ph236;
        break L58;
       }
      }
      $142 = (($$0147$ph235) + ($$0150$ph234))|0;
      $143 = ($142|0)<($3|0);
      L75: do {
       if ($143) {
        $$1144$ph227 = $$0143$ph236;$$1148$ph226 = $$0147$ph235;$$1151$ph225 = $$0150$ph234;$$1157$ph224 = $$0156$ph233;$175 = $142;
        while(1) {
         $144 = ((($$1157$ph224)) + 1|0);
         HEAP32[$14>>2] = $$3169;
         $145 = (_recvfrom($$0154178180,$$1157$ph224,512,0,$7,$14)|0);
         $146 = ($145|0)>(1);
         if (!($146)) {
          $$1144$ph$lcssa = $$1144$ph227;$$1148$ph$lcssa = $$1148$ph226;$$1151$ph$lcssa = $$1151$ph225;$$1157$ph$lcssa = $$1157$ph224;$$lcssa = $175;
          break L75;
         }
         while(1) {
          L82: do {
           if ($120) {
            $$3200 = 0;
            while(1) {
             $147 = (($8) + (($$3200*28)|0)|0);
             $148 = (_memcmp($147,$7,$$3169)|0);
             $149 = ($148|0)==(0);
             if ($149) {
              $$3$lcssa = $$3200;
              break L82;
             }
             $150 = (($$3200) + 1)|0;
             $151 = ($150|0)<($$2165|0);
             if ($151) {
              $$3200 = $150;
             } else {
              $$3$lcssa = $150;
              break;
             }
            }
           } else {
            $$3$lcssa = 0;
           }
          } while(0);
          $152 = ($$3$lcssa|0)==($$2165|0);
          if (!($152)) {
           $155 = HEAP8[$$1157$ph224>>0]|0;
           $156 = $155&255;
           $157 = $156 << 8;
           $158 = HEAP8[$144>>0]|0;
           $159 = $158&255;
           $160 = $157 | $159;
           $161 = (($160) - ($43))|0;
           $162 = $161 & 65535;
           $163 = ($162>>>0)<($3>>>0);
           if ($163) {
            $164 = (($2) + ($162<<2)|0);
            $165 = HEAP32[$164>>2]|0;
            $166 = ($165|0)==(0);
            if (!($166)) {
             break;
            }
           }
          }
          HEAP32[$14>>2] = $$3169;
          $153 = (_recvfrom($$0154178180,$$1157$ph224,512,0,$7,$14)|0);
          $154 = ($153|0)>(1);
          if (!($154)) {
           $$1144$ph$lcssa = $$1144$ph227;$$1148$ph$lcssa = $$1148$ph226;$$1151$ph$lcssa = $$1151$ph225;$$1157$ph$lcssa = $$1157$ph224;$$lcssa = $175;
           break L75;
          }
         }
         $167 = ((($$1157$ph224)) + 3|0);
         $trunc = HEAP8[$167>>0]|0;
         $trunc$clear = $trunc & 15;
         switch ($trunc$clear<<24>>24) {
         case 0:  {
          $168 = (($$1151$ph225) + 1)|0;
          $$2149 = $$1148$ph226;$$2152 = $168;$$3146 = $$1144$ph227;
          break;
         }
         case 3:  {
          $$2145 = -2;
          label = 67;
          break;
         }
         default: {
          $$2145 = -4;
          label = 67;
         }
         }
         if ((label|0) == 67) {
          label = 0;
          $169 = (($$1148$ph226) + 1)|0;
          $$2149 = $169;$$2152 = $$1151$ph225;$$3146 = $$2145;
         }
         HEAP32[$164>>2] = 0;
         $170 = ((($$1157$ph224)) + 512|0);
         $171 = (($$2149) + ($$2152))|0;
         $172 = ($171|0)<($3|0);
         if ($172) {
          $$1144$ph227 = $$3146;$$1148$ph226 = $$2149;$$1151$ph225 = $$2152;$$1157$ph224 = $170;$175 = $171;
         } else {
          $$1144$ph$lcssa = $$3146;$$1148$ph$lcssa = $$2149;$$1151$ph$lcssa = $$2152;$$1157$ph$lcssa = $170;$$lcssa = $171;
          break L75;
         }
        }
       } else {
        $$1144$ph$lcssa = $$0143$ph236;$$1148$ph$lcssa = $$0147$ph235;$$1151$ph$lcssa = $$0150$ph234;$$1157$ph$lcssa = $$0156$ph233;$$lcssa = $142;
       }
      } while(0);
      $173 = ($$lcssa|0)==($3|0);
      if ($173) {
       $$3153 = $$1151$ph$lcssa;$$4 = $$1144$ph$lcssa;
       break;
      }
      $121 = (_time((0|0))|0);
      $122 = (($121) - ($15))|0;
      $123 = ($122|0)<(5);
      if ($123) {
       $$0143$ph236 = $$1144$ph$lcssa;$$0147$ph235 = $$1148$ph$lcssa;$$0150$ph234 = $$1151$ph$lcssa;$$0156$ph233 = $$1157$ph$lcssa;
      } else {
       $$3153 = $$1151$ph$lcssa;$$4 = $$1144$ph$lcssa;
       break;
      }
     }
     _pthread_cleanup_pop(1);
     $174 = ($$3153|0)==(0);
     if ($174) {
      $$4182 = $$4;
     } else {
      $$0 = $$3153;
      break L1;
     }
    }
   } while(0);
   $$0 = $$4182;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___ipparse($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02935 = 0, $$030 = 0, $$134 = 0, $$phi$trans$insert = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$phi42Z2D = 0, $$pre$phiZ2D = 0, $$pre41 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $trunc = 0, $trunc$clear = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $3 = sp;
 $4 = sp + 64|0;
 dest=$3; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $5 = ($1|0)==(10);
 L1: do {
  if ($5) {
   label = 18;
  } else {
   $$02935 = $2;$trunc = 0;
   L3: while(1) {
    $6 = (_strtoul($$02935,$4,0)|0);
    $7 = (($3) + ($trunc<<2)|0);
    HEAP32[$7>>2] = $6;
    $8 = HEAP32[$4>>2]|0;
    $9 = ($8|0)==($$02935|0);
    if ($9) {
     label = 6;
     break;
    }
    $10 = HEAP8[$8>>0]|0;
    switch ($10<<24>>24) {
    case 46: case 0:  {
     break;
    }
    default: {
     label = 6;
     break L3;
    }
    }
    $11 = HEAP8[$$02935>>0]|0;
    $12 = $11 << 24 >> 24;
    $13 = (_isdigit($12)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     label = 6;
     break;
    }
    $16 = HEAP8[$8>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     break;
    }
    $18 = ((($8)) + 1|0);
    $19 = (($trunc) + 1)|0;
    $20 = ($19>>>0)<(4);
    if ($20) {
     $$02935 = $18;$trunc = $19;
    } else {
     $$030 = -1;
     break L1;
    }
   }
   if ((label|0) == 6) {
    $15 = ($1|0)==(2);
    if ($15) {
     $$030 = -1;
     break;
    } else {
     label = 18;
     break;
    }
   }
   $trunc$clear = $trunc & 2147483647;
   switch ($trunc$clear|0) {
   case 0:  {
    $21 = HEAP32[$3>>2]|0;
    $22 = $21 & 16777215;
    $23 = ((($3)) + 4|0);
    HEAP32[$23>>2] = $22;
    $24 = $21 >>> 24;
    HEAP32[$3>>2] = $24;
    $$pre$phiZ2D = $23;$26 = $22;
    label = 13;
    break;
   }
   case 1:  {
    $$phi$trans$insert = ((($3)) + 4|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $$pre$phiZ2D = $$phi$trans$insert;$26 = $$pre;
    label = 13;
    break;
   }
   case 2:  {
    $$phi$trans$insert40 = ((($3)) + 8|0);
    $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
    $$pre$phi42Z2D = $$phi$trans$insert40;$30 = $$pre41;
    label = 14;
    break;
   }
   default: {
   }
   }
   if ((label|0) == 13) {
    $25 = $26 & 65535;
    $27 = ((($3)) + 8|0);
    HEAP32[$27>>2] = $25;
    $28 = $26 >>> 16;
    HEAP32[$$pre$phiZ2D>>2] = $28;
    $$pre$phi42Z2D = $27;$30 = $25;
    label = 14;
   }
   if ((label|0) == 14) {
    $29 = $30 & 255;
    $31 = ((($3)) + 12|0);
    HEAP32[$31>>2] = $29;
    $32 = $30 >>> 8;
    HEAP32[$$pre$phi42Z2D>>2] = $32;
   }
   HEAP16[$0>>1] = 2;
   $33 = ((($0)) + 4|0);
   $$134 = 0;
   while(1) {
    $34 = (($3) + ($$134<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35>>>0)>(255);
    if ($36) {
     $$030 = -1;
     break L1;
    }
    $37 = $35&255;
    $38 = (($33) + ($$134)|0);
    HEAP8[$38>>0] = $37;
    $39 = (($$134) + 1)|0;
    $40 = ($39>>>0)<(4);
    if ($40) {
     $$134 = $39;
    } else {
     $$030 = 0;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  HEAP16[$0>>1] = 10;
  $41 = ((($0)) + 8|0);
  $42 = (_inet_pton(10,$2,$41)|0);
  $43 = ($42|0)<(1);
  $44 = $43 << 31 >> 31;
  $$030 = $44;
 }
 STACKTOP = sp;return ($$030|0);
}
function _htonl($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___bswap_32_225($0)|0);
 return ($1|0);
}
function _cleanup($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 (_close($1)|0);
 return;
}
function ___bswap_32_225($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_llvm_bswap_i32(($0|0))|0);
 return ($1|0);
}
function ___dns_query($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$08 = 0, $$pre$phiZ2D = 0, $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $4 = sp;
 $5 = sp + 80|0;
 $6 = ($3|0)==(0);
 $7 = ($2|0)==(10);
 do {
  if ($6) {
   if ($7) {
    HEAP32[$5>>2] = 28;
    $$0 = 1;$$08 = $1;$$pre$phiZ2D = $5;
    break;
   }
   HEAP32[$5>>2] = 1;
   $8 = ($2|0)==(2);
   if ($8) {
    $$0 = 1;$$08 = $1;$$pre$phiZ2D = $5;
   } else {
    $9 = ((($5)) + 4|0);
    HEAP32[$9>>2] = 28;
    $$0 = 2;$$08 = $1;$$pre$phiZ2D = $5;
   }
  } else {
   if ($7) {
    _mkptr6($4,$1);
   } else {
    _mkptr4($4,$1);
   }
   HEAP32[$5>>2] = 12;
   $$0 = 1;$$08 = $4;$$pre$phiZ2D = $5;
  }
 } while(0);
 $10 = (___dns_doqueries($0,$$08,$$pre$phiZ2D,$$0)|0);
 STACKTOP = sp;return ($10|0);
}
function _mkptr6($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01112 = 0, $$013 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$01112 = $0;$$013 = 15;
 while(1) {
  $2 = (($1) + ($$013)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 & 15;
  $5 = $4&255;
  $6 = ((gb + (143664) | 0) + ($5)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ((($$01112)) + 1|0);
  HEAP8[$$01112>>0] = $7;
  $9 = ((($$01112)) + 2|0);
  HEAP8[$8>>0] = 46;
  $10 = HEAP8[$2>>0]|0;
  $11 = $10&255;
  $12 = $11 >>> 4;
  $13 = ((gb + (143664) | 0) + ($12)|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ((($$01112)) + 3|0);
  HEAP8[$9>>0] = $14;
  $16 = ((($$01112)) + 4|0);
  HEAP8[$15>>0] = 46;
  $17 = (($$013) + -1)|0;
  $18 = ($$013|0)==(0);
  if ($18) {
   break;
  } else {
   $$01112 = $16;$$013 = $17;
  }
 }
 $scevgep = ((($0)) + 64|0);
 (_strcpy($scevgep,(gb + (166899) | 0))|0);
 return;
}
function _mkptr4($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = ((($1)) + 3|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ((($1)) + 2|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ((($1)) + 1|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = HEAP8[$1>>0]|0;
 $12 = $11&255;
 HEAP32[$vararg_buffer>>2] = $4;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $7;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $10;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $12;
 (_sprintf($0,(gb + (166874) | 0),$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _sprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vsprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _vsprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_vsnprintf($0,2147483647,$1,$2)|0);
 return ($3|0);
}
function ___dns_get_rr($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $$066107 = 0, $$067$idx$lcssa = 0, $$067$idx130 = 0, $$071105 = 0, $$074104 = 0, $$1 = 0, $$168$add = 0, $$168$add78 = 0, $$168$idx$lcssa = 0, $$168$idx120 = 0, $$168$ptr = 0, $$168$ptr$lcssa = 0, $$168$ptr119 = 0, $$168$ptr121 = 0, $$172 = 0, $$175 = 0, $$2$idx106 = 0, $$273 = 0, $$276 = 0;
 var $$3$add = 0, $$3$add77 = 0, $$3$idx$lcssa = 0, $$3$idx96 = 0, $$3$ptr = 0, $$3$ptr$lcssa = 0, $$3$ptr95 = 0, $$3$ptr97 = 0, $$add = 0, $$in = 0, $$in133 = 0, $$lcssa = 0, $$lcssa93 = 0, $$old = 0, $$old87 = 0, $$ptr79$add = 0, $$ptr79$ptr = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $or$cond = 0, $or$cond85 = 0, $or$cond88 = 0, $or$cond90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $7 = sp;
 $8 = ((($4)) + 3|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 15;
 $11 = ($10<<24>>24)==(0);
 L1: do {
  if ($11) {
   $12 = ((($4)) + 4|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = $13&255;
   $15 = $14 << 8;
   $16 = ((($4)) + 5|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = $17&255;
   $19 = $15 | $18;
   $20 = ((($4)) + 6|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = $22 << 8;
   $24 = ((($4)) + 7|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $27 = $23 | $26;
   $28 = (($27) + ($19))|0;
   $29 = ($28>>>0)>(64);
   if ($29) {
    $$0 = -1;
   } else {
    $30 = ($19|0)==(0);
    if ($30) {
     $$067$idx$lcssa = 12;
    } else {
     $$067$idx130 = 12;$$in = $19;
     while(1) {
      $31 = (($$in) + -1)|0;
      $$168$ptr119 = (($4) + ($$067$idx130)|0);
      $32 = ($$067$idx130|0)<(512);
      $33 = HEAP8[$$168$ptr119>>0]|0;
      L8: do {
       if ($32) {
        $$168$idx120 = $$067$idx130;$$168$ptr121 = $$168$ptr119;$35 = $33;
        while(1) {
         $34 = $35&255;
         $36 = (($34) + -1)|0;
         $37 = ($36>>>0)<(127);
         if (!($37)) {
          $$168$idx$lcssa = $$168$idx120;$$168$ptr$lcssa = $$168$ptr121;$$lcssa93 = $35;
          break L8;
         }
         $$168$add78 = (($$168$idx120) + 1)|0;
         $$168$ptr = (($4) + ($$168$add78)|0);
         $38 = ($$168$idx120|0)<(511);
         $39 = HEAP8[$$168$ptr>>0]|0;
         if ($38) {
          $$168$idx120 = $$168$add78;$$168$ptr121 = $$168$ptr;$35 = $39;
         } else {
          $$168$idx$lcssa = $$168$add78;$$168$ptr$lcssa = $$168$ptr;$$lcssa93 = $39;
          break;
         }
        }
       } else {
        $$168$idx$lcssa = $$067$idx130;$$168$ptr$lcssa = $$168$ptr119;$$lcssa93 = $33;
       }
      } while(0);
      $40 = ($$lcssa93&255)>(193);
      if ($40) {
       $$0 = -1;
       break L1;
      }
      $41 = ($$lcssa93<<24>>24)==(-63);
      if ($41) {
       $42 = ((($$168$ptr$lcssa)) + 1|0);
       $43 = HEAP8[$42>>0]|0;
       $44 = ($43<<24>>24)==(-1);
       $45 = ($$168$idx$lcssa|0)>(506);
       $or$cond85 = $45 | $44;
       if ($or$cond85) {
        $$0 = -1;
        break L1;
       }
      } else {
       $$old = ($$168$idx$lcssa|0)>(506);
       if ($$old) {
        $$0 = -1;
        break L1;
       }
      }
      $46 = ($$lcssa93<<24>>24)==(0);
      $47 = $46 ? 5 : 6;
      $$168$add = (($47) + ($$168$idx$lcssa))|0;
      $48 = ($31|0)==(0);
      if ($48) {
       $$067$idx$lcssa = $$168$add;
       break;
      } else {
       $$067$idx130 = $$168$add;$$in = $31;
      }
     }
    }
    $49 = ($27|0)==(0);
    if ($49) {
     $$0 = 0;
    } else {
     $50 = ((($4)) + 512|0);
     $51 = ($6|0)!=(0);
     $$066107 = 0;$$071105 = $0;$$074104 = $3;$$2$idx106 = $$067$idx$lcssa;$$in133 = $27;
     while(1) {
      $52 = (($$in133) + -1)|0;
      $$3$ptr95 = (($4) + ($$2$idx106)|0);
      $53 = ($$2$idx106|0)<(512);
      $54 = HEAP8[$$3$ptr95>>0]|0;
      L23: do {
       if ($53) {
        $$3$idx96 = $$2$idx106;$$3$ptr97 = $$3$ptr95;$56 = $54;
        while(1) {
         $55 = $56&255;
         $57 = (($55) + -1)|0;
         $58 = ($57>>>0)<(127);
         if (!($58)) {
          $$3$idx$lcssa = $$3$idx96;$$3$ptr$lcssa = $$3$ptr97;$$lcssa = $56;
          break L23;
         }
         $$3$add = (($$3$idx96) + 1)|0;
         $$3$ptr = (($4) + ($$3$add)|0);
         $59 = ($$3$idx96|0)<(511);
         $60 = HEAP8[$$3$ptr>>0]|0;
         if ($59) {
          $$3$idx96 = $$3$add;$$3$ptr97 = $$3$ptr;$56 = $60;
         } else {
          $$3$idx$lcssa = $$3$add;$$3$ptr$lcssa = $$3$ptr;$$lcssa = $60;
          break;
         }
        }
       } else {
        $$3$idx$lcssa = $$2$idx106;$$3$ptr$lcssa = $$3$ptr95;$$lcssa = $54;
       }
      } while(0);
      $61 = ($$lcssa&255)>(193);
      if ($61) {
       $$0 = -1;
       break L1;
      }
      $62 = ($$lcssa<<24>>24)==(-63);
      if ($62) {
       $63 = ((($$3$ptr$lcssa)) + 1|0);
       $64 = HEAP8[$63>>0]|0;
       $65 = ($64<<24>>24)==(-1);
       $66 = ($$3$idx$lcssa|0)>(506);
       $or$cond88 = $66 | $65;
       if ($or$cond88) {
        $$0 = -1;
        break L1;
       }
      } else {
       $$old87 = ($$3$idx$lcssa|0)>(506);
       if ($$old87) {
        $$0 = -1;
        break L1;
       }
      }
      $67 = ($$lcssa<<24>>24)==(0);
      $68 = $67 ? 1 : 2;
      $$3$add77 = (($68) + ($$3$idx$lcssa))|0;
      $$ptr79$ptr = (($4) + ($$3$add77)|0);
      $69 = ((($$ptr79$ptr)) + 8|0);
      $70 = HEAP8[$69>>0]|0;
      $71 = $70&255;
      $72 = $71 << 8;
      $73 = ((($$ptr79$ptr)) + 9|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = $74&255;
      $76 = $72 | $75;
      $$ptr79$add = (($76) + ($$3$add77))|0;
      $77 = ($$ptr79$add|0)>(512);
      if ($77) {
       $$0 = -1;
       break L1;
      }
      $78 = ((($$ptr79$ptr)) + 1|0);
      $79 = HEAP8[$78>>0]|0;
      $80 = $79&255;
      $81 = ($80|0)!=($5|0);
      $82 = ($76>>>0)>($2>>>0);
      $or$cond90 = $82 | $81;
      if ($or$cond90) {
       $$1 = $$066107;$$273 = $$071105;$$276 = $$074104;
      } else {
       if ($51) {
        $83 = ((($$ptr79$ptr)) + 10|0);
        $84 = (___dn_expand($4,$50,$83,$7,256)|0);
        $85 = ($84|0)<(0);
        if ($85) {
         $$0 = -1;
         break L1;
        }
       }
       $86 = ($$071105|0)!=(0|0);
       $87 = ($$074104|0)!=(0);
       $or$cond = $87 & $86;
       if ($or$cond) {
        if ($51) {
         (_strcpy($$071105,$7)|0);
        } else {
         $88 = ((($$ptr79$ptr)) + 10|0);
         (_memcpy(($$071105|0),($88|0),($76|0))|0);
        }
        $89 = (($$071105) + ($1)|0);
        $90 = (($$074104) + -1)|0;
        $$172 = $89;$$175 = $90;
       } else {
        $$172 = $$071105;$$175 = $$074104;
       }
       $91 = (($$066107) + 1)|0;
       $$1 = $91;$$273 = $$172;$$276 = $$175;
      }
      $$add = (($$ptr79$add) + 10)|0;
      $92 = ($52|0)==(0);
      if ($92) {
       $$0 = $$1;
       break;
      } else {
       $$066107 = $$1;$$071105 = $$273;$$074104 = $$276;$$2$idx106 = $$add;$$in133 = $52;
      }
     }
    }
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___dn_expand($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$05475 = 0, $$05574 = 0, $$056 = 0, $$05773 = 0, $$06172 = 0, $$070 = 0, $$1 = 0, $$158 = 0, $$16268 = 0, $$2 = 0, $$25969 = 0, $$263 = 0, $$3 = 0, $$360 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre87 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $scevgep85 = 0, $scevgep86 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)==($1|0);
 $6 = ($4|0)<(1);
 $or$cond = $5 | $6;
 L1: do {
  if ($or$cond) {
   $$056 = -1;
  } else {
   $7 = $1;
   $8 = $0;
   $9 = (($7) - ($8))|0;
   $10 = ($9|0)>(0);
   if ($10) {
    $11 = ($4|0)<(254);
    $12 = $11 ? $4 : 254;
    $13 = (($3) + ($12)|0);
    $14 = $2;
    $15 = $13;
    $$05475 = 0;$$05574 = -1;$$05773 = $3;$$06172 = $2;
    while(1) {
     $16 = HEAP8[$$06172>>0]|0;
     $17 = $16&255;
     $18 = $17 & 192;
     $19 = ($18|0)==(0);
     if ($19) {
      $33 = ($16<<24>>24)==(0);
      if ($33) {
       break;
      }
      $34 = ($$05773|0)==($3|0);
      if ($34) {
       $$158 = $3;$$pre$phiZ2D = $17;$44 = $16;
      } else {
       $35 = ((($$05773)) + 1|0);
       HEAP8[$$05773>>0] = 46;
       $$pre = HEAP8[$$06172>>0]|0;
       $$pre87 = $$pre&255;
       $$158 = $35;$$pre$phiZ2D = $$pre87;$44 = $$pre;
      }
      $36 = ((($$06172)) + 1|0);
      $37 = $36;
      $38 = (($7) - ($37))|0;
      $39 = ($38|0)>($$pre$phiZ2D|0);
      if (!($39)) {
       $$056 = -1;
       break L1;
      }
      $40 = $$158;
      $41 = (($15) - ($40))|0;
      $42 = ($41|0)>($$pre$phiZ2D|0);
      if (!($42)) {
       $$056 = -1;
       break L1;
      }
      $43 = ($44<<24>>24)==(0);
      if ($43) {
       $$263 = $36;$$3 = $$05574;$$360 = $$158;
      } else {
       $scevgep85 = (($36) + ($$pre$phiZ2D)|0);
       $$070 = $$pre$phiZ2D;$$16268 = $36;$$25969 = $$158;
       while(1) {
        $45 = (($$070) + -1)|0;
        $46 = ((($$16268)) + 1|0);
        $47 = HEAP8[$$16268>>0]|0;
        $48 = ((($$25969)) + 1|0);
        HEAP8[$$25969>>0] = $47;
        $49 = ($45|0)==(0);
        if ($49) {
         break;
        } else {
         $$070 = $45;$$16268 = $46;$$25969 = $48;
        }
       }
       $scevgep86 = (($$158) + ($$pre$phiZ2D)|0);
       $$263 = $scevgep85;$$3 = $$05574;$$360 = $scevgep86;
      }
     } else {
      $20 = ((($$06172)) + 1|0);
      $21 = ($20|0)==($1|0);
      if ($21) {
       $$056 = -1;
       break L1;
      }
      $22 = $17 << 8;
      $23 = $22 & 16128;
      $24 = HEAP8[$20>>0]|0;
      $25 = $24&255;
      $26 = $23 | $25;
      $27 = ($26|0)<($9|0);
      if (!($27)) {
       $$056 = -1;
       break L1;
      }
      $28 = ($$05574|0)<(0);
      $29 = ((($$06172)) + 2|0);
      $30 = $29;
      $31 = (($30) - ($14))|0;
      $$1 = $28 ? $31 : $$05574;
      $32 = (($0) + ($26)|0);
      $$263 = $32;$$3 = $$1;$$360 = $$05773;
     }
     $54 = (($$05475) + 2)|0;
     $55 = ($54|0)<($9|0);
     if ($55) {
      $$05475 = $54;$$05574 = $$3;$$05773 = $$360;$$06172 = $$263;
     } else {
      $$056 = -1;
      break L1;
     }
    }
    HEAP8[$$05773>>0] = 0;
    $50 = ($$05574|0)<(0);
    $51 = ((($$06172)) + 1|0);
    $52 = $51;
    $53 = (($52) - ($14))|0;
    $$2 = $50 ? $53 : $$05574;
    $$056 = $$2;
   } else {
    $$056 = -1;
   }
  }
 } while(0);
 return ($$056|0);
}
function ___dns_count_addrs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$016 = 0, $$01726 = 0, $$01925 = 0, $$024 = 0, $$123 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $$016 = 0;
  } else {
   $$01726 = 0;$$01925 = $0;$$in = $1;
   while(1) {
    $3 = (($$in) + -1)|0;
    $$024 = 0;$$123 = $$01726;
    while(1) {
     $4 = ((gb + (143696) | 0) + ($$024<<3)|0);
     $5 = HEAP32[$4>>2]|0;
     $6 = ((((gb + (143696) | 0) + ($$024<<3)|0)) + 4|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = (___dns_get_rr(0,0,$5,-1,$$01925,$7,0)|0);
     $9 = ($8|0)<(0);
     if ($9) {
      $$016 = $8;
      break L1;
     }
     $10 = (($8) + ($$123))|0;
     $11 = (($$024) + 1)|0;
     $12 = ($11>>>0)<(2);
     if ($12) {
      $$024 = 1;$$123 = $10;
     } else {
      break;
     }
    }
    $13 = ((($$01925)) + 512|0);
    $14 = ($3|0)==(0);
    if ($14) {
     $$016 = $10;
     break;
    } else {
     $$01726 = $10;$$01925 = $13;$$in = $3;
    }
   }
  }
 } while(0);
 return ($$016|0);
}
function _sendmsg($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = $3;
 HEAP32[$vararg_buffer>>2] = 16;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $11 = (___syscall102(102,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function _inet_ntoa($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ((($0)) + 1|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ((($0)) + 2|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ((($0)) + 3|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $8;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $11;
 (_snprintf((gb + (170048) | 0),16,(gb + (166945) | 0),$vararg_buffer)|0);
 STACKTOP = sp;return ((gb + (170048) | 0)|0);
}
function _herror($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = HEAP32[(gb + (161300) | 0)>>2]|0;
 $2 = ($0|0)!=(0|0);
 $3 = $2 ? $0 : (gb + (172139) | 0);
 $4 = $2 ? (gb + (167578) | 0) : (gb + (172139) | 0);
 $5 = (___h_errno_location()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_hstrerror($6)|0);
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $7;
 (_fprintf($1,(gb + (166908) | 0),$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function ___h_errno_location() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (171172) | 0)|0);
}
function _hstrerror($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$010 = 0, $$01011 = 0, $$01013 = 0, $$012 = 0, $$pr = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $$01011 = (($0) + -1)|0;
 $1 = ($$01011|0)==(0);
 L1: do {
  if ($1) {
   $$0$lcssa = (gb + (143712) | 0);
  } else {
   $$01013 = $$01011;$$012 = (gb + (143712) | 0);
   while(1) {
    $2 = HEAP8[$$012>>0]|0;
    $3 = ($2<<24>>24)==(0);
    if ($3) {
     $$0$lcssa = $$012;
     break L1;
    }
    $4 = ((($$012)) + 1|0);
    $5 = $4;
    while(1) {
     $$pr = HEAP8[$5>>0]|0;
     $6 = ($$pr<<24>>24)==(0);
     $7 = ((($5)) + 1|0);
     if ($6) {
      break;
     } else {
      $5 = $7;
     }
    }
    $$010 = (($$01013) + -1)|0;
    $8 = ($$010|0)==(0);
    if ($8) {
     $$0$lcssa = $7;
     break;
    } else {
     $$01013 = $$010;$$012 = $7;
    }
   }
  }
 } while(0);
 $9 = HEAP8[$$0$lcssa>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $11 = ((($$0$lcssa)) + 1|0);
 $spec$select = $10 ? $11 : $$0$lcssa;
 $12 = (___lctrans_cur($spec$select)|0);
 return ($12|0);
}
function _fprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vfprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _recvmsg($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = $3;
 HEAP32[$vararg_buffer>>2] = 17;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $11 = (___syscall102(102,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function _listen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $2 = sp + 8|0;
 HEAP32[$2>>2] = $0;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $1;
 $4 = ((($2)) + 8|0);
 $5 = $2;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$vararg_buffer>>2] = 4;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $6 = (___syscall102(102,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _inet_network($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_inet_addr(($0|0))|0);
 $2 = (_ntohl($1)|0);
 return ($2|0);
}
function _inet_makeaddr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$sink = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)<(256);
 $3 = ($0>>>0)<(65536);
 $$ = $3 ? 16 : 8;
 $$sink = $2 ? 24 : $$;
 $4 = $0 << $$sink;
 $$0 = $4 | $1;
 return ($$0|0);
}
function _inet_lnaof($0) {
 $0 = $0|0;
 var $$ = 0, $$sink = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 $3 = ($1>>>0)<(3221225472);
 $$ = $3 ? 65535 : 255;
 $$sink = $2 ? 16777215 : $$;
 $4 = $1 & $$sink;
 return ($4|0);
}
function _inet_netof($0) {
 $0 = $0|0;
 var $$ = 0, $$sink = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 $3 = ($1>>>0)<(3221225472);
 $$ = $3 ? 16 : 8;
 $$sink = $2 ? 24 : $$;
 $4 = $1 >>> $$sink;
 return ($4|0);
}
function _getservbyport_r($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$044 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $6 = sp;
 HEAP16[$6>>1] = 2;
 $7 = ((($6)) + 2|0);
 $8 = $0&65535;
 HEAP16[$7>>1] = $8;
 $9 = ((($6)) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($6)) + 8|0);
 $11 = $10;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = ($1|0)==(0|0);
 L1: do {
  if ($15) {
   $16 = (_getservbyport_r($0,(gb + (166915) | 0),$2,$3,$4,$5)|0);
   $17 = ($16|0)==(0);
   if ($17) {
    $$044 = 0;
   } else {
    $18 = (_getservbyport_r($0,(gb + (166919) | 0),$2,$3,$4,$5)|0);
    $$044 = $18;
   }
  } else {
   $19 = $3;
   $20 = $19 & 3;
   $21 = ($20|0)==(0);
   $spec$store$select = $21 ? 4 : $20;
   $22 = (12 - ($spec$store$select))|0;
   $23 = ($22>>>0)>($4>>>0);
   if ($23) {
    $$044 = 34;
   } else {
    $24 = (4 - ($spec$store$select))|0;
    $25 = (($3) + ($24)|0);
    $26 = (_strcmp($1,(gb + (166915) | 0))|0);
    $27 = ($26|0)==(0);
    if (!($27)) {
     $28 = (_strcmp($1,(gb + (166919) | 0))|0);
     $29 = ($28|0)==(0);
     if (!($29)) {
      $$044 = 22;
      break;
     }
    }
    $30 = ((($2)) + 8|0);
    HEAP32[$30>>2] = $0;
    $31 = ((($2)) + 12|0);
    HEAP32[$31>>2] = $1;
    $32 = ((($2)) + 4|0);
    HEAP32[$32>>2] = $25;
    $33 = ((($25)) + 8|0);
    $34 = (($4) + -8)|0;
    $35 = (($34) - ($24))|0;
    $36 = ((($25)) + 4|0);
    HEAP32[$36>>2] = 0;
    HEAP32[$2>>2] = $33;
    $37 = HEAP32[$32>>2]|0;
    HEAP32[$37>>2] = $33;
    $38 = (_strcmp($1,(gb + (166919) | 0))|0);
    $39 = ($38|0)==(0);
    $40 = $39 ? 16 : 0;
    $41 = (_getnameinfo(($6|0),16,(0|0),0,($33|0),($35|0),($40|0))|0);
    switch ($41|0) {
    case -11: case -10:  {
     $$044 = 12;
     break L1;
     break;
    }
    case 0:  {
     HEAP32[$5>>2] = $2;
     $$044 = 0;
     break L1;
     break;
    }
    default: {
     $$044 = 2;
     break L1;
    }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$044|0);
}
function _freeifaddrs($0) {
 $0 = $0|0;
 var $$05 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$05 = $0;
  while(1) {
   $2 = HEAP32[$$05>>2]|0;
   _free($$05);
   $3 = ($2|0)==(0|0);
   if ($3) {
    break;
   } else {
    $$05 = $2;
   }
  }
 }
 return;
}
function _getifaddrs($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $1 = sp;
 (_memset(($1|0),0,264)|0);
 $2 = (___rtnetlink_enumerate(0,0,(fb + (13) | 0),$1)|0);
 $3 = ($2|0)==(0);
 $4 = HEAP32[$1>>2]|0;
 if ($3) {
  HEAP32[$0>>2] = $4;
 } else {
  _freeifaddrs($4);
 }
 STACKTOP = sp;return ($2|0);
}
function _netlink_msg_to_ifaddr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$0140 = 0, $$0141152 = 0, $$0142 = 0, $$0142156 = 0, $$0142157 = 0, $$1143 = 0, $$1146 = 0, $$2147 = 0, $$pr = 0, $$pre = 0, $$pre$phi163$phZ2D = 0, $$pre$phi168Z2D = 0, $$pre$phi170Z2D = 0, $$pre$phi174Z2D = 0, $$pre$phi176Z2D = 0, $$pre171 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 16|0);
 $3 = ((($1)) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(16);
 L1: do {
  if ($5) {
   $6 = ((($1)) + 32|0);
   $7 = HEAP32[$1>>2]|0;
   $8 = $7 & -4;
   $9 = ($8|0)==(32);
   if ($9) {
    $$0140 = 164;$$1143 = 0;
    label = 11;
   } else {
    $10 = (($1) + ($7)|0);
    $11 = $10;
    $$0141152 = $6;$21 = $6;
    while(1) {
     $12 = ((($$0141152)) + 2|0);
     $13 = HEAP16[$12>>1]|0;
     $14 = ($13<<16>>16)==(7);
     $15 = HEAP16[$$0141152>>1]|0;
     $16 = $15&65535;
     if ($14) {
      break;
     }
     $18 = (($16) + 3)|0;
     $19 = $18 & 131068;
     $20 = (($21) + ($19)|0);
     $22 = $20;
     $23 = (($11) - ($22))|0;
     $24 = ($23>>>0)>(3);
     if ($24) {
      $$0141152 = $20;$21 = $20;
     } else {
      $$0140 = 164;$$1143 = 0;
      label = 11;
      break L1;
     }
    }
    $17 = $15&65535;
    $phitmp = (($17) + 160)|0;
    $$0140 = $phitmp;$$1143 = 0;
    label = 11;
   }
  } else {
   $25 = ((($0)) + 8|0);
   $26 = ((($1)) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $27 & 63;
   $29 = (($25) + ($28<<2)|0);
   $$0142156 = HEAP32[$29>>2]|0;
   $30 = ($$0142156|0)==(0|0);
   if ($30) {
    $$0 = 0;
   } else {
    $$0142157 = $$0142156;
    while(1) {
     $31 = ((($$0142157)) + 140|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==($27|0);
     if ($33) {
      $$0140 = 164;$$1143 = $$0142157;
      label = 11;
      break L1;
     }
     $34 = ((($$0142157)) + 28|0);
     $$0142 = HEAP32[$34>>2]|0;
     $35 = ($$0142|0)==(0|0);
     if ($35) {
      $$0 = 0;
      break;
     } else {
      $$0142157 = $$0142;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $36 = (_calloc(1,$$0140)|0);
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0 = -1;
   } else {
    $38 = HEAP16[$3>>1]|0;
    $39 = ($38<<16>>16)==(16);
    if ($39) {
     $40 = ((($1)) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ((($36)) + 140|0);
     HEAP32[$42>>2] = $41;
     $43 = ((($1)) + 24|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($36)) + 8|0);
     HEAP32[$45>>2] = $44;
     $46 = ((($1)) + 32|0);
     $47 = HEAP32[$1>>2]|0;
     $48 = $47 & -4;
     $49 = ($48|0)==(32);
     L18: do {
      if ($49) {
       $$pre = ((($36)) + 4|0);
       $$pre$phi168Z2D = $$pre;
      } else {
       $50 = ((($36)) + 12|0);
       $51 = ((($36)) + 32|0);
       $52 = ((($2)) + 2|0);
       $53 = ((($36)) + 20|0);
       $54 = ((($36)) + 104|0);
       $55 = ((($36)) + 164|0);
       $56 = ((($36)) + 24|0);
       $57 = ((($36)) + 144|0);
       $58 = ((($36)) + 4|0);
       $$1146 = $46;$87 = $46;
       while(1) {
        $59 = ((($$1146)) + 2|0);
        $60 = HEAP16[$59>>1]|0;
        switch ($60<<16>>16) {
        case 3:  {
         $61 = HEAP16[$$1146>>1]|0;
         $62 = $61&65535;
         $63 = (($62) + -4)|0;
         $64 = ($63>>>0)<(17);
         if ($64) {
          $65 = ((($$1146)) + 4|0);
          (_memcpy(($57|0),($65|0),($63|0))|0);
          HEAP32[$58>>2] = $57;
          $$pre$phi170Z2D = $$1146;
         } else {
          $$pre$phi170Z2D = $$1146;
         }
         break;
        }
        case 1:  {
         $66 = ((($$1146)) + 4|0);
         $67 = HEAP16[$$1146>>1]|0;
         $68 = $67&65535;
         $69 = (($68) + -4)|0;
         $70 = HEAP32[$40>>2]|0;
         $71 = HEAP16[$52>>1]|0;
         _copy_lladdr($50,$51,$66,$69,$70,$71);
         $$pre$phi170Z2D = $$1146;
         break;
        }
        case 2:  {
         $72 = ((($$1146)) + 4|0);
         $73 = HEAP16[$$1146>>1]|0;
         $74 = $73&65535;
         $75 = (($74) + -4)|0;
         $76 = HEAP32[$40>>2]|0;
         $77 = HEAP16[$52>>1]|0;
         _copy_lladdr($53,$54,$72,$75,$76,$77);
         $$pre$phi170Z2D = $$1146;
         break;
        }
        case 7:  {
         HEAP32[$56>>2] = $55;
         $78 = ((($$1146)) + 4|0);
         $79 = HEAP16[$$1146>>1]|0;
         $80 = $79&65535;
         $81 = (($80) + -4)|0;
         (_memcpy(($55|0),($78|0),($81|0))|0);
         $$pre$phi170Z2D = $$1146;
         break;
        }
        default: {
         $$pre$phi170Z2D = $$1146;
        }
        }
        $82 = HEAP16[$$pre$phi170Z2D>>1]|0;
        $83 = $82&65535;
        $84 = (($83) + 3)|0;
        $85 = $84 & 131068;
        $86 = (($87) + ($85)|0);
        $88 = HEAP32[$1>>2]|0;
        $89 = (($1) + ($88)|0);
        $90 = $89;
        $91 = $86;
        $92 = (($90) - ($91))|0;
        $93 = ($92>>>0)>(3);
        if ($93) {
         $$1146 = $86;$87 = $86;
        } else {
         $$pre$phi168Z2D = $58;
         break L18;
        }
       }
      }
     } while(0);
     $94 = HEAP32[$$pre$phi168Z2D>>2]|0;
     $95 = ($94|0)==(0|0);
     if (!($95)) {
      $96 = HEAP32[$42>>2]|0;
      $97 = $96 & 63;
      $98 = ((($0)) + 8|0);
      $99 = (($98) + ($97<<2)|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ((($36)) + 28|0);
      HEAP32[$101>>2] = $100;
      HEAP32[$99>>2] = $36;
      $$pre$phi163$phZ2D = $$pre$phi168Z2D;
      label = 43;
     }
    } else {
     $102 = ((($$1143)) + 4|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ((($36)) + 4|0);
     HEAP32[$104>>2] = $103;
     $105 = ((($$1143)) + 8|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ((($36)) + 8|0);
     HEAP32[$107>>2] = $106;
     $108 = ((($1)) + 24|0);
     $109 = HEAP32[$1>>2]|0;
     $110 = $109 & -4;
     $111 = ($110|0)==(24);
     L34: do {
      if ($111) {
       $$pre171 = ((($36)) + 12|0);
       $$pre$phi174Z2D = $$pre171;
      } else {
       $112 = ((($36)) + 12|0);
       $113 = ((($36)) + 20|0);
       $114 = ((($36)) + 104|0);
       $115 = ((($1)) + 20|0);
       $116 = ((($36)) + 32|0);
       $117 = ((($36)) + 144|0);
       $$2147 = $108;$155 = $108;
       while(1) {
        $118 = ((($$2147)) + 2|0);
        $119 = HEAP16[$118>>1]|0;
        L39: do {
         switch ($119<<16>>16) {
         case 1:  {
          $120 = HEAP32[$112>>2]|0;
          $121 = ($120|0)==(0|0);
          $122 = HEAP8[$2>>0]|0;
          $123 = $122&255;
          $124 = ((($$2147)) + 4|0);
          $125 = HEAP16[$$2147>>1]|0;
          $126 = $125&65535;
          $127 = (($126) + -4)|0;
          $128 = HEAP32[$115>>2]|0;
          if ($121) {
           _copy_addr($112,$123,$116,$124,$127,$128);
           $$pre$phi176Z2D = $$2147;
           break L39;
          } else {
           _copy_addr($113,$123,$114,$124,$127,$128);
           $$pre$phi176Z2D = $$2147;
           break L39;
          }
          break;
         }
         case 4:  {
          $129 = HEAP8[$2>>0]|0;
          $130 = $129&255;
          $131 = ((($$2147)) + 4|0);
          $132 = HEAP16[$$2147>>1]|0;
          $133 = $132&65535;
          $134 = (($133) + -4)|0;
          $135 = HEAP32[$115>>2]|0;
          _copy_addr($113,$130,$114,$131,$134,$135);
          $$pre$phi176Z2D = $$2147;
          break;
         }
         case 2:  {
          $136 = HEAP32[$112>>2]|0;
          $137 = ($136|0)==(0|0);
          if (!($137)) {
           dest=$114; src=$116; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           HEAP32[$113>>2] = $114;
           (_memset(($116|0),0,36)|0);
          }
          $138 = HEAP8[$2>>0]|0;
          $139 = $138&255;
          $140 = ((($$2147)) + 4|0);
          $141 = HEAP16[$$2147>>1]|0;
          $142 = $141&65535;
          $143 = (($142) + -4)|0;
          $144 = HEAP32[$115>>2]|0;
          _copy_addr($112,$139,$116,$140,$143,$144);
          $$pre$phi176Z2D = $$2147;
          break;
         }
         case 3:  {
          $145 = HEAP16[$$2147>>1]|0;
          $146 = $145&65535;
          $147 = (($146) + -4)|0;
          $148 = ($147>>>0)<(17);
          if ($148) {
           $149 = ((($$2147)) + 4|0);
           (_memcpy(($117|0),($149|0),($147|0))|0);
           HEAP32[$104>>2] = $117;
           $$pre$phi176Z2D = $$2147;
          } else {
           $$pre$phi176Z2D = $$2147;
          }
          break;
         }
         default: {
          $$pre$phi176Z2D = $$2147;
         }
         }
        } while(0);
        $150 = HEAP16[$$pre$phi176Z2D>>1]|0;
        $151 = $150&65535;
        $152 = (($151) + 3)|0;
        $153 = $152 & 131068;
        $154 = (($155) + ($153)|0);
        $156 = HEAP32[$1>>2]|0;
        $157 = (($1) + ($156)|0);
        $158 = $157;
        $159 = $154;
        $160 = (($158) - ($159))|0;
        $161 = ($160>>>0)>(3);
        if ($161) {
         $$2147 = $154;$155 = $154;
        } else {
         $$pre$phi174Z2D = $112;
         break L34;
        }
       }
      }
     } while(0);
     $162 = HEAP32[$$pre$phi174Z2D>>2]|0;
     $163 = ($162|0)==(0|0);
     if ($163) {
      $$pre$phi163$phZ2D = $104;
      label = 43;
     } else {
      $164 = ((($36)) + 16|0);
      $165 = HEAP8[$2>>0]|0;
      $166 = $165&255;
      $167 = ((($36)) + 68|0);
      $168 = ((($2)) + 1|0);
      $169 = HEAP8[$168>>0]|0;
      $170 = $169&255;
      _gen_netmask($164,$166,$167,$170);
      $$pre$phi163$phZ2D = $104;
      label = 43;
     }
    }
    if ((label|0) == 43) {
     $$pr = HEAP32[$$pre$phi163$phZ2D>>2]|0;
     $171 = ($$pr|0)==(0|0);
     if (!($171)) {
      $172 = HEAP32[$0>>2]|0;
      $173 = ($172|0)==(0|0);
      if ($173) {
       HEAP32[$0>>2] = $36;
      }
      $174 = ((($0)) + 4|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==(0|0);
      if (!($176)) {
       HEAP32[$175>>2] = $36;
      }
      HEAP32[$174>>2] = $36;
      $$0 = 0;
      break;
     }
    }
    _free($36);
    $$0 = 0;
   }
  }
 } while(0);
 return ($$0|0);
}
function _copy_lladdr($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ($3>>>0)>(24);
 if (!($6)) {
  HEAP16[$1>>1] = 17;
  $7 = ((($1)) + 4|0);
  HEAP32[$7>>2] = $4;
  $8 = ((($1)) + 8|0);
  HEAP16[$8>>1] = $5;
  $9 = $3&255;
  $10 = ((($1)) + 11|0);
  HEAP8[$10>>0] = $9;
  $11 = ((($1)) + 12|0);
  (_memcpy(($11|0),($2|0),($3|0))|0);
  HEAP32[$0>>2] = $1;
 }
 return;
}
function _copy_addr($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $$020 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: do {
  switch ($1|0) {
  case 2:  {
   $6 = ((($2)) + 4|0);
   $$0 = 4;$$020 = $6;
   label = 7;
   break;
  }
  case 10:  {
   $7 = ((($2)) + 8|0);
   $8 = HEAP8[$3>>0]|0;
   switch ($8<<24>>24) {
   case -2:  {
    $9 = ((($3)) + 1|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = $10 & -64;
    $12 = ($11<<24>>24)==(-128);
    if (!($12)) {
     $$0 = 16;$$020 = $7;
     label = 7;
     break L1;
    }
    break;
   }
   case -1:  {
    $13 = ((($3)) + 1|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14 & 15;
    $16 = ($15<<24>>24)==(2);
    if (!($16)) {
     $$0 = 16;$$020 = $7;
     label = 7;
     break L1;
    }
    break;
   }
   default: {
    $$0 = 16;$$020 = $7;
    label = 7;
    break L1;
   }
   }
   $17 = ((($2)) + 24|0);
   HEAP32[$17>>2] = $5;
   $$0 = 16;$$020 = $7;
   label = 7;
   break;
  }
  default: {
  }
  }
 } while(0);
 if ((label|0) == 7) {
  $18 = ($$0>>>0)>($4>>>0);
  if (!($18)) {
   $19 = $1&65535;
   HEAP16[$2>>1] = $19;
   (_memcpy(($$020|0),($3|0),($$0|0))|0);
   HEAP32[$0>>2] = $2;
  }
 }
 return;
}
function _gen_netmask($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 $5 = ($3>>>0)<(128);
 $spec$select = $5 ? $3 : 128;
 $6 = $spec$select >>> 3;
 (_memset(($4|0),255,($6|0))|0);
 if ($5) {
  $7 = $spec$select & 7;
  $8 = (8 - ($7))|0;
  $9 = 255 << $8;
  $10 = $9&255;
  $11 = (($4) + ($6)|0);
  HEAP8[$11>>0] = $10;
 }
 _copy_addr($0,$1,$2,$4,16,0);
 STACKTOP = sp;return;
}
function _dn_skipname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$011 = 0, $$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0>>>0)<($1>>>0);
 L1: do {
  if ($2) {
   $$015 = $0;
   while(1) {
    $3 = HEAP8[$$015>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     label = 5;
     break;
    }
    $9 = ($3&255)>(191);
    $10 = ((($$015)) + 1|0);
    $11 = ($10>>>0)<($1>>>0);
    if ($9) {
     label = 7;
     break;
    }
    if ($11) {
     $$015 = $10;
    } else {
     $$011 = -1;
     break L1;
    }
   }
   if ((label|0) == 5) {
    $5 = $$015;
    $6 = $0;
    $7 = (1 - ($6))|0;
    $8 = (($7) + ($5))|0;
    $$011 = $8;
    break;
   }
   else if ((label|0) == 7) {
    $12 = $$015;
    $13 = $0;
    $14 = (2 - ($13))|0;
    $15 = (($14) + ($12))|0;
    $spec$select = $11 ? $15 : -1;
    return ($spec$select|0);
   }
  } else {
   $$011 = -1;
  }
 } while(0);
 return ($$011|0);
}
function _socketpair($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$020 = 0, $$old = 0, $$old21 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer11 = 0, $vararg_buffer16 = 0, $vararg_buffer2 = 0, $vararg_buffer21 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr20 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $vararg_buffer21 = sp + 64|0;
 $vararg_buffer16 = sp + 48|0;
 $vararg_buffer11 = sp + 32|0;
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $4 = sp + 104|0;
 $5 = sp + 80|0;
 HEAP32[$4>>2] = $0;
 $6 = ((($4)) + 4|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($4)) + 8|0);
 HEAP32[$7>>2] = $2;
 $8 = ((($4)) + 12|0);
 $9 = $3;
 HEAP32[$8>>2] = $9;
 $10 = ((($4)) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($4)) + 20|0);
 HEAP32[$11>>2] = 0;
 $12 = $4;
 HEAP32[$vararg_buffer>>2] = 8;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $12;
 $13 = (___syscall102(102,($vararg_buffer|0))|0);
 $14 = (___syscall_ret($13)|0);
 $15 = ($14|0)<(0);
 do {
  if ($15) {
   $16 = (___errno_location()|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(22);
   if ($18) {
    $$old = $1 & 526336;
    $$old21 = ($$old|0)==(0);
    if ($$old21) {
     $$020 = $14;
     break;
    }
   } else {
    $19 = (___errno_location()|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)!=(93);
    $22 = $1 & 526336;
    $23 = ($22|0)==(0);
    $or$cond = $23 | $21;
    if ($or$cond) {
     $$020 = $14;
     break;
    }
   }
   HEAP32[$5>>2] = $0;
   $24 = ((($5)) + 4|0);
   $25 = $1 & -526337;
   HEAP32[$24>>2] = $25;
   $26 = ((($5)) + 8|0);
   HEAP32[$26>>2] = $2;
   $27 = ((($5)) + 12|0);
   HEAP32[$27>>2] = $9;
   $28 = ((($5)) + 16|0);
   HEAP32[$28>>2] = 0;
   $29 = ((($5)) + 20|0);
   HEAP32[$29>>2] = 0;
   $30 = $5;
   HEAP32[$vararg_buffer2>>2] = 8;
   $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
   HEAP32[$vararg_ptr5>>2] = $30;
   $31 = (___syscall102(102,($vararg_buffer2|0))|0);
   $32 = (___syscall_ret($31)|0);
   $33 = ($32|0)<(0);
   if ($33) {
    $$020 = $32;
   } else {
    $34 = $1 & 524288;
    $35 = ($34|0)==(0);
    if (!($35)) {
     $36 = HEAP32[$3>>2]|0;
     HEAP32[$vararg_buffer6>>2] = $36;
     $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
     HEAP32[$vararg_ptr9>>2] = 2;
     $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
     HEAP32[$vararg_ptr10>>2] = 1;
     (___syscall221(221,($vararg_buffer6|0))|0);
     $37 = ((($3)) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$vararg_buffer11>>2] = $38;
     $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
     HEAP32[$vararg_ptr14>>2] = 2;
     $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
     HEAP32[$vararg_ptr15>>2] = 1;
     (___syscall221(221,($vararg_buffer11|0))|0);
    }
    $39 = $1 & 2048;
    $40 = ($39|0)==(0);
    if ($40) {
     $$020 = $32;
    } else {
     $41 = HEAP32[$3>>2]|0;
     HEAP32[$vararg_buffer16>>2] = $41;
     $vararg_ptr19 = ((($vararg_buffer16)) + 4|0);
     HEAP32[$vararg_ptr19>>2] = 4;
     $vararg_ptr20 = ((($vararg_buffer16)) + 8|0);
     HEAP32[$vararg_ptr20>>2] = 2048;
     (___syscall221(221,($vararg_buffer16|0))|0);
     $42 = ((($3)) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$vararg_buffer21>>2] = $43;
     $vararg_ptr24 = ((($vararg_buffer21)) + 4|0);
     HEAP32[$vararg_ptr24>>2] = 4;
     $vararg_ptr25 = ((($vararg_buffer21)) + 8|0);
     HEAP32[$vararg_ptr25>>2] = 2048;
     (___syscall221(221,($vararg_buffer21|0))|0);
     $$020 = $32;
    }
   }
  } else {
   $$020 = $14;
  }
 } while(0);
 STACKTOP = sp;return ($$020|0);
}
function _if_nameindex() {
 var $$03844 = 0, $$03943 = 0, $$040$lcssa = 0, $$04042 = 0, $$041 = 0, $$045 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $0 = sp + 8|0;
 $1 = sp;
 (_pthread_setcancelstate(1,($1|0))|0);
 (_memset(($0|0),0,272)|0);
 $2 = (___rtnetlink_enumerate(0,2,(fb + (14) | 0),$0)|0);
 $3 = ($2|0)<(0);
 if ($3) {
  $$041 = 0;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = $4 << 3;
  $6 = (($5) + 8)|0;
  $7 = ((($0)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + ($8))|0;
  $10 = (_malloc($9)|0);
  $11 = ($10|0)==(0|0);
  if ($11) {
   $$041 = $10;
  } else {
   $12 = HEAP32[$0>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    $$040$lcssa = $10;
   } else {
    $14 = ((($0)) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($10) + ($12<<3)|0);
    $17 = ((($16)) + 8|0);
    $18 = $12 << 3;
    $scevgep = (($10) + ($18)|0);
    $$03844 = $17;$$03943 = $15;$$04042 = $10;$$045 = $12;
    while(1) {
     $19 = ((($$03943)) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$$04042>>2] = $20;
     $21 = ((($$04042)) + 4|0);
     HEAP32[$21>>2] = $$03844;
     $22 = ((($$03943)) + 9|0);
     $23 = ((($$03943)) + 8|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24&255;
     (_memcpy(($$03844|0),($22|0),($25|0))|0);
     $26 = HEAP8[$23>>0]|0;
     $27 = $26&255;
     $28 = (($$03844) + ($27)|0);
     $29 = ((($28)) + 1|0);
     HEAP8[$28>>0] = 0;
     $30 = (($$045) + -1)|0;
     $31 = ((($$03943)) + 28|0);
     $32 = ((($$04042)) + 8|0);
     $33 = ($30|0)==(0);
     if ($33) {
      break;
     } else {
      $$03844 = $29;$$03943 = $31;$$04042 = $32;$$045 = $30;
     }
    }
    $$040$lcssa = $scevgep;
   }
   HEAP32[$$040$lcssa>>2] = 0;
   $34 = ((($$040$lcssa)) + 4|0);
   HEAP32[$34>>2] = 0;
   $$041 = $10;
  }
 }
 $35 = HEAP32[$1>>2]|0;
 (_pthread_setcancelstate(($35|0),(0|0))|0);
 $36 = ((($0)) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 _free($37);
 $38 = (___errno_location()|0);
 HEAP32[$38>>2] = 105;
 STACKTOP = sp;return ($$041|0);
}
function _netlink_msg_to_nameindex($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$082 = 0, $$084 = 0, $$08490 = 0, $$08491 = 0, $$085 = 0, $$085$in$in = 0, $$1 = 0, $$in = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre101 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(16);
 $5 = ((($1)) + 32|0);
 $6 = ((($1)) + 24|0);
 $$082 = $4 ? $5 : $6;
 $$085$in$in = ((($1)) + 20|0);
 $$085 = HEAP32[$$085$in$in>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = (($1) + ($7)|0);
 $9 = $8;
 $10 = $$082;
 $11 = (($9) - ($10))|0;
 $12 = ($11>>>0)>(3);
 L1: do {
  if ($12) {
   $$in = $$082;
   while(1) {
    $13 = ((($$in)) + 2|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = ($14<<16>>16)==(3);
    $16 = HEAP16[$$in>>1]|0;
    $17 = $16&65535;
    if ($15) {
     break;
    }
    $69 = (($17) + 3)|0;
    $70 = $69 & 131068;
    $71 = (($$in) + ($70)|0);
    $72 = $71;
    $73 = (($9) - ($72))|0;
    $74 = ($73>>>0)>(3);
    if ($74) {
     $$in = $71;
    } else {
     $$1 = 0;
     break L1;
    }
   }
   $18 = (($17) + -4)|0;
   $19 = (($17) + -5)|0;
   $20 = ($16&65535)>(21);
   if ($20) {
    $$1 = 0;
   } else {
    $21 = (($$085|0) % 64)&-1;
    $22 = ((($0)) + 16|0);
    $23 = (($22) + ($21<<2)|0);
    $$08490 = HEAP32[$23>>2]|0;
    $24 = ($$08490|0)==(0);
    if (!($24)) {
     $25 = ((($0)) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ((($$in)) + 4|0);
     $$08491 = $$08490;
     while(1) {
      $28 = (($$08491) + -1)|0;
      $29 = (((($26) + (($28*28)|0)|0)) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = ($30|0)==($$085|0);
      if ($31) {
       $32 = (((($26) + (($28*28)|0)|0)) + 8|0);
       $33 = HEAP8[$32>>0]|0;
       $34 = $33&255;
       $35 = ($19|0)==($34|0);
       if ($35) {
        $36 = (((($26) + (($28*28)|0)|0)) + 9|0);
        $37 = (_memcmp($36,$27,$19)|0);
        $38 = ($37|0)==(0);
        if ($38) {
         $$1 = 0;
         break L1;
        }
       }
      }
      $39 = (($26) + (($28*28)|0)|0);
      $$084 = HEAP32[$39>>2]|0;
      $40 = ($$084|0)==(0);
      if ($40) {
       break;
      } else {
       $$08491 = $$084;
      }
     }
    }
    $41 = HEAP32[$0>>2]|0;
    $42 = ((($0)) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41>>>0)<($43>>>0);
    if ($44) {
     $$phi$trans$insert = ((($0)) + 12|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $56 = $$pre;$57 = $41;
    } else {
     $45 = ($43|0)==(0);
     $46 = $43 << 1;
     $47 = $46 | 1;
     $48 = $45 ? 8 : $47;
     $49 = ($48>>>0)>(153391689);
     if ($49) {
      $$1 = -1;
      break;
     }
     $50 = ((($0)) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($48*28)|0;
     $53 = (_realloc($51,$52)|0);
     $54 = ($53|0)==(0|0);
     if ($54) {
      $$1 = -1;
      break;
     }
     HEAP32[$50>>2] = $53;
     HEAP32[$42>>2] = $48;
     $$pre101 = HEAP32[$0>>2]|0;
     $56 = $53;$57 = $$pre101;
    }
    $55 = (((($56) + (($57*28)|0)|0)) + 4|0);
    HEAP32[$55>>2] = $$085;
    $58 = $19&255;
    $59 = (((($56) + (($57*28)|0)|0)) + 8|0);
    HEAP8[$59>>0] = $58;
    $60 = (((($56) + (($57*28)|0)|0)) + 9|0);
    $61 = ((($$in)) + 4|0);
    (_memcpy(($60|0),($61|0),($19|0))|0);
    $62 = ((($0)) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($18) + ($63))|0;
    HEAP32[$62>>2] = $64;
    $65 = HEAP32[$0>>2]|0;
    $66 = (($65) + 1)|0;
    HEAP32[$0>>2] = $66;
    $67 = HEAP32[$23>>2]|0;
    $68 = (($56) + (($57*28)|0)|0);
    HEAP32[$68>>2] = $67;
    HEAP32[$23>>2] = $66;
    $$1 = 0;
   }
  } else {
   $$1 = 0;
  }
 } while(0);
 return ($$1|0);
}
function _recvmmsg($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = $1;
 $6 = $4;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $6;
 $7 = (___syscall337(337,($vararg_buffer|0))|0);
 $8 = (___syscall_ret($7)|0);
 STACKTOP = sp;return ($8|0);
}
function _ether_aton_r($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02031 = 0, $$02130 = 0, $$122 = 0, $$3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp + 4|0;
 $3 = sp;
 $$02031 = 0;$$02130 = $0;
 while(1) {
  $4 = ($$02031|0)==(0);
  if ($4) {
   $$122 = $$02130;
  } else {
   $5 = HEAP8[$$02130>>0]|0;
   $6 = ($5<<24>>24)==(58);
   if (!($6)) {
    $$3 = 0;
    break;
   }
   $7 = ((($$02130)) + 1|0);
   $$122 = $7;
  }
  $8 = (_strtoul($$122,$3,16)|0);
  $9 = ($8>>>0)>(255);
  if ($9) {
   $$3 = 0;
   break;
  }
  $10 = HEAP32[$3>>2]|0;
  $11 = $8&255;
  $12 = (($2) + ($$02031)|0);
  HEAP8[$12>>0] = $11;
  $13 = (($$02031) + 1)|0;
  $14 = ($13>>>0)<(6);
  if ($14) {
   $$02031 = $13;$$02130 = $10;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $15 = HEAP8[$10>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ;HEAP8[$1>>0]=HEAP8[$2>>0]|0;HEAP8[$1+1>>0]=HEAP8[$2+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[$2+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[$2+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[$2+4>>0]|0;HEAP8[$1+5>>0]=HEAP8[$2+5>>0]|0;
   $$3 = $1;
  } else {
   $$3 = 0;
  }
 }
 STACKTOP = sp;return ($$3|0);
}
function _ether_aton($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ether_aton_r($0,(gb + (172126) | 0))|0);
 return ($1|0);
}
function _ether_ntoa_r($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01112 = 0, $$013 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $$01112 = $1;$$013 = 0;
 while(1) {
  $2 = ($$013|0)==(0);
  $3 = $2 ? (gb + (166923) | 0) : (gb + (166928) | 0);
  $4 = (($0) + ($$013)|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  HEAP32[$vararg_buffer>>2] = $6;
  $7 = (_sprintf($$01112,$3,$vararg_buffer)|0);
  $8 = (($$01112) + ($7)|0);
  $9 = (($$013) + 1)|0;
  $exitcond = ($9|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $$01112 = $8;$$013 = $9;
  }
 }
 STACKTOP = sp;return ($1|0);
}
function _ether_ntoa($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ether_ntoa_r($0,(gb + (170064) | 0))|0);
 return ($1|0);
}
function _ether_line($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function _ether_ntohost($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function _ether_hostton($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return -1;
}
function _sendmmsg($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $5 = (___syscall345(345,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _sethostent($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _gethostent() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function _endhostent() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _res_init() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _ns_get16($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 8;
 $4 = ((($0)) + 1|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $3 | $6;
 return ($7|0);
}
function _ns_get32($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 24;
 $4 = ((($0)) + 1|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 16;
 $8 = $7 | $3;
 $9 = ((($0)) + 2|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 << 8;
 $13 = $8 | $12;
 $14 = ((($0)) + 3|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = $13 | $16;
 return ($17|0);
}
function _ns_put16($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 >>> 8;
 $3 = $2&255;
 $4 = ((($1)) + 1|0);
 HEAP8[$1>>0] = $3;
 $5 = $0&255;
 HEAP8[$4>>0] = $5;
 return;
}
function _ns_put32($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 >>> 24;
 $3 = $2&255;
 $4 = ((($1)) + 1|0);
 HEAP8[$1>>0] = $3;
 $5 = $0 >>> 16;
 $6 = $5&255;
 $7 = ((($1)) + 2|0);
 HEAP8[$4>>0] = $6;
 $8 = $0 >>> 8;
 $9 = $8&255;
 $10 = ((($1)) + 3|0);
 HEAP8[$7>>0] = $9;
 $11 = $0&255;
 HEAP8[$10>>0] = $11;
 return;
}
function _ns_skiprr($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$lcssa = 0, $$025 = 0, $$027 = 0, $$1 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0$lcssa = $0;
   label = 10;
  } else {
   $5 = $1;
   $6 = ($2|0)==(0);
   $$027 = $0;$$in = $3;
   while(1) {
    $7 = (($$in) + -1)|0;
    $8 = (_dn_skipname($$027,$1)|0);
    $9 = ($8|0)<(0);
    if ($9) {
     break;
    }
    $10 = (($8) + 4)|0;
    $11 = $$027;
    $12 = (($5) - ($11))|0;
    $13 = ($10|0)>($12|0);
    if ($13) {
     break;
    }
    $14 = (($$027) + ($10)|0);
    if ($6) {
     $$1 = $14;
    } else {
     $15 = $14;
     $16 = (($5) - ($15))|0;
     $17 = ($16|0)<(6);
     if ($17) {
      break;
     }
     $18 = ((($14)) + 4|0);
     $19 = ((($18)) + 2|0);
     $20 = ((($19)) + -2|0);
     $21 = (_ns_get16($20)|0);
     $22 = $19;
     $23 = (($5) - ($22))|0;
     $24 = ($21|0)>($23|0);
     if ($24) {
      break;
     }
     $25 = (($19) + ($21)|0);
     $$1 = $25;
    }
    $26 = ($7|0)==(0);
    if ($26) {
     $$0$lcssa = $$1;
     label = 10;
     break L1;
    } else {
     $$027 = $$1;$$in = $7;
    }
   }
   $30 = (___errno_location()|0);
   HEAP32[$30>>2] = 90;
   $$025 = -1;
  }
 } while(0);
 if ((label|0) == 10) {
  $27 = $$0$lcssa;
  $28 = $0;
  $29 = (($27) - ($28))|0;
  $$025 = $29;
 }
 return ($$025|0);
}
function _ns_initparse($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$04047 = 0, $$04146 = 0, $$14244 = 0, $$145 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$2>>2] = $0;
 $3 = (($0) + ($1)|0);
 $4 = ((($2)) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = ($1|0)<(12);
 L1: do {
  if ($5) {
   label = 12;
  } else {
   $6 = (_ns_get16($0)|0);
   $7 = $6&65535;
   $8 = ((($2)) + 8|0);
   HEAP16[$8>>1] = $7;
   $9 = ((($0)) + 4|0);
   $10 = ((($0)) + 2|0);
   $11 = (_ns_get16($10)|0);
   $12 = $11&65535;
   $13 = ((($2)) + 10|0);
   HEAP16[$13>>1] = $12;
   $$04047 = 0;$$04146 = $9;
   while(1) {
    $14 = ((($$04146)) + 2|0);
    $15 = (_ns_get16($$04146)|0);
    $16 = $15&65535;
    $17 = (((($2)) + 12|0) + ($$04047<<1)|0);
    HEAP16[$17>>1] = $16;
    $18 = (($$04047) + 1)|0;
    $exitcond = ($18|0)==(4);
    if ($exitcond) {
     break;
    } else {
     $$04047 = $18;$$04146 = $14;
    }
   }
   $scevgep = ((($0)) + 12|0);
   $$14244 = $scevgep;$$145 = 0;
   while(1) {
    $19 = (((($2)) + 12|0) + ($$145<<1)|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = ($20<<16>>16)==(0);
    $22 = (((($2)) + 20|0) + ($$145<<2)|0);
    if ($21) {
     HEAP32[$22>>2] = 0;
     $$2 = $$14244;
    } else {
     HEAP32[$22>>2] = $$14244;
     $23 = HEAP32[$4>>2]|0;
     $24 = $20&65535;
     $25 = (_ns_skiprr($$14244,$23,$$145,$24)|0);
     $26 = ($25|0)<(0);
     if ($26) {
      $$0 = -1;
      break L1;
     }
     $27 = (($$14244) + ($25)|0);
     $$2 = $27;
    }
    $28 = (($$145) + 1)|0;
    $29 = ($28>>>0)<(4);
    if ($29) {
     $$14244 = $$2;$$145 = $28;
    } else {
     break;
    }
   }
   $30 = HEAP32[$4>>2]|0;
   $31 = ($$2|0)==($30|0);
   if ($31) {
    $32 = ((($2)) + 36|0);
    HEAP32[$32>>2] = 4;
    $33 = ((($2)) + 40|0);
    HEAP32[$33>>2] = -1;
    $34 = ((($2)) + 44|0);
    HEAP32[$34>>2] = 0;
    $$0 = 0;
   } else {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $35 = (___errno_location()|0);
  HEAP32[$35>>2] = 90;
  $$0 = -1;
 }
 return ($$0|0);
}
function _ns_name_uncompress($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (mftCall_iiiiii((fb + (15) | 0)|0,($0|0),($1|0),($2|0),($3|0),($4|0))|0);
 $6 = ($5|0)<(0);
 if ($6) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 90;
 }
 return ($5|0);
}
function _ns_parserr($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$073 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($1>>>0)>(3);
 L1: do {
  if ($4) {
   label = 24;
  } else {
   $5 = ((($0)) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($1|0);
   if (!($7)) {
    $8 = ((($0)) + 44|0);
    $9 = (((($0)) + 20|0) + ($1<<2)|0);
    $10 = ((($0)) + 40|0);
    HEAP32[$5>>2] = $1;
    HEAP32[$10>>2] = 0;
    $11 = HEAP32[$9>>2]|0;
    HEAP32[$8>>2] = $11;
   }
   $12 = ($2|0)==(-1);
   if ($12) {
    $13 = ((($0)) + 40|0);
    $14 = HEAP32[$13>>2]|0;
    $$073 = $14;
   } else {
    $$073 = $2;
   }
   $15 = ($$073|0)<(0);
   if ($15) {
    label = 24;
   } else {
    $16 = (((($0)) + 12|0) + ($1<<1)|0);
    $17 = HEAP16[$16>>1]|0;
    $18 = $17&65535;
    $19 = ($$073|0)<($18|0);
    if ($19) {
     $20 = ((($0)) + 40|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($$073|0)<($21|0);
     if ($22) {
      $23 = ((($0)) + 44|0);
      $24 = (((($0)) + 20|0) + ($1<<2)|0);
      HEAP32[$20>>2] = 0;
      $25 = HEAP32[$24>>2]|0;
      HEAP32[$23>>2] = $25;
      $27 = 0;
     } else {
      $27 = $21;
     }
     $26 = ($$073|0)>($27|0);
     $28 = ((($0)) + 44|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($0)) + 4|0);
     if ($26) {
      $31 = HEAP32[$30>>2]|0;
      $32 = (($$073) - ($27))|0;
      $33 = (_ns_skiprr($29,$31,$1,$32)|0);
      $34 = ($33|0)<(0);
      if ($34) {
       $$0 = -1;
       break;
      }
      $35 = HEAP32[$28>>2]|0;
      $36 = (($35) + ($33)|0);
      HEAP32[$28>>2] = $36;
      HEAP32[$20>>2] = $$073;
      $39 = $36;
     } else {
      $39 = $29;
     }
     $37 = HEAP32[$0>>2]|0;
     $38 = HEAP32[$30>>2]|0;
     $40 = (_ns_name_uncompress($37,$38,$39,$3,1025)|0);
     $41 = ($40|0)<(0);
     if ($41) {
      $$0 = -1;
     } else {
      $42 = HEAP32[$28>>2]|0;
      $43 = (($42) + ($40)|0);
      HEAP32[$28>>2] = $43;
      $44 = HEAP32[$30>>2]|0;
      $45 = $43;
      $46 = (($44) - ($45))|0;
      $47 = ($46|0)<(4);
      do {
       if (!($47)) {
        $48 = ((($43)) + 2|0);
        HEAP32[$28>>2] = $48;
        $49 = ((($48)) + -2|0);
        $50 = (_ns_get16($49)|0);
        $51 = $50&65535;
        $52 = ((($3)) + 1026|0);
        HEAP16[$52>>1] = $51;
        $53 = ((($48)) + 2|0);
        HEAP32[$28>>2] = $53;
        $54 = (_ns_get16($48)|0);
        $55 = $54&65535;
        $56 = ((($3)) + 1028|0);
        HEAP16[$56>>1] = $55;
        $57 = ($1|0)==(0);
        if ($57) {
         $74 = ((($3)) + 1032|0);
         HEAP32[$74>>2] = 0;
         $75 = ((($3)) + 1036|0);
         HEAP16[$75>>1] = 0;
         $76 = ((($3)) + 1040|0);
         HEAP32[$76>>2] = 0;
        } else {
         $58 = $53;
         $59 = (($44) - ($58))|0;
         $60 = ($59|0)<(6);
         if ($60) {
          break;
         }
         $61 = ((($53)) + 4|0);
         HEAP32[$28>>2] = $61;
         $62 = (_ns_get32($53)|0);
         $63 = ((($3)) + 1032|0);
         HEAP32[$63>>2] = $62;
         $64 = ((($61)) + 2|0);
         HEAP32[$28>>2] = $64;
         $65 = (_ns_get16($61)|0);
         $66 = $65&65535;
         $67 = ((($3)) + 1036|0);
         HEAP16[$67>>1] = $66;
         $68 = $65 & 65535;
         $69 = $64;
         $70 = (($44) - ($69))|0;
         $71 = ($68|0)>($70|0);
         if ($71) {
          break;
         }
         $72 = ((($3)) + 1040|0);
         HEAP32[$72>>2] = $64;
         $73 = (($64) + ($68)|0);
         HEAP32[$28>>2] = $73;
        }
        $77 = HEAP32[$20>>2]|0;
        $78 = (($77) + 1)|0;
        HEAP32[$20>>2] = $78;
        $79 = HEAP16[$16>>1]|0;
        $80 = $79&65535;
        $81 = ($77|0)<($80|0);
        if ($81) {
         $$0 = 0;
         break L1;
        }
        $82 = (($1) + 1)|0;
        HEAP32[$5>>2] = $82;
        $83 = ($82|0)==(4);
        if ($83) {
         HEAP32[$20>>2] = -1;
         HEAP32[$28>>2] = 0;
         $$0 = 0;
         break L1;
        } else {
         HEAP32[$20>>2] = 0;
         $$0 = 0;
         break L1;
        }
       }
      } while(0);
      $85 = (___errno_location()|0);
      HEAP32[$85>>2] = 90;
      $$0 = -1;
     }
    } else {
     label = 24;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $84 = (___errno_location()|0);
  HEAP32[$84>>2] = 19;
  $$0 = -1;
 }
 return ($$0|0);
}
function _ntohs($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___bswap_16_258($0)|0);
 return ($1|0);
}
function ___bswap_16_258($0) {
 $0 = $0|0;
 var $rev = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $rev = (_llvm_bswap_i16(($0|0))|0);
 return ($rev|0);
}
function _connect($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($3)) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = $3;
 HEAP32[$vararg_buffer>>2] = 3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $11 = (___syscall102(102,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function ___dns_parse($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$056$lcssa = 0, $$05688 = 0, $$1$lcssa = 0, $$181 = 0, $$269 = 0, $$3$lcssa = 0, $$364 = 0, $$in = 0, $$in93 = 0, $$lcssa = 0, $$lcssa62 = 0, $$old = 0, $$old91 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($1|0)<(12);
 L1: do {
  if ($4) {
   $$0 = -1;
  } else {
   $5 = ((($0)) + 3|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = $6 & 15;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    $9 = ((($0)) + 4|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = $10&255;
    $12 = $11 << 8;
    $13 = ((($0)) + 5|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14&255;
    $16 = $12 | $15;
    $17 = ((($0)) + 6|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    $20 = $19 << 8;
    $21 = ((($0)) + 7|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22&255;
    $24 = $20 | $23;
    $25 = (($24) + ($16))|0;
    $26 = ($25>>>0)>(64);
    if ($26) {
     $$0 = -1;
    } else {
     $27 = ((($0)) + 12|0);
     $28 = ($16|0)==(0);
     if ($28) {
      $$056$lcssa = $27;
     } else {
      $29 = $0;
      $30 = (($0) + ($1)|0);
      $31 = ((($30)) + -6|0);
      $$05688 = $27;$$in = $16;
      while(1) {
       $32 = (($$in) + -1)|0;
       $33 = $$05688;
       $34 = (($33) - ($29))|0;
       $35 = ($34|0)<($1|0);
       $36 = HEAP8[$$05688>>0]|0;
       L9: do {
        if ($35) {
         $$181 = $$05688;$38 = $36;
         while(1) {
          $37 = $38&255;
          $39 = (($37) + -1)|0;
          $40 = ($39>>>0)<(127);
          if (!($40)) {
           $$1$lcssa = $$181;$$lcssa62 = $38;
           break L9;
          }
          $41 = ((($$181)) + 1|0);
          $42 = $41;
          $43 = (($42) - ($29))|0;
          $44 = ($43|0)<($1|0);
          $45 = HEAP8[$41>>0]|0;
          if ($44) {
           $$181 = $41;$38 = $45;
          } else {
           $$1$lcssa = $41;$$lcssa62 = $45;
           break;
          }
         }
        } else {
         $$1$lcssa = $$05688;$$lcssa62 = $36;
        }
       } while(0);
       $46 = ($$lcssa62&255)>(193);
       if ($46) {
        $$0 = -1;
        break L1;
       }
       $47 = ($$lcssa62<<24>>24)==(-63);
       if ($47) {
        $48 = ((($$1$lcssa)) + 1|0);
        $49 = HEAP8[$48>>0]|0;
        $50 = ($49<<24>>24)==(-1);
        $51 = ($$1$lcssa>>>0)>($31>>>0);
        $or$cond = $50 | $51;
        if ($or$cond) {
         $$0 = -1;
         break L1;
        }
       } else {
        $$old = ($$1$lcssa>>>0)>($31>>>0);
        if ($$old) {
         $$0 = -1;
         break L1;
        }
       }
       $52 = ($$lcssa62<<24>>24)==(0);
       $53 = $52 ? 5 : 6;
       $54 = (($$1$lcssa) + ($53)|0);
       $55 = ($32|0)==(0);
       if ($55) {
        $$056$lcssa = $54;
        break;
       } else {
        $$05688 = $54;$$in = $32;
       }
      }
     }
     $56 = ($24|0)==(0);
     if ($56) {
      $$0 = 0;
     } else {
      $57 = $0;
      $58 = (($0) + ($1)|0);
      $59 = ((($58)) + -6|0);
      $$269 = $$056$lcssa;$$in93 = $24;
      while(1) {
       $60 = (($$in93) + -1)|0;
       $61 = $$269;
       $62 = (($61) - ($57))|0;
       $63 = ($62|0)<($1|0);
       $64 = HEAP8[$$269>>0]|0;
       L24: do {
        if ($63) {
         $$364 = $$269;$66 = $64;
         while(1) {
          $65 = $66&255;
          $67 = (($65) + -1)|0;
          $68 = ($67>>>0)<(127);
          if (!($68)) {
           $$3$lcssa = $$364;$$lcssa = $66;
           break L24;
          }
          $69 = ((($$364)) + 1|0);
          $70 = $69;
          $71 = (($70) - ($57))|0;
          $72 = ($71|0)<($1|0);
          $73 = HEAP8[$69>>0]|0;
          if ($72) {
           $$364 = $69;$66 = $73;
          } else {
           $$3$lcssa = $69;$$lcssa = $73;
           break;
          }
         }
        } else {
         $$3$lcssa = $$269;$$lcssa = $64;
        }
       } while(0);
       $74 = ($$lcssa&255)>(193);
       if ($74) {
        $$0 = -1;
        break L1;
       }
       $75 = ($$lcssa<<24>>24)==(-63);
       if ($75) {
        $76 = ((($$3$lcssa)) + 1|0);
        $77 = HEAP8[$76>>0]|0;
        $78 = ($77<<24>>24)==(-1);
        $79 = ($$3$lcssa>>>0)>($59>>>0);
        $or$cond92 = $78 | $79;
        if ($or$cond92) {
         $$0 = -1;
         break L1;
        }
       } else {
        $$old91 = ($$3$lcssa>>>0)>($59>>>0);
        if ($$old91) {
         $$0 = -1;
         break L1;
        }
       }
       $80 = ($$lcssa<<24>>24)==(0);
       $81 = $80 ? 1 : 2;
       $82 = (($$3$lcssa) + ($81)|0);
       $83 = ((($82)) + 8|0);
       $84 = HEAP8[$83>>0]|0;
       $85 = $84&255;
       $86 = $85 << 8;
       $87 = ((($82)) + 9|0);
       $88 = HEAP8[$87>>0]|0;
       $89 = $88&255;
       $90 = $86 | $89;
       $91 = (($82) + ($90)|0);
       $92 = ($91>>>0)>($58>>>0);
       if ($92) {
        $$0 = -1;
        break L1;
       }
       $93 = ((($82)) + 1|0);
       $94 = HEAP8[$93>>0]|0;
       $95 = $94&255;
       $96 = ((($82)) + 10|0);
       $97 = (mftCall_iiiiii($2|0,($3|0),($95|0),($96|0),($90|0),($0|0))|0);
       $98 = ($97|0)<(0);
       if ($98) {
        $$0 = -1;
        break L1;
       }
       $99 = (($90) + 10)|0;
       $100 = (($82) + ($99)|0);
       $101 = ($60|0)==(0);
       if ($101) {
        $$0 = 0;
        break;
       } else {
        $$269 = $100;$$in93 = $60;
       }
      }
     }
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 return ($$0|0);
}
function _endservent() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _setservent($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return;
}
function _getservent() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function _getpeername($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 $7 = $2;
 HEAP32[$6>>2] = $7;
 $8 = ((($3)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($3)) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = $3;
 HEAP32[$vararg_buffer>>2] = 7;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $11;
 $12 = (___syscall102(102,($vararg_buffer|0))|0);
 $13 = (___syscall_ret($12)|0);
 STACKTOP = sp;return ($13|0);
}
function _getsockopt($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = sp + 8|0;
 HEAP32[$5>>2] = $0;
 $6 = ((($5)) + 4|0);
 HEAP32[$6>>2] = $1;
 $7 = ((($5)) + 8|0);
 HEAP32[$7>>2] = $2;
 $8 = ((($5)) + 12|0);
 $9 = $3;
 HEAP32[$8>>2] = $9;
 $10 = ((($5)) + 16|0);
 $11 = $4;
 HEAP32[$10>>2] = $11;
 $12 = ((($5)) + 20|0);
 HEAP32[$12>>2] = 0;
 $13 = $5;
 HEAP32[$vararg_buffer>>2] = 15;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $13;
 $14 = (___syscall102(102,($vararg_buffer|0))|0);
 $15 = (___syscall_ret($14)|0);
 STACKTOP = sp;return ($15|0);
}
function ___res_state() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (171384) | 0)|0);
}
function ___res_mkquery($0,$1,$2,$3,$4,$5,$6,$7,$8) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 var $$0 = 0, $$05154 = 0, $$052 = 0, $$053$lcssa = 0, $$05356 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $9 = 0, $or$cond = 0;
 var $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $9 = sp;
 $10 = sp + 280|0;
 $11 = (_strnlen($1,255)|0);
 $12 = ($11|0)==(0);
 $13 = (($11) + -1)|0;
 if ($12) {
  $$05154 = 0;$23 = 17;
  label = 3;
 } else {
  $14 = (($1) + ($13)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(46);
  $spec$select = $16 ? $13 : $11;
  $17 = (($spec$select) + 17)|0;
  $18 = ($spec$select|0)!=(0);
  $19 = $18&1;
  $20 = (($17) + ($19))|0;
  $21 = ($spec$select>>>0)>(253);
  if ($21) {
   $$0 = -1;
  } else {
   $$05154 = $spec$select;$23 = $20;
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $22 = ($23|0)>($8|0);
   $24 = ($0>>>0)>(15);
   $or$cond = $24 | $22;
   $25 = $3 | $2;
   $26 = ($25>>>0)>(255);
   $27 = $26 | $or$cond;
   if ($27) {
    $$0 = -1;
   } else {
    (_memset(($9|0),0,($23|0))|0);
    $28 = $0 << 3;
    $29 = $28 | 1;
    $30 = $29&255;
    $31 = ((($9)) + 2|0);
    HEAP8[$31>>0] = $30;
    $32 = ((($9)) + 5|0);
    HEAP8[$32>>0] = 1;
    $33 = ((($9)) + 13|0);
    (_memcpy(($33|0),($1|0),($$05154|0))|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $$053$lcssa = 13;
    } else {
     $$05356 = 13;
     while(1) {
      $$052 = $$05356;
      L10: while(1) {
       $36 = (($9) + ($$052)|0);
       $37 = HEAP8[$36>>0]|0;
       switch ($37<<24>>24) {
       case 46: case 0:  {
        break L10;
        break;
       }
       default: {
       }
       }
       $38 = (($$052) + 1)|0;
       $$052 = $38;
      }
      $39 = (($$052) - ($$05356))|0;
      $40 = (($39) + -1)|0;
      $41 = ($40>>>0)>(62);
      if ($41) {
       $$0 = -1;
       break L3;
      }
      $42 = $39&255;
      $43 = (($$05356) + -1)|0;
      $44 = (($9) + ($43)|0);
      HEAP8[$44>>0] = $42;
      $45 = (($$052) + 1)|0;
      $46 = (($9) + ($45)|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = ($47<<24>>24)==(0);
      if ($48) {
       $$053$lcssa = $45;
       break;
      } else {
       $$05356 = $45;
      }
     }
    }
    $49 = $3&255;
    $50 = (($$053$lcssa) + 1)|0;
    $51 = (($9) + ($50)|0);
    HEAP8[$51>>0] = $49;
    $52 = $2&255;
    $53 = (($$053$lcssa) + 3)|0;
    $54 = (($9) + ($53)|0);
    HEAP8[$54>>0] = $52;
    (_clock_gettime(0,($10|0))|0);
    $55 = ((($10)) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = $56 >>> 16;
    $58 = (($57) + ($56))|0;
    $59 = $58 >>> 8;
    $60 = $59&255;
    HEAP8[$9>>0] = $60;
    $61 = $58&255;
    $62 = ((($9)) + 1|0);
    HEAP8[$62>>0] = $61;
    (_memcpy(($7|0),($9|0),($23|0))|0);
    $$0 = $23;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _freeaddrinfo($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($0);
 return;
}
function _getnetbyaddr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function _getnetbyname($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return (0|0);
}
function ___lookup_name($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0132 = 0, $$0138171 = 0, $$0147168 = 0, $$1 = 0, $$1133 = 0, $$1137 = 0, $$1139169 = 0, $$1143 = 0, $$1148 = 0, $$2 = 0, $$2140166 = 0, $$2144 = 0, $$2179 = 0, $$3 = 0, $$3141162 = 0, $$3145 = 0, $$4161 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond177 = 0, $exitcond178 = 0, $or$cond = 0, $spec$select = 0, $spec$select154 = 0, $spec$select156 = 0, $spec$select157 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $5 = sp + 60|0;
 $6 = sp + 32|0;
 $7 = sp + 4|0;
 $8 = sp;
 HEAP8[$1>>0] = 0;
 $9 = ($2|0)==(0|0);
 if ($9) {
  label = 4;
 } else {
  $10 = (_strnlen($2,255)|0);
  $11 = (($10) + -1)|0;
  $12 = ($11>>>0)>(253);
  if ($12) {
   $$1 = -2;
  } else {
   $13 = (($10) + 1)|0;
   (_memcpy(($1|0),($2|0),($13|0))|0);
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $14 = $4 & 8;
   $15 = ($14|0)==(0);
   $16 = ($3|0)==(10);
   $17 = (($4) + -8)|0;
   $spec$select154 = $16 ? 0 : $3;
   $18 = $16 | $15;
   $spec$select156 = $18 ? $4 : $17;
   $spec$select157 = $15 ? $3 : $spec$select154;
   $19 = (_name_from_null($0,$2,$spec$select157,$spec$select156)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $21 = (_name_from_numeric($0,$2,$spec$select157)|0);
    $22 = $spec$select156 & 4;
    $23 = $21 | $22;
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = (_name_from_hosts($0,$1,$2,$spec$select157)|0);
     $26 = ($25|0)==(0);
     if ($26) {
      $27 = (_name_from_dns_search($0,$1,$2,$spec$select157)|0);
      $$1137 = $27;
     } else {
      $$1137 = $25;
     }
    } else {
     $$1137 = $21;
    }
   } else {
    $$1137 = $19;
   }
   $28 = ($$1137|0)<(1);
   if ($28) {
    $29 = ($$1137|0)==(0);
    $30 = $29 ? -2 : $$1137;
    $$1 = $30;
    break;
   }
   $31 = $spec$select156 & 8;
   $32 = ($31|0)==(0);
   if ($32) {
    $$3 = $$1137;
   } else {
    $33 = $spec$select156 & 16;
    $34 = ($33|0)==(0);
    if ($34) {
     $$0138171 = 0;
     while(1) {
      $35 = (($0) + (($$0138171*28)|0)|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)==(10);
      if ($37) {
       label = 15;
       break;
      }
      $38 = (($$0138171) + 1)|0;
      $39 = ($38|0)<($$1137|0);
      if ($39) {
       $$0138171 = $38;
      } else {
       $$2 = $$1137;
       break;
      }
     }
     if ((label|0) == 15) {
      $40 = ($$0138171|0)<($$1137|0);
      if (!($40)) {
       $$1 = 0;
       break;
      }
      $$0147168 = 0;$$1139169 = $$0138171;
      while(1) {
       $41 = (($0) + (($$1139169*28)|0)|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(10);
       if ($43) {
        $44 = (($0) + (($$0147168*28)|0)|0);
        $45 = (($$0147168) + 1)|0;
        ;HEAP32[$44>>2]=HEAP32[$41>>2]|0;HEAP32[$44+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$44+16>>2]=HEAP32[$41+16>>2]|0;HEAP32[$44+20>>2]=HEAP32[$41+20>>2]|0;HEAP32[$44+24>>2]=HEAP32[$41+24>>2]|0;
        $$1148 = $45;
       } else {
        $$1148 = $$0147168;
       }
       $46 = (($$1139169) + 1)|0;
       $exitcond178 = ($46|0)==($$1137|0);
       if ($exitcond178) {
        $$2 = $$1148;
        break;
       } else {
        $$0147168 = $$1148;$$1139169 = $46;
       }
      }
     }
     $47 = ($$2|0)>(0);
     if ($47) {
      $$2179 = $$2;
     } else {
      $$1 = $$2;
      break;
     }
    } else {
     $$2179 = $$1137;
    }
    $$2140166 = 0;
    while(1) {
     $48 = (($0) + (($$2140166*28)|0)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(2);
     $51 = (((($0) + (($$2140166*28)|0)|0)) + 8|0);
     if ($50) {
      $52 = (((($0) + (($$2140166*28)|0)|0)) + 20|0);
      (_memcpy(($52|0),($51|0),4)|0);
      (_memcpy(($51|0),((gb + (166957) | 0)|0),12)|0);
      HEAP32[$48>>2] = 10;
     }
     $53 = (($$2140166) + 1)|0;
     $exitcond177 = ($53|0)==($$2179|0);
     if ($exitcond177) {
      $$3 = $$2179;
      break;
     } else {
      $$2140166 = $53;
     }
    }
   }
   $54 = ($$3|0)<(2);
   $55 = ($spec$select157|0)==(2);
   $or$cond = $55 | $54;
   if ($or$cond) {
    $$1 = $$3;
   } else {
    $56 = HEAP32[$0>>2]|0;
    $57 = ($56|0)==(2);
    if ($57) {
     $$3141162 = 0;
     while(1) {
      $62 = ($$3141162|0)==($$3|0);
      $59 = (($$3141162) + 1)|0;
      if ($62) {
       $$1 = $$3;
       break L4;
      }
      $58 = (($0) + (($59*28)|0)|0);
      $60 = HEAP32[$58>>2]|0;
      $61 = ($60|0)==(2);
      if ($61) {
       $$3141162 = $59;
      } else {
       break;
      }
     }
    }
    (_pthread_setcancelstate(1,($5|0))|0);
    $63 = ($$3|0)>(0);
    if ($63) {
     $64 = ((($7)) + 2|0);
     $65 = ((($7)) + 4|0);
     $66 = ((($7)) + 8|0);
     $67 = ((($7)) + 24|0);
     $68 = ((($7)) + 20|0);
     $69 = ((($6)) + 8|0);
     $$4161 = 0;
     while(1) {
      HEAP16[$7>>1] = 10;
      HEAP16[$64>>1] = -1;
      $70 = (((($0) + (($$4161*28)|0)|0)) + 4|0);
      ;HEAP32[$65>>2]=0|0;HEAP32[$65+4>>2]=0|0;HEAP32[$65+8>>2]=0|0;HEAP32[$65+12>>2]=0|0;HEAP32[$65+16>>2]=0|0;
      $71 = HEAP32[$70>>2]|0;
      HEAP32[$67>>2] = $71;
      $72 = (($0) + (($$4161*28)|0)|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ($73|0)==(10);
      if ($74) {
       $75 = (((($0) + (($$4161*28)|0)|0)) + 8|0);
       (_memcpy(($66|0),($75|0),16)|0);
      } else {
       (_memcpy(($66|0),((gb + (166957) | 0)|0),12)|0);
       $76 = (((($0) + (($$4161*28)|0)|0)) + 8|0);
       (_memcpy(($68|0),($76|0),4)|0);
      }
      $77 = (_policyof($66)|0);
      $78 = (_scopeof($66)|0);
      $79 = ((($77)) + 19|0);
      $80 = HEAP8[$79>>0]|0;
      $81 = $80&255;
      $82 = ((($77)) + 18|0);
      $83 = HEAP8[$82>>0]|0;
      $84 = $83&255;
      $85 = (_socket(10,524290,17)|0);
      $86 = ($85|0)>(-1);
      if ($86) {
       $87 = (_connect($85,$7,28)|0);
       $88 = ($87|0)==(0);
       if ($88) {
        HEAP32[$8>>2] = 28;
        $89 = (_getsockname($85,$6,$8)|0);
        $90 = ($89|0)==(0);
        if ($90) {
         $91 = (_scopeof($69)|0);
         $92 = ($78|0)==($91|0);
         $spec$select = $92 ? 1610612736 : 1073741824;
         $93 = (_labelof($69)|0);
         $94 = ($93|0)==($81|0);
         $95 = $spec$select | 268435456;
         $$1143 = $94 ? $95 : $spec$select;
         $96 = (_prefixmatch($69,$66)|0);
         $$0132 = $96;$$2144 = $$1143;
        } else {
         $$0132 = 0;$$2144 = 1073741824;
        }
       } else {
        $$0132 = 0;$$2144 = 0;
       }
       (_close($85)|0);
       $$1133 = $$0132;$$3145 = $$2144;
      } else {
       $$1133 = 0;$$3145 = 0;
      }
      $97 = $84 << 20;
      $98 = $78 << 16;
      $99 = (983040 - ($98))|0;
      $100 = $$1133 << 8;
      $101 = (48 - ($$4161))|0;
      $102 = $99 | $101;
      $103 = $102 | $97;
      $104 = $103 | $$3145;
      $105 = $104 | $100;
      $106 = (((($0) + (($$4161*28)|0)|0)) + 24|0);
      HEAP32[$106>>2] = $105;
      $107 = (($$4161) + 1)|0;
      $exitcond = ($107|0)==($$3|0);
      if ($exitcond) {
       break;
      } else {
       $$4161 = $107;
      }
     }
    }
    _qsort($0,$$3,28,(fb + (16) | 0));
    $108 = HEAP32[$5>>2]|0;
    (_pthread_setcancelstate(($108|0),(0|0))|0);
    $$1 = $$3;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _name_from_null($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$136 = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$05$0$$sroa_idx = 0, $$sroa$05$0$$sroa_idx33 = 0, $$sroa$3$0$$sroa_idx = 0, $$sroa$310$0$$sroa_idx = 0, $$sroa$32$0$$sroa_idx = 0, $$sroa$36$0$$sroa_cast34$in = 0, $$sroa$36$0$$sroa_idx = 0, $$sroa$36$0$$sroa_idx30 = 0, $$sroa$4$0$$sroa_idx3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 $5 = ($1|0)==(0|0);
 do {
  if ($5) {
   $6 = $3 & 1;
   $7 = ($6|0)==(0);
   $8 = ($2|0)!=(10);
   if ($7) {
    if ($8) {
     HEAP32[$4>>2] = 2;
     $10 = ((($4)) + 4|0);
     HEAP32[$10>>2] = 0;
     $11 = ((($4)) + 8|0);
     HEAP8[$11>>0] = 127;
     $12 = ((($4)) + 9|0);
     HEAP8[$12>>0] = 0;
     $13 = ((($4)) + 10|0);
     HEAP8[$13>>0] = 0;
     $14 = ((($4)) + 11|0);
     HEAP8[$14>>0] = 1;
     $15 = ((($4)) + 12|0);
     ;HEAP32[$15>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;
     ;HEAP32[$0>>2]=HEAP32[$4>>2]|0;HEAP32[$0+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$4+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$4+24>>2]|0;
     $16 = ($2|0)==(2);
     if ($16) {
      $$0 = 1;
      break;
     } else {
      $$136 = 1;
     }
    } else {
     $$136 = 0;
    }
    $17 = (($$136) + 1)|0;
    $$sroa$0$0$$sroa_idx = (($0) + (($$136*28)|0)|0);
    HEAP32[$$sroa$0$0$$sroa_idx>>2] = 10;
    $$sroa$3$0$$sroa_idx = (((($0) + (($$136*28)|0)|0)) + 4|0);
    ;HEAP32[$$sroa$3$0$$sroa_idx>>2]=0|0;HEAP32[$$sroa$3$0$$sroa_idx+4>>2]=0|0;HEAP32[$$sroa$3$0$$sroa_idx+8>>2]=0|0;HEAP32[$$sroa$3$0$$sroa_idx+12>>2]=0|0;HEAP16[$$sroa$3$0$$sroa_idx+16>>1]=0|0;HEAP8[$$sroa$3$0$$sroa_idx+18>>0]=0|0;
    $$sroa$32$0$$sroa_idx = (((($0) + (($$136*28)|0)|0)) + 23|0);
    HEAP8[$$sroa$32$0$$sroa_idx>>0] = 1;
    $$sroa$4$0$$sroa_idx3 = (((($0) + (($$136*28)|0)|0)) + 24|0);
    HEAP32[$$sroa$4$0$$sroa_idx3>>2] = 0;
    $$0 = $17;
    break;
   }
   if ($8) {
    HEAP32[$0>>2] = 2;
    $$sroa$310$0$$sroa_idx = ((($0)) + 4|0);
    ;HEAP32[$$sroa$310$0$$sroa_idx>>2]=0|0;HEAP32[$$sroa$310$0$$sroa_idx+4>>2]=0|0;HEAP32[$$sroa$310$0$$sroa_idx+8>>2]=0|0;HEAP32[$$sroa$310$0$$sroa_idx+12>>2]=0|0;HEAP32[$$sroa$310$0$$sroa_idx+16>>2]=0|0;HEAP32[$$sroa$310$0$$sroa_idx+20>>2]=0|0;
    $9 = ($2|0)==(2);
    $$sroa$05$0$$sroa_idx = ((($0)) + 28|0);
    $$sroa$36$0$$sroa_idx = ((($0)) + 32|0);
    if ($9) {
     $$0 = 1;
     break;
    } else {
     $$sroa$05$0$$sroa_idx33 = $$sroa$05$0$$sroa_idx;$$sroa$36$0$$sroa_cast34$in = $$sroa$36$0$$sroa_idx;$18 = 2;
    }
   } else {
    $$sroa$36$0$$sroa_idx30 = ((($0)) + 4|0);
    $$sroa$05$0$$sroa_idx33 = $0;$$sroa$36$0$$sroa_cast34$in = $$sroa$36$0$$sroa_idx30;$18 = 1;
   }
   HEAP32[$$sroa$05$0$$sroa_idx33>>2] = 10;
   ;HEAP32[$$sroa$36$0$$sroa_cast34$in>>2]=0|0;HEAP32[$$sroa$36$0$$sroa_cast34$in+4>>2]=0|0;HEAP32[$$sroa$36$0$$sroa_cast34$in+8>>2]=0|0;HEAP32[$$sroa$36$0$$sroa_cast34$in+12>>2]=0|0;HEAP32[$$sroa$36$0$$sroa_cast34$in+16>>2]=0|0;HEAP32[$$sroa$36$0$$sroa_cast34$in+20>>2]=0|0;
   $$0 = $18;
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _name_from_numeric($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___lookup_ipliteral($0,$1,$2)|0);
 return ($3|0);
}
function _name_from_hosts($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$lcssa = 0, $$056 = 0, $$057$ph65$lcssa67 = 0, $$057$ph65$lcssa67107 = 0, $$057$ph6577 = 0, $$057$ph95 = 0, $$059$ph94 = 0, $$089 = 0, $$1$lcssa = 0, $$168 = 0, $$2 = 0, $$2$lcssa106 = 0, $$282 = 0, $$283 = 0, $$pre$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1680|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1680|0);
 $4 = sp + 1040|0;
 $5 = sp;
 $6 = sp + 1552|0;
 $7 = (_strlen($2)|0);
 $8 = (___fopen_rb_ca((gb + (166934) | 0),$6,$5,1032)|0);
 $9 = ($8|0)==(0|0);
 L1: do {
  if ($9) {
   $10 = (___errno_location()|0);
   $11 = HEAP32[$10>>2]|0;
   switch ($11|0) {
   case 13: case 20: case 2:  {
    $$056 = 0;
    break L1;
    break;
   }
   default: {
   }
   }
   $$056 = -11;
  } else {
   $12 = (_fgets($4,512,$8)|0);
   $13 = ($12|0)==(0|0);
   do {
    if ($13) {
     (___fclose_ca($8)|0);
     $$057$ph65$lcssa67107 = 0;
    } else {
     $14 = ((($4)) + 1|0);
     $$057$ph95 = 0;$$059$ph94 = 0;
     L8: while(1) {
      $15 = (($0) + (($$059$ph94*28)|0)|0);
      $$057$ph6577 = $$057$ph95;
      L10: while(1) {
       L12: while(1) {
        $16 = (_strchr($4,35)|0);
        $17 = ($16|0)==(0|0);
        if (!($17)) {
         $18 = ((($16)) + 1|0);
         HEAP8[$16>>0] = 10;
         HEAP8[$18>>0] = 0;
        }
        $19 = (_strstr($14,$2)|0);
        $20 = ($19|0)==(0|0);
        L17: do {
         if (!($20)) {
          $22 = $19;
          while(1) {
           $21 = ((($22)) + -1|0);
           $23 = HEAP8[$21>>0]|0;
           $24 = $23 << 24 >> 24;
           $25 = (_isspace($24)|0);
           $26 = ($25|0)==(0);
           if (!($26)) {
            $27 = (($22) + ($7)|0);
            $28 = HEAP8[$27>>0]|0;
            $29 = $28 << 24 >> 24;
            $30 = (_isspace($29)|0);
            $31 = ($30|0)==(0);
            if (!($31)) {
             break;
            }
           }
           $32 = ((($22)) + 1|0);
           $33 = (_strstr($32,$2)|0);
           $34 = ($33|0)==(0|0);
           if ($34) {
            break L17;
           } else {
            $22 = $33;
           }
          }
          $35 = HEAP8[$4>>0]|0;
          $36 = ($35<<24>>24)==(0);
          L25: do {
           if ($36) {
            $$1$lcssa = $4;
           } else {
            $$168 = $4;$38 = $35;
            while(1) {
             $37 = $38 << 24 >> 24;
             $39 = (_isspace($37)|0);
             $40 = ($39|0)==(0);
             if (!($40)) {
              $$1$lcssa = $$168;
              break L25;
             }
             $41 = ((($$168)) + 1|0);
             $42 = HEAP8[$41>>0]|0;
             $43 = ($42<<24>>24)==(0);
             if ($43) {
              $$1$lcssa = $41;
              break;
             } else {
              $$168 = $41;$38 = $42;
             }
            }
           }
          } while(0);
          HEAP8[$$1$lcssa>>0] = 0;
          $44 = (_name_from_numeric($15,$4,$3)|0);
          switch ($44|0) {
          case 1:  {
           break L10;
           break;
          }
          case 0:  {
           break;
          }
          default: {
           break L12;
          }
          }
         }
        } while(0);
        $70 = (_fgets($4,512,$8)|0);
        $71 = ($70|0)==(0|0);
        if ($71) {
         $$057$ph65$lcssa67 = $$057$ph6577;
         label = 35;
         break L8;
        }
       }
       $48 = (_fgets($4,512,$8)|0);
       $49 = ($48|0)==(0|0);
       if ($49) {
        $$057$ph65$lcssa67 = -2;
        label = 35;
        break L8;
       } else {
        $$057$ph6577 = -2;
       }
      }
      $45 = (($$059$ph94) + 1)|0;
      $$282 = ((($$1$lcssa)) + 1|0);
      $46 = HEAP8[$$282>>0]|0;
      $47 = ($46<<24>>24)==(0);
      L34: do {
       if ($47) {
        $$0$lcssa = $$282;$$2$lcssa106 = $$282;
       } else {
        $$283 = $$282;$53 = $46;
        while(1) {
         $52 = $53 << 24 >> 24;
         $54 = (_isspace($52)|0);
         $55 = ($54|0)==(0);
         if ($55) {
          break;
         }
         $$2 = ((($$283)) + 1|0);
         $50 = HEAP8[$$2>>0]|0;
         $51 = ($50<<24>>24)==(0);
         if ($51) {
          $$0$lcssa = $$2;$$2$lcssa106 = $$2;
          break L34;
         } else {
          $$283 = $$2;$53 = $50;
         }
        }
        $$pre$pre = HEAP8[$$283>>0]|0;
        $56 = ($$pre$pre<<24>>24)==(0);
        if ($56) {
         $$0$lcssa = $$283;$$2$lcssa106 = $$283;
        } else {
         $$089 = $$283;$58 = $$pre$pre;
         while(1) {
          $57 = $58 << 24 >> 24;
          $59 = (_isspace($57)|0);
          $60 = ($59|0)==(0);
          if (!($60)) {
           $$0$lcssa = $$089;$$2$lcssa106 = $$283;
           break L34;
          }
          $61 = ((($$089)) + 1|0);
          $62 = HEAP8[$61>>0]|0;
          $63 = ($62<<24>>24)==(0);
          if ($63) {
           $$0$lcssa = $61;$$2$lcssa106 = $$283;
           break;
          } else {
           $$089 = $61;$58 = $62;
          }
         }
        }
       }
      } while(0);
      HEAP8[$$0$lcssa>>0] = 0;
      $64 = (_is_valid_hostname($$2$lcssa106)|0);
      $65 = ($64|0)==(0);
      if (!($65)) {
       $66 = $$0$lcssa;
       $67 = $$2$lcssa106;
       $68 = (1 - ($67))|0;
       $69 = (($68) + ($66))|0;
       (_memcpy(($1|0),($$2$lcssa106|0),($69|0))|0);
      }
      $72 = (_fgets($4,512,$8)|0);
      $73 = ($72|0)!=(0|0);
      $74 = ($45>>>0)<(48);
      $75 = $74 & $73;
      if ($75) {
       $$057$ph95 = $$057$ph6577;$$059$ph94 = $45;
      } else {
       label = 34;
       break;
      }
     }
     if ((label|0) == 34) {
      (___fclose_ca($8)|0);
      $$056 = $45;
      break L1;
     }
     else if ((label|0) == 35) {
      (___fclose_ca($8)|0);
      $76 = ($$059$ph94|0)==(0);
      if ($76) {
       $$057$ph65$lcssa67107 = $$057$ph65$lcssa67;
       break;
      } else {
       $$056 = $$059$ph94;
       break L1;
      }
     }
    }
   } while(0);
   $$056 = $$057$ph65$lcssa67107;
  }
 } while(0);
 STACKTOP = sp;return ($$056|0);
}
function _name_from_dns_search($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$059$lcssa = 0, $$05965 = 0, $$06068 = 0, $$06068$pn = 0, $$062 = 0, $$064 = 0, $$161$lcssa = 0, $$163 = 0, $$3 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(368|0);
 $4 = sp;
 $5 = sp + 256|0;
 $6 = (___get_resolv_conf($5,$4,256)|0);
 $7 = ($6|0)<(0);
 L1: do {
  if ($7) {
   $$3 = -1;
  } else {
   $$062 = 0;$$064 = 0;
   L3: while(1) {
    $8 = (($2) + ($$064)|0);
    $9 = HEAP8[$8>>0]|0;
    switch ($9<<24>>24) {
    case 0:  {
     break L3;
     break;
    }
    case 46:  {
     $10 = (($$062) + 1)|0;
     $$163 = $10;
     break;
    }
    default: {
     $$163 = $$062;
    }
    }
    $11 = (($$064) + 1)|0;
    $$062 = $$163;$$064 = $11;
   }
   $12 = ((($5)) + 92|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($$062>>>0)<($13>>>0);
   if ($14) {
    $15 = (($$064) + -1)|0;
    $16 = (($2) + ($15)|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(46);
    if ($18) {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    HEAP8[$4>>0] = 0;
   }
   $19 = ($$064>>>0)>(255);
   if ($19) {
    $$3 = -2;
   } else {
    (_memcpy(($1|0),($2|0),($$064|0))|0);
    $20 = (($1) + ($$064)|0);
    HEAP8[$20>>0] = 46;
    $21 = HEAP8[$4>>0]|0;
    $22 = ($21<<24>>24)==(0);
    L15: do {
     if (!($22)) {
      $23 = (255 - ($$064))|0;
      $24 = ((($20)) + 1|0);
      $25 = (($$064) + 1)|0;
      $$06068 = $4;$27 = $21;
      while(1) {
       $26 = $27 << 24 >> 24;
       $28 = (_isspace($26)|0);
       $29 = ($28|0)==(0);
       if ($29) {
        $$161$lcssa = $$06068;
       } else {
        $$06068$pn = $$06068;
        while(1) {
         $30 = ((($$06068$pn)) + 1|0);
         $$pre = HEAP8[$30>>0]|0;
         $31 = $$pre << 24 >> 24;
         $32 = (_isspace($31)|0);
         $33 = ($32|0)==(0);
         if ($33) {
          $$161$lcssa = $30;
          break;
         } else {
          $$06068$pn = $30;
         }
        }
       }
       $34 = HEAP8[$$161$lcssa>>0]|0;
       $35 = ($34<<24>>24)==(0);
       if ($35) {
        break L15;
       }
       $$05965 = $$161$lcssa;$37 = $34;
       while(1) {
        $36 = $37 << 24 >> 24;
        $38 = (_isspace($36)|0);
        $39 = ($38|0)==(0);
        if (!($39)) {
         $$059$lcssa = $$05965;
         break;
        }
        $40 = ((($$05965)) + 1|0);
        $41 = HEAP8[$40>>0]|0;
        $42 = ($41<<24>>24)==(0);
        if ($42) {
         $$059$lcssa = $40;
         break;
        } else {
         $$05965 = $40;$37 = $41;
        }
       }
       $43 = ($$059$lcssa|0)==($$161$lcssa|0);
       if ($43) {
        break L15;
       }
       $44 = $$059$lcssa;
       $45 = $$161$lcssa;
       $46 = (($44) - ($45))|0;
       $47 = ($46>>>0)<($23>>>0);
       if ($47) {
        (_memcpy(($24|0),($$161$lcssa|0),($46|0))|0);
        $48 = (($25) + ($46))|0;
        $49 = (($1) + ($48)|0);
        HEAP8[$49>>0] = 0;
        $50 = (_name_from_dns($0,$1,$1,$3,$5)|0);
        $51 = ($50|0)==(0);
        if (!($51)) {
         $$3 = $50;
         break L1;
        }
       }
       $52 = HEAP8[$$059$lcssa>>0]|0;
       $53 = ($52<<24>>24)==(0);
       if ($53) {
        break;
       } else {
        $$06068 = $$059$lcssa;$27 = $52;
       }
      }
     }
    } while(0);
    HEAP8[$20>>0] = 0;
    $54 = (_name_from_dns($0,$1,$2,$3,$5)|0);
    $$3 = $54;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$3|0);
}
function _policyof($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = 0;
 while(1) {
  $1 = ((gb + (143808) | 0) + (($$0*20)|0)|0);
  $2 = ((((gb + (143808) | 0) + (($$0*20)|0)|0)) + 16|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = (_memcmp($0,$1,$4)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($0) + ($4)|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ((((gb + (143808) | 0) + (($$0*20)|0)|0)) + 17|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 & $8;
   $12 = (((gb + (143808) | 0) + (($$0*20)|0)|0) + ($4)|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($11<<24>>24)==($13<<24>>24);
   if ($14) {
    break;
   }
  }
  $16 = (($$0) + 1)|0;
  $$0 = $16;
 }
 $15 = ((gb + (143808) | 0) + (($$0*20)|0)|0);
 return ($15|0);
}
function _scopeof($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 switch ($1<<24>>24) {
 case -1:  {
  $2 = ((($0)) + 1|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 & 15;
  $5 = $4&255;
  $$0 = $5;
  break;
 }
 case -2:  {
  $6 = ((($0)) + 1|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7 & -64;
  $9 = ($8<<24>>24)==(-128);
  if ($9) {
   $$0 = 2;
  } else {
   label = 4;
  }
  break;
 }
 default: {
  label = 4;
 }
 }
 do {
  if ((label|0) == 4) {
   $10 = HEAP32[$0>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = ((($0)) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0);
    if ($14) {
     $15 = ((($0)) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = ((($0)) + 12|0);
      $19 = HEAP8[$18>>0]|0;
      $20 = ($19<<24>>24)==(0);
      if ($20) {
       $21 = ((($0)) + 13|0);
       $22 = HEAP8[$21>>0]|0;
       $23 = ($22<<24>>24)==(0);
       if ($23) {
        $24 = ((($0)) + 14|0);
        $25 = HEAP8[$24>>0]|0;
        $26 = ($25<<24>>24)==(0);
        if ($26) {
         $27 = ((($0)) + 15|0);
         $28 = HEAP8[$27>>0]|0;
         $29 = ($28<<24>>24)==(1);
         if ($29) {
          $$0 = 2;
          break;
         }
        }
       }
      }
     }
    }
   }
   $30 = ($1<<24>>24)==(-2);
   if ($30) {
    $31 = ((($0)) + 1|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32&255)>(191);
    if ($33) {
     $$0 = 5;
     break;
    }
   }
   $$0 = 14;
  }
 } while(0);
 return ($$0|0);
}
function _getsockname($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $3 = sp + 8|0;
 HEAP32[$3>>2] = $0;
 $4 = ((($3)) + 4|0);
 $5 = $1;
 HEAP32[$4>>2] = $5;
 $6 = ((($3)) + 8|0);
 $7 = $2;
 HEAP32[$6>>2] = $7;
 $8 = ((($3)) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($3)) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($3)) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = $3;
 HEAP32[$vararg_buffer>>2] = 6;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $11;
 $12 = (___syscall102(102,($vararg_buffer|0))|0);
 $13 = (___syscall_ret($12)|0);
 STACKTOP = sp;return ($13|0);
}
function _labelof($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_policyof($0)|0);
 $2 = ((($1)) + 19|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 return ($4|0);
}
function _prefixmatch($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$08 = 0;
 while(1) {
  $2 = $$08 >>> 3;
  $3 = (($0) + ($2)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = (($1) + ($2)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6 ^ $4;
  $8 = $7&255;
  $9 = $$08 & 7;
  $10 = 128 >>> $9;
  $11 = $10 & $8;
  $12 = ($11|0)==(0);
  if (!($12)) {
   $$0$lcssa = $$08;
   break;
  }
  $13 = (($$08) + 1)|0;
  $14 = ($13>>>0)<(128);
  if ($14) {
   $$08 = $13;
  } else {
   $$0$lcssa = 128;
   break;
  }
 }
 return ($$0$lcssa|0);
}
function _addrcmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 return ($6|0);
}
function _qsort($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$067$lcssa = 0, $$06772 = 0, $$068$lcssa = 0, $$06871 = 0, $$1 = 0, $$169 = 0, $$169$be = 0, $$2 = 0, $$2$be = 0, $$be = 0, $$pre$pre = 0, $$pre76 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $15$phi = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(208|0);
 $4 = sp;
 $5 = sp + 192|0;
 $6 = Math_imul($2, $1)|0;
 $7 = $5;
 $8 = $7;
 HEAP32[$8>>2] = 1;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = ($6|0)==(0);
 L1: do {
  if (!($11)) {
   $12 = (0 - ($2))|0;
   $13 = ((($4)) + 4|0);
   HEAP32[$13>>2] = $2;
   HEAP32[$4>>2] = $2;
   $$0 = 2;$15 = $2;$17 = $2;
   while(1) {
    $14 = (($15) + ($2))|0;
    $16 = (($14) + ($17))|0;
    $18 = (($4) + ($$0<<2)|0);
    HEAP32[$18>>2] = $16;
    $19 = ($16>>>0)<($6>>>0);
    $20 = (($$0) + 1)|0;
    if ($19) {
     $15$phi = $17;$$0 = $20;$17 = $16;$15 = $15$phi;
    } else {
     break;
    }
   }
   $21 = (($0) + ($6)|0);
   $22 = (($21) + ($12)|0);
   $23 = ($22>>>0)>($0>>>0);
   if ($23) {
    $24 = $22;
    $$06772 = 1;$$06871 = $0;$26 = 1;
    while(1) {
     $25 = $26 & 3;
     $27 = ($25|0)==(3);
     do {
      if ($27) {
       _sift($$06871,$2,$3,$$06772,$4);
       _shr($5,2);
       $28 = (($$06772) + 2)|0;
       $$1 = $28;
      } else {
       $29 = (($$06772) + -1)|0;
       $30 = (($4) + ($29<<2)|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = $$06871;
       $33 = (($24) - ($32))|0;
       $34 = ($31>>>0)<($33>>>0);
       if ($34) {
        _sift($$06871,$2,$3,$$06772,$4);
       } else {
        _trinkle($$06871,$2,$3,$5,$$06772,0,$4);
       }
       $35 = ($$06772|0)==(1);
       if ($35) {
        _shl($5,1);
        $$1 = 0;
        break;
       } else {
        _shl($5,$29);
        $$1 = 1;
        break;
       }
      }
     } while(0);
     $36 = HEAP32[$5>>2]|0;
     $37 = $36 | 1;
     HEAP32[$5>>2] = $37;
     $38 = (($$06871) + ($2)|0);
     $39 = ($38>>>0)<($22>>>0);
     if ($39) {
      $$06772 = $$1;$$06871 = $38;$26 = $37;
     } else {
      $$067$lcssa = $$1;$$068$lcssa = $38;$61 = $37;
      break;
     }
    }
   } else {
    $$067$lcssa = 1;$$068$lcssa = $0;$61 = 1;
   }
   _trinkle($$068$lcssa,$2,$3,$5,$$067$lcssa,0,$4);
   $40 = ((($5)) + 4|0);
   $$169 = $$068$lcssa;$$2 = $$067$lcssa;$43 = $61;
   while(1) {
    $41 = ($$2|0)==(1);
    $42 = ($43|0)==(1);
    $or$cond = $41 & $42;
    if ($or$cond) {
     $44 = HEAP32[$40>>2]|0;
     $45 = ($44|0)==(0);
     if ($45) {
      break L1;
     } else {
      label = 19;
     }
    } else {
     $46 = ($$2|0)<(2);
     if ($46) {
      label = 19;
     } else {
      _shl($5,2);
      $49 = (($$2) + -2)|0;
      $50 = HEAP32[$5>>2]|0;
      $51 = $50 ^ 7;
      HEAP32[$5>>2] = $51;
      _shr($5,1);
      $52 = (($4) + ($49<<2)|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (0 - ($53))|0;
      $55 = (($$169) + ($54)|0);
      $56 = (($55) + ($12)|0);
      $57 = (($$2) + -1)|0;
      _trinkle($56,$2,$3,$5,$57,1,$4);
      _shl($5,1);
      $58 = HEAP32[$5>>2]|0;
      $59 = $58 | 1;
      HEAP32[$5>>2] = $59;
      $60 = (($$169) + ($12)|0);
      _trinkle($60,$2,$3,$5,$49,1,$4);
      $$169$be = $60;$$2$be = $49;$$be = $59;
     }
    }
    if ((label|0) == 19) {
     label = 0;
     $47 = (_pntz($5)|0);
     _shr($5,$47);
     $48 = (($47) + ($$2))|0;
     $$pre$pre = HEAP32[$5>>2]|0;
     $$pre76 = (($$169) + ($12)|0);
     $$169$be = $$pre76;$$2$be = $48;$$be = $$pre$pre;
    }
    $$169 = $$169$be;$$2 = $$2$be;$43 = $$be;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _sift($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$02934 = 0, $$03133 = 0, $$035 = 0, $$1 = 0, $$130 = 0, $$132 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $5 = sp;
 HEAP32[$5>>2] = $0;
 $6 = ($3|0)>(1);
 L1: do {
  if ($6) {
   $7 = (0 - ($1))|0;
   $$02934 = $0;$$03133 = $3;$$035 = 1;$14 = $0;
   while(1) {
    $8 = (($$02934) + ($7)|0);
    $9 = (($$03133) + -2)|0;
    $10 = (($4) + ($9<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (0 - ($11))|0;
    $13 = (($8) + ($12)|0);
    $15 = (mftCall_iii($2|0,($14|0),($13|0))|0);
    $16 = ($15|0)>(-1);
    if ($16) {
     $17 = (mftCall_iii($2|0,($14|0),($8|0))|0);
     $18 = ($17|0)>(-1);
     if ($18) {
      $$0$lcssa = $$035;
      break L1;
     }
    }
    $19 = (mftCall_iii($2|0,($13|0),($8|0))|0);
    $20 = ($19|0)>(-1);
    $21 = (($5) + ($$035<<2)|0);
    if ($20) {
     HEAP32[$21>>2] = $13;
     $22 = (($$03133) + -1)|0;
     $$130 = $13;$$132 = $22;
    } else {
     HEAP32[$21>>2] = $8;
     $$130 = $8;$$132 = $9;
    }
    $$1 = (($$035) + 1)|0;
    $23 = ($$132|0)>(1);
    if (!($23)) {
     $$0$lcssa = $$1;
     break L1;
    }
    $$pre = HEAP32[$5>>2]|0;
    $$02934 = $$130;$$03133 = $$132;$$035 = $$1;$14 = $$pre;
   }
  } else {
   $$0$lcssa = 1;
  }
 } while(0);
 _cycle($1,$5,$$0$lcssa);
 STACKTOP = sp;return;
}
function _shr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(31);
 $3 = ((($0)) + 4|0);
 if ($2) {
  $4 = (($1) + -32)|0;
  $5 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $5;
  HEAP32[$3>>2] = 0;
  $$0 = $4;$10 = 0;$7 = $5;
 } else {
  $$pre = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $$0 = $1;$10 = $$pre11;$7 = $$pre;
 }
 $6 = $7 >>> $$0;
 $8 = (32 - ($$0))|0;
 $9 = $10 << $8;
 $11 = $9 | $6;
 HEAP32[$0>>2] = $11;
 $12 = $10 >>> $$0;
 HEAP32[$3>>2] = $12;
 return;
}
function _trinkle($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0$lcssa = 0, $$045$lcssa = 0, $$04551 = 0, $$0455780 = 0, $$046$lcssa = 0, $$04653 = 0, $$0465681 = 0, $$047$lcssa = 0, $$0475582 = 0, $$049 = 0, $$05879 = 0, $$05879$phi = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(240|0);
 $7 = sp + 232|0;
 $8 = sp;
 $9 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = ((($3)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($7)) + 4|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$8>>2] = $0;
 $13 = ($9|0)!=(1);
 $14 = ($11|0)!=(0);
 $15 = $13 | $14;
 L1: do {
  if ($15) {
   $16 = (0 - ($1))|0;
   $17 = (($6) + ($4<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (0 - ($18))|0;
   $20 = (($0) + ($19)|0);
   $21 = (mftCall_iii($2|0,($20|0),($0|0))|0);
   $22 = ($21|0)<(1);
   if ($22) {
    $$0$lcssa = $0;$$045$lcssa = 1;$$046$lcssa = $4;$$047$lcssa = $5;
    label = 9;
   } else {
    $phitmp = ($5|0)==(0);
    $$0455780 = 1;$$0465681 = $4;$$0475582 = $phitmp;$$05879 = $0;$28 = $20;
    while(1) {
     $23 = ($$0465681|0)>(1);
     $or$cond = $$0475582 & $23;
     if ($or$cond) {
      $24 = (($$05879) + ($16)|0);
      $25 = (($$0465681) + -2)|0;
      $26 = (($6) + ($25<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $29 = (mftCall_iii($2|0,($24|0),($28|0))|0);
      $30 = ($29|0)>(-1);
      if ($30) {
       $$04551 = $$0455780;$$04653 = $$0465681;$$049 = $$05879;
       label = 10;
       break L1;
      }
      $31 = (0 - ($27))|0;
      $32 = (($24) + ($31)|0);
      $33 = (mftCall_iii($2|0,($32|0),($28|0))|0);
      $34 = ($33|0)>(-1);
      if ($34) {
       $$04551 = $$0455780;$$04653 = $$0465681;$$049 = $$05879;
       label = 10;
       break L1;
      }
     }
     $35 = (($$0455780) + 1)|0;
     $36 = (($8) + ($$0455780<<2)|0);
     HEAP32[$36>>2] = $28;
     $37 = (_pntz($7)|0);
     _shr($7,$37);
     $38 = (($37) + ($$0465681))|0;
     $39 = HEAP32[$7>>2]|0;
     $40 = ($39|0)!=(1);
     $41 = HEAP32[$12>>2]|0;
     $42 = ($41|0)!=(0);
     $43 = $40 | $42;
     if (!($43)) {
      $$04551 = $35;$$04653 = $38;$$049 = $28;
      label = 10;
      break L1;
     }
     $$pre = HEAP32[$8>>2]|0;
     $44 = (($6) + ($38<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (0 - ($45))|0;
     $47 = (($28) + ($46)|0);
     $48 = (mftCall_iii($2|0,($47|0),($$pre|0))|0);
     $49 = ($48|0)<(1);
     if ($49) {
      $$0$lcssa = $28;$$045$lcssa = $35;$$046$lcssa = $38;$$047$lcssa = 0;
      label = 9;
      break;
     } else {
      $$05879$phi = $28;$$0455780 = $35;$$0465681 = $38;$$0475582 = 1;$28 = $47;$$05879 = $$05879$phi;
     }
    }
   }
  } else {
   $$0$lcssa = $0;$$045$lcssa = 1;$$046$lcssa = $4;$$047$lcssa = $5;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $50 = ($$047$lcssa|0)==(0);
  if ($50) {
   $$04551 = $$045$lcssa;$$04653 = $$046$lcssa;$$049 = $$0$lcssa;
   label = 10;
  }
 }
 if ((label|0) == 10) {
  _cycle($1,$8,$$04551);
  _sift($$049,$1,$2,$$04653,$6);
 }
 STACKTOP = sp;return;
}
function _shl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $$pre11 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1>>>0)>(31);
 $3 = ((($0)) + 4|0);
 if ($2) {
  $4 = (($1) + -32)|0;
  $5 = HEAP32[$0>>2]|0;
  HEAP32[$3>>2] = $5;
  HEAP32[$0>>2] = 0;
  $$0 = $4;$10 = 0;$7 = $5;
 } else {
  $$pre = HEAP32[$3>>2]|0;
  $$pre11 = HEAP32[$0>>2]|0;
  $$0 = $1;$10 = $$pre11;$7 = $$pre;
 }
 $6 = $7 << $$0;
 $8 = (32 - ($$0))|0;
 $9 = $10 >>> $8;
 $11 = $9 | $6;
 HEAP32[$3>>2] = $11;
 $12 = $10 << $$0;
 HEAP32[$0>>2] = $12;
 return;
}
function _pntz($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (_a_ctz_l($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = ((($0)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_a_ctz_l($6)|0);
  $8 = (($7) + 32)|0;
  $9 = ($7|0)==(0);
  $spec$select = $9 ? 0 : $8;
  return ($spec$select|0);
 } else {
  return ($3|0);
 }
 return (0)|0;
}
function _a_ctz_l($0) {
 $0 = $0|0;
 var $$068 = 0, $$07 = 0, $$09 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$07 = 32;
 } else {
  $2 = $0 & 1;
  $3 = ($2|0)==(0);
  if ($3) {
   $$068 = $0;$$09 = 0;
   while(1) {
    $4 = (($$09) + 1)|0;
    $5 = $$068 >>> 1;
    $6 = $$068 & 2;
    $7 = ($6|0)==(0);
    if ($7) {
     $$068 = $5;$$09 = $4;
    } else {
     $$07 = $4;
     break;
    }
   }
  } else {
   $$07 = 0;
  }
 }
 return ($$07|0);
}
function _cycle($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$02527 = 0, $$026 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $3 = sp;
 $4 = ($2|0)<(2);
 L1: do {
  if (!($4)) {
   $5 = (($1) + ($2<<2)|0);
   HEAP32[$5>>2] = $3;
   $6 = ($0|0)==(0);
   if (!($6)) {
    $$02527 = $0;$10 = $3;
    while(1) {
     $7 = ($$02527>>>0)<(256);
     $8 = $7 ? $$02527 : 256;
     $9 = HEAP32[$1>>2]|0;
     (_memcpy(($10|0),($9|0),($8|0))|0);
     $$026 = 0;
     while(1) {
      $11 = (($1) + ($$026<<2)|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($$026) + 1)|0;
      $14 = (($1) + ($13<<2)|0);
      $15 = HEAP32[$14>>2]|0;
      (_memcpy(($12|0),($15|0),($8|0))|0);
      $16 = HEAP32[$11>>2]|0;
      $17 = (($16) + ($8)|0);
      HEAP32[$11>>2] = $17;
      $exitcond = ($13|0)==($2|0);
      if ($exitcond) {
       break;
      } else {
       $$026 = $13;
      }
     }
     $18 = (($$02527) - ($8))|0;
     $19 = ($18|0)==(0);
     if ($19) {
      break L1;
     }
     $$pre = HEAP32[$5>>2]|0;
     $$02527 = $18;$10 = $$pre;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _name_from_dns($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$02227 = 0, $$024 = 0, $$028 = 0, $$1 = 0, $$12326 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1632|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1632|0);
 $5 = sp + 1024|0;
 $6 = sp;
 $7 = sp + 1624|0;
 $8 = sp + 1616|0;
 $9 = sp + 1608|0;
 $10 = sp + 1600|0;
 $11 = sp + 1584|0;
 HEAP32[$7>>2] = $5;
 $12 = ((($7)) + 4|0);
 $13 = ((($5)) + 280|0);
 HEAP32[$12>>2] = $13;
 HEAP32[$8>>2] = $6;
 $14 = ((($8)) + 4|0);
 $15 = ((($6)) + 512|0);
 HEAP32[$14>>2] = $15;
 HEAP32[$11>>2] = $0;
 $16 = ((($11)) + 4|0);
 HEAP32[$16>>2] = $1;
 $17 = ((($11)) + 8|0);
 HEAP32[$17>>2] = 0;
 $$02227 = 0;$$028 = 0;
 while(1) {
  $18 = ((gb + (143936) | 0) + ($$02227<<3)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($3|0);
  if ($20) {
   $$1 = $$028;
  } else {
   $21 = ((((gb + (143936) | 0) + ($$02227<<3)|0)) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($5) + (($$028*280)|0)|0);
   $24 = (___res_mkquery(0,$2,1,$22,0,0,0,$23,280)|0);
   $25 = (($9) + ($$028<<2)|0);
   HEAP32[$25>>2] = $24;
   $26 = ($24|0)==(-1);
   if ($26) {
    $$024 = -2;
    break;
   }
   $27 = (($$028) + 1)|0;
   $$1 = $27;
  }
  $28 = (($$02227) + 1)|0;
  $29 = ($28>>>0)<(2);
  if ($29) {
   $$02227 = 1;$$028 = $$1;
  } else {
   label = 6;
   break;
  }
 }
 L7: do {
  if ((label|0) == 6) {
   $30 = (___res_msend_rc($$1,$7,$9,$8,$10,512,$4)|0);
   $31 = ($30|0)<(0);
   if ($31) {
    $$024 = -11;
   } else {
    $32 = ($$1|0)>(0);
    if ($32) {
     $$12326 = 0;
     while(1) {
      $33 = (($6) + ($$12326<<9)|0);
      $34 = (($10) + ($$12326<<2)|0);
      $35 = HEAP32[$34>>2]|0;
      (___dns_parse($33,$35,(fb + (17) | 0),$11)|0);
      $36 = (($$12326) + 1)|0;
      $exitcond = ($36|0)==($$1|0);
      if ($exitcond) {
       break;
      } else {
       $$12326 = $36;
      }
     }
    }
    $37 = HEAP32[$17>>2]|0;
    $38 = ($37|0)==(0);
    if ($38) {
     $39 = HEAP32[$10>>2]|0;
     $40 = ($39|0)<(4);
     if ($40) {
      $$024 = -3;
     } else {
      $41 = ((($6)) + 3|0);
      $trunc = HEAP8[$41>>0]|0;
      $trunc$clear = $trunc & 15;
      switch ($trunc$clear<<24>>24) {
      case 2:  {
       $$024 = -3;
       break L7;
       break;
      }
      case 0:  {
       $$024 = -2;
       break L7;
       break;
      }
      case 3:  {
       $$024 = 0;
       break L7;
       break;
      }
      default: {
       $$024 = -4;
       break L7;
      }
      }
     }
    } else {
     $$024 = $37;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$024|0);
}
function _dns_parse_callback($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $5 = sp;
 switch ($1|0) {
 case 1:  {
  $6 = ($3|0)==(4);
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + (($9*28)|0)|0);
   HEAP32[$10>>2] = 2;
   $11 = (((($7) + (($9*28)|0)|0)) + 4|0);
   HEAP32[$11>>2] = 0;
   $12 = (($9) + 1)|0;
   HEAP32[$8>>2] = $12;
   $13 = (((($7) + (($9*28)|0)|0)) + 8|0);
   (_memcpy(($13|0),($2|0),4)|0);
   $$0 = 0;
  } else {
   $$0 = -1;
  }
  break;
 }
 case 28:  {
  $14 = ($3|0)==(16);
  if ($14) {
   $15 = HEAP32[$0>>2]|0;
   $16 = ((($0)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + (($17*28)|0)|0);
   HEAP32[$18>>2] = 10;
   $19 = (((($15) + (($17*28)|0)|0)) + 4|0);
   HEAP32[$19>>2] = 0;
   $20 = (($17) + 1)|0;
   HEAP32[$16>>2] = $20;
   $21 = (((($15) + (($17*28)|0)|0)) + 8|0);
   (_memcpy(($21|0),($2|0),16)|0);
   $$0 = 0;
  } else {
   $$0 = -1;
  }
  break;
 }
 case 5:  {
  $22 = ((($4)) + 512|0);
  $23 = (___dn_expand($4,$22,$2,$5,256)|0);
  $24 = ($23|0)>(0);
  if ($24) {
   $25 = (_is_valid_hostname($5)|0);
   $26 = ($25|0)==(0);
   if ($26) {
    $$0 = 0;
   } else {
    $27 = ((($0)) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    (_strcpy($28,$5)|0);
    $$0 = 0;
   }
  } else {
   $$0 = 0;
  }
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 STACKTOP = sp;return ($$0|0);
}
function _is_valid_hostname($0) {
 $0 = $0|0;
 var $$0 = 0, $$012 = 0, $$off = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $switch = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (_strnlen($0,255)|0);
 $2 = (($1) + -1)|0;
 $3 = ($2>>>0)>(253);
 if ($3) {
  $$012 = 0;
 } else {
  $4 = (_mbstowcs(0,$0,0)|0);
  $5 = ($4|0)==(-1);
  if ($5) {
   $$012 = 0;
  } else {
   $$0 = $0;
   while(1) {
    $6 = HEAP8[$$0>>0]|0;
    $7 = ($6<<24>>24)<(0);
    $$off = (($6) + -45)<<24>>24;
    $switch = ($$off&255)<(2);
    $or$cond = $7 | $switch;
    if (!($or$cond)) {
     $8 = $6&255;
     $9 = (_isalnum($8)|0);
     $10 = ($9|0)==(0);
     if ($10) {
      break;
     }
    }
    $11 = ((($$0)) + 1|0);
    $$0 = $11;
   }
   $12 = HEAP8[$$0>>0]|0;
   $13 = ($12<<24>>24)==(0);
   $14 = $13&1;
   $$012 = $14;
  }
 }
 return ($$012|0);
}
function _mbstowcs($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = (_mbsrtowcs($0,$3,$2,0)|0);
 STACKTOP = sp;return ($4|0);
}
function _mbsrtowcs($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0105132 = 0, $$0111131 = 0, $$097 = 0, $$098$lcssa = 0, $$098133 = 0, $$10 = 0, $$11$ph = 0, $$1106$ph = 0, $$1106147 = 0, $$1112 = 0, $$1112$ph = 0, $$11122124 = 0, $$11182 = 0, $$11183 = 0, $$199 = 0, $$199$ph = 0, $$2 = 0, $$2100154 = 0, $$2107135 = 0, $$2113153 = 0;
 var $$3101 = 0, $$3108 = 0, $$3108$ph = 0, $$3108176 = 0, $$3114 = 0, $$4 = 0, $$4102 = 0, $$4109 = 0, $$4115 = 0, $$5 = 0, $$5103 = 0, $$5110 = 0, $$5110180 = 0, $$5110181 = 0, $$5116$ph = 0, $$5116146 = 0, $$6 = 0, $$6104$lcssa = 0, $$6104$ph = 0, $$6104148 = 0;
 var $$6117134 = 0, $$7118 = 0, $$7118$ph = 0, $$7118175 = 0, $$7136 = 0, $$8 = 0, $$8$ph = 0, $$8119 = 0, $$8177 = 0, $$9 = 0, $$9$sink = 0, $$9120 = 0, $$9120179 = 0, $$pre = 0, $$pre$phi173Z2D = 0, $$pre$phi174Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre171 = 0, $$pre172 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==(0|0);
 if ($5) {
  label = 5;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   label = 5;
  } else {
   $8 = ($0|0)==(0|0);
   if ($8) {
    $$2 = $6;$$4102 = $4;$$4115 = $2;
    label = 26;
   } else {
    HEAP32[$3>>2] = 0;
    $$4 = $6;$$4109 = $0;$$8119 = $2;$$9 = $4;
    label = 48;
   }
  }
 }
 L5: do {
  if ((label|0) == 5) {
   $9 = (___pthread_self_503()|0);
   $10 = ((($9)) + 188|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   $14 = ($0|0)!=(0|0);
   if (!($13)) {
    if ($14) {
     $$1106$ph = $0;$$5116$ph = $2;$$6104$ph = $4;
     label = 33;
     break;
    } else {
     $$1112$ph = $2;$$199$ph = $4;
     label = 15;
     break;
    }
   }
   if (!($14)) {
    $15 = (_strlen($4)|0);
    $$097 = $15;
    label = 63;
    break;
   }
   $16 = ($2|0)==(0);
   L13: do {
    if ($16) {
     $$098$lcssa = $4;
    } else {
     $$0105132 = $0;$$0111131 = $2;$$098133 = $4;
     while(1) {
      $17 = HEAP8[$$098133>>0]|0;
      $18 = ($17<<24>>24)==(0);
      if ($18) {
       break;
      }
      $19 = ((($$098133)) + 1|0);
      $20 = $17 << 24 >> 24;
      $21 = $20 & 57343;
      $22 = ((($$0105132)) + 4|0);
      HEAP32[$$0105132>>2] = $21;
      $23 = (($$0111131) + -1)|0;
      $24 = ($23|0)==(0);
      if ($24) {
       $$098$lcssa = $19;
       break L13;
      } else {
       $$0105132 = $22;$$0111131 = $23;$$098133 = $19;
      }
     }
     HEAP32[$$0105132>>2] = 0;
     HEAP32[$1>>2] = 0;
     $25 = (($2) - ($$0111131))|0;
     $$097 = $25;
     label = 63;
     break L5;
    }
   } while(0);
   HEAP32[$1>>2] = $$098$lcssa;
   $$097 = $2;
   label = 63;
  }
 } while(0);
 L20: while(1) {
  L21: do {
   if ((label|0) == 15) {
    label = 0;
    $$1112 = $$1112$ph;$$199 = $$199$ph;
    while(1) {
     $26 = HEAP8[$$199>>0]|0;
     $27 = $26&255;
     $28 = (($27) + -1)|0;
     $29 = ($28>>>0)<(127);
     if ($29) {
      $30 = $$199;
      $31 = $30 & 3;
      $32 = ($31|0)==(0);
      if ($32) {
       $33 = HEAP32[$$199>>2]|0;
       $34 = (($33) + -16843009)|0;
       $35 = $34 | $33;
       $36 = $35 & -2139062144;
       $37 = ($36|0)==(0);
       $38 = $33&255;
       if ($37) {
        $$2100154 = $$199;$$2113153 = $$1112;
        while(1) {
         $39 = ((($$2100154)) + 4|0);
         $40 = (($$2113153) + -4)|0;
         $41 = HEAP32[$39>>2]|0;
         $42 = (($41) + -16843009)|0;
         $43 = $42 | $41;
         $44 = $43 & -2139062144;
         $45 = ($44|0)==(0);
         if ($45) {
          $$2100154 = $39;$$2113153 = $40;
         } else {
          break;
         }
        }
        $46 = $41&255;
        $$3101 = $39;$$3114 = $40;$48 = $46;
       } else {
        $$3101 = $$199;$$3114 = $$1112;$48 = $38;
       }
      } else {
       $$3101 = $$199;$$3114 = $$1112;$48 = $26;
      }
     } else {
      $$3101 = $$199;$$3114 = $$1112;$48 = $26;
     }
     $47 = $48&255;
     $49 = (($47) + -1)|0;
     $50 = ($49>>>0)<(127);
     if (!($50)) {
      break;
     }
     $51 = ((($$3101)) + 1|0);
     $52 = (($$3114) + -1)|0;
     $$1112 = $52;$$199 = $51;
    }
    $53 = (($47) + -194)|0;
    $54 = ($53>>>0)>(50);
    if ($54) {
     $$11182 = $$3101;$$5110180 = $0;$$9120179 = $$3114;
     label = 57;
    } else {
     $55 = ((($$3101)) + 1|0);
     $56 = ((gb + (160) | 0) + ($53<<2)|0);
     $57 = HEAP32[$56>>2]|0;
     $$2 = $57;$$4102 = $55;$$4115 = $$3114;
     label = 26;
     continue L20;
    }
   }
   else if ((label|0) == 26) {
    label = 0;
    $58 = HEAP8[$$4102>>0]|0;
    $59 = $58&255;
    $60 = $59 >>> 3;
    $61 = (($60) + -16)|0;
    $62 = $$2 >> 26;
    $63 = (($60) + ($62))|0;
    $64 = $61 | $63;
    $65 = ($64>>>0)>(7);
    if ($65) {
     $$5110 = $0;$$6 = $$2;$$9$sink = $$4102;$$9120 = $$4115;
     label = 56;
    } else {
     $66 = ((($$4102)) + 1|0);
     $67 = $$2 & 33554432;
     $68 = ($67|0)==(0);
     if ($68) {
      $$5103 = $66;
     } else {
      $69 = HEAP8[$66>>0]|0;
      $70 = $69 & -64;
      $71 = ($70<<24>>24)==(-128);
      if (!($71)) {
       $$5110 = $0;$$6 = $$2;$$9$sink = $$4102;$$9120 = $$4115;
       label = 56;
       break;
      }
      $72 = ((($$4102)) + 2|0);
      $73 = $$2 & 524288;
      $74 = ($73|0)==(0);
      if ($74) {
       $$5103 = $72;
      } else {
       $75 = HEAP8[$72>>0]|0;
       $76 = $75 & -64;
       $77 = ($76<<24>>24)==(-128);
       if (!($77)) {
        $$5110 = $0;$$6 = $$2;$$9$sink = $$4102;$$9120 = $$4115;
        label = 56;
        break;
       }
       $78 = ((($$4102)) + 3|0);
       $$5103 = $78;
      }
     }
     $79 = (($$4115) + -1)|0;
     $$1112$ph = $79;$$199$ph = $$5103;
     label = 15;
     continue L20;
    }
   }
   else if ((label|0) == 33) {
    label = 0;
    $80 = ($$5116$ph|0)==(0);
    L23: do {
     if ($80) {
      $$6104$lcssa = $$6104$ph;
     } else {
      $$1106147 = $$1106$ph;$$5116146 = $$5116$ph;$$6104148 = $$6104$ph;
      while(1) {
       $81 = HEAP8[$$6104148>>0]|0;
       $82 = $81&255;
       $83 = (($82) + -1)|0;
       $84 = ($83>>>0)<(127);
       if ($84) {
        $85 = $$6104148;
        $86 = $85 & 3;
        $87 = ($86|0)==(0);
        $88 = ($$5116146>>>0)>(4);
        $or$cond = $87 & $88;
        if ($or$cond) {
         $$2107135 = $$1106147;$$6117134 = $$5116146;$$7136 = $$6104148;
         while(1) {
          $89 = HEAP32[$$7136>>2]|0;
          $90 = (($89) + -16843009)|0;
          $91 = $90 | $89;
          $92 = $91 & -2139062144;
          $93 = ($92|0)==(0);
          if (!($93)) {
           label = 42;
           break;
          }
          $94 = ((($$7136)) + 1|0);
          $95 = $89 & 255;
          $96 = ((($$2107135)) + 4|0);
          HEAP32[$$2107135>>2] = $95;
          $97 = ((($$7136)) + 2|0);
          $98 = HEAP8[$94>>0]|0;
          $99 = $98&255;
          $100 = ((($$2107135)) + 8|0);
          HEAP32[$96>>2] = $99;
          $101 = ((($$7136)) + 3|0);
          $102 = HEAP8[$97>>0]|0;
          $103 = $102&255;
          $104 = ((($$2107135)) + 12|0);
          HEAP32[$100>>2] = $103;
          $105 = ((($$7136)) + 4|0);
          $106 = HEAP8[$101>>0]|0;
          $107 = $106&255;
          $108 = ((($$2107135)) + 16|0);
          HEAP32[$104>>2] = $107;
          $109 = (($$6117134) + -4)|0;
          $110 = ($109>>>0)>(4);
          if ($110) {
           $$2107135 = $108;$$6117134 = $109;$$7136 = $105;
          } else {
           label = 41;
           break;
          }
         }
         if ((label|0) == 41) {
          label = 0;
          $$pre$pre = HEAP8[$105>>0]|0;
          $$3108$ph = $108;$$7118$ph = $109;$$8$ph = $105;$$pre = $$pre$pre;
         }
         else if ((label|0) == 42) {
          label = 0;
          $111 = $89&255;
          $$3108$ph = $$2107135;$$7118$ph = $$6117134;$$8$ph = $$7136;$$pre = $111;
         }
         $$pre171 = $$pre&255;
         $$pre172 = (($$pre171) + -1)|0;
         $$3108 = $$3108$ph;$$7118 = $$7118$ph;$$8 = $$8$ph;$$pre$phi173Z2D = $$pre172;$$pre$phiZ2D = $$pre171;
         label = 44;
        } else {
         $$3108176 = $$1106147;$$7118175 = $$5116146;$$8177 = $$6104148;$$pre$phi174Z2D = $82;
        }
       } else {
        $$3108 = $$1106147;$$7118 = $$5116146;$$8 = $$6104148;$$pre$phi173Z2D = $83;$$pre$phiZ2D = $82;
        label = 44;
       }
       if ((label|0) == 44) {
        label = 0;
        $112 = ($$pre$phi173Z2D>>>0)<(127);
        if ($112) {
         $$3108176 = $$3108;$$7118175 = $$7118;$$8177 = $$8;$$pre$phi174Z2D = $$pre$phiZ2D;
        } else {
         break;
        }
       }
       $113 = ((($$8177)) + 1|0);
       $114 = ((($$3108176)) + 4|0);
       HEAP32[$$3108176>>2] = $$pre$phi174Z2D;
       $115 = (($$7118175) + -1)|0;
       $116 = ($115|0)==(0);
       if ($116) {
        $$6104$lcssa = $113;
        break L23;
       } else {
        $$1106147 = $114;$$5116146 = $115;$$6104148 = $113;
       }
      }
      $117 = (($$pre$phiZ2D) + -194)|0;
      $118 = ($117>>>0)>(50);
      if ($118) {
       $$11182 = $$8;$$5110180 = $$3108;$$9120179 = $$7118;
       label = 57;
       break L21;
      }
      $119 = ((($$8)) + 1|0);
      $120 = ((gb + (160) | 0) + ($117<<2)|0);
      $121 = HEAP32[$120>>2]|0;
      $$4 = $121;$$4109 = $$3108;$$8119 = $$7118;$$9 = $119;
      label = 48;
      continue L20;
     }
    } while(0);
    HEAP32[$1>>2] = $$6104$lcssa;
    $$097 = $2;
    label = 63;
    continue L20;
   }
   else if ((label|0) == 48) {
    label = 0;
    $122 = HEAP8[$$9>>0]|0;
    $123 = $122&255;
    $124 = $123 >>> 3;
    $125 = (($124) + -16)|0;
    $126 = $$4 >> 26;
    $127 = (($124) + ($126))|0;
    $128 = $125 | $127;
    $129 = ($128>>>0)>(7);
    if ($129) {
     $$5110 = $$4109;$$6 = $$4;$$9$sink = $$9;$$9120 = $$8119;
     label = 56;
    } else {
     $130 = $$4 << 6;
     $131 = ((($$9)) + 1|0);
     $132 = (($123) + -128)|0;
     $133 = $132 | $130;
     $134 = ($133|0)<(0);
     do {
      if ($134) {
       $135 = HEAP8[$131>>0]|0;
       $136 = $135&255;
       $137 = (($136) + -128)|0;
       $138 = ($137>>>0)>(63);
       if (!($138)) {
        $139 = $133 << 6;
        $140 = ((($$9)) + 2|0);
        $141 = $137 | $139;
        $142 = ($141|0)<(0);
        if (!($142)) {
         $$10 = $140;$$5 = $141;
         break;
        }
        $143 = HEAP8[$140>>0]|0;
        $144 = $143&255;
        $145 = (($144) + -128)|0;
        $146 = ($145>>>0)>(63);
        if (!($146)) {
         $147 = $141 << 6;
         $148 = ((($$9)) + 3|0);
         $149 = $145 | $147;
         $$10 = $148;$$5 = $149;
         break;
        }
       }
       $$11$ph = ((($$9)) + -1|0);
       $152 = (___errno_location()|0);
       HEAP32[$152>>2] = 84;
       $$11122124 = $$11$ph;
       break L21;
      } else {
       $$10 = $131;$$5 = $133;
      }
     } while(0);
     $150 = ((($$4109)) + 4|0);
     HEAP32[$$4109>>2] = $$5;
     $151 = (($$8119) + -1)|0;
     $$1106$ph = $150;$$5116$ph = $151;$$6104$ph = $$10;
     label = 33;
     continue L20;
    }
   }
   else if ((label|0) == 63) {
    label = 0;
    return ($$097|0);
   }
  } while(0);
  if ((label|0) == 56) {
   label = 0;
   $153 = ((($$9$sink)) + -1|0);
   $154 = ($$6|0)==(0);
   if ($154) {
    $$11182 = $153;$$5110180 = $$5110;$$9120179 = $$9120;
    label = 57;
   } else {
    $$11183 = $153;$$5110181 = $$5110;
    label = 61;
   }
  }
  if ((label|0) == 57) {
   label = 0;
   $155 = HEAP8[$$11182>>0]|0;
   $156 = ($155<<24>>24)==(0);
   if ($156) {
    $157 = ($$5110180|0)==(0|0);
    if (!($157)) {
     HEAP32[$$5110180>>2] = 0;
     HEAP32[$1>>2] = 0;
    }
    $158 = (($2) - ($$9120179))|0;
    $$097 = $158;
    label = 63;
    continue;
   } else {
    $$11183 = $$11182;$$5110181 = $$5110180;
    label = 61;
   }
  }
  if ((label|0) == 61) {
   label = 0;
   $159 = (___errno_location()|0);
   HEAP32[$159>>2] = 84;
   $160 = ($$5110181|0)==(0|0);
   if ($160) {
    $$097 = -1;
    label = 63;
    continue;
   } else {
    $$11122124 = $$11183;
   }
  }
  HEAP32[$1>>2] = $$11122124;
  $$097 = -1;
  label = 63;
 }
 return (0)|0;
}
function ___pthread_self_503() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _inet_ntop($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$06066 = 0, $$062 = 0, $$06365 = 0, $$067 = 0, $$1 = 0, $$161 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp = 0;
 var $spec$select = 0, $spec$select64 = 0, $vararg_buffer = 0, $vararg_buffer14 = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr12 = 0, $vararg_ptr13 = 0, $vararg_ptr17 = 0, $vararg_ptr18 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0;
 var $vararg_ptr3 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $vararg_buffer14 = sp + 152|0;
 $vararg_buffer4 = sp + 120|0;
 $vararg_buffer = sp + 104|0;
 $4 = sp;
 switch ($0|0) {
 case 2:  {
  $5 = HEAP8[$1>>0]|0;
  $6 = $5&255;
  $7 = ((($1)) + 1|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = ((($1)) + 2|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = ((($1)) + 3|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  HEAP32[$vararg_buffer>>2] = $6;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $9;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $12;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = $15;
  $16 = (_snprintf($2,$3,(gb + (166945) | 0),$vararg_buffer)|0);
  $17 = ($16>>>0)<($3>>>0);
  if ($17) {
   $$062 = $2;
  } else {
   label = 16;
  }
  break;
 }
 case 10:  {
  $18 = (_memcmp($1,(gb + (166957) | 0),12)|0);
  $19 = ($18|0)==(0);
  $20 = HEAP8[$1>>0]|0;
  $21 = $20&255;
  $22 = $21 << 8;
  $23 = ((($1)) + 1|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $22 | $25;
  $27 = ((($1)) + 2|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $29 << 8;
  $31 = ((($1)) + 3|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32&255;
  $34 = $30 | $33;
  $35 = ((($1)) + 4|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = $37 << 8;
  $39 = ((($1)) + 5|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = $38 | $41;
  $43 = ((($1)) + 6|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = $45 << 8;
  $47 = ((($1)) + 7|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = $48&255;
  $50 = $46 | $49;
  $51 = ((($1)) + 8|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = $53 << 8;
  $55 = ((($1)) + 9|0);
  $56 = HEAP8[$55>>0]|0;
  $57 = $56&255;
  $58 = $54 | $57;
  $59 = ((($1)) + 10|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  $62 = $61 << 8;
  $63 = ((($1)) + 11|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = $62 | $65;
  $67 = ((($1)) + 12|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = $68&255;
  if ($19) {
   $83 = ((($1)) + 13|0);
   $84 = HEAP8[$83>>0]|0;
   $85 = $84&255;
   $86 = ((($1)) + 14|0);
   $87 = HEAP8[$86>>0]|0;
   $88 = $87&255;
   $89 = ((($1)) + 15|0);
   $90 = HEAP8[$89>>0]|0;
   $91 = $90&255;
   HEAP32[$vararg_buffer14>>2] = $26;
   $vararg_ptr17 = ((($vararg_buffer14)) + 4|0);
   HEAP32[$vararg_ptr17>>2] = $34;
   $vararg_ptr18 = ((($vararg_buffer14)) + 8|0);
   HEAP32[$vararg_ptr18>>2] = $42;
   $vararg_ptr19 = ((($vararg_buffer14)) + 12|0);
   HEAP32[$vararg_ptr19>>2] = $50;
   $vararg_ptr20 = ((($vararg_buffer14)) + 16|0);
   HEAP32[$vararg_ptr20>>2] = $58;
   $vararg_ptr21 = ((($vararg_buffer14)) + 20|0);
   HEAP32[$vararg_ptr21>>2] = $66;
   $vararg_ptr22 = ((($vararg_buffer14)) + 24|0);
   HEAP32[$vararg_ptr22>>2] = $69;
   $vararg_ptr23 = ((($vararg_buffer14)) + 28|0);
   HEAP32[$vararg_ptr23>>2] = $85;
   $vararg_ptr24 = ((($vararg_buffer14)) + 32|0);
   HEAP32[$vararg_ptr24>>2] = $88;
   $vararg_ptr25 = ((($vararg_buffer14)) + 36|0);
   HEAP32[$vararg_ptr25>>2] = $91;
   (_snprintf($4,100,(gb + (166994) | 0),$vararg_buffer14)|0);
  } else {
   $70 = $69 << 8;
   $71 = ((($1)) + 13|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = $72&255;
   $74 = $70 | $73;
   $75 = ((($1)) + 14|0);
   $76 = HEAP8[$75>>0]|0;
   $77 = $76&255;
   $78 = $77 << 8;
   $79 = ((($1)) + 15|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = $80&255;
   $82 = $78 | $81;
   HEAP32[$vararg_buffer4>>2] = $26;
   $vararg_ptr7 = ((($vararg_buffer4)) + 4|0);
   HEAP32[$vararg_ptr7>>2] = $34;
   $vararg_ptr8 = ((($vararg_buffer4)) + 8|0);
   HEAP32[$vararg_ptr8>>2] = $42;
   $vararg_ptr9 = ((($vararg_buffer4)) + 12|0);
   HEAP32[$vararg_ptr9>>2] = $50;
   $vararg_ptr10 = ((($vararg_buffer4)) + 16|0);
   HEAP32[$vararg_ptr10>>2] = $58;
   $vararg_ptr11 = ((($vararg_buffer4)) + 20|0);
   HEAP32[$vararg_ptr11>>2] = $66;
   $vararg_ptr12 = ((($vararg_buffer4)) + 24|0);
   HEAP32[$vararg_ptr12>>2] = $74;
   $vararg_ptr13 = ((($vararg_buffer4)) + 28|0);
   HEAP32[$vararg_ptr13>>2] = $82;
   (_snprintf($4,100,(gb + (166970) | 0),$vararg_buffer4)|0);
  }
  $92 = HEAP8[$4>>0]|0;
  $93 = ($92<<24>>24)==(0);
  if (!($93)) {
   $$06066 = 2;$$06365 = 0;$$067 = 0;$96 = $92;$97 = $4;
   while(1) {
    $94 = ($$06365|0)==(0);
    $95 = ($96<<24>>24)==(58);
    $or$cond = $94 | $95;
    if ($or$cond) {
     $98 = (_strspn($97,(gb + (167024) | 0))|0);
     $99 = ($98|0)>($$06066|0);
     $spec$select = $99 ? $98 : $$06066;
     $spec$select64 = $99 ? $$06365 : $$067;
     $$1 = $spec$select64;$$161 = $spec$select;
    } else {
     $$1 = $$067;$$161 = $$06066;
    }
    $100 = (($$06365) + 1)|0;
    $101 = (($4) + ($100)|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     break;
    } else {
     $$06066 = $$161;$$06365 = $100;$$067 = $$1;$96 = $102;$97 = $101;
    }
   }
   $$pre = (($4) + ($$1)|0);
   $104 = ($$161|0)>(2);
   if ($104) {
    $phitmp = (($$06365) + 2)|0;
    $105 = (($phitmp) - ($$161))|0;
    $106 = (($105) - ($$1))|0;
    $107 = (($$pre) + ($$161)|0);
    $108 = ((($$pre)) + 2|0);
    $109 = (($$1) + 1)|0;
    $110 = (($4) + ($109)|0);
    HEAP8[$110>>0] = 58;
    HEAP8[$$pre>>0] = 58;
    (_memmove(($108|0),($107|0),($106|0))|0);
   }
  }
  $111 = (_strlen($4)|0);
  $112 = ($111>>>0)<($3>>>0);
  if ($112) {
   (_strcpy($2,$4)|0);
   $$062 = $2;
  } else {
   label = 16;
  }
  break;
 }
 default: {
  $113 = (___errno_location()|0);
  HEAP32[$113>>2] = 97;
  $$062 = 0;
 }
 }
 if ((label|0) == 16) {
  $114 = (___errno_location()|0);
  HEAP32[$114>>2] = 28;
  $$062 = 0;
 }
 STACKTOP = sp;return ($$062|0);
}
function _strspn($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$01924 = 0, $$020 = 0, $$1$lcssa = 0, $$121 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 $3 = HEAP8[$1>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = ((($1)) + 1|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $$020 = $0;
    while(1) {
     $8 = HEAP8[$$020>>0]|0;
     $9 = ($8<<24>>24)==($3<<24>>24);
     $10 = ((($$020)) + 1|0);
     if ($9) {
      $$020 = $10;
     } else {
      break;
     }
    }
    $11 = $$020;
    $12 = $0;
    $13 = (($11) - ($12))|0;
    $$0 = $13;
    break;
   }
   $$01924 = $1;$15 = $3;
   while(1) {
    $14 = $15&255;
    $16 = $14 & 31;
    $17 = 1 << $16;
    $18 = $14 >>> 5;
    $19 = (($2) + ($18<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 | $17;
    HEAP32[$19>>2] = $21;
    $22 = ((($$01924)) + 1|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     break;
    } else {
     $$01924 = $22;$15 = $23;
    }
   }
   $25 = HEAP8[$0>>0]|0;
   $26 = ($25<<24>>24)==(0);
   L12: do {
    if ($26) {
     $$1$lcssa = $0;
    } else {
     $$121 = $0;$28 = $25;
     while(1) {
      $27 = $28&255;
      $29 = $27 >>> 5;
      $30 = (($2) + ($29<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = $27 & 31;
      $33 = 1 << $32;
      $34 = $31 & $33;
      $35 = ($34|0)==(0);
      if ($35) {
       $$1$lcssa = $$121;
       break L12;
      }
      $36 = ((($$121)) + 1|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = ($37<<24>>24)==(0);
      if ($38) {
       $$1$lcssa = $36;
       break;
      } else {
       $$121 = $36;$28 = $37;
      }
     }
    }
   } while(0);
   $39 = $$1$lcssa;
   $40 = $0;
   $41 = (($39) - ($40))|0;
   $$0 = $41;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _sockatmark($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,35077,$vararg_buffer)|0);
 $3 = ($2|0)<(0);
 $4 = HEAP32[$1>>2]|0;
 $$0 = $3 ? -1 : $4;
 STACKTOP = sp;return ($$0|0);
}
function _getservbyport($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $getservbyport$se$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (_getservbyport_r($0,$1,(gb + (171896) | 0),(gb + (170096) | 0),32,$2)|0);
 $4 = ($3|0)==(0);
 $getservbyport$se$ = $4 ? (gb + (171896) | 0) : 0;
 STACKTOP = sp;return ($getservbyport$se$|0);
}
function _mincore($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $2;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $4;
 $5 = (___syscall218(218,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _mlock($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall150(150,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function ___mremap($0,$1,$2,$3,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $varargs = $varargs|0;
 var $$0 = 0, $$09 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0;
 var $expanded = 0, $expanded2 = 0, $expanded4 = 0, $expanded5 = 0, $expanded6 = 0, $phitmp = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer = sp + 16|0;
 $4 = sp;
 $5 = ($2>>>0)>(2147483646);
 if ($5) {
  $6 = (___errno_location()|0);
  HEAP32[$6>>2] = 12;
  $$0 = (-1);
 } else {
  $7 = $3 & 2;
  $8 = ($7|0)==(0);
  if ($8) {
   $$09 = 0;
  } else {
   mftCall_v((fb + (10) | 0)|0);
   HEAP32[$4>>2] = $varargs;
   $arglist_current = HEAP32[$4>>2]|0;
   $9 = $arglist_current;
   $10 = ((0) + 4|0);
   $expanded2 = $10;
   $expanded = (($expanded2) - 1)|0;
   $11 = (($9) + ($expanded))|0;
   $12 = ((0) + 4|0);
   $expanded6 = $12;
   $expanded5 = (($expanded6) - 1)|0;
   $expanded4 = $expanded5 ^ -1;
   $13 = $11 & $expanded4;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $arglist_next = ((($14)) + 4|0);
   HEAP32[$4>>2] = $arglist_next;
   $phitmp = $15;
   $$09 = $phitmp;
  }
  $16 = $0;
  HEAP32[$vararg_buffer>>2] = $16;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $1;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $2;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = $3;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $$09;
  $17 = (___syscall163(163,($vararg_buffer|0))|0);
  $18 = (___syscall_ret($17)|0);
  $19 = $18;
  $$0 = $19;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___mmap($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $6 = ($5|0)<(0);
 $7 = $6 << 31 >> 31;
 $8 = $5 & 4095;
 $9 = $7 & -4096;
 $10 = ($8|0)==(0);
 $11 = ($9|0)==(0);
 $12 = $10 & $11;
 do {
  if ($12) {
   $14 = ($1>>>0)>(2147483646);
   if ($14) {
    $15 = (___errno_location()|0);
    HEAP32[$15>>2] = 12;
    $$0 = (-1);
    break;
   }
   $16 = $3 & 16;
   $17 = ($16|0)==(0);
   if (!($17)) {
    mftCall_v((fb + (10) | 0)|0);
   }
   $18 = $0;
   $19 = $5 >> 12;
   HEAP32[$vararg_buffer>>2] = $18;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $1;
   $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $2;
   $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
   HEAP32[$vararg_ptr3>>2] = $3;
   $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
   HEAP32[$vararg_ptr4>>2] = $4;
   $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
   HEAP32[$vararg_ptr5>>2] = $19;
   $20 = (___syscall192(192,($vararg_buffer|0))|0);
   $21 = (___syscall_ret($20)|0);
   $22 = $21;
   $$0 = $22;
  } else {
   $13 = (___errno_location()|0);
   HEAP32[$13>>2] = 22;
   $$0 = (-1);
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___shm_mapname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$018 = $0;
 while(1) {
  $2 = HEAP8[$$018>>0]|0;
  $3 = ($2<<24>>24)==(47);
  $4 = ((($$018)) + 1|0);
  if ($3) {
   $$018 = $4;
  } else {
   break;
  }
 }
 $5 = (___strchrnul($$018,47)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = ($5|0)==($$018|0);
 $or$cond = $8 | $7;
 do {
  if ($or$cond) {
   label = 7;
  } else {
   $9 = $5;
   $10 = $$018;
   $11 = (($9) - ($10))|0;
   $12 = ($11|0)<(3);
   if ($12) {
    $13 = HEAP8[$$018>>0]|0;
    $14 = ($13<<24>>24)==(46);
    if ($14) {
     $15 = ((($5)) + -1|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)==(46);
     if ($17) {
      label = 7;
      break;
     }
    }
   } else {
    $19 = ($11|0)>(255);
    if ($19) {
     $20 = (___errno_location()|0);
     HEAP32[$20>>2] = 36;
     $$0 = 0;
     break;
    }
   }
   (_memcpy(($1|0),((gb + (167027) | 0)|0),9)|0);
   $21 = ((($1)) + 9|0);
   $22 = (($11) + 1)|0;
   (_memcpy(($21|0),($$018|0),($22|0))|0);
   $$0 = $1;
  }
 } while(0);
 if ((label|0) == 7) {
  $18 = (___errno_location()|0);
  HEAP32[$18>>2] = 22;
  $$0 = 0;
 }
 return ($$0|0);
}
function _shm_open($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $vararg_buffer = sp + 272|0;
 $3 = sp + 276|0;
 $4 = sp;
 $5 = (___shm_mapname($0,$4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = -1;
 } else {
  $7 = $1 | 657408;
  (_pthread_setcancelstate(1,($3|0))|0);
  HEAP32[$vararg_buffer>>2] = $2;
  $8 = (_open($5,$7,$vararg_buffer)|0);
  $9 = HEAP32[$3>>2]|0;
  (_pthread_setcancelstate(($9|0),(0|0))|0);
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _shm_unlink($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $1 = sp;
 $2 = (___shm_mapname($0,$1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = -1;
 } else {
  $4 = (_unlink($2)|0);
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function _msync($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall144(144,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _posix_madvise($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ($2|0)==(4);
 if ($3) {
  $$0 = 0;
 } else {
  $4 = $0;
  HEAP32[$vararg_buffer>>2] = $4;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $1;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $2;
  $5 = (___syscall219(219,($vararg_buffer|0))|0);
  $6 = (0 - ($5))|0;
  $$0 = $6;
 }
 STACKTOP = sp;return ($$0|0);
}
function _munlockall() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $0 = (___syscall153(153,($vararg_buffer|0))|0);
 $1 = (___syscall_ret($0)|0);
 STACKTOP = sp;return ($1|0);
}
function _mlockall($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall152(152,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function ___mprotect($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $3 & -16384;
 $5 = (($0) + ($1)|0);
 $6 = ((($5)) + 16384|0);
 $7 = ((($6)) + -1|0);
 $8 = $7;
 $9 = $8 & -16384;
 $10 = (($9) - ($4))|0;
 HEAP32[$vararg_buffer>>2] = $4;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $11 = (___syscall125(125,($vararg_buffer|0))|0);
 $12 = (___syscall_ret($11)|0);
 STACKTOP = sp;return ($12|0);
}
function ___madvise($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall219(219,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _munlock($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall151(151,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function ___crypt_blowfish($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond28 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(416|0);
 $3 = sp + 312|0;
 $4 = sp + 240|0;
 $5 = sp + 160|0;
 $6 = sp + 80|0;
 $7 = sp;
 $8 = (_BF_crypt($0,$1,$2,16)|0);
 (_memcpy(($3|0),((gb + (167037) | 0)|0),30)|0);
 $9 = ($8|0)!=(0|0);
 if ($9) {
  $10 = ((($1)) + 2|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ((($3)) + 2|0);
  HEAP8[$12>>0] = $11;
 }
 $13 = ((($3)) + 30|0);
 (_memset(($13|0),85,63)|0);
 $14 = ((($3)) + 92|0);
 HEAP8[$14>>0] = 0;
 $15 = (_BF_crypt((gb + (167067) | 0),$3,$13,1)|0);
 $16 = ($15|0)==($13|0);
 if ($16) {
  $17 = (_memcmp($13,$3,29)|0);
  $18 = ($17|0)==(0);
  if ($18) {
   $19 = ((($3)) + 59|0);
   $20 = ((($3)) + 2|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21 & 1;
   $23 = $22&255;
   $24 = ((gb + (143952) | 0) + (($23*34)|0)|0);
   $25 = (_memcmp($19,$24,34)|0);
   $26 = ($25|0)==(0);
   $30 = $26;
  } else {
   $30 = 0;
  }
 } else {
  $30 = 0;
 }
 _BF_set_key((gb + (167077) | 0),$4,$5,2);
 _BF_set_key((gb + (167077) | 0),$6,$7,4);
 $27 = HEAP32[$5>>2]|0;
 $28 = $27 ^ 65536;
 HEAP32[$5>>2] = $28;
 $29 = ($28|0)==(-610510404);
 $or$cond28 = $30 & $29;
 if ($or$cond28) {
  $31 = ((($6)) + 68|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(859059456);
  if ($33) {
   $34 = (_memcmp($4,$6,72)|0);
   $35 = ($34|0)==(0);
   if ($35) {
    $36 = (_memcmp($5,$7,72)|0);
    $37 = ($36|0)==(0);
    $38 = $37;
   } else {
    $38 = 0;
   }
  } else {
   $38 = 0;
  }
 } else {
  $38 = 0;
 }
 $or$cond = $9 & $38;
 $$ = $or$cond ? $8 : (gb + (167222) | 0);
 STACKTOP = sp;return ($$|0);
}
function _BF_crypt($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$084 = 0, $$085 = 0, $$08694 = 0, $$08996 = 0, $$18795 = 0, $$293 = 0, $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4272|0);
 $4 = sp + 8|0;
 $5 = sp;
 $6 = HEAP8[$1>>0]|0;
 $7 = ($6<<24>>24)==(36);
 if ($7) {
  $8 = ((($1)) + 1|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(50);
  if ($10) {
   $11 = ((($1)) + 2|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12 << 24 >> 24;
   $14 = (($13) + -97)|0;
   $15 = ($14>>>0)>(25);
   if ($15) {
    $$084 = 0;
   } else {
    $16 = 25165825 >>> $14;
    $17 = $16 & 1;
    $18 = ($17|0)==(0);
    if ($18) {
     $$084 = 0;
    } else {
     $19 = ((($1)) + 3|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($20<<24>>24)==(36);
     if ($21) {
      $22 = ((($1)) + 4|0);
      $23 = HEAP8[$22>>0]|0;
      $24 = $23 << 24 >> 24;
      $25 = (($24) + -48)|0;
      $26 = ($25>>>0)>(1);
      if ($26) {
       $$084 = 0;
      } else {
       $27 = ((($1)) + 5|0);
       $28 = HEAP8[$27>>0]|0;
       $29 = $28 << 24 >> 24;
       $30 = (($29) + -48)|0;
       $31 = ($30>>>0)>(9);
       if ($31) {
        $$084 = 0;
       } else {
        $32 = ((($1)) + 6|0);
        $33 = HEAP8[$32>>0]|0;
        $34 = ($33<<24>>24)==(36);
        if ($34) {
         $35 = ($25*10)|0;
         $36 = (($30) + ($35))|0;
         $37 = 1 << $36;
         $38 = ($37>>>0)<($3>>>0);
         if ($38) {
          $$084 = 0;
         } else {
          $39 = ((($4)) + 4240|0);
          $40 = ((($1)) + 7|0);
          $41 = (_BF_decode($39,$40)|0);
          $42 = ($41|0)==(0);
          if ($42) {
           _BF_swap($39,4);
           $43 = ((($4)) + 4168|0);
           $44 = HEAP8[$11>>0]|0;
           $45 = $44 << 24 >> 24;
           $46 = (($45) + -97)|0;
           $47 = ((gb + (144032) | 0) + ($46)|0);
           $48 = HEAP8[$47>>0]|0;
           _BF_set_key($0,$43,$4,$48);
           $49 = ((($4)) + 72|0);
           (_memcpy(($49|0),(((((gb + (162140) | 0)) + 72|0))|0),4096)|0);
           $50 = HEAP32[$39>>2]|0;
           $51 = ((($4)) + 4244|0);
           $52 = HEAP32[$51>>2]|0;
           $53 = (_BF_encrypt($4,$50,$52,$4,$4)|0);
           $54 = ((($4)) + 8|0);
           $55 = ((($4)) + 4248|0);
           $56 = ((($4)) + 4252|0);
           $$08996 = $4;$61 = $53;$64 = $54;
           while(1) {
            $57 = ((($$08996)) + 4|0);
            $58 = HEAP32[$57>>2]|0;
            $59 = HEAP32[$55>>2]|0;
            $60 = $59 ^ $61;
            $62 = HEAP32[$56>>2]|0;
            $63 = $62 ^ $58;
            $65 = (_BF_encrypt($4,$60,$63,$64,$64)|0);
            $66 = ((($$08996)) + 12|0);
            $67 = HEAP32[$66>>2]|0;
            $68 = ((($$08996)) + 16|0);
            $69 = HEAP32[$39>>2]|0;
            $70 = $69 ^ $65;
            $71 = HEAP32[$51>>2]|0;
            $72 = $71 ^ $67;
            $73 = (_BF_encrypt($4,$70,$72,$68,$68)|0);
            $74 = ((($$08996)) + 24|0);
            $75 = ($74>>>0)<($43>>>0);
            if ($75) {
             $$08996 = $68;$61 = $73;$64 = $74;
            } else {
             break;
            }
           }
           $76 = ((($4)) + 64|0);
           $77 = ((($4)) + 68|0);
           $$085 = $37;
           while(1) {
            $$08694 = 0;
            while(1) {
             $78 = (((($4)) + 4168|0) + ($$08694<<2)|0);
             $79 = HEAP32[$78>>2]|0;
             $80 = (($4) + ($$08694<<2)|0);
             $81 = HEAP32[$80>>2]|0;
             $82 = $81 ^ $79;
             HEAP32[$80>>2] = $82;
             $83 = $$08694 | 1;
             $84 = (((($4)) + 4168|0) + ($83<<2)|0);
             $85 = HEAP32[$84>>2]|0;
             $86 = (($4) + ($83<<2)|0);
             $87 = HEAP32[$86>>2]|0;
             $88 = $87 ^ $85;
             HEAP32[$86>>2] = $88;
             $89 = (($$08694) + 2)|0;
             $90 = ($89>>>0)<(18);
             if ($90) {
              $$08694 = $89;
             } else {
              break;
             }
            }
            (_BF_encrypt($4,0,0,$4,$43)|0);
            $91 = HEAP32[$39>>2]|0;
            $92 = HEAP32[$51>>2]|0;
            $93 = HEAP32[$55>>2]|0;
            $94 = HEAP32[$56>>2]|0;
            $$18795 = 0;
            while(1) {
             $95 = (($4) + ($$18795<<2)|0);
             $96 = HEAP32[$95>>2]|0;
             $97 = $96 ^ $91;
             HEAP32[$95>>2] = $97;
             $98 = $$18795 | 1;
             $99 = (($4) + ($98<<2)|0);
             $100 = HEAP32[$99>>2]|0;
             $101 = $100 ^ $92;
             HEAP32[$99>>2] = $101;
             $102 = $$18795 | 2;
             $103 = (($4) + ($102<<2)|0);
             $104 = HEAP32[$103>>2]|0;
             $105 = $104 ^ $93;
             HEAP32[$103>>2] = $105;
             $106 = $$18795 | 3;
             $107 = (($4) + ($106<<2)|0);
             $108 = HEAP32[$107>>2]|0;
             $109 = $108 ^ $94;
             HEAP32[$107>>2] = $109;
             $110 = (($$18795) + 4)|0;
             $111 = ($110>>>0)<(16);
             if ($111) {
              $$18795 = $110;
             } else {
              break;
             }
            }
            $112 = HEAP32[$76>>2]|0;
            $113 = $112 ^ $91;
            HEAP32[$76>>2] = $113;
            $114 = HEAP32[$77>>2]|0;
            $115 = $114 ^ $92;
            HEAP32[$77>>2] = $115;
            (_BF_encrypt($4,0,0,$4,$43)|0);
            $116 = (($$085) + -1)|0;
            $117 = ($116|0)==(0);
            if ($117) {
             break;
            } else {
             $$085 = $116;
            }
           }
           $118 = ((($5)) + 4|0);
           $$293 = 0;
           while(1) {
            $119 = ((gb + (144064) | 0) + ($$293<<2)|0);
            $120 = HEAP32[$119>>2]|0;
            $121 = $$293 | 1;
            $122 = ((gb + (144064) | 0) + ($121<<2)|0);
            $123 = HEAP32[$122>>2]|0;
            HEAP32[$118>>2] = $123;
            $124 = (_BF_encrypt($4,$120,$123,$5,$5)|0);
            $125 = $124;$128 = 63;
            while(1) {
             $$pre = HEAP32[$118>>2]|0;
             $126 = (_BF_encrypt($4,$125,$$pre,$5,$5)|0);
             $127 = (($128) + -1)|0;
             $129 = ($127|0)==(0);
             if ($129) {
              break;
             } else {
              $125 = $126;$128 = $127;
             }
            }
            $130 = (((($4)) + 4240|0) + ($$293<<2)|0);
            HEAP32[$130>>2] = $126;
            $131 = HEAP32[$118>>2]|0;
            $132 = (((($4)) + 4240|0) + ($121<<2)|0);
            HEAP32[$132>>2] = $131;
            $133 = (($$293) + 2)|0;
            $134 = ($133>>>0)<(6);
            if ($134) {
             $$293 = $133;
            } else {
             break;
            }
           }
           (_memcpy(($2|0),($1|0),28)|0);
           $135 = ((($1)) + 28|0);
           $136 = HEAP8[$135>>0]|0;
           $137 = $136 << 24 >> 24;
           $138 = (($137) + -32)|0;
           $139 = ((gb + (144096) | 0) + ($138)|0);
           $140 = HEAP8[$139>>0]|0;
           $141 = $140 & 48;
           $142 = $141&255;
           $143 = ((gb + (144192) | 0) + ($142)|0);
           $144 = HEAP8[$143>>0]|0;
           $145 = ((($2)) + 28|0);
           HEAP8[$145>>0] = $144;
           _BF_swap($39,6);
           $146 = ((($2)) + 29|0);
           _BF_encode($146,$39);
           $147 = ((($2)) + 60|0);
           HEAP8[$147>>0] = 0;
           $$084 = $2;
          } else {
           $$084 = 0;
          }
         }
        } else {
         $$084 = 0;
        }
       }
      }
     } else {
      $$084 = 0;
     }
    }
   }
  } else {
   $$084 = 0;
  }
 } else {
  $$084 = 0;
 }
 STACKTOP = sp;return ($$084|0);
}
function _BF_set_key($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$masked = 0, $$04455 = 0, $$04554 = 0, $$04850 = 0, $$04953 = 0, $$056 = 0, $$14651 = 0, $$152 = 0, $$2 = 0, $$247 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond58 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = $3&255;
 $6 = $5 & 1;
 $7 = $5 << 15;
 $8 = ((($4)) + 4|0);
 $9 = (($4) + ($6<<2)|0);
 $$04455 = 0;$$04554 = $0;$$04953 = 0;$$056 = 0;
 while(1) {
  HEAP32[$8>>2] = 0;
  HEAP32[$4>>2] = 0;
  $$04850 = 0;$$14651 = $$04554;$$152 = $$04455;$11 = 0;$16 = 0;
  while(1) {
   $10 = $11 << 8;
   HEAP32[$4>>2] = $10;
   $12 = HEAP8[$$14651>>0]|0;
   $13 = $12&255;
   $14 = $10 | $13;
   HEAP32[$4>>2] = $14;
   $15 = $16 << 8;
   HEAP32[$8>>2] = $15;
   $17 = HEAP8[$$14651>>0]|0;
   $18 = $17 << 24 >> 24;
   $19 = $15 | $18;
   HEAP32[$8>>2] = $19;
   $20 = ($$04850|0)==(0);
   $21 = $18 & 128;
   $22 = $20 ? 0 : $21;
   $$2 = $22 | $$152;
   $23 = HEAP8[$$14651>>0]|0;
   $24 = ($23<<24>>24)==(0);
   $25 = ((($$14651)) + 1|0);
   $$247 = $24 ? $0 : $25;
   $26 = (($$04850) + 1)|0;
   $exitcond = ($26|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $$04850 = $26;$$14651 = $$247;$$152 = $$2;$11 = $14;$16 = $19;
   }
  }
  $27 = $19 ^ $14;
  $28 = $27 | $$056;
  $29 = HEAP32[$9>>2]|0;
  $30 = (($1) + ($$04953<<2)|0);
  HEAP32[$30>>2] = $29;
  $31 = ((gb + (162140) | 0) + ($$04953<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32 ^ $29;
  $34 = (($2) + ($$04953<<2)|0);
  HEAP32[$34>>2] = $33;
  $35 = (($$04953) + 1)|0;
  $exitcond58 = ($35|0)==(18);
  if ($exitcond58) {
   break;
  } else {
   $$04455 = $$2;$$04554 = $$247;$$04953 = $35;$$056 = $28;
  }
 }
 $36 = $7 & 65536;
 $37 = $28 >>> 16;
 $$0$masked = $28 & 65535;
 $38 = $$0$masked | $37;
 $39 = $$2 << 9;
 $40 = (65536 - ($38))|0;
 $41 = $36 & $39;
 $42 = $41 & $40;
 $43 = HEAP32[$2>>2]|0;
 $44 = $43 ^ $42;
 HEAP32[$2>>2] = $44;
 STACKTOP = sp;return;
}
function _BF_decode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$054 = 0, $$055 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 $$054 = $0;$$055 = $1;
 while(1) {
  $3 = ((($$055)) + 1|0);
  $4 = HEAP8[$$055>>0]|0;
  $5 = $4&255;
  $6 = (($5) + -32)|0;
  $7 = ($6>>>0)>(95);
  if ($7) {
   $$0 = -1;
   break;
  }
  $8 = ((gb + (144096) | 0) + ($6)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = ($9&255)>(63);
  if ($11) {
   $$0 = -1;
   break;
  }
  $12 = ((($$055)) + 2|0);
  $13 = HEAP8[$3>>0]|0;
  $14 = $13&255;
  $15 = (($14) + -32)|0;
  $16 = ($15>>>0)>(95);
  if ($16) {
   $$0 = -1;
   break;
  }
  $17 = ((gb + (144096) | 0) + ($15)|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = ($18&255)>(63);
  if ($20) {
   $$0 = -1;
   break;
  }
  $21 = $10 << 2;
  $22 = $19 >>> 4;
  $23 = $22 & 3;
  $24 = $23 | $21;
  $25 = $24&255;
  $26 = ((($$054)) + 1|0);
  HEAP8[$$054>>0] = $25;
  $27 = ($26>>>0)<($2>>>0);
  if (!($27)) {
   $$0 = 0;
   break;
  }
  $28 = ((($$055)) + 3|0);
  $29 = HEAP8[$12>>0]|0;
  $30 = $29&255;
  $31 = (($30) + -32)|0;
  $32 = ($31>>>0)>(95);
  if ($32) {
   $$0 = -1;
   break;
  }
  $33 = ((gb + (144096) | 0) + ($31)|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = ($34&255)>(63);
  if ($36) {
   $$0 = -1;
   break;
  }
  $37 = $19 << 4;
  $38 = $35 >>> 2;
  $39 = $38 & 15;
  $40 = $39 | $37;
  $41 = $40&255;
  $42 = ((($$054)) + 2|0);
  HEAP8[$26>>0] = $41;
  $43 = ($42>>>0)<($2>>>0);
  if (!($43)) {
   $$0 = 0;
   break;
  }
  $44 = ((($$055)) + 4|0);
  $45 = HEAP8[$28>>0]|0;
  $46 = $45&255;
  $47 = (($46) + -32)|0;
  $48 = ($47>>>0)>(95);
  if ($48) {
   $$0 = -1;
   break;
  }
  $49 = ((gb + (144096) | 0) + ($47)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($50&255)>(63);
  if ($51) {
   $$0 = -1;
   break;
  }
  $52 = $50&255;
  $53 = $35 << 6;
  $54 = $53 | $52;
  $55 = $54&255;
  $56 = ((($$054)) + 3|0);
  HEAP8[$42>>0] = $55;
  $57 = ($56>>>0)<($2>>>0);
  if ($57) {
   $$054 = $56;$$055 = $44;
  } else {
   $$0 = 0;
   break;
  }
 }
 return ($$0|0);
}
function _BF_swap($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$07 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $0;$$07 = $1;
 while(1) {
  $2 = HEAP32[$$0>>2]|0;
  $3 = (_llvm_bswap_i32(($2|0))|0);
  $4 = ((($$0)) + 4|0);
  HEAP32[$$0>>2] = $3;
  $5 = (($$07) + -1)|0;
  $6 = ($5|0)==(0);
  if ($6) {
   break;
  } else {
   $$0 = $4;$$07 = $5;
  }
 }
 return;
}
function _BF_encrypt($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$074 = 0, $$075 = 0, $$076 = 0, $$080 = 0, $$17778 = 0, $$179 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 68|0);
 $$074 = $3;$$075 = $1;$$076 = $2;
 while(1) {
  $6 = HEAP32[$0>>2]|0;
  $7 = $6 ^ $$075;
  $$080 = 0;$$17778 = $$076;$$179 = $7;
  while(1) {
   $15 = $$179 & 255;
   $16 = $$179 >>> 8;
   $17 = $16 & 255;
   $18 = $$179 >>> 16;
   $19 = $18 & 255;
   $20 = $$179 >>> 24;
   $21 = (((($0)) + 3144|0) + ($15<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (((($0)) + 2120|0) + ($17<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (((($0)) + 1096|0) + ($19<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (((($0)) + 72|0) + ($20<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + ($26))|0;
   $30 = $29 ^ $24;
   $31 = $$080 | 1;
   $32 = (($0) + ($31<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = $33 ^ $$17778;
   $35 = (($30) + ($22))|0;
   $10 = $34 ^ $35;
   $36 = $10 & 255;
   $37 = $10 >>> 8;
   $38 = $37 & 255;
   $39 = $10 >>> 16;
   $40 = $39 & 255;
   $41 = $10 >>> 24;
   $42 = (((($0)) + 3144|0) + ($36<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (((($0)) + 2120|0) + ($38<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (((($0)) + 1096|0) + ($40<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (((($0)) + 72|0) + ($41<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + ($47))|0;
   $51 = $50 ^ $45;
   $52 = (($31) + 1)|0;
   $53 = (($0) + ($52<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $54 ^ $$179;
   $56 = (($51) + ($43))|0;
   $13 = $55 ^ $56;
   $57 = (($$080) + 2)|0;
   $58 = ($57>>>0)<(16);
   if ($58) {
    $$080 = $57;$$17778 = $10;$$179 = $13;
   } else {
    break;
   }
  }
  $8 = HEAP32[$5>>2]|0;
  $9 = $8 ^ $10;
  $11 = ((($$074)) + 4|0);
  HEAP32[$$074>>2] = $9;
  $12 = ((($$074)) + 8|0);
  HEAP32[$11>>2] = $13;
  $14 = ($12>>>0)<($4>>>0);
  if ($14) {
   $$074 = $12;$$075 = $9;$$076 = $13;
  } else {
   break;
  }
 }
 return ($9|0);
}
function _BF_encode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$039$add = 0, $$039$idx = 0, $$039$ptr = 0, $$add = 0, $$add1 = 0, $$ptr = 0, $$ptr2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $0;$$039$idx = 0;
 while(1) {
  $$039$ptr = (($1) + ($$039$idx)|0);
  $2 = HEAP8[$$039$ptr>>0]|0;
  $3 = $2&255;
  $4 = $3 >>> 2;
  $5 = ((gb + (144192) | 0) + ($4)|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP8[$$0>>0] = $6;
  $7 = $3 << 4;
  $8 = $7 & 48;
  $9 = ((($$0)) + 1|0);
  $$039$add = (($$039$idx) + 1)|0;
  $$ptr = (($1) + ($$039$add)|0);
  $$add = (($$039$idx) + 2)|0;
  $10 = HEAP8[$$ptr>>0]|0;
  $11 = $10&255;
  $12 = $11 >>> 4;
  $13 = $12 | $8;
  $14 = ((gb + (144192) | 0) + ($13)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ((($$0)) + 2|0);
  HEAP8[$9>>0] = $15;
  $17 = $11 << 2;
  $18 = $17 & 60;
  $19 = ($$add>>>0)>(22);
  if ($19) {
   label = 3;
   break;
  }
  $$ptr2 = (($1) + ($$add)|0);
  $$add1 = (($$039$idx) + 3)|0;
  $22 = HEAP8[$$ptr2>>0]|0;
  $23 = $22&255;
  $24 = $23 >>> 6;
  $25 = $24 | $18;
  $26 = ((gb + (144192) | 0) + ($25)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ((($$0)) + 3|0);
  HEAP8[$16>>0] = $27;
  $29 = $23 & 63;
  $30 = ((gb + (144192) | 0) + ($29)|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ((($$0)) + 4|0);
  HEAP8[$28>>0] = $31;
  $33 = ($$add1>>>0)<(23);
  if ($33) {
   $$0 = $32;$$039$idx = $$add1;
  } else {
   break;
  }
 }
 if ((label|0) == 3) {
  $20 = ((gb + (144192) | 0) + ($18)|0);
  $21 = HEAP8[$20>>0]|0;
  HEAP8[$16>>0] = $21;
 }
 return;
}
function ___des_setkey($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0100105 = 0, $$0104 = 0, $$093103 = 0, $$094110 = 0, $$095109 = 0, $$096106 = 0, $$097108 = 0, $$098107 = 0, $$1102 = 0, $$199101 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond114 = 0, $exitcond115 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 3|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ((($0)) + 2|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 8;
 $9 = $8 | $4;
 $10 = ((($0)) + 1|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 16;
 $14 = $9 | $13;
 $15 = HEAP8[$0>>0]|0;
 $16 = $15&255;
 $17 = $16 << 24;
 $18 = $14 | $17;
 $19 = ((($0)) + 7|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = ((($0)) + 6|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 8;
 $26 = $25 | $21;
 $27 = ((($0)) + 5|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = $29 << 16;
 $31 = $26 | $30;
 $32 = ((($0)) + 4|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $34 << 24;
 $36 = $31 | $35;
 $$094110 = 0;$$095109 = 0;$$097108 = 28;$$098107 = 0;
 while(1) {
  $37 = $$098107 << 1;
  $38 = $18 >>> $$097108;
  $39 = $38 & 15;
  $40 = (((gb + (144272) | 0) + ($$098107<<6)|0) + ($39<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($$098107) + 4)|0;
  $43 = $36 >>> $$097108;
  $44 = $43 & 15;
  $45 = (((gb + (144272) | 0) + ($42<<6)|0) + ($44<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $41 | $$094110;
  $48 = $47 | $46;
  $49 = (((gb + (144784) | 0) + ($37<<6)|0) + ($39<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($$097108) + -4)|0;
  $52 = $37 | 1;
  $53 = $18 >>> $51;
  $54 = $53 & 15;
  $55 = (((gb + (144784) | 0) + ($52<<6)|0) + ($54<<2)|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($$098107) + 8)|0;
  $58 = $36 >>> $51;
  $59 = $58 & 15;
  $60 = (((gb + (144784) | 0) + ($57<<6)|0) + ($59<<2)|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = $50 | $$095109;
  $63 = $62 | $56;
  $64 = $63 | $61;
  $65 = (($$098107) + 1)|0;
  $66 = (($$097108) + -8)|0;
  $exitcond115 = ($65|0)==(4);
  if ($exitcond115) {
   break;
  } else {
   $$094110 = $48;$$095109 = $64;$$097108 = $66;$$098107 = $65;
  }
 }
 $$0100105 = 0;$$096106 = 0;
 while(1) {
  $67 = ((gb + (145552) | 0) + ($$0100105)|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = $68&255;
  $70 = (($$096106) + ($69))|0;
  $71 = $48 << $70;
  $72 = (28 - ($70))|0;
  $73 = $48 >>> $72;
  $74 = $73 | $71;
  $75 = $64 << $70;
  $76 = $64 >>> $72;
  $77 = $76 | $75;
  $$0104 = 0;$$093103 = 0;$$1102 = 25;$$199101 = 0;
  while(1) {
   $78 = $74 >>> $$1102;
   $79 = $78 & 7;
   $80 = (((gb + (145568) | 0) + ($$199101<<5)|0) + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $81 | $$093103;
   $83 = $77 >>> $$1102;
   $84 = $83 & 7;
   $85 = (((gb + (145696) | 0) + ($$199101<<5)|0) + ($84<<2)|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = $86 | $$0104;
   $88 = (($$1102) + -4)|0;
   $89 = $74 >>> $88;
   $90 = $89 & 15;
   $91 = (((gb + (145824) | 0) + ($$199101<<6)|0) + ($90<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $82 | $92;
   $94 = $77 >>> $88;
   $95 = $94 & 15;
   $96 = (((gb + (146080) | 0) + ($$199101<<6)|0) + ($95<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = $87 | $97;
   $99 = (($$1102) + -7)|0;
   $100 = (($$199101) + 1)|0;
   $exitcond = ($100|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $$0104 = $98;$$093103 = $93;$$1102 = $99;$$199101 = $100;
   }
  }
  $101 = (($1) + ($$0100105<<2)|0);
  HEAP32[$101>>2] = $93;
  $102 = (((($1)) + 64|0) + ($$0100105<<2)|0);
  HEAP32[$102>>2] = $98;
  $103 = (($$0100105) + 1)|0;
  $exitcond114 = ($103|0)==(16);
  if ($exitcond114) {
   break;
  } else {
   $$0100105 = $103;$$096106 = $70;
  }
 }
 return;
}
function ___do_des($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0104122 = 0, $$0105121 = 0, $$0106120 = 0, $$0108135 = 0, $$0111127 = 0, $$0112126 = 0, $$0113125 = 0, $$0114134 = 0, $$0115133 = 0, $$0116132 = 0, $$0123 = 0, $$1 = 0, $$1117 = 0, $$2$lcssa = 0, $$2118$lcssa = 0, $$2118129 = 0, $$2130 = 0, $$3119124 = 0, $$3128 = 0, $$3128$phi = 0;
 var $$in = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond140 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = $1 | $0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$1 = 0;$$1117 = 0;
 } else {
  $$0108135 = 0;$$0114134 = 28;$$0115133 = 0;$$0116132 = 0;
  while(1) {
   $9 = $0 >>> $$0114134;
   $10 = $9 & 15;
   $11 = (((gb + (146336) | 0) + ($$0115133<<6)|0) + ($10<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($$0115133) + 8)|0;
   $14 = $1 >>> $$0114134;
   $15 = $14 & 15;
   $16 = (((gb + (146336) | 0) + ($13<<6)|0) + ($15<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $12 | $$0108135;
   $19 = $18 | $17;
   $20 = (((gb + (147360) | 0) + ($$0115133<<6)|0) + ($10<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (((gb + (147360) | 0) + ($13<<6)|0) + ($15<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $21 | $$0116132;
   $25 = $24 | $23;
   $26 = (($$0115133) + 1)|0;
   $27 = (($$0114134) + -4)|0;
   $exitcond140 = ($26|0)==(8);
   if ($exitcond140) {
    $$1 = $19;$$1117 = $25;
    break;
   } else {
    $$0108135 = $19;$$0114134 = $27;$$0115133 = $26;$$0116132 = $25;
   }
  }
 }
 $28 = ($4|0)==(0);
 if ($28) {
  $$2$lcssa = $$1;$$2118$lcssa = $$1117;
 } else {
  $29 = ((($6)) + 64|0);
  $$2118129 = $$1117;$$2130 = $$1;$$in = $4;
  while(1) {
   $$0111127 = $29;$$0112126 = $6;$$0113125 = 16;$$3119124 = $$2118129;$$3128 = $$2130;
   while(1) {
    $30 = (($$0113125) + -1)|0;
    $31 = $$3119124 << 23;
    $32 = $31 & 8388608;
    $33 = $$3119124 >>> 9;
    $34 = $33 & 8126464;
    $35 = $32 | $34;
    $36 = $$3119124 >>> 11;
    $37 = $36 & 258048;
    $38 = $35 | $37;
    $39 = $$3119124 >>> 13;
    $40 = $39 & 4032;
    $41 = $38 | $40;
    $42 = $$3119124 >>> 15;
    $43 = $42 & 63;
    $44 = $41 | $43;
    $45 = $$3119124 << 7;
    $46 = $45 & 16515072;
    $47 = $$3119124 << 5;
    $48 = $47 & 258048;
    $49 = $$3119124 << 3;
    $50 = $49 & 4032;
    $51 = $$3119124 << 1;
    $52 = $51 & 62;
    $53 = $$3119124 >>> 31;
    $54 = $48 | $53;
    $55 = $54 | $46;
    $56 = $55 | $50;
    $57 = $56 | $52;
    $58 = $44 ^ $57;
    $59 = $58 & $5;
    $60 = ((($$0112126)) + 4|0);
    $61 = HEAP32[$$0112126>>2]|0;
    $62 = $59 ^ $44;
    $63 = $62 ^ $61;
    $64 = ((($$0111127)) + 4|0);
    $65 = HEAP32[$$0111127>>2]|0;
    $66 = $59 ^ $57;
    $67 = $66 ^ $65;
    $68 = $63 >>> 18;
    $69 = ((gb + (148384) | 0) + ($68<<2)|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = $63 >>> 12;
    $72 = $71 & 63;
    $73 = ((((gb + (148384) | 0)) + 256|0) + ($72<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = $74 | $70;
    $76 = $63 >>> 6;
    $77 = $76 & 63;
    $78 = ((((gb + (148384) | 0)) + 512|0) + ($77<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = $75 | $79;
    $81 = $63 & 63;
    $82 = ((((gb + (148384) | 0)) + 768|0) + ($81<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = $80 | $83;
    $85 = $67 >>> 18;
    $86 = ((((gb + (148384) | 0)) + 1024|0) + ($85<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = $84 | $87;
    $89 = $67 >>> 12;
    $90 = $89 & 63;
    $91 = ((((gb + (148384) | 0)) + 1280|0) + ($90<<2)|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = $88 | $92;
    $94 = $67 >>> 6;
    $95 = $94 & 63;
    $96 = ((((gb + (148384) | 0)) + 1536|0) + ($95<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = $93 | $97;
    $99 = $67 & 63;
    $100 = ((((gb + (148384) | 0)) + 1792|0) + ($99<<2)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $98 | $101;
    $103 = $102 ^ $$3128;
    $104 = ($30|0)==(0);
    if ($104) {
     break;
    } else {
     $$3128$phi = $$3119124;$$0111127 = $64;$$0112126 = $60;$$0113125 = $30;$$3119124 = $103;$$3128 = $$3128$phi;
    }
   }
   $105 = (($$in) + -1)|0;
   $106 = ($105|0)==(0);
   if ($106) {
    $$2$lcssa = $103;$$2118$lcssa = $$3119124;
    break;
   } else {
    $$2118129 = $$3119124;$$2130 = $103;$$in = $105;
   }
  }
 }
 $$0104122 = 0;$$0105121 = 28;$$0106120 = 0;$$0123 = 0;
 while(1) {
  $107 = $$2$lcssa >>> $$0105121;
  $108 = $107 & 15;
  $109 = (((gb + (150432) | 0) + ($$0106120<<6)|0) + ($108<<2)|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($$0106120) + 4)|0;
  $112 = $$2118$lcssa >>> $$0105121;
  $113 = $112 & 15;
  $114 = (((gb + (150432) | 0) + ($111<<6)|0) + ($113<<2)|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = $110 | $$0123;
  $117 = $116 | $115;
  $118 = (($$0105121) + -4)|0;
  $119 = $$2$lcssa >>> $118;
  $120 = $119 & 15;
  $121 = (((gb + (150432) | 0) + ($$0106120<<6)|0) + ($120<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = $$2118$lcssa >>> $118;
  $124 = $123 & 15;
  $125 = (((gb + (150432) | 0) + ($111<<6)|0) + ($124<<2)|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = $122 | $$0104122;
  $128 = $127 | $126;
  $129 = (($$0106120) + 1)|0;
  $130 = (($$0105121) + -8)|0;
  $exitcond = ($129|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$0104122 = $128;$$0105121 = $130;$$0106120 = $129;$$0123 = $117;
  }
 }
 HEAP32[$2>>2] = $128;
 HEAP32[$3>>2] = $117;
 return;
}
function ___crypt_des($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$023 = 0, $$024 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($4<<24>>24)==(95);
 $$023 = $5 ? (gb + (167089) | 0) : (gb + (167099) | 0);
 $6 = (__crypt_extended_r_uut($0,$1,$2)|0);
 $7 = (__crypt_extended_r_uut((gb + (167102) | 0),$$023,$3)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 3;
 } else {
  $$024 = $5 ? (gb + (167123) | 0) : (gb + (167144) | 0);
  $9 = (_strcmp($7,$$024)|0);
  $10 = ($9|0)==(0);
  $11 = ($6|0)!=(0|0);
  $or$cond = $11 & $10;
  if ($or$cond) {
   $$0 = $6;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $12 = HEAP8[$1>>0]|0;
  $13 = ($12<<24>>24)==(42);
  $14 = $13 ? (gb + (167158) | 0) : (gb + (167222) | 0);
  $$0 = $14;
 }
 STACKTOP = sp;return ($$0|0);
}
function __crypt_extended_r_uut($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0101123 = 0, $$0103 = 0, $$0104120 = 0, $$0107122 = 0, $$0110124 = 0, $$097125 = 0, $$1102121 = 0, $$1111117 = 0, $$2106 = 0, $$2109 = 0, $$299119 = 0, $$3100$lcssa = 0, $$3100118 = 0, $$4 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $3 = sp + 8|0;
 $4 = sp + 136|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = ((($4)) + 7|0);
 $$0110124 = $4;$$097125 = $0;
 while(1) {
  $8 = HEAP8[$$097125>>0]|0;
  $9 = $8&255;
  $10 = $9 << 1;
  $11 = $10&255;
  $12 = ((($$0110124)) + 1|0);
  HEAP8[$$0110124>>0] = $11;
  $13 = HEAP8[$$097125>>0]|0;
  $14 = ($13<<24>>24)==(0);
  $15 = ((($$097125)) + 1|0);
  $spec$select = $14 ? $$097125 : $15;
  $16 = ($12>>>0)>($7>>>0);
  if ($16) {
   break;
  } else {
   $$0110124 = $12;$$097125 = $spec$select;
  }
 }
 ___des_setkey($4,$3);
 $17 = HEAP8[$1>>0]|0;
 $18 = ($17<<24>>24)==(95);
 L4: do {
  if ($18) {
   $$0101123 = 1;$$0107122 = 0;
   while(1) {
    $19 = (($1) + ($$0101123)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = (_ascii_to_bin($21)|0);
    $23 = ((gb + (152352) | 0) + ($22)|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==($20<<24>>24);
    if (!($25)) {
     $$4 = 0;
     break L4;
    }
    $26 = ($$0101123*6)|0;
    $27 = (($26) + -6)|0;
    $28 = $22 << $27;
    $29 = $28 | $$0107122;
    $30 = (($$0101123) + 1)|0;
    $31 = ($30>>>0)<(5);
    if ($31) {
     $$0101123 = $30;$$0107122 = $29;
    } else {
     break;
    }
   }
   $32 = ($29|0)==(0);
   if ($32) {
    $$4 = 0;
   } else {
    $$0104120 = 0;$$1102121 = 5;
    while(1) {
     $33 = (($1) + ($$1102121)|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = $34&255;
     $36 = (_ascii_to_bin($35)|0);
     $37 = ((gb + (152352) | 0) + ($36)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = ($38<<24>>24)==($34<<24>>24);
     if (!($39)) {
      $$4 = 0;
      break L4;
     }
     $40 = ($$1102121*6)|0;
     $41 = (($40) + -30)|0;
     $42 = $36 << $41;
     $43 = $42 | $$0104120;
     $44 = (($$1102121) + 1)|0;
     $45 = ($44>>>0)<(9);
     if ($45) {
      $$0104120 = $43;$$1102121 = $44;
     } else {
      break;
     }
    }
    $46 = HEAP8[$spec$select>>0]|0;
    $47 = ($46<<24>>24)==(0);
    if (!($47)) {
     $$299119 = $spec$select;
     while(1) {
      _des_cipher($4,$4,$3);
      $$1111117 = $4;$$3100118 = $$299119;
      while(1) {
       $48 = HEAP8[$$3100118>>0]|0;
       $49 = ($48<<24>>24)==(0);
       if ($49) {
        $$3100$lcssa = $$3100118;
        break;
       }
       $50 = $48&255;
       $51 = ((($$3100118)) + 1|0);
       $52 = $50 << 1;
       $53 = ((($$1111117)) + 1|0);
       $54 = HEAP8[$$1111117>>0]|0;
       $55 = $54&255;
       $56 = $52 ^ $55;
       $57 = $56&255;
       HEAP8[$$1111117>>0] = $57;
       $58 = ($53>>>0)>($7>>>0);
       if ($58) {
        $$3100$lcssa = $51;
        break;
       } else {
        $$1111117 = $53;$$3100118 = $51;
       }
      }
      ___des_setkey($4,$3);
      $59 = HEAP8[$$3100$lcssa>>0]|0;
      $60 = ($59<<24>>24)==(0);
      if ($60) {
       break;
      } else {
       $$299119 = $$3100$lcssa;
      }
     }
    }
    (_memcpy(($2|0),($1|0),9)|0);
    $61 = ((($2)) + 9|0);
    HEAP8[$61>>0] = 0;
    $$0103 = $61;$$2106 = $43;$$2109 = $29;
    label = 21;
   }
  } else {
   $62 = (_ascii_is_unsafe($17)|0);
   $63 = ($62|0)==(0);
   if ($63) {
    $64 = ((($1)) + 1|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = (_ascii_is_unsafe($65)|0);
    $67 = ($66|0)==(0);
    if ($67) {
     $68 = $65&255;
     $69 = (_ascii_to_bin($68)|0);
     $70 = $69 << 6;
     $71 = $17&255;
     $72 = (_ascii_to_bin($71)|0);
     $73 = $70 | $72;
     HEAP8[$2>>0] = $17;
     $74 = HEAP8[$64>>0]|0;
     $75 = ((($2)) + 1|0);
     HEAP8[$75>>0] = $74;
     $76 = ((($2)) + 2|0);
     $$0103 = $76;$$2106 = $73;$$2109 = 25;
     label = 21;
    } else {
     $$4 = 0;
    }
   } else {
    $$4 = 0;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $77 = (_setup_salt($$2106)|0);
  ___do_des(0,0,$5,$6,$$2109,$77,$3);
  $78 = HEAP32[$5>>2]|0;
  $79 = $78 >>> 8;
  $80 = $78 >>> 26;
  $81 = ((gb + (152352) | 0) + ($80)|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ((($$0103)) + 1|0);
  HEAP8[$$0103>>0] = $82;
  $84 = $78 >>> 20;
  $85 = $84 & 63;
  $86 = ((gb + (152352) | 0) + ($85)|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ((($$0103)) + 2|0);
  HEAP8[$83>>0] = $87;
  $89 = $78 >>> 14;
  $90 = $89 & 63;
  $91 = ((gb + (152352) | 0) + ($90)|0);
  $92 = HEAP8[$91>>0]|0;
  $93 = ((($$0103)) + 3|0);
  HEAP8[$88>>0] = $92;
  $94 = $79 & 63;
  $95 = ((gb + (152352) | 0) + ($94)|0);
  $96 = HEAP8[$95>>0]|0;
  $97 = ((($$0103)) + 4|0);
  HEAP8[$93>>0] = $96;
  $98 = $78 << 16;
  $99 = HEAP32[$6>>2]|0;
  $100 = $99 >>> 16;
  $101 = $100 | $98;
  $102 = $78 >>> 2;
  $103 = $102 & 63;
  $104 = ((gb + (152352) | 0) + ($103)|0);
  $105 = HEAP8[$104>>0]|0;
  $106 = ((($$0103)) + 5|0);
  HEAP8[$97>>0] = $105;
  $107 = $101 >>> 12;
  $108 = $107 & 63;
  $109 = ((gb + (152352) | 0) + ($108)|0);
  $110 = HEAP8[$109>>0]|0;
  $111 = ((($$0103)) + 6|0);
  HEAP8[$106>>0] = $110;
  $112 = $99 >>> 22;
  $113 = $112 & 63;
  $114 = ((gb + (152352) | 0) + ($113)|0);
  $115 = HEAP8[$114>>0]|0;
  $116 = ((($$0103)) + 7|0);
  HEAP8[$111>>0] = $115;
  $117 = $100 & 63;
  $118 = ((gb + (152352) | 0) + ($117)|0);
  $119 = HEAP8[$118>>0]|0;
  $120 = ((($$0103)) + 8|0);
  HEAP8[$116>>0] = $119;
  $121 = $99 << 2;
  $122 = $99 >>> 10;
  $123 = $122 & 63;
  $124 = ((gb + (152352) | 0) + ($123)|0);
  $125 = HEAP8[$124>>0]|0;
  $126 = ((($$0103)) + 9|0);
  HEAP8[$120>>0] = $125;
  $127 = $99 >>> 4;
  $128 = $127 & 63;
  $129 = ((gb + (152352) | 0) + ($128)|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ((($$0103)) + 10|0);
  HEAP8[$126>>0] = $130;
  $132 = $121 & 60;
  $133 = ((gb + (152352) | 0) + ($132)|0);
  $134 = HEAP8[$133>>0]|0;
  $135 = ((($$0103)) + 11|0);
  HEAP8[$131>>0] = $134;
  HEAP8[$135>>0] = 0;
  $$4 = $2;
 }
 STACKTOP = sp;return ($$4|0);
}
function _ascii_to_bin($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $spec$select$v = 0, $spec$select12 = 0, $spec$select12$v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)<(128);
 $2 = (($0) + -256)|0;
 $3 = $1 ? $0 : $2;
 $4 = ($3|0)>(64);
 $5 = ($3|0)>(96);
 $spec$select$v = $5 ? 5 : 11;
 $spec$select12$v = $4 ? $spec$select$v : 18;
 $spec$select12 = (($spec$select12$v) + ($3))|0;
 $6 = $spec$select12 & 63;
 return ($6|0);
}
function _des_cipher($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = ((($0)) + 3|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ((($0)) + 2|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 8;
 $12 = $11 | $7;
 $13 = ((($0)) + 1|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 16;
 $17 = $12 | $16;
 $18 = HEAP8[$0>>0]|0;
 $19 = $18&255;
 $20 = $19 << 24;
 $21 = $17 | $20;
 $22 = ((($0)) + 7|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = ((($0)) + 6|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $27 << 8;
 $29 = $28 | $24;
 $30 = ((($0)) + 5|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31&255;
 $33 = $32 << 16;
 $34 = $29 | $33;
 $35 = ((($0)) + 4|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = $36&255;
 $38 = $37 << 24;
 $39 = $34 | $38;
 ___do_des($21,$39,$3,$4,1,0,$2);
 $40 = HEAP32[$3>>2]|0;
 $41 = $40 >>> 24;
 $42 = $41&255;
 HEAP8[$1>>0] = $42;
 $43 = $40 >>> 16;
 $44 = $43&255;
 $45 = ((($1)) + 1|0);
 HEAP8[$45>>0] = $44;
 $46 = $40 >>> 8;
 $47 = $46&255;
 $48 = ((($1)) + 2|0);
 HEAP8[$48>>0] = $47;
 $49 = $40&255;
 $50 = ((($1)) + 3|0);
 HEAP8[$50>>0] = $49;
 $51 = HEAP32[$4>>2]|0;
 $52 = $51 >>> 24;
 $53 = $52&255;
 $54 = ((($1)) + 4|0);
 HEAP8[$54>>0] = $53;
 $55 = $51 >>> 16;
 $56 = $55&255;
 $57 = ((($1)) + 5|0);
 HEAP8[$57>>0] = $56;
 $58 = $51 >>> 8;
 $59 = $58&255;
 $60 = ((($1)) + 6|0);
 HEAP8[$60>>0] = $59;
 $61 = $51&255;
 $62 = ((($1)) + 7|0);
 HEAP8[$62>>0] = $61;
 STACKTOP = sp;return;
}
function _ascii_is_unsafe($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($0<<24>>24) {
 case 10: case 0:  {
  $2 = 1;
  break;
 }
 default: {
  $1 = ($0<<24>>24)==(58);
  $phitmp = $1&1;
  $2 = $phitmp;
 }
 }
 return ($2|0);
}
function _setup_salt($0) {
 $0 = $0|0;
 var $$01621 = 0, $$01720 = 0, $$01819 = 0, $$022 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$01621 = 0;$$01720 = 1;$$01819 = 8388608;$$022 = 0;
 while(1) {
  $1 = $$01720 & $0;
  $2 = ($1|0)==(0);
  $3 = $2 ? 0 : $$01819;
  $spec$select = $3 | $$01621;
  $4 = $$01720 << 1;
  $5 = $$01819 >>> 1;
  $6 = (($$022) + 1)|0;
  $exitcond = ($6|0)==(24);
  if ($exitcond) {
   break;
  } else {
   $$01621 = $spec$select;$$01720 = $4;$$01819 = $5;$$022 = $6;
  }
 }
 return ($spec$select|0);
}
function ___crypt_sha256($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 $4 = (_sha256crypt($0,$1,$2)|0);
 $5 = (_sha256crypt((gb + (150944) | 0),(gb + (150976) | 0),$3)|0);
 $6 = ($4|0)!=(0|0);
 $7 = ($5|0)==($3|0);
 $or$cond = $6 & $7;
 if ($or$cond) {
  $8 = (_memcmp($3,(gb + (151008) | 0),73)|0);
  $9 = ($8|0)==(0);
  $spec$select = $9 ? $4 : (gb + (167222) | 0);
  $$0 = $spec$select;
 } else {
  $$0 = (gb + (167222) | 0);
 }
 STACKTOP = sp;return ($$0|0);
}
function _sha256crypt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$08999 = 0, $$092$lcssa = 0, $$092109 = 0, $$094 = 0, $$1 = 0, $$191 = 0, $$193106 = 0, $$2102 = 0, $$296 = 0, $$3101 = 0, $$4100 = 0, $$598 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $exitcond = 0, $exitcond110 = 0, $exitcond111 = 0, $exitcond112 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0;
 var $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $vararg_buffer1 = sp + 240|0;
 $vararg_buffer = sp + 232|0;
 $3 = sp + 128|0;
 $4 = sp + 96|0;
 $5 = sp + 64|0;
 $6 = sp + 32|0;
 $7 = sp;
 $8 = sp + 252|0;
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;
 $9 = (_strnlen($0,257)|0);
 $10 = ($9>>>0)>(256);
 L1: do {
  if ($10) {
   $$1 = 0;
  } else {
   $11 = (_strncmp($1,(gb + (167160) | 0),3)|0);
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = ((($1)) + 3|0);
    $14 = (_strncmp($13,(gb + (167179) | 0),7)|0);
    $15 = ($14|0)==(0);
    L4: do {
     if ($15) {
      $16 = ((($1)) + 10|0);
      $17 = HEAP8[$16>>0]|0;
      $18 = $17 << 24 >> 24;
      $19 = (_isdigit($18)|0);
      $20 = ($19|0)==(0);
      do {
       if (!($20)) {
        $21 = (_strtoul($16,$8,10)|0);
        $22 = HEAP32[$8>>2]|0;
        $23 = HEAP8[$22>>0]|0;
        $24 = ($23<<24>>24)==(36);
        if ($24) {
         $25 = ((($22)) + 1|0);
         $26 = ($21>>>0)<(1000);
         if ($26) {
          $$094 = 1000;
         } else {
          $27 = ($21>>>0)>(9999999);
          if ($27) {
           break;
          } else {
           $$094 = $21;
          }
         }
         HEAP32[$vararg_buffer>>2] = $$094;
         (_sprintf($7,(gb + (167187) | 0),$vararg_buffer)|0);
         $$191 = $25;$$296 = $$094;
         break L4;
        }
       }
      } while(0);
      $$1 = 0;
      break L1;
     } else {
      $$191 = $13;$$296 = 5000;
     }
    } while(0);
    $$092109 = 0;
    L14: while(1) {
     $28 = (($$191) + ($$092109)|0);
     $29 = HEAP8[$28>>0]|0;
     switch ($29<<24>>24) {
     case 58: case 10:  {
      $$1 = 0;
      break L1;
      break;
     }
     case 36: case 0:  {
      $$092$lcssa = $$092109;
      break L14;
      break;
     }
     default: {
     }
     }
     $30 = (($$092109) + 1)|0;
     $31 = ($30>>>0)<(16);
     if ($31) {
      $$092109 = $30;
     } else {
      $$092$lcssa = 16;
      break;
     }
    }
    _sha256_init($3);
    _sha256_update($3,$0,$9);
    _sha256_update($3,$$191,$$092$lcssa);
    _sha256_update($3,$0,$9);
    _sha256_sum($3,$4);
    _sha256_init($3);
    _sha256_update($3,$0,$9);
    _sha256_update($3,$$191,$$092$lcssa);
    _hashmd($3,$9,$4);
    $32 = ($9|0)==(0);
    if ($32) {
     _sha256_sum($3,$4);
     _sha256_init($3);
    } else {
     $$193106 = $9;
     while(1) {
      $33 = $$193106 & 1;
      $34 = ($33|0)==(0);
      if ($34) {
       _sha256_update($3,$0,$9);
      } else {
       _sha256_update($3,$4,32);
      }
      $35 = $$193106 >>> 1;
      $36 = ($35|0)==(0);
      if ($36) {
       break;
      } else {
       $$193106 = $35;
      }
     }
     _sha256_sum($3,$4);
     _sha256_init($3);
     if (!($32)) {
      $$2102 = 0;
      while(1) {
       _sha256_update($3,$0,$9);
       $37 = (($$2102) + 1)|0;
       $exitcond112 = ($37|0)==($9|0);
       if ($exitcond112) {
        break;
       } else {
        $$2102 = $37;
       }
      }
     }
    }
    _sha256_sum($3,$5);
    _sha256_init($3);
    $38 = HEAP8[$4>>0]|0;
    $39 = $38&255;
    $40 = (($39) + 15)|0;
    $$3101 = 0;
    while(1) {
     _sha256_update($3,$$191,$$092$lcssa);
     $41 = (($$3101) + 1)|0;
     $exitcond111 = ($$3101|0)==($40|0);
     if ($exitcond111) {
      break;
     } else {
      $$3101 = $41;
     }
    }
    _sha256_sum($3,$6);
    $42 = ($$296|0)==(0);
    if (!($42)) {
     $$4100 = 0;
     while(1) {
      _sha256_init($3);
      $43 = $$4100 & 1;
      $44 = ($43|0)!=(0);
      if ($44) {
       _hashmd($3,$9,$5);
      } else {
       _sha256_update($3,$4,32);
      }
      $45 = (($$4100>>>0) % 3)&-1;
      $46 = ($45|0)==(0);
      if (!($46)) {
       _sha256_update($3,$6,$$092$lcssa);
      }
      $47 = (($$4100>>>0) % 7)&-1;
      $48 = ($47|0)==(0);
      if (!($48)) {
       _hashmd($3,$9,$5);
      }
      if ($44) {
       _sha256_update($3,$4,32);
      } else {
       _hashmd($3,$9,$5);
      }
      _sha256_sum($3,$4);
      $49 = (($$4100) + 1)|0;
      $exitcond110 = ($49|0)==($$296|0);
      if ($exitcond110) {
       break;
      } else {
       $$4100 = $49;
      }
     }
    }
    HEAP32[$vararg_buffer1>>2] = $7;
    $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
    HEAP32[$vararg_ptr4>>2] = $$092$lcssa;
    $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
    HEAP32[$vararg_ptr5>>2] = $$191;
    $50 = (_sprintf($2,(gb + (167164) | 0),$vararg_buffer1)|0);
    $51 = (($2) + ($50)|0);
    $$08999 = $51;$$598 = 0;
    while(1) {
     $52 = ((gb + (151088) | 0) + (($$598*3)|0)|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53&255;
     $55 = (($4) + ($54)|0);
     $56 = HEAP8[$55>>0]|0;
     $57 = $56&255;
     $58 = $57 << 16;
     $59 = ((((gb + (151088) | 0) + (($$598*3)|0)|0)) + 1|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = (($4) + ($61)|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = $63&255;
     $65 = $64 << 8;
     $66 = $65 | $58;
     $67 = ((((gb + (151088) | 0) + (($$598*3)|0)|0)) + 2|0);
     $68 = HEAP8[$67>>0]|0;
     $69 = $68&255;
     $70 = (($4) + ($69)|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = $71&255;
     $73 = $66 | $72;
     $74 = (_to64($$08999,$73,4)|0);
     $75 = (($$598) + 1)|0;
     $exitcond = ($75|0)==(10);
     if ($exitcond) {
      break;
     } else {
      $$08999 = $74;$$598 = $75;
     }
    }
    $76 = ((($4)) + 31|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = $77&255;
    $79 = $78 << 8;
    $80 = ((($4)) + 30|0);
    $81 = HEAP8[$80>>0]|0;
    $82 = $81&255;
    $83 = $79 | $82;
    $84 = (_to64($74,$83,3)|0);
    HEAP8[$84>>0] = 0;
    $$1 = $2;
   } else {
    $$1 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _sha256_init($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = 1779033703;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = -1150833019;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = 1013904242;
 $8 = ((($0)) + 20|0);
 HEAP32[$8>>2] = -1521486534;
 $9 = ((($0)) + 24|0);
 HEAP32[$9>>2] = 1359893119;
 $10 = ((($0)) + 28|0);
 HEAP32[$10>>2] = -1694144372;
 $11 = ((($0)) + 32|0);
 HEAP32[$11>>2] = 528734635;
 $12 = ((($0)) + 36|0);
 HEAP32[$12>>2] = 1541459225;
 return;
}
function _sha256_update($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$027 = 0, $$1$lcssa = 0, $$128$lcssa = 0, $$12829 = 0, $$130 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5 & 63;
 $10 = (_i64Add(($5|0),($8|0),($2|0),0)|0);
 $11 = (getTempRet0() | 0);
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $10;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = ($9|0)==(0);
 do {
  if ($16) {
   $$0 = $2;$$027 = $1;
   label = 5;
  } else {
   $17 = (64 - ($9))|0;
   $18 = ($17>>>0)>($2>>>0);
   $19 = (((($0)) + 40|0) + ($9)|0);
   if ($18) {
    (_memcpy(($19|0),($1|0),($2|0))|0);
    break;
   } else {
    $20 = ((($0)) + 40|0);
    (_memcpy(($19|0),($1|0),($17|0))|0);
    $21 = (($2) - ($17))|0;
    $22 = (($1) + ($17)|0);
    _processblock($0,$20);
    $$0 = $21;$$027 = $22;
    label = 5;
    break;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $23 = ($$0>>>0)>(63);
  if ($23) {
   $24 = (($$0) + -64)|0;
   $25 = $24 & -64;
   $26 = (($25) + 64)|0;
   $$12829 = $$027;$$130 = $$0;
   while(1) {
    _processblock($0,$$12829);
    $27 = (($$130) + -64)|0;
    $28 = ((($$12829)) + 64|0);
    $29 = ($27>>>0)>(63);
    if ($29) {
     $$12829 = $28;$$130 = $27;
    } else {
     break;
    }
   }
   $30 = (($24) - ($25))|0;
   $scevgep = (($$027) + ($26)|0);
   $$1$lcssa = $30;$$128$lcssa = $scevgep;
  } else {
   $$1$lcssa = $$0;$$128$lcssa = $$027;
  }
  $31 = ((($0)) + 40|0);
  (_memcpy(($31|0),($$128$lcssa|0),($$1$lcssa|0))|0);
 }
 return;
}
function _sha256_sum($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _pad($0);
 $$019 = 0;
 while(1) {
  $2 = (((($0)) + 8|0) + ($$019<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 >>> 24;
  $5 = $4&255;
  $6 = $$019 << 2;
  $7 = (($1) + ($6)|0);
  HEAP8[$7>>0] = $5;
  $8 = HEAP32[$2>>2]|0;
  $9 = $8 >>> 16;
  $10 = $9&255;
  $11 = $6 | 1;
  $12 = (($1) + ($11)|0);
  HEAP8[$12>>0] = $10;
  $13 = HEAP32[$2>>2]|0;
  $14 = $13 >>> 8;
  $15 = $14&255;
  $16 = $6 | 2;
  $17 = (($1) + ($16)|0);
  HEAP8[$17>>0] = $15;
  $18 = HEAP32[$2>>2]|0;
  $19 = $18&255;
  $20 = $6 | 3;
  $21 = (($1) + ($20)|0);
  HEAP8[$21>>0] = $19;
  $22 = (($$019) + 1)|0;
  $exitcond = ($22|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $$019 = $22;
  }
 }
 return;
}
function _hashmd($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$06 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(32);
 if ($3) {
  $4 = (($1) + -33)|0;
  $5 = $4 & -32;
  $$06 = $1;
  while(1) {
   _sha256_update($0,$2,32);
   $6 = (($$06) + -32)|0;
   $7 = ($6>>>0)>(32);
   if ($7) {
    $$06 = $6;
   } else {
    break;
   }
  }
  $8 = (($1) + -32)|0;
  $9 = (($8) - ($5))|0;
  $$0$lcssa = $9;
 } else {
  $$0$lcssa = $1;
 }
 _sha256_update($0,$2,$$0$lcssa);
 return;
}
function _to64($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$047 = 0, $$05$lcssa = 0, $$056 = 0, $$08 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)>(0);
 if ($3) {
  $$047 = $1;$$056 = $0;$$08 = $2;
  while(1) {
   $4 = (($$08) + -1)|0;
   $5 = $$047 & 63;
   $6 = ((gb + (152352) | 0) + ($5)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ((($$056)) + 1|0);
   HEAP8[$$056>>0] = $7;
   $9 = $$047 >>> 6;
   $10 = ($$08|0)>(1);
   if ($10) {
    $$047 = $9;$$056 = $8;$$08 = $4;
   } else {
    $$05$lcssa = $8;
    break;
   }
  }
 } else {
  $$05$lcssa = $0;
 }
 return ($$05$lcssa|0);
}
function _pad($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3 & 63;
 $8 = ((($0)) + 40|0);
 $9 = (($7) + 1)|0;
 $10 = (((($0)) + 40|0) + ($7)|0);
 HEAP8[$10>>0] = -128;
 $11 = ($7>>>0)>(55);
 if ($11) {
  $12 = $7 ^ 63;
  $13 = (((($0)) + 40|0) + ($9)|0);
  (_memset(($13|0),0,($12|0))|0);
  _processblock($0,$8);
  $$0 = 0;$$pre$phiZ2D = $8;
 } else {
  $$0 = $9;$$pre$phiZ2D = $8;
 }
 $14 = (((($0)) + 40|0) + ($$0)|0);
 $15 = (56 - ($$0))|0;
 (_memset(($14|0),0,($15|0))|0);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (_bitshift64Shl(($18|0),($21|0),3)|0);
 $23 = (getTempRet0() | 0);
 $24 = $0;
 $25 = $24;
 HEAP32[$25>>2] = $22;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = (_bitshift64Lshr(($18|0),($21|0),53)|0);
 $29 = (getTempRet0() | 0);
 $30 = $28&255;
 $31 = ((($0)) + 96|0);
 HEAP8[$31>>0] = $30;
 $32 = (_bitshift64Lshr(($18|0),($21|0),45)|0);
 $33 = (getTempRet0() | 0);
 $34 = $32&255;
 $35 = ((($0)) + 97|0);
 HEAP8[$35>>0] = $34;
 $36 = (_bitshift64Lshr(($18|0),($21|0),37)|0);
 $37 = (getTempRet0() | 0);
 $38 = $36&255;
 $39 = ((($0)) + 98|0);
 HEAP8[$39>>0] = $38;
 $40 = (_bitshift64Lshr(($18|0),($21|0),29)|0);
 $41 = (getTempRet0() | 0);
 $42 = $40&255;
 $43 = ((($0)) + 99|0);
 HEAP8[$43>>0] = $42;
 $44 = (_bitshift64Lshr(($18|0),($21|0),21)|0);
 $45 = (getTempRet0() | 0);
 $46 = $44&255;
 $47 = ((($0)) + 100|0);
 HEAP8[$47>>0] = $46;
 $48 = (_bitshift64Lshr(($18|0),($21|0),13)|0);
 $49 = (getTempRet0() | 0);
 $50 = $48&255;
 $51 = ((($0)) + 101|0);
 HEAP8[$51>>0] = $50;
 $52 = (_bitshift64Lshr(($18|0),($21|0),5)|0);
 $53 = (getTempRet0() | 0);
 $54 = $52&255;
 $55 = ((($0)) + 102|0);
 HEAP8[$55>>0] = $54;
 $56 = $22&255;
 $57 = ((($0)) + 103|0);
 HEAP8[$57>>0] = $56;
 _processblock($0,$$pre$phiZ2D);
 return;
}
function _processblock($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0100113 = 0, $$0100113$phi = 0, $$0101112 = 0, $$0101112$phi = 0, $$0102111 = 0, $$0103110 = 0, $$0103110$phi = 0, $$0104109 = 0, $$0104109$phi = 0, $$0105108 = 0, $$0105108$phi = 0, $$0106107 = 0, $$0117 = 0, $$099114 = 0, $$099114$phi = 0, $$1116 = 0, $$2115 = 0, $$pre = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond120 = 0, $exitcond121 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(256|0);
 $2 = sp;
 $$0117 = 0;
 while(1) {
  $3 = $$0117 << 2;
  $4 = (($1) + ($3)|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 << 24;
  $8 = (($2) + ($$0117<<2)|0);
  $9 = $3 | 1;
  $10 = (($1) + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = $12 << 16;
  $14 = $13 | $7;
  $15 = $3 | 2;
  $16 = (($1) + ($15)|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 << 8;
  $20 = $19 | $14;
  $21 = $3 | 3;
  $22 = (($1) + ($21)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = $20 | $24;
  HEAP32[$8>>2] = $25;
  $26 = (($$0117) + 1)|0;
  $exitcond121 = ($26|0)==(16);
  if ($exitcond121) {
   break;
  } else {
   $$0117 = $26;
  }
 }
 $$pre = HEAP32[$2>>2]|0;
 $$1116 = 16;$48 = $$pre;
 while(1) {
  $27 = (($$1116) + -2)|0;
  $28 = (($2) + ($27<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (_ror($29,17)|0);
  $31 = (_ror($29,19)|0);
  $32 = $29 >>> 10;
  $33 = $32 ^ $30;
  $34 = $33 ^ $31;
  $35 = (($$1116) + -7)|0;
  $36 = (($2) + ($35<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($34) + ($37))|0;
  $39 = (($$1116) + -15)|0;
  $40 = (($2) + ($39<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (_ror($41,7)|0);
  $43 = (_ror($41,18)|0);
  $44 = $41 >>> 3;
  $45 = $44 ^ $42;
  $46 = $45 ^ $43;
  $47 = (($38) + ($48))|0;
  $49 = (($47) + ($46))|0;
  $50 = (($2) + ($$1116<<2)|0);
  HEAP32[$50>>2] = $49;
  $51 = (($$1116) + 1)|0;
  $exitcond120 = ($51|0)==(64);
  if ($exitcond120) {
   break;
  } else {
   $$1116 = $51;$48 = $41;
  }
 }
 $52 = ((($0)) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($0)) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ((($0)) + 16|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ((($0)) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($0)) + 24|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ((($0)) + 28|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ((($0)) + 32|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($0)) + 36|0);
 $67 = HEAP32[$66>>2]|0;
 $$0100113 = $65;$$0101112 = $63;$$0102111 = $61;$$0103110 = $59;$$0104109 = $57;$$0105108 = $55;$$0106107 = $53;$$099114 = $67;$$2115 = 0;
 while(1) {
  $68 = (_ror($$0102111,6)|0);
  $69 = (_ror($$0102111,11)|0);
  $70 = $69 ^ $68;
  $71 = (_ror($$0102111,25)|0);
  $72 = $70 ^ $71;
  $73 = $$0100113 ^ $$0101112;
  $74 = $73 & $$0102111;
  $75 = $74 ^ $$0100113;
  $76 = ((gb + (151120) | 0) + ($$2115<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($2) + ($$2115<<2)|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($75) + ($$099114))|0;
  $81 = (($80) + ($72))|0;
  $82 = (($81) + ($77))|0;
  $83 = (($82) + ($79))|0;
  $84 = (_ror($$0106107,2)|0);
  $85 = (_ror($$0106107,13)|0);
  $86 = $85 ^ $84;
  $87 = (_ror($$0106107,22)|0);
  $88 = $86 ^ $87;
  $89 = $$0105108 & $$0106107;
  $90 = $$0105108 | $$0106107;
  $91 = $$0104109 & $90;
  $92 = $91 | $89;
  $93 = (($83) + ($$0103110))|0;
  $94 = (($83) + ($92))|0;
  $95 = (($94) + ($88))|0;
  $96 = (($$2115) + 1)|0;
  $exitcond = ($96|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $$099114$phi = $$0100113;$$0105108$phi = $$0106107;$$0104109$phi = $$0105108;$$0103110$phi = $$0104109;$$0101112$phi = $$0102111;$$0100113$phi = $$0101112;$$0102111 = $93;$$0106107 = $95;$$2115 = $96;$$099114 = $$099114$phi;$$0105108 = $$0105108$phi;$$0104109 = $$0104109$phi;$$0103110 = $$0103110$phi;$$0101112 = $$0101112$phi;$$0100113 = $$0100113$phi;
  }
 }
 $97 = (($95) + ($53))|0;
 HEAP32[$52>>2] = $97;
 $98 = (($$0106107) + ($55))|0;
 HEAP32[$54>>2] = $98;
 $99 = (($$0105108) + ($57))|0;
 HEAP32[$56>>2] = $99;
 $100 = (($$0104109) + ($59))|0;
 HEAP32[$58>>2] = $100;
 $101 = (($93) + ($61))|0;
 HEAP32[$60>>2] = $101;
 $102 = (($$0102111) + ($63))|0;
 HEAP32[$62>>2] = $102;
 $103 = (($$0101112) + ($65))|0;
 HEAP32[$64>>2] = $103;
 $104 = (($$0100113) + ($67))|0;
 HEAP32[$66>>2] = $104;
 STACKTOP = sp;return;
}
function _ror($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 >>> $1;
 $3 = (32 - ($1))|0;
 $4 = $0 << $3;
 $5 = $4 | $2;
 return ($5|0);
}
function ___crypt_sha512($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 $4 = (_sha512crypt($0,$1,$2)|0);
 $5 = (_sha512crypt((gb + (151376) | 0),(gb + (151408) | 0),$3)|0);
 $6 = ($4|0)!=(0|0);
 $7 = ($5|0)==($3|0);
 $or$cond = $6 & $7;
 if ($or$cond) {
  $8 = (_memcmp($3,(gb + (151440) | 0),116)|0);
  $9 = ($8|0)==(0);
  $spec$select = $9 ? $4 : (gb + (167222) | 0);
  $$0 = $spec$select;
 } else {
  $$0 = (gb + (167222) | 0);
 }
 STACKTOP = sp;return ($$0|0);
}
function _sha512crypt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$094106 = 0, $$097117 = 0, $$099 = 0, $$1 = 0, $$196 = 0, $$198$lcssa = 0, $$198116 = 0, $$2101 = 0, $$2113 = 0, $$3109 = 0, $$4108 = 0, $$5107 = 0, $$6105 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $exitcond = 0, $exitcond120 = 0, $exitcond121 = 0, $exitcond122 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0;
 var $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(448|0);
 $vararg_buffer1 = sp + 432|0;
 $vararg_buffer = sp + 424|0;
 $3 = sp + 224|0;
 $4 = sp + 160|0;
 $5 = sp + 96|0;
 $6 = sp + 32|0;
 $7 = sp;
 $8 = sp + 444|0;
 ;HEAP32[$7>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;
 $$097117 = 0;
 while(1) {
  $9 = (($0) + ($$097117)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   label = 4;
   break;
  }
  $12 = (($$097117) + 1)|0;
  $13 = ($12>>>0)<(257);
  if ($13) {
   $$097117 = $12;
  } else {
   $$1 = 0;
   break;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $14 = (_strncmp($1,(gb + (167175) | 0),3)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = ((($1)) + 3|0);
    $17 = (_strncmp($16,(gb + (167179) | 0),7)|0);
    $18 = ($17|0)==(0);
    L7: do {
     if ($18) {
      $19 = ((($1)) + 10|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = $20 << 24 >> 24;
      $22 = (_isdigit($21)|0);
      $23 = ($22|0)==(0);
      do {
       if (!($23)) {
        $24 = (_strtoul($19,$8,10)|0);
        $25 = HEAP32[$8>>2]|0;
        $26 = HEAP8[$25>>0]|0;
        $27 = ($26<<24>>24)==(36);
        if ($27) {
         $28 = ((($25)) + 1|0);
         $29 = ($24>>>0)<(1000);
         if ($29) {
          $$099 = 1000;
         } else {
          $30 = ($24>>>0)>(9999999);
          if ($30) {
           break;
          } else {
           $$099 = $24;
          }
         }
         HEAP32[$vararg_buffer>>2] = $$099;
         (_sprintf($7,(gb + (167187) | 0),$vararg_buffer)|0);
         $$196 = $28;$$2101 = $$099;
         break L7;
        }
       }
      } while(0);
      $$1 = 0;
      break L4;
     } else {
      $$196 = $16;$$2101 = 5000;
     }
    } while(0);
    $$198116 = 0;
    L17: while(1) {
     $31 = (($$196) + ($$198116)|0);
     $32 = HEAP8[$31>>0]|0;
     switch ($32<<24>>24) {
     case 58: case 10:  {
      $$1 = 0;
      break L4;
      break;
     }
     case 36: case 0:  {
      $$198$lcssa = $$198116;
      break L17;
      break;
     }
     default: {
     }
     }
     $33 = (($$198116) + 1)|0;
     $34 = ($33>>>0)<(16);
     if ($34) {
      $$198116 = $33;
     } else {
      $$198$lcssa = 16;
      break;
     }
    }
    _sha512_init($3);
    _sha512_update($3,$0,$$097117);
    _sha512_update($3,$$196,$$198$lcssa);
    _sha512_update($3,$0,$$097117);
    _sha512_sum($3,$4);
    _sha512_init($3);
    _sha512_update($3,$0,$$097117);
    _sha512_update($3,$$196,$$198$lcssa);
    _hashmd_306($3,$$097117,$4);
    $35 = ($$097117|0)==(0);
    if ($35) {
     _sha512_sum($3,$4);
     _sha512_init($3);
    } else {
     $$2113 = $$097117;
     while(1) {
      $36 = $$2113 & 1;
      $37 = ($36|0)==(0);
      if ($37) {
       _sha512_update($3,$0,$$097117);
      } else {
       _sha512_update($3,$4,64);
      }
      $38 = $$2113 >>> 1;
      $39 = ($38|0)==(0);
      if ($39) {
       break;
      } else {
       $$2113 = $38;
      }
     }
     _sha512_sum($3,$4);
     _sha512_init($3);
     if (!($35)) {
      $$3109 = 0;
      while(1) {
       _sha512_update($3,$0,$$097117);
       $40 = (($$3109) + 1)|0;
       $exitcond122 = ($40|0)==($$097117|0);
       if ($exitcond122) {
        break;
       } else {
        $$3109 = $40;
       }
      }
     }
    }
    _sha512_sum($3,$5);
    _sha512_init($3);
    $41 = HEAP8[$4>>0]|0;
    $42 = $41&255;
    $43 = (($42) + 15)|0;
    $$4108 = 0;
    while(1) {
     _sha512_update($3,$$196,$$198$lcssa);
     $44 = (($$4108) + 1)|0;
     $exitcond121 = ($$4108|0)==($43|0);
     if ($exitcond121) {
      break;
     } else {
      $$4108 = $44;
     }
    }
    _sha512_sum($3,$6);
    $45 = ($$2101|0)==(0);
    if (!($45)) {
     $$5107 = 0;
     while(1) {
      _sha512_init($3);
      $46 = $$5107 & 1;
      $47 = ($46|0)!=(0);
      if ($47) {
       _hashmd_306($3,$$097117,$5);
      } else {
       _sha512_update($3,$4,64);
      }
      $48 = (($$5107>>>0) % 3)&-1;
      $49 = ($48|0)==(0);
      if (!($49)) {
       _sha512_update($3,$6,$$198$lcssa);
      }
      $50 = (($$5107>>>0) % 7)&-1;
      $51 = ($50|0)==(0);
      if (!($51)) {
       _hashmd_306($3,$$097117,$5);
      }
      if ($47) {
       _sha512_update($3,$4,64);
      } else {
       _hashmd_306($3,$$097117,$5);
      }
      _sha512_sum($3,$4);
      $52 = (($$5107) + 1)|0;
      $exitcond120 = ($52|0)==($$2101|0);
      if ($exitcond120) {
       break;
      } else {
       $$5107 = $52;
      }
     }
    }
    HEAP32[$vararg_buffer1>>2] = $7;
    $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
    HEAP32[$vararg_ptr4>>2] = $$198$lcssa;
    $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
    HEAP32[$vararg_ptr5>>2] = $$196;
    $53 = (_sprintf($2,(gb + (167198) | 0),$vararg_buffer1)|0);
    $54 = (($2) + ($53)|0);
    $$094106 = $54;$$6105 = 0;
    while(1) {
     $55 = ((gb + (151568) | 0) + (($$6105*3)|0)|0);
     $56 = HEAP8[$55>>0]|0;
     $57 = $56&255;
     $58 = (($4) + ($57)|0);
     $59 = HEAP8[$58>>0]|0;
     $60 = $59&255;
     $61 = $60 << 16;
     $62 = ((((gb + (151568) | 0) + (($$6105*3)|0)|0)) + 1|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = $63&255;
     $65 = (($4) + ($64)|0);
     $66 = HEAP8[$65>>0]|0;
     $67 = $66&255;
     $68 = $67 << 8;
     $69 = $68 | $61;
     $70 = ((((gb + (151568) | 0) + (($$6105*3)|0)|0)) + 2|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = $71&255;
     $73 = (($4) + ($72)|0);
     $74 = HEAP8[$73>>0]|0;
     $75 = $74&255;
     $76 = $69 | $75;
     $77 = (_to64_308($$094106,$76,4)|0);
     $78 = (($$6105) + 1)|0;
     $exitcond = ($78|0)==(21);
     if ($exitcond) {
      break;
     } else {
      $$094106 = $77;$$6105 = $78;
     }
    }
    $79 = ((($4)) + 63|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = (_to64_308($77,$81,2)|0);
    HEAP8[$82>>0] = 0;
    $$1 = $2;
   } else {
    $$1 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _sha512_init($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 8|0);
 $6 = $5;
 $7 = $6;
 HEAP32[$7>>2] = -205731576;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 1779033703;
 $10 = ((($0)) + 16|0);
 $11 = $10;
 $12 = $11;
 HEAP32[$12>>2] = -2067093701;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = -1150833019;
 $15 = ((($0)) + 24|0);
 $16 = $15;
 $17 = $16;
 HEAP32[$17>>2] = -23791573;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = 1013904242;
 $20 = ((($0)) + 32|0);
 $21 = $20;
 $22 = $21;
 HEAP32[$22>>2] = 1595750129;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = -1521486534;
 $25 = ((($0)) + 40|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = -1377402159;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 1359893119;
 $30 = ((($0)) + 48|0);
 $31 = $30;
 $32 = $31;
 HEAP32[$32>>2] = 725511199;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = -1694144372;
 $35 = ((($0)) + 56|0);
 $36 = $35;
 $37 = $36;
 HEAP32[$37>>2] = -79577749;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = 528734635;
 $40 = ((($0)) + 64|0);
 $41 = $40;
 $42 = $41;
 HEAP32[$42>>2] = 327033209;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = 1541459225;
 return;
}
function _sha512_update($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$027 = 0, $$1$lcssa = 0, $$128$lcssa = 0, $$12829 = 0, $$130 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5 & 127;
 $10 = (_i64Add(($5|0),($8|0),($2|0),0)|0);
 $11 = (getTempRet0() | 0);
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $10;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = ($9|0)==(0);
 do {
  if ($16) {
   $$0 = $2;$$027 = $1;
   label = 5;
  } else {
   $17 = (128 - ($9))|0;
   $18 = ($17>>>0)>($2>>>0);
   $19 = (((($0)) + 72|0) + ($9)|0);
   if ($18) {
    (_memcpy(($19|0),($1|0),($2|0))|0);
    break;
   } else {
    $20 = ((($0)) + 72|0);
    (_memcpy(($19|0),($1|0),($17|0))|0);
    $21 = (($2) - ($17))|0;
    $22 = (($1) + ($17)|0);
    _processblock_311($0,$20);
    $$0 = $21;$$027 = $22;
    label = 5;
    break;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $23 = ($$0>>>0)>(127);
  if ($23) {
   $24 = (($$0) + -128)|0;
   $25 = $24 & -128;
   $26 = (($25) + 128)|0;
   $$12829 = $$027;$$130 = $$0;
   while(1) {
    _processblock_311($0,$$12829);
    $27 = (($$130) + -128)|0;
    $28 = ((($$12829)) + 128|0);
    $29 = ($27>>>0)>(127);
    if ($29) {
     $$12829 = $28;$$130 = $27;
    } else {
     break;
    }
   }
   $30 = (($24) - ($25))|0;
   $scevgep = (($$027) + ($26)|0);
   $$1$lcssa = $30;$$128$lcssa = $scevgep;
  } else {
   $$1$lcssa = $$0;$$128$lcssa = $$027;
  }
  $31 = ((($0)) + 72|0);
  (_memcpy(($31|0),($$128$lcssa|0),($$1$lcssa|0))|0);
 }
 return;
}
function _sha512_sum($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$035 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _pad_310($0);
 $$035 = 0;
 while(1) {
  $2 = (((($0)) + 8|0) + ($$035<<3)|0);
  $3 = $2;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (_bitshift64Lshr(($5|0),($8|0),56)|0);
  $10 = (getTempRet0() | 0);
  $11 = $9&255;
  $12 = $$035 << 3;
  $13 = (($1) + ($12)|0);
  HEAP8[$13>>0] = $11;
  $14 = $2;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (_bitshift64Lshr(($16|0),($19|0),48)|0);
  $21 = (getTempRet0() | 0);
  $22 = $20&255;
  $23 = $12 | 1;
  $24 = (($1) + ($23)|0);
  HEAP8[$24>>0] = $22;
  $25 = $2;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = (_bitshift64Lshr(($27|0),($30|0),40)|0);
  $32 = (getTempRet0() | 0);
  $33 = $31&255;
  $34 = $12 | 2;
  $35 = (($1) + ($34)|0);
  HEAP8[$35>>0] = $33;
  $36 = $2;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $41&255;
  $43 = $12 | 3;
  $44 = (($1) + ($43)|0);
  HEAP8[$44>>0] = $42;
  $45 = $2;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = (_bitshift64Lshr(($47|0),($50|0),24)|0);
  $52 = (getTempRet0() | 0);
  $53 = $51&255;
  $54 = $12 | 4;
  $55 = (($1) + ($54)|0);
  HEAP8[$55>>0] = $53;
  $56 = $2;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = (($56) + 4)|0;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (_bitshift64Lshr(($58|0),($61|0),16)|0);
  $63 = (getTempRet0() | 0);
  $64 = $62&255;
  $65 = $12 | 5;
  $66 = (($1) + ($65)|0);
  HEAP8[$66>>0] = $64;
  $67 = $2;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + 4)|0;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = (_bitshift64Lshr(($69|0),($72|0),8)|0);
  $74 = (getTempRet0() | 0);
  $75 = $73&255;
  $76 = $12 | 6;
  $77 = (($1) + ($76)|0);
  HEAP8[$77>>0] = $75;
  $78 = $2;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = (($78) + 4)|0;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = $80&255;
  $85 = $12 | 7;
  $86 = (($1) + ($85)|0);
  HEAP8[$86>>0] = $84;
  $87 = (($$035) + 1)|0;
  $exitcond = ($87|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $$035 = $87;
  }
 }
 return;
}
function _hashmd_306($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$06 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(64);
 if ($3) {
  $4 = (($1) + -65)|0;
  $5 = $4 & -64;
  $$06 = $1;
  while(1) {
   _sha512_update($0,$2,64);
   $6 = (($$06) + -64)|0;
   $7 = ($6>>>0)>(64);
   if ($7) {
    $$06 = $6;
   } else {
    break;
   }
  }
  $8 = (($1) + -64)|0;
  $9 = (($8) - ($5))|0;
  $$0$lcssa = $9;
 } else {
  $$0$lcssa = $1;
 }
 _sha512_update($0,$2,$$0$lcssa);
 return;
}
function _to64_308($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$047 = 0, $$05$lcssa = 0, $$056 = 0, $$08 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)>(0);
 if ($3) {
  $$047 = $1;$$056 = $0;$$08 = $2;
  while(1) {
   $4 = (($$08) + -1)|0;
   $5 = $$047 & 63;
   $6 = ((gb + (152352) | 0) + ($5)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ((($$056)) + 1|0);
   HEAP8[$$056>>0] = $7;
   $9 = $$047 >>> 6;
   $10 = ($$08|0)>(1);
   if ($10) {
    $$047 = $9;$$056 = $8;$$08 = $4;
   } else {
    $$05$lcssa = $8;
    break;
   }
  }
 } else {
  $$05$lcssa = $0;
 }
 return ($$05$lcssa|0);
}
function _pad_310($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3 & 127;
 $8 = ((($0)) + 72|0);
 $9 = (($7) + 1)|0;
 $10 = (((($0)) + 72|0) + ($7)|0);
 HEAP8[$10>>0] = -128;
 $11 = ($7>>>0)>(111);
 if ($11) {
  $12 = $7 ^ 127;
  $13 = (((($0)) + 72|0) + ($9)|0);
  (_memset(($13|0),0,($12|0))|0);
  _processblock_311($0,$8);
  $$0 = 0;$$pre$phiZ2D = $8;
 } else {
  $$0 = $9;$$pre$phiZ2D = $8;
 }
 $14 = (((($0)) + 72|0) + ($$0)|0);
 $15 = (120 - ($$0))|0;
 (_memset(($14|0),0,($15|0))|0);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (_bitshift64Shl(($18|0),($21|0),3)|0);
 $23 = (getTempRet0() | 0);
 $24 = $0;
 $25 = $24;
 HEAP32[$25>>2] = $22;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = (_bitshift64Lshr(($18|0),($21|0),53)|0);
 $29 = (getTempRet0() | 0);
 $30 = $28&255;
 $31 = ((($0)) + 192|0);
 HEAP8[$31>>0] = $30;
 $32 = (_bitshift64Lshr(($18|0),($21|0),45)|0);
 $33 = (getTempRet0() | 0);
 $34 = $32&255;
 $35 = ((($0)) + 193|0);
 HEAP8[$35>>0] = $34;
 $36 = (_bitshift64Lshr(($18|0),($21|0),37)|0);
 $37 = (getTempRet0() | 0);
 $38 = $36&255;
 $39 = ((($0)) + 194|0);
 HEAP8[$39>>0] = $38;
 $40 = (_bitshift64Lshr(($18|0),($21|0),29)|0);
 $41 = (getTempRet0() | 0);
 $42 = $40&255;
 $43 = ((($0)) + 195|0);
 HEAP8[$43>>0] = $42;
 $44 = (_bitshift64Lshr(($18|0),($21|0),21)|0);
 $45 = (getTempRet0() | 0);
 $46 = $44&255;
 $47 = ((($0)) + 196|0);
 HEAP8[$47>>0] = $46;
 $48 = (_bitshift64Lshr(($18|0),($21|0),13)|0);
 $49 = (getTempRet0() | 0);
 $50 = $48&255;
 $51 = ((($0)) + 197|0);
 HEAP8[$51>>0] = $50;
 $52 = (_bitshift64Lshr(($18|0),($21|0),5)|0);
 $53 = (getTempRet0() | 0);
 $54 = $52&255;
 $55 = ((($0)) + 198|0);
 HEAP8[$55>>0] = $54;
 $56 = $22&255;
 $57 = ((($0)) + 199|0);
 HEAP8[$57>>0] = $56;
 _processblock_311($0,$$pre$phiZ2D);
 return;
}
function _processblock_311($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0129 = 0, $$1128 = 0, $$2127 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $198$phi = 0, $199 = 0, $199$phi = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $201$phi = 0;
 var $202 = 0, $202$phi = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $221$phi = 0, $222 = 0, $222$phi = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $244$phi = 0, $245 = 0, $246 = 0, $246$phi = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $250$phi = 0;
 var $251 = 0, $252 = 0, $252$phi = 0, $253 = 0, $254 = 0, $255 = 0, $255$phi = 0, $256 = 0, $256$phi = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond132 = 0, $exitcond133 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(640|0);
 $2 = sp;
 $$0129 = 0;
 while(1) {
  $3 = $$0129 << 3;
  $4 = (($1) + ($3)|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = (_bitshift64Shl(($6|0),0,56)|0);
  $8 = (getTempRet0() | 0);
  $9 = (($2) + ($$0129<<3)|0);
  $10 = $3 | 1;
  $11 = (($1) + ($10)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = (_bitshift64Shl(($13|0),0,48)|0);
  $15 = (getTempRet0() | 0);
  $16 = $14 | $7;
  $17 = $15 | $8;
  $18 = $3 | 2;
  $19 = (($1) + ($18)|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = (_bitshift64Shl(($21|0),0,40)|0);
  $23 = (getTempRet0() | 0);
  $24 = $22 | $16;
  $25 = $23 | $17;
  $26 = $3 | 3;
  $27 = (($1) + ($26)|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $29 | $25;
  $31 = $3 | 4;
  $32 = (($1) + ($31)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = (_bitshift64Shl(($34|0),0,24)|0);
  $36 = (getTempRet0() | 0);
  $37 = $35 | $24;
  $38 = $36 | $30;
  $39 = $3 | 5;
  $40 = (($1) + ($39)|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = (_bitshift64Shl(($42|0),0,16)|0);
  $44 = (getTempRet0() | 0);
  $45 = $43 | $37;
  $46 = $44 | $38;
  $47 = $3 | 6;
  $48 = (($1) + ($47)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = (_bitshift64Shl(($50|0),0,8)|0);
  $52 = (getTempRet0() | 0);
  $53 = $51 | $45;
  $54 = $52 | $46;
  $55 = $3 | 7;
  $56 = (($1) + ($55)|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = $53 | $58;
  $60 = $9;
  $61 = $60;
  HEAP32[$61>>2] = $59;
  $62 = (($60) + 4)|0;
  $63 = $62;
  HEAP32[$63>>2] = $54;
  $64 = (($$0129) + 1)|0;
  $exitcond133 = ($64|0)==(16);
  if ($exitcond133) {
   break;
  } else {
   $$0129 = $64;
  }
 }
 $65 = $2;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) + 4)|0;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $$1128 = 16;$117 = $67;$118 = $70;
 while(1) {
  $71 = (($$1128) + -2)|0;
  $72 = (($2) + ($71<<3)|0);
  $73 = $72;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + 4)|0;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = (_ror_312($75,$78,19)|0);
  $80 = (getTempRet0() | 0);
  $81 = (_ror_312($75,$78,61)|0);
  $82 = (getTempRet0() | 0);
  $83 = (_bitshift64Lshr(($75|0),($78|0),6)|0);
  $84 = (getTempRet0() | 0);
  $85 = $83 ^ $79;
  $86 = $84 ^ $80;
  $87 = $85 ^ $81;
  $88 = $86 ^ $82;
  $89 = (($$1128) + -7)|0;
  $90 = (($2) + ($89<<3)|0);
  $91 = $90;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 4)|0;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = (_i64Add(($87|0),($88|0),($93|0),($96|0))|0);
  $98 = (getTempRet0() | 0);
  $99 = (($$1128) + -15)|0;
  $100 = (($2) + ($99<<3)|0);
  $101 = $100;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + 4)|0;
  $105 = $104;
  $106 = HEAP32[$105>>2]|0;
  $107 = (_ror_312($103,$106,1)|0);
  $108 = (getTempRet0() | 0);
  $109 = (_ror_312($103,$106,8)|0);
  $110 = (getTempRet0() | 0);
  $111 = (_bitshift64Lshr(($103|0),($106|0),7)|0);
  $112 = (getTempRet0() | 0);
  $113 = $111 ^ $107;
  $114 = $112 ^ $108;
  $115 = $113 ^ $109;
  $116 = $114 ^ $110;
  $119 = (_i64Add(($97|0),($98|0),($117|0),($118|0))|0);
  $120 = (getTempRet0() | 0);
  $121 = (_i64Add(($119|0),($120|0),($115|0),($116|0))|0);
  $122 = (getTempRet0() | 0);
  $123 = (($2) + ($$1128<<3)|0);
  $124 = $123;
  $125 = $124;
  HEAP32[$125>>2] = $121;
  $126 = (($124) + 4)|0;
  $127 = $126;
  HEAP32[$127>>2] = $122;
  $128 = (($$1128) + 1)|0;
  $exitcond132 = ($128|0)==(80);
  if ($exitcond132) {
   break;
  } else {
   $$1128 = $128;$117 = $103;$118 = $106;
  }
 }
 $129 = ((($0)) + 8|0);
 $130 = $129;
 $131 = $130;
 $132 = HEAP32[$131>>2]|0;
 $133 = (($130) + 4)|0;
 $134 = $133;
 $135 = HEAP32[$134>>2]|0;
 $136 = ((($0)) + 16|0);
 $137 = $136;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = (($137) + 4)|0;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = ((($0)) + 24|0);
 $144 = $143;
 $145 = $144;
 $146 = HEAP32[$145>>2]|0;
 $147 = (($144) + 4)|0;
 $148 = $147;
 $149 = HEAP32[$148>>2]|0;
 $150 = ((($0)) + 32|0);
 $151 = $150;
 $152 = $151;
 $153 = HEAP32[$152>>2]|0;
 $154 = (($151) + 4)|0;
 $155 = $154;
 $156 = HEAP32[$155>>2]|0;
 $157 = ((($0)) + 40|0);
 $158 = $157;
 $159 = $158;
 $160 = HEAP32[$159>>2]|0;
 $161 = (($158) + 4)|0;
 $162 = $161;
 $163 = HEAP32[$162>>2]|0;
 $164 = ((($0)) + 48|0);
 $165 = $164;
 $166 = $165;
 $167 = HEAP32[$166>>2]|0;
 $168 = (($165) + 4)|0;
 $169 = $168;
 $170 = HEAP32[$169>>2]|0;
 $171 = ((($0)) + 56|0);
 $172 = $171;
 $173 = $172;
 $174 = HEAP32[$173>>2]|0;
 $175 = (($172) + 4)|0;
 $176 = $175;
 $177 = HEAP32[$176>>2]|0;
 $178 = ((($0)) + 64|0);
 $179 = $178;
 $180 = $179;
 $181 = HEAP32[$180>>2]|0;
 $182 = (($179) + 4)|0;
 $183 = $182;
 $184 = HEAP32[$183>>2]|0;
 $$2127 = 0;$185 = $160;$186 = $163;$198 = $174;$199 = $167;$201 = $177;$202 = $170;$221 = $181;$222 = $184;$231 = $132;$232 = $135;$244 = $139;$246 = $142;$250 = $146;$252 = $149;$255 = $153;$256 = $156;
 while(1) {
  $187 = (_ror_312($185,$186,14)|0);
  $188 = (getTempRet0() | 0);
  $189 = (_ror_312($185,$186,18)|0);
  $190 = (getTempRet0() | 0);
  $191 = $189 ^ $187;
  $192 = $190 ^ $188;
  $193 = (_ror_312($185,$186,41)|0);
  $194 = (getTempRet0() | 0);
  $195 = $191 ^ $193;
  $196 = $192 ^ $194;
  $197 = $198 ^ $199;
  $200 = $201 ^ $202;
  $203 = $197 & $185;
  $204 = $200 & $186;
  $205 = $203 ^ $198;
  $206 = $204 ^ $201;
  $207 = ((gb + (151632) | 0) + ($$2127<<3)|0);
  $208 = $207;
  $209 = $208;
  $210 = HEAP32[$209>>2]|0;
  $211 = (($208) + 4)|0;
  $212 = $211;
  $213 = HEAP32[$212>>2]|0;
  $214 = (($2) + ($$2127<<3)|0);
  $215 = $214;
  $216 = $215;
  $217 = HEAP32[$216>>2]|0;
  $218 = (($215) + 4)|0;
  $219 = $218;
  $220 = HEAP32[$219>>2]|0;
  $223 = (_i64Add(($205|0),($206|0),($221|0),($222|0))|0);
  $224 = (getTempRet0() | 0);
  $225 = (_i64Add(($223|0),($224|0),($195|0),($196|0))|0);
  $226 = (getTempRet0() | 0);
  $227 = (_i64Add(($225|0),($226|0),($210|0),($213|0))|0);
  $228 = (getTempRet0() | 0);
  $229 = (_i64Add(($227|0),($228|0),($217|0),($220|0))|0);
  $230 = (getTempRet0() | 0);
  $233 = (_ror_312($231,$232,28)|0);
  $234 = (getTempRet0() | 0);
  $235 = (_ror_312($231,$232,34)|0);
  $236 = (getTempRet0() | 0);
  $237 = $235 ^ $233;
  $238 = $236 ^ $234;
  $239 = (_ror_312($231,$232,39)|0);
  $240 = (getTempRet0() | 0);
  $241 = $237 ^ $239;
  $242 = $238 ^ $240;
  $243 = $244 & $231;
  $245 = $246 & $232;
  $247 = $244 | $231;
  $248 = $246 | $232;
  $249 = $250 & $247;
  $251 = $252 & $248;
  $253 = $249 | $243;
  $254 = $251 | $245;
  $257 = (_i64Add(($229|0),($230|0),($255|0),($256|0))|0);
  $258 = (getTempRet0() | 0);
  $259 = (_i64Add(($229|0),($230|0),($253|0),($254|0))|0);
  $260 = (getTempRet0() | 0);
  $261 = (_i64Add(($259|0),($260|0),($241|0),($242|0))|0);
  $262 = (getTempRet0() | 0);
  $263 = (($$2127) + 1)|0;
  $exitcond = ($263|0)==(80);
  if ($exitcond) {
   break;
  } else {
   $256$phi = $252;$255$phi = $250;$252$phi = $246;$250$phi = $244;$246$phi = $232;$244$phi = $231;$222$phi = $201;$221$phi = $198;$202$phi = $186;$201$phi = $202;$199$phi = $185;$198$phi = $199;$$2127 = $263;$185 = $257;$186 = $258;$231 = $261;$232 = $262;$256 = $256$phi;$255 = $255$phi;$252 = $252$phi;$250 = $250$phi;$246 = $246$phi;$244 = $244$phi;$222 = $222$phi;$221 = $221$phi;$202 = $202$phi;$201 = $201$phi;$199 = $199$phi;$198 = $198$phi;
  }
 }
 $264 = (_i64Add(($261|0),($262|0),($132|0),($135|0))|0);
 $265 = (getTempRet0() | 0);
 $266 = $129;
 $267 = $266;
 HEAP32[$267>>2] = $264;
 $268 = (($266) + 4)|0;
 $269 = $268;
 HEAP32[$269>>2] = $265;
 $270 = (_i64Add(($231|0),($232|0),($139|0),($142|0))|0);
 $271 = (getTempRet0() | 0);
 $272 = $136;
 $273 = $272;
 HEAP32[$273>>2] = $270;
 $274 = (($272) + 4)|0;
 $275 = $274;
 HEAP32[$275>>2] = $271;
 $276 = (_i64Add(($244|0),($246|0),($146|0),($149|0))|0);
 $277 = (getTempRet0() | 0);
 $278 = $143;
 $279 = $278;
 HEAP32[$279>>2] = $276;
 $280 = (($278) + 4)|0;
 $281 = $280;
 HEAP32[$281>>2] = $277;
 $282 = (_i64Add(($250|0),($252|0),($153|0),($156|0))|0);
 $283 = (getTempRet0() | 0);
 $284 = $150;
 $285 = $284;
 HEAP32[$285>>2] = $282;
 $286 = (($284) + 4)|0;
 $287 = $286;
 HEAP32[$287>>2] = $283;
 $288 = (_i64Add(($257|0),($258|0),($160|0),($163|0))|0);
 $289 = (getTempRet0() | 0);
 $290 = $157;
 $291 = $290;
 HEAP32[$291>>2] = $288;
 $292 = (($290) + 4)|0;
 $293 = $292;
 HEAP32[$293>>2] = $289;
 $294 = (_i64Add(($185|0),($186|0),($167|0),($170|0))|0);
 $295 = (getTempRet0() | 0);
 $296 = $164;
 $297 = $296;
 HEAP32[$297>>2] = $294;
 $298 = (($296) + 4)|0;
 $299 = $298;
 HEAP32[$299>>2] = $295;
 $300 = (_i64Add(($199|0),($202|0),($174|0),($177|0))|0);
 $301 = (getTempRet0() | 0);
 $302 = $171;
 $303 = $302;
 HEAP32[$303>>2] = $300;
 $304 = (($302) + 4)|0;
 $305 = $304;
 HEAP32[$305>>2] = $301;
 $306 = (_i64Add(($198|0),($201|0),($181|0),($184|0))|0);
 $307 = (getTempRet0() | 0);
 $308 = $178;
 $309 = $308;
 HEAP32[$309>>2] = $306;
 $310 = (($308) + 4)|0;
 $311 = $310;
 HEAP32[$311>>2] = $307;
 STACKTOP = sp;return;
}
function _ror_312($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_bitshift64Lshr(($0|0),($1|0),($2|0))|0);
 $4 = (getTempRet0() | 0);
 $5 = (64 - ($2))|0;
 $6 = (_bitshift64Shl(($0|0),($1|0),($5|0))|0);
 $7 = (getTempRet0() | 0);
 $8 = $6 | $3;
 $9 = $7 | $4;
 setTempRet0(($9) | 0);
 return ($8|0);
}
function ___crypt_md5($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $3 = sp;
 $4 = (_md5crypt($0,$1,$2)|0);
 $5 = (_md5crypt((gb + (152272) | 0),(gb + (167209) | 0),$3)|0);
 $6 = ($4|0)!=(0|0);
 $7 = ($5|0)==($3|0);
 $or$cond = $6 & $7;
 if ($or$cond) {
  $8 = (_memcmp($3,(gb + (152304) | 0),35)|0);
  $9 = ($8|0)==(0);
  $spec$select = $9 ? $4 : (gb + (167222) | 0);
  $$0 = $spec$select;
 } else {
  $$0 = (gb + (167222) | 0);
 }
 STACKTOP = sp;return ($$0|0);
}
function _md5crypt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$068 = 0, $$069$lcssa = 0, $$06977 = 0, $$071 = 0, $$1$lcssa = 0, $$174 = 0, $$273 = 0, $$372 = 0, $$470 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond79 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $3 = sp + 16|0;
 $4 = sp;
 $5 = (_strnlen($0,30001)|0);
 $6 = ($5>>>0)>(30000);
 if ($6) {
  $$068 = 0;
 } else {
  $7 = (_strncmp($1,(gb + (167224) | 0),3)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = ((($1)) + 3|0);
   $$06977 = 0;
   L4: while(1) {
    $10 = (($9) + ($$06977)|0);
    $11 = HEAP8[$10>>0]|0;
    switch ($11<<24>>24) {
    case 36: case 0:  {
     $$069$lcssa = $$06977;
     break L4;
     break;
    }
    default: {
    }
    }
    $12 = (($$06977) + 1)|0;
    $13 = ($12>>>0)<(8);
    if ($13) {
     $$06977 = $12;
    } else {
     $$069$lcssa = 8;
     break;
    }
   }
   _md5_init($3);
   _md5_update($3,$0,$5);
   _md5_update($3,$9,$$069$lcssa);
   _md5_update($3,$0,$5);
   _md5_sum($3,$4);
   _md5_init($3);
   _md5_update($3,$0,$5);
   $14 = (($$069$lcssa) + 3)|0;
   _md5_update($3,$1,$14);
   $15 = ($5>>>0)>(16);
   if ($15) {
    $16 = (($5) + -17)|0;
    $17 = $16 & -16;
    $$174 = $5;
    while(1) {
     _md5_update($3,$4,16);
     $18 = (($$174) + -16)|0;
     $19 = ($18>>>0)>(16);
     if ($19) {
      $$174 = $18;
     } else {
      break;
     }
    }
    $20 = (($5) + -16)|0;
    $21 = (($20) - ($17))|0;
    $$1$lcssa = $21;
   } else {
    $$1$lcssa = $5;
   }
   _md5_update($3,$4,$$1$lcssa);
   HEAP8[$4>>0] = 0;
   $22 = ($5|0)==(0);
   if (!($22)) {
    $$273 = $5;
    while(1) {
     $23 = $$273 & 1;
     $24 = ($23|0)==(0);
     if ($24) {
      _md5_update($3,$0,1);
     } else {
      _md5_update($3,$4,1);
     }
     $25 = $$273 >>> 1;
     $26 = ($25|0)==(0);
     if ($26) {
      break;
     } else {
      $$273 = $25;
     }
    }
   }
   _md5_sum($3,$4);
   $$372 = 0;
   while(1) {
    _md5_init($3);
    $27 = $$372 & 1;
    $28 = ($27|0)!=(0);
    if ($28) {
     _md5_update($3,$0,$5);
    } else {
     _md5_update($3,$4,16);
    }
    $29 = (($$372>>>0) % 3)&-1;
    $30 = ($29|0)==(0);
    if (!($30)) {
     _md5_update($3,$9,$$069$lcssa);
    }
    $31 = (($$372>>>0) % 7)&-1;
    $32 = ($31|0)==(0);
    if (!($32)) {
     _md5_update($3,$0,$5);
    }
    if ($28) {
     _md5_update($3,$4,16);
    } else {
     _md5_update($3,$0,$5);
    }
    _md5_sum($3,$4);
    $33 = (($$372) + 1)|0;
    $exitcond79 = ($33|0)==(1000);
    if ($exitcond79) {
     break;
    } else {
     $$372 = $33;
    }
   }
   (_memcpy(($2|0),($1|0),($14|0))|0);
   $34 = ((($2)) + 3|0);
   $35 = (($34) + ($$069$lcssa)|0);
   $36 = ((($35)) + 1|0);
   HEAP8[$35>>0] = 36;
   $$071 = $36;$$470 = 0;
   while(1) {
    $37 = ((gb + (167228) | 0) + (($$470*3)|0)|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = $38&255;
    $40 = (($4) + ($39)|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = $41&255;
    $43 = $42 << 16;
    $44 = ((((gb + (167228) | 0) + (($$470*3)|0)|0)) + 1|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = (($4) + ($46)|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = $49 << 8;
    $51 = $50 | $43;
    $52 = ((((gb + (167228) | 0) + (($$470*3)|0)|0)) + 2|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = (($4) + ($54)|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56&255;
    $58 = $51 | $57;
    $59 = (_to64_316($$071,$58,4)|0);
    $60 = (($$470) + 1)|0;
    $exitcond = ($60|0)==(5);
    if ($exitcond) {
     break;
    } else {
     $$071 = $59;$$470 = $60;
    }
   }
   $61 = ((($4)) + 11|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = $62&255;
   $64 = (_to64_316($59,$63,2)|0);
   HEAP8[$64>>0] = 0;
   $$068 = $2;
  } else {
   $$068 = 0;
  }
 }
 STACKTOP = sp;return ($$068|0);
}
function _md5_init($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = 1732584193;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = -271733879;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = -1732584194;
 $8 = ((($0)) + 20|0);
 HEAP32[$8>>2] = 271733878;
 return;
}
function _md5_update($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$027 = 0, $$1$lcssa = 0, $$128$lcssa = 0, $$12829 = 0, $$130 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5 & 63;
 $10 = (_i64Add(($5|0),($8|0),($2|0),0)|0);
 $11 = (getTempRet0() | 0);
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $10;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = ($9|0)==(0);
 do {
  if ($16) {
   $$0 = $2;$$027 = $1;
   label = 5;
  } else {
   $17 = (64 - ($9))|0;
   $18 = ($17>>>0)>($2>>>0);
   $19 = (((($0)) + 24|0) + ($9)|0);
   if ($18) {
    (_memcpy(($19|0),($1|0),($2|0))|0);
    break;
   } else {
    $20 = ((($0)) + 24|0);
    (_memcpy(($19|0),($1|0),($17|0))|0);
    $21 = (($2) - ($17))|0;
    $22 = (($1) + ($17)|0);
    _processblock_319($0,$20);
    $$0 = $21;$$027 = $22;
    label = 5;
    break;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $23 = ($$0>>>0)>(63);
  if ($23) {
   $24 = (($$0) + -64)|0;
   $25 = $24 & -64;
   $26 = (($25) + 64)|0;
   $$12829 = $$027;$$130 = $$0;
   while(1) {
    _processblock_319($0,$$12829);
    $27 = (($$130) + -64)|0;
    $28 = ((($$12829)) + 64|0);
    $29 = ($27>>>0)>(63);
    if ($29) {
     $$12829 = $28;$$130 = $27;
    } else {
     break;
    }
   }
   $30 = (($24) - ($25))|0;
   $scevgep = (($$027) + ($26)|0);
   $$1$lcssa = $30;$$128$lcssa = $scevgep;
  } else {
   $$1$lcssa = $$0;$$128$lcssa = $$027;
  }
  $31 = ((($0)) + 24|0);
  (_memcpy(($31|0),($$128$lcssa|0),($$1$lcssa|0))|0);
 }
 return;
}
function _md5_sum($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _pad_318($0);
 $$019 = 0;
 while(1) {
  $2 = (((($0)) + 8|0) + ($$019<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3&255;
  $5 = $$019 << 2;
  $6 = (($1) + ($5)|0);
  HEAP8[$6>>0] = $4;
  $7 = HEAP32[$2>>2]|0;
  $8 = $7 >>> 8;
  $9 = $8&255;
  $10 = $5 | 1;
  $11 = (($1) + ($10)|0);
  HEAP8[$11>>0] = $9;
  $12 = HEAP32[$2>>2]|0;
  $13 = $12 >>> 16;
  $14 = $13&255;
  $15 = $5 | 2;
  $16 = (($1) + ($15)|0);
  HEAP8[$16>>0] = $14;
  $17 = HEAP32[$2>>2]|0;
  $18 = $17 >>> 24;
  $19 = $18&255;
  $20 = $5 | 3;
  $21 = (($1) + ($20)|0);
  HEAP8[$21>>0] = $19;
  $22 = (($$019) + 1)|0;
  $exitcond = ($22|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$019 = $22;
  }
 }
 return;
}
function _to64_316($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$047 = 0, $$05$lcssa = 0, $$056 = 0, $$08 = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)>(0);
 if ($3) {
  $$047 = $1;$$056 = $0;$$08 = $2;
  while(1) {
   $4 = (($$08) + -1)|0;
   $5 = $$047 & 63;
   $6 = ((gb + (152352) | 0) + ($5)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ((($$056)) + 1|0);
   HEAP8[$$056>>0] = $7;
   $9 = $$047 >>> 6;
   $10 = ($$08|0)>(1);
   if ($10) {
    $$047 = $9;$$056 = $8;$$08 = $4;
   } else {
    $$05$lcssa = $8;
    break;
   }
  }
 } else {
  $$05$lcssa = $0;
 }
 return ($$05$lcssa|0);
}
function _pad_318($0) {
 $0 = $0|0;
 var $$0 = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3 & 63;
 $8 = ((($0)) + 24|0);
 $9 = (($7) + 1)|0;
 $10 = (((($0)) + 24|0) + ($7)|0);
 HEAP8[$10>>0] = -128;
 $11 = ($7>>>0)>(55);
 if ($11) {
  $12 = $7 ^ 63;
  $13 = (((($0)) + 24|0) + ($9)|0);
  (_memset(($13|0),0,($12|0))|0);
  _processblock_319($0,$8);
  $$0 = 0;$$pre$phiZ2D = $8;
 } else {
  $$0 = $9;$$pre$phiZ2D = $8;
 }
 $14 = (((($0)) + 24|0) + ($$0)|0);
 $15 = (56 - ($$0))|0;
 (_memset(($14|0),0,($15|0))|0);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (_bitshift64Shl(($18|0),($21|0),3)|0);
 $23 = (getTempRet0() | 0);
 $24 = $0;
 $25 = $24;
 HEAP32[$25>>2] = $22;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = $22&255;
 $29 = ((($0)) + 80|0);
 HEAP8[$29>>0] = $28;
 $30 = (_bitshift64Lshr(($18|0),($21|0),5)|0);
 $31 = (getTempRet0() | 0);
 $32 = $30&255;
 $33 = ((($0)) + 81|0);
 HEAP8[$33>>0] = $32;
 $34 = (_bitshift64Lshr(($18|0),($21|0),13)|0);
 $35 = (getTempRet0() | 0);
 $36 = $34&255;
 $37 = ((($0)) + 82|0);
 HEAP8[$37>>0] = $36;
 $38 = (_bitshift64Lshr(($18|0),($21|0),21)|0);
 $39 = (getTempRet0() | 0);
 $40 = $38&255;
 $41 = ((($0)) + 83|0);
 HEAP8[$41>>0] = $40;
 $42 = (_bitshift64Lshr(($18|0),($21|0),29)|0);
 $43 = (getTempRet0() | 0);
 $44 = $42&255;
 $45 = ((($0)) + 84|0);
 HEAP8[$45>>0] = $44;
 $46 = (_bitshift64Lshr(($18|0),($21|0),37)|0);
 $47 = (getTempRet0() | 0);
 $48 = $46&255;
 $49 = ((($0)) + 85|0);
 HEAP8[$49>>0] = $48;
 $50 = (_bitshift64Lshr(($18|0),($21|0),45)|0);
 $51 = (getTempRet0() | 0);
 $52 = $50&255;
 $53 = ((($0)) + 86|0);
 HEAP8[$53>>0] = $52;
 $54 = (_bitshift64Lshr(($18|0),($21|0),53)|0);
 $55 = (getTempRet0() | 0);
 $56 = $54&255;
 $57 = ((($0)) + 87|0);
 HEAP8[$57>>0] = $56;
 _processblock_319($0,$$pre$phiZ2D);
 return;
}
function _processblock_319($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0190243 = 0, $$0194242 = 0, $$0198241 = 0, $$0202245 = 0, $$0244 = 0, $$1191230 = 0, $$1195229 = 0, $$1199228 = 0, $$1203240 = 0, $$1231 = 0, $$2192217 = 0, $$2196216 = 0, $$2200215 = 0, $$2204227 = 0, $$2218 = 0, $$3193209 = 0, $$3197208 = 0, $$3201207 = 0, $$3205214 = 0, $$3210 = 0;
 var $$4206 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $2 = sp;
 $$0202245 = 0;
 while(1) {
  $3 = $$0202245 << 2;
  $4 = (($1) + ($3)|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = (($2) + ($$0202245<<2)|0);
  $8 = $3 | 1;
  $9 = (($1) + ($8)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $11 << 8;
  $13 = $12 | $6;
  $14 = $3 | 2;
  $15 = (($1) + ($14)|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = $17 << 16;
  $19 = $18 | $13;
  $20 = $3 | 3;
  $21 = (($1) + ($20)|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = $23 << 24;
  $25 = $24 | $19;
  HEAP32[$7>>2] = $25;
  $26 = (($$0202245) + 1)|0;
  $exitcond = ($26|0)==(16);
  if ($exitcond) {
   break;
  } else {
   $$0202245 = $26;
  }
 }
 $27 = ((($0)) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($0)) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($0)) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $$0190243 = $32;$$0194242 = $30;$$0198241 = $28;$$0244 = $34;$$1203240 = 0;
 while(1) {
  $35 = $$0244 ^ $$0190243;
  $36 = $35 & $$0194242;
  $37 = $36 ^ $$0244;
  $38 = (($2) + ($$1203240<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((gb + (152432) | 0) + ($$1203240<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($37) + ($$0198241))|0;
  $43 = (($42) + ($39))|0;
  $44 = (($43) + ($41))|0;
  $45 = (_rol($44,7)|0);
  $46 = (($45) + ($$0194242))|0;
  $47 = $$1203240 | 1;
  $48 = $$0190243 ^ $$0194242;
  $49 = $46 & $48;
  $50 = $49 ^ $$0190243;
  $51 = (($2) + ($47<<2)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((gb + (152432) | 0) + ($47<<2)|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + ($$0244))|0;
  $56 = (($55) + ($54))|0;
  $57 = (($56) + ($50))|0;
  $58 = (_rol($57,12)|0);
  $59 = (($58) + ($46))|0;
  $60 = $$1203240 | 2;
  $61 = $46 ^ $$0194242;
  $62 = $59 & $61;
  $63 = $62 ^ $$0194242;
  $64 = (($2) + ($60<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((gb + (152432) | 0) + ($60<<2)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + ($$0190243))|0;
  $69 = (($68) + ($67))|0;
  $70 = (($69) + ($63))|0;
  $71 = (_rol($70,17)|0);
  $72 = (($71) + ($59))|0;
  $73 = $$1203240 | 3;
  $74 = $59 ^ $46;
  $75 = $72 & $74;
  $76 = $75 ^ $46;
  $77 = (($2) + ($73<<2)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((gb + (152432) | 0) + ($73<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($78) + ($$0194242))|0;
  $82 = (($81) + ($80))|0;
  $83 = (($82) + ($76))|0;
  $84 = (_rol($83,22)|0);
  $85 = (($84) + ($72))|0;
  $86 = (($$1203240) + 4)|0;
  $87 = ($86>>>0)<(16);
  if ($87) {
   $$0190243 = $72;$$0194242 = $85;$$0198241 = $46;$$0244 = $59;$$1203240 = $86;
  } else {
   break;
  }
 }
 $$1191230 = $72;$$1195229 = $85;$$1199228 = $46;$$1231 = $59;$$2204227 = 16;
 while(1) {
  $88 = $$1191230 ^ $$1195229;
  $89 = $$1231 & $88;
  $90 = $89 ^ $$1191230;
  $91 = ($$2204227*5)|0;
  $92 = $91 & 12;
  $93 = $92 | 1;
  $94 = (($2) + ($93<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ((gb + (152432) | 0) + ($$2204227<<2)|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($90) + ($$1199228))|0;
  $99 = (($98) + ($95))|0;
  $100 = (($99) + ($97))|0;
  $101 = (_rol($100,5)|0);
  $102 = (($101) + ($$1195229))|0;
  $103 = $$2204227 | 1;
  $104 = $102 ^ $$1195229;
  $105 = $104 & $$1191230;
  $106 = $105 ^ $$1195229;
  $107 = ($103*5)|0;
  $108 = (($107) + 1)|0;
  $109 = $108 & 14;
  $110 = (($2) + ($109<<2)|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ((gb + (152432) | 0) + ($103<<2)|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($111) + ($$1231))|0;
  $115 = (($114) + ($113))|0;
  $116 = (($115) + ($106))|0;
  $117 = (_rol($116,9)|0);
  $118 = (($117) + ($102))|0;
  $119 = $$2204227 | 2;
  $120 = $118 ^ $102;
  $121 = $120 & $$1195229;
  $122 = $121 ^ $102;
  $123 = ($119*5)|0;
  $124 = $123 & 14;
  $125 = $124 | 1;
  $126 = (($2) + ($125<<2)|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ((gb + (152432) | 0) + ($119<<2)|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($127) + ($$1191230))|0;
  $131 = (($130) + ($129))|0;
  $132 = (($131) + ($122))|0;
  $133 = (_rol($132,14)|0);
  $134 = (($133) + ($118))|0;
  $135 = $$2204227 | 3;
  $136 = $134 ^ $118;
  $137 = $136 & $102;
  $138 = $137 ^ $118;
  $139 = ($135*5)|0;
  $140 = (($139) + 1)|0;
  $141 = $140 & 12;
  $142 = (($2) + ($141<<2)|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ((gb + (152432) | 0) + ($135<<2)|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($143) + ($$1195229))|0;
  $147 = (($146) + ($145))|0;
  $148 = (($147) + ($138))|0;
  $149 = (_rol($148,20)|0);
  $150 = (($149) + ($134))|0;
  $151 = (($$2204227) + 4)|0;
  $152 = ($151>>>0)<(32);
  if ($152) {
   $$1191230 = $134;$$1195229 = $150;$$1199228 = $102;$$1231 = $118;$$2204227 = $151;
  } else {
   break;
  }
 }
 $$2192217 = $134;$$2196216 = $150;$$2200215 = $102;$$2218 = $118;$$3205214 = 32;
 while(1) {
  $153 = $$2192217 ^ $$2196216;
  $154 = $153 ^ $$2218;
  $155 = ($$3205214*3)|0;
  $156 = (($155) + 5)|0;
  $157 = $156 & 13;
  $158 = (($2) + ($157<<2)|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = ((gb + (152432) | 0) + ($$3205214<<2)|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = (($154) + ($$2200215))|0;
  $163 = (($162) + ($159))|0;
  $164 = (($163) + ($161))|0;
  $165 = (_rol($164,4)|0);
  $166 = (($165) + ($$2196216))|0;
  $167 = $$3205214 | 1;
  $168 = $153 ^ $166;
  $169 = ($167*3)|0;
  $170 = (($169) + 5)|0;
  $171 = $170 & 12;
  $172 = (($2) + ($171<<2)|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ((gb + (152432) | 0) + ($167<<2)|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = (($173) + ($$2218))|0;
  $177 = (($176) + ($175))|0;
  $178 = (($177) + ($168))|0;
  $179 = (_rol($178,11)|0);
  $180 = (($179) + ($166))|0;
  $181 = $$3205214 | 2;
  $182 = $166 ^ $$2196216;
  $183 = $182 ^ $180;
  $184 = ($181*3)|0;
  $185 = (($184) + 5)|0;
  $186 = $185 & 15;
  $187 = (($2) + ($186<<2)|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ((gb + (152432) | 0) + ($181<<2)|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (($188) + ($$2192217))|0;
  $192 = (($191) + ($190))|0;
  $193 = (($192) + ($183))|0;
  $194 = (_rol($193,16)|0);
  $195 = (($194) + ($180))|0;
  $196 = $$3205214 | 3;
  $197 = $180 ^ $166;
  $198 = $197 ^ $195;
  $199 = ($196*3)|0;
  $200 = (($199) + 5)|0;
  $201 = $200 & 14;
  $202 = (($2) + ($201<<2)|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = ((gb + (152432) | 0) + ($196<<2)|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = (($203) + ($$2196216))|0;
  $207 = (($206) + ($205))|0;
  $208 = (($207) + ($198))|0;
  $209 = (_rol($208,23)|0);
  $210 = (($209) + ($195))|0;
  $211 = (($$3205214) + 4)|0;
  $212 = ($211>>>0)<(48);
  if ($212) {
   $$2192217 = $195;$$2196216 = $210;$$2200215 = $166;$$2218 = $180;$$3205214 = $211;
  } else {
   break;
  }
 }
 $$3193209 = $195;$$3197208 = $210;$$3201207 = $166;$$3210 = $180;$$4206 = 48;
 while(1) {
  $213 = $$3210 ^ -1;
  $214 = $$3197208 | $213;
  $215 = $214 ^ $$3193209;
  $216 = ($$4206*7)|0;
  $217 = $216 & 12;
  $218 = (($2) + ($217<<2)|0);
  $219 = HEAP32[$218>>2]|0;
  $220 = ((gb + (152432) | 0) + ($$4206<<2)|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = (($215) + ($$3201207))|0;
  $223 = (($222) + ($219))|0;
  $224 = (($223) + ($221))|0;
  $225 = (_rol($224,6)|0);
  $226 = (($225) + ($$3197208))|0;
  $227 = $$4206 | 1;
  $228 = $$3193209 ^ -1;
  $229 = $226 | $228;
  $230 = $229 ^ $$3197208;
  $231 = ($227*7)|0;
  $232 = $231 & 15;
  $233 = (($2) + ($232<<2)|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = ((gb + (152432) | 0) + ($227<<2)|0);
  $236 = HEAP32[$235>>2]|0;
  $237 = (($234) + ($$3210))|0;
  $238 = (($237) + ($236))|0;
  $239 = (($238) + ($230))|0;
  $240 = (_rol($239,10)|0);
  $241 = (($240) + ($226))|0;
  $242 = $$4206 | 2;
  $243 = $$3197208 ^ -1;
  $244 = $241 | $243;
  $245 = $244 ^ $226;
  $246 = ($242*7)|0;
  $247 = $246 & 14;
  $248 = (($2) + ($247<<2)|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = ((gb + (152432) | 0) + ($242<<2)|0);
  $251 = HEAP32[$250>>2]|0;
  $252 = (($249) + ($$3193209))|0;
  $253 = (($252) + ($251))|0;
  $254 = (($253) + ($245))|0;
  $255 = (_rol($254,15)|0);
  $256 = (($255) + ($241))|0;
  $257 = $$4206 | 3;
  $258 = $226 ^ -1;
  $259 = $256 | $258;
  $260 = $259 ^ $241;
  $261 = ($257*7)|0;
  $262 = $261 & 13;
  $263 = (($2) + ($262<<2)|0);
  $264 = HEAP32[$263>>2]|0;
  $265 = ((gb + (152432) | 0) + ($257<<2)|0);
  $266 = HEAP32[$265>>2]|0;
  $267 = (($264) + ($$3197208))|0;
  $268 = (($267) + ($266))|0;
  $269 = (($268) + ($260))|0;
  $270 = (_rol($269,21)|0);
  $271 = (($270) + ($256))|0;
  $272 = (($$4206) + 4)|0;
  $273 = ($272>>>0)<(64);
  if ($273) {
   $$3193209 = $256;$$3197208 = $271;$$3201207 = $226;$$3210 = $241;$$4206 = $272;
  } else {
   break;
  }
 }
 $274 = (($226) + ($28))|0;
 HEAP32[$27>>2] = $274;
 $275 = (($271) + ($30))|0;
 HEAP32[$29>>2] = $275;
 $276 = (($256) + ($32))|0;
 HEAP32[$31>>2] = $276;
 $277 = (($241) + ($34))|0;
 HEAP32[$33>>2] = $277;
 STACKTOP = sp;return;
}
function _rol($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 << $1;
 $3 = (32 - ($1))|0;
 $4 = $0 >>> $3;
 $5 = $4 | $2;
 return ($5|0);
}
function ___crypt_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP8[$1>>0]|0;
 $4 = ($3<<24>>24)==(36);
 L1: do {
  if ($4) {
   $5 = ((($1)) + 1|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 13;
   } else {
    $8 = ((($1)) + 2|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     label = 13;
    } else {
     $11 = ($6<<24>>24)==(49);
     $12 = ($9<<24>>24)==(36);
     $or$cond = $11 & $12;
     if ($or$cond) {
      $13 = (___crypt_md5($0,$1,$2)|0);
      $$0 = $13;
      break;
     }
     switch ($6<<24>>24) {
     case 50:  {
      $14 = ((($1)) + 3|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)==(36);
      if (!($16)) {
       label = 13;
       break L1;
      }
      $17 = (___crypt_blowfish($0,$1,$2)|0);
      $$0 = $17;
      break L1;
      break;
     }
     case 53:  {
      if (!($12)) {
       label = 13;
       break L1;
      }
      $18 = (___crypt_sha256($0,$1,$2)|0);
      $$0 = $18;
      break L1;
      break;
     }
     case 54:  {
      if (!($12)) {
       label = 13;
       break L1;
      }
      $19 = (___crypt_sha512($0,$1,$2)|0);
      $$0 = $19;
      break L1;
      break;
     }
     default: {
      label = 13;
      break L1;
     }
     }
    }
   }
  } else {
   label = 13;
  }
 } while(0);
 if ((label|0) == 13) {
  $20 = (___crypt_des($0,$1,$2)|0);
  $$0 = $20;
 }
 return ($$0|0);
}
function _setkey($0) {
 $0 = $0|0;
 var $$01116 = 0, $$01215 = 0, $$014 = 0, $$113 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $scevgep = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $$01116 = 0;$$01215 = $0;
 while(1) {
  $2 = (($1) + ($$01116)|0);
  HEAP8[$2>>0] = 0;
  $$014 = 7;$$113 = $$01215;$8 = 0;
  while(1) {
   $3 = HEAP8[$$113>>0]|0;
   $4 = $3 & 1;
   $5 = $4&255;
   $6 = $5 << $$014;
   $7 = $8 & 255;
   $9 = $6 | $7;
   $10 = $9&255;
   HEAP8[$2>>0] = $10;
   $11 = (($$014) + -1)|0;
   $12 = ((($$113)) + 1|0);
   $13 = ($$014|0)==(0);
   if ($13) {
    break;
   } else {
    $$014 = $11;$$113 = $12;$8 = $9;
   }
  }
  $scevgep = ((($$01215)) + 8|0);
  $14 = (($$01116) + 1)|0;
  $exitcond = ($14|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $$01116 = $14;$$01215 = $scevgep;
  }
 }
 ___des_setkey($1,(gb + (171912) | 0));
 STACKTOP = sp;return;
}
function _encrypt($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$03142 = 0, $$03344 = 0, $$036 = 0, $$045 = 0, $$13237 = 0, $$13441 = 0, $$143 = 0, $$23539 = 0, $$240 = 0, $$338 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond47 = 0, $exitcond49 = 0, $scevgep = 0, $scevgep48 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $2 = sp + 8|0;
 $3 = sp;
 $$03344 = 0;$$045 = $0;
 while(1) {
  $4 = (($3) + ($$03344<<2)|0);
  HEAP32[$4>>2] = 0;
  $$03142 = 31;$$143 = $$045;$10 = 0;
  while(1) {
   $5 = HEAP8[$$143>>0]|0;
   $6 = $5 & 1;
   $7 = $6&255;
   $8 = $7 << $$03142;
   $9 = $8 | $10;
   HEAP32[$4>>2] = $9;
   $11 = (($$03142) + -1)|0;
   $12 = ((($$143)) + 1|0);
   $13 = ($$03142|0)==(0);
   if ($13) {
    break;
   } else {
    $$03142 = $11;$$143 = $12;$10 = $9;
   }
  }
  $scevgep48 = ((($$045)) + 32|0);
  $14 = (($$03344) + 1)|0;
  $exitcond49 = ($14|0)==(2);
  if ($exitcond49) {
   break;
  } else {
   $$03344 = $14;$$045 = $scevgep48;
  }
 }
 $15 = ($1|0)==(0);
 if ($15) {
  $$036 = (gb + (171912) | 0);
 } else {
  $$13441 = 0;
  while(1) {
   $16 = (15 - ($$13441))|0;
   $17 = ((gb + (171912) | 0) + ($16<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($2) + ($$13441<<2)|0);
   HEAP32[$19>>2] = $18;
   $20 = ((((gb + (171912) | 0)) + 64|0) + ($16<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (((($2)) + 64|0) + ($$13441<<2)|0);
   HEAP32[$22>>2] = $21;
   $23 = (($$13441) + 1)|0;
   $exitcond47 = ($23|0)==(16);
   if ($exitcond47) {
    $$036 = $2;
    break;
   } else {
    $$13441 = $23;
   }
  }
 }
 $24 = HEAP32[$3>>2]|0;
 $25 = ((($3)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 ___do_des($24,$26,$3,$25,1,0,$$036);
 $$23539 = 0;$$240 = $0;
 while(1) {
  $27 = (($3) + ($$23539<<2)|0);
  $$13237 = 31;$$338 = $$240;
  while(1) {
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 >>> $$13237;
   $30 = $29 & 1;
   $31 = $30&255;
   $32 = ((($$338)) + 1|0);
   HEAP8[$$338>>0] = $31;
   $33 = (($$13237) + -1)|0;
   $34 = ($$13237|0)==(0);
   if ($34) {
    break;
   } else {
    $$13237 = $33;$$338 = $32;
   }
  }
  $scevgep = ((($$240)) + 32|0);
  $35 = (($$23539) + 1)|0;
  $exitcond = ($35|0)==(2);
  if ($exitcond) {
   break;
  } else {
   $$23539 = $35;$$240 = $scevgep;
  }
 }
 STACKTOP = sp;return;
}
function _crypt($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___crypt_r($0,$1,(gb + (170128) | 0))|0);
 return ($2|0);
}
function _wcstoull($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstox($0,$1,$2,-1,-1)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _wcstox($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $5 = sp;
 $6 = sp + 64|0;
 $7 = ((($6)) + 8|0);
 $8 = ((($6)) + 4|0);
 $9 = ((($5)) + 4|0);
 $10 = ((($6)) + 44|0);
 dest=$6; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$10>>2] = $9;
 $11 = ((($6)) + 48|0);
 HEAP32[$11>>2] = 60;
 $12 = ((($6)) + 76|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($6)) + 32|0);
 HEAP32[$13>>2] = (fb + (18) | 0);
 $$0 = $0;
 while(1) {
  $14 = HEAP32[$$0>>2]|0;
  $15 = (_iswspace($14)|0);
  $16 = ($15|0)==(0);
  $17 = ((($$0)) + 4|0);
  if ($16) {
   break;
  } else {
   $$0 = $17;
  }
 }
 $18 = ((($6)) + 84|0);
 HEAP32[$18>>2] = $$0;
 ___shlim($6,0);
 $19 = (___intscan($6,$2,1,$3,$4)|0);
 $20 = (getTempRet0() | 0);
 $21 = ($1|0)==(0|0);
 if (!($21)) {
  $22 = ((($6)) + 108|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$8>>2]|0;
  $25 = HEAP32[$7>>2]|0;
  $26 = (($24) - ($25))|0;
  $27 = (($26) + ($23))|0;
  $28 = ($27|0)==(0);
  $29 = (($$0) + ($27<<2)|0);
  $30 = $28 ? $0 : $29;
  HEAP32[$1>>2] = $30;
 }
 setTempRet0(($20) | 0);
 STACKTOP = sp;return ($19|0);
}
function _do_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$029 = 0, $$030 = 0, $$cast = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 $spec$store$select = $6 ? (gb + (166316) | 0) : $4;
 $7 = ((($0)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 $$pre = ((($0)) + 44|0);
 L1: do {
  if ($9) {
   $$0$lcssa = 0;
  } else {
   $$030 = 0;
   while(1) {
    $10 = (($spec$store$select) + ($$030<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0);
    if ($12) {
     $$0$lcssa = $$030;
     break L1;
    }
    $13 = ($11|0)<(128);
    $14 = $11&255;
    $15 = $13 ? $14 : 64;
    $16 = HEAP32[$$pre>>2]|0;
    $17 = (($16) + ($$030)|0);
    HEAP8[$17>>0] = $15;
    $18 = (($$030) + 1)|0;
    $19 = HEAP32[$7>>2]|0;
    $20 = ($18>>>0)<($19>>>0);
    if ($20) {
     $$030 = $18;
    } else {
     $$0$lcssa = $18;
     break;
    }
   }
  }
 } while(0);
 $21 = HEAP32[$$pre>>2]|0;
 $22 = ((($0)) + 4|0);
 HEAP32[$22>>2] = $21;
 $$cast = $21;
 $23 = (($$cast) + ($$0$lcssa)|0);
 $24 = ((($0)) + 8|0);
 HEAP32[$24>>2] = $23;
 $25 = (($spec$store$select) + ($$0$lcssa<<2)|0);
 HEAP32[$3>>2] = $25;
 $26 = ($$0$lcssa|0)!=(0);
 $27 = ($2|0)!=(0);
 $or$cond = $27 & $26;
 if ($or$cond) {
  $28 = ((($$cast)) + 1|0);
  HEAP32[$22>>2] = $28;
  $29 = HEAP8[$$cast>>0]|0;
  HEAP8[$1>>0] = $29;
  $$029 = 1;
 } else {
  $$029 = 0;
 }
 return ($$029|0);
}
function _wcstoll($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstox($0,$1,$2,0,-2147483648)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _wcstoul($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstox($0,$1,$2,-1,0)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _wcstol($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstox($0,$1,$2,-2147483648,0)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _wcstoimax($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstoll($0,$1,$2)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _wcstoumax($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcstoull($0,$1,$2)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _strtof($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox($0,$1,0));
 $3 = $2;
 return (+$3);
}
function _strtox($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 dest=$3; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = ((($3)) + 4|0);
 HEAP32[$4>>2] = $0;
 $5 = ((($3)) + 8|0);
 HEAP32[$5>>2] = (-1);
 $6 = ((($3)) + 44|0);
 HEAP32[$6>>2] = $0;
 $7 = ((($3)) + 76|0);
 HEAP32[$7>>2] = -1;
 ___shlim($3,0);
 $8 = (+___floatscan($3,$2,1));
 $9 = ((($3)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = (($11) - ($12))|0;
 $14 = (($13) + ($10))|0;
 $15 = ($1|0)==(0|0);
 if (!($15)) {
  $16 = ($14|0)==(0);
  $17 = (($0) + ($14)|0);
  $18 = $16 ? $0 : $17;
  HEAP32[$1>>2] = $18;
 }
 STACKTOP = sp;return (+$8);
}
function ___floatscan($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0102 = 0, $$0103 = 0, $$0104122 = 0, $$0110 = 0, $$0111 = 0.0, $$1$lcssa = 0, $$1105118 = 0, $$1123 = 0, $$2 = 0, $$2106120 = 0, $$3107 = 0, $$3121 = 0, $$4 = 0, $$4108 = 0, $$5 = 0, $$6 = 0, $$in = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0.0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond124 = 0, $or$cond5 = 0, $or$cond7 = 0, $trunc = 0, $trunc$clear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($1|0) {
 case 0:  {
  $$0102 = -149;$$0103 = 24;
  label = 4;
  break;
 }
 case 1:  {
  $$0102 = -1074;$$0103 = 53;
  label = 4;
  break;
 }
 case 2:  {
  $$0102 = -1074;$$0103 = 53;
  label = 4;
  break;
 }
 default: {
  $$0111 = 0.0;
 }
 }
 L4: do {
  if ((label|0) == 4) {
   $3 = ((($0)) + 4|0);
   $4 = ((($0)) + 100|0);
   while(1) {
    $5 = HEAP32[$3>>2]|0;
    $6 = HEAP32[$4>>2]|0;
    $7 = ($5>>>0)<($6>>>0);
    if ($7) {
     $8 = ((($5)) + 1|0);
     HEAP32[$3>>2] = $8;
     $9 = HEAP8[$5>>0]|0;
     $10 = $9&255;
     $12 = $10;
    } else {
     $11 = (___shgetc($0)|0);
     $12 = $11;
    }
    $13 = (_isspace($12)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     break;
    }
   }
   L13: do {
    switch ($12|0) {
    case 43: case 45:  {
     $15 = ($12|0)==(45);
     $16 = $15&1;
     $17 = $16 << 1;
     $18 = (1 - ($17))|0;
     $19 = HEAP32[$3>>2]|0;
     $20 = HEAP32[$4>>2]|0;
     $21 = ($19>>>0)<($20>>>0);
     if ($21) {
      $22 = ((($19)) + 1|0);
      HEAP32[$3>>2] = $22;
      $23 = HEAP8[$19>>0]|0;
      $24 = $23&255;
      $$0 = $24;$$0110 = $18;
      break L13;
     } else {
      $25 = (___shgetc($0)|0);
      $$0 = $25;$$0110 = $18;
      break L13;
     }
     break;
    }
    default: {
     $$0 = $12;$$0110 = 1;
    }
    }
   } while(0);
   $$0104122 = 0;$$1123 = $$0;
   while(1) {
    $26 = $$1123 | 32;
    $27 = ((gb + (167243) | 0) + ($$0104122)|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28 << 24 >> 24;
    $30 = ($26|0)==($29|0);
    if (!($30)) {
     $$1$lcssa = $$1123;$trunc = $$0104122;
     break;
    }
    $31 = ($$0104122>>>0)<(7);
    do {
     if ($31) {
      $32 = HEAP32[$3>>2]|0;
      $33 = HEAP32[$4>>2]|0;
      $34 = ($32>>>0)<($33>>>0);
      if ($34) {
       $35 = ((($32)) + 1|0);
       HEAP32[$3>>2] = $35;
       $36 = HEAP8[$32>>0]|0;
       $37 = $36&255;
       $$2 = $37;
       break;
      } else {
       $38 = (___shgetc($0)|0);
       $$2 = $38;
       break;
      }
     } else {
      $$2 = $$1123;
     }
    } while(0);
    $39 = (($$0104122) + 1)|0;
    $40 = ($39>>>0)<(8);
    if ($40) {
     $$0104122 = $39;$$1123 = $$2;
    } else {
     $$1$lcssa = $$2;$trunc = 8;
     break;
    }
   }
   $trunc$clear = $trunc & 2147483647;
   L29: do {
    switch ($trunc$clear|0) {
    case 8:  {
     break;
    }
    case 3:  {
     label = 23;
     break;
    }
    default: {
     $41 = ($trunc>>>0)>(3);
     $42 = ($2|0)!=(0);
     $or$cond5 = $42 & $41;
     if ($or$cond5) {
      $43 = ($trunc|0)==(8);
      if ($43) {
       break L29;
      } else {
       label = 23;
       break L29;
      }
     }
     $57 = ($trunc|0)==(0);
     L34: do {
      if ($57) {
       $$2106120 = 0;$$3121 = $$1$lcssa;
       while(1) {
        $58 = $$3121 | 32;
        $59 = ((gb + (167252) | 0) + ($$2106120)|0);
        $60 = HEAP8[$59>>0]|0;
        $61 = $60 << 24 >> 24;
        $62 = ($58|0)==($61|0);
        if (!($62)) {
         $$3107 = $$2106120;$$5 = $$3121;
         break L34;
        }
        $63 = ($$2106120>>>0)<(2);
        do {
         if ($63) {
          $64 = HEAP32[$3>>2]|0;
          $65 = HEAP32[$4>>2]|0;
          $66 = ($64>>>0)<($65>>>0);
          if ($66) {
           $67 = ((($64)) + 1|0);
           HEAP32[$3>>2] = $67;
           $68 = HEAP8[$64>>0]|0;
           $69 = $68&255;
           $$4 = $69;
           break;
          } else {
           $70 = (___shgetc($0)|0);
           $$4 = $70;
           break;
          }
         } else {
          $$4 = $$3121;
         }
        } while(0);
        $71 = (($$2106120) + 1)|0;
        $72 = ($71>>>0)<(3);
        if ($72) {
         $$2106120 = $71;$$3121 = $$4;
        } else {
         $$3107 = 3;$$5 = $$4;
         break;
        }
       }
      } else {
       $$3107 = $trunc;$$5 = $$1$lcssa;
      }
     } while(0);
     switch ($$3107|0) {
     case 3:  {
      $73 = HEAP32[$3>>2]|0;
      $74 = HEAP32[$4>>2]|0;
      $75 = ($73>>>0)<($74>>>0);
      if ($75) {
       $76 = ((($73)) + 1|0);
       HEAP32[$3>>2] = $76;
       $77 = HEAP8[$73>>0]|0;
       $78 = $77&255;
       $81 = $78;
      } else {
       $79 = (___shgetc($0)|0);
       $81 = $79;
      }
      $80 = ($81|0)==(40);
      if (!($80)) {
       $82 = HEAP32[$4>>2]|0;
       $83 = ($82|0)==(0|0);
       if ($83) {
        $$0111 = nan;
        break L4;
       }
       $84 = HEAP32[$3>>2]|0;
       $85 = ((($84)) + -1|0);
       HEAP32[$3>>2] = $85;
       $$0111 = nan;
       break L4;
      }
      $$4108 = 1;
      while(1) {
       $86 = HEAP32[$3>>2]|0;
       $87 = HEAP32[$4>>2]|0;
       $88 = ($86>>>0)<($87>>>0);
       if ($88) {
        $89 = ((($86)) + 1|0);
        HEAP32[$3>>2] = $89;
        $90 = HEAP8[$86>>0]|0;
        $91 = $90&255;
        $94 = $91;
       } else {
        $92 = (___shgetc($0)|0);
        $94 = $92;
       }
       $93 = (($94) + -48)|0;
       $95 = ($93>>>0)<(10);
       $96 = (($94) + -65)|0;
       $97 = ($96>>>0)<(26);
       $or$cond = $95 | $97;
       if (!($or$cond)) {
        $98 = (($94) + -97)|0;
        $99 = ($98>>>0)<(26);
        $100 = ($94|0)==(95);
        $or$cond7 = $100 | $99;
        if (!($or$cond7)) {
         break;
        }
       }
       $112 = (($$4108) + 1)|0;
       $$4108 = $112;
      }
      $101 = ($94|0)==(41);
      if ($101) {
       $$0111 = nan;
       break L4;
      }
      $102 = HEAP32[$4>>2]|0;
      $103 = ($102|0)==(0|0);
      if (!($103)) {
       $104 = HEAP32[$3>>2]|0;
       $105 = ((($104)) + -1|0);
       HEAP32[$3>>2] = $105;
      }
      if (!($42)) {
       $106 = (___errno_location()|0);
       HEAP32[$106>>2] = 22;
       ___shlim($0,0);
       $$0111 = 0.0;
       break L4;
      }
      $107 = ($$4108|0)==(0);
      if ($107) {
       $$0111 = nan;
       break L4;
      }
      $$in = $$4108;
      while(1) {
       $108 = (($$in) + -1)|0;
       if (!($103)) {
        $109 = HEAP32[$3>>2]|0;
        $110 = ((($109)) + -1|0);
        HEAP32[$3>>2] = $110;
       }
       $111 = ($108|0)==(0);
       if ($111) {
        $$0111 = nan;
        break L4;
       } else {
        $$in = $108;
       }
      }
      break;
     }
     case 0:  {
      $118 = ($$5|0)==(48);
      if ($118) {
       $119 = HEAP32[$3>>2]|0;
       $120 = HEAP32[$4>>2]|0;
       $121 = ($119>>>0)<($120>>>0);
       if ($121) {
        $122 = ((($119)) + 1|0);
        HEAP32[$3>>2] = $122;
        $123 = HEAP8[$119>>0]|0;
        $124 = $123&255;
        $127 = $124;
       } else {
        $125 = (___shgetc($0)|0);
        $127 = $125;
       }
       $126 = $127 | 32;
       $128 = ($126|0)==(120);
       if ($128) {
        $129 = (+_hexfloat($0,$$0103,$$0102,$$0110,$2));
        $$0111 = $129;
        break L4;
       }
       $130 = HEAP32[$4>>2]|0;
       $131 = ($130|0)==(0|0);
       if ($131) {
        $$6 = 48;
       } else {
        $132 = HEAP32[$3>>2]|0;
        $133 = ((($132)) + -1|0);
        HEAP32[$3>>2] = $133;
        $$6 = 48;
       }
      } else {
       $$6 = $$5;
      }
      $134 = (+_decfloat($0,$$6,$$0103,$$0102,$$0110,$2));
      $$0111 = $134;
      break L4;
      break;
     }
     default: {
      $113 = HEAP32[$4>>2]|0;
      $114 = ($113|0)==(0|0);
      if (!($114)) {
       $115 = HEAP32[$3>>2]|0;
       $116 = ((($115)) + -1|0);
       HEAP32[$3>>2] = $116;
      }
      $117 = (___errno_location()|0);
      HEAP32[$117>>2] = 22;
      ___shlim($0,0);
      $$0111 = 0.0;
      break L4;
     }
     }
    }
    }
   } while(0);
   if ((label|0) == 23) {
    $44 = HEAP32[$4>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = HEAP32[$3>>2]|0;
     $47 = ((($46)) + -1|0);
     HEAP32[$3>>2] = $47;
    }
    $48 = ($2|0)!=(0);
    $49 = ($trunc>>>0)>(3);
    $or$cond124 = $48 & $49;
    if ($or$cond124) {
     $$1105118 = $trunc;
     while(1) {
      if (!($45)) {
       $50 = HEAP32[$3>>2]|0;
       $51 = ((($50)) + -1|0);
       HEAP32[$3>>2] = $51;
      }
      $52 = (($$1105118) + -1)|0;
      $53 = ($52>>>0)>(3);
      if ($53) {
       $$1105118 = $52;
      } else {
       break;
      }
     }
    }
   }
   $54 = (+($$0110|0));
   $55 = $54 * inf;
   $56 = $55;
   $$0111 = $56;
  }
 } while(0);
 return (+$$0111);
}
function _hexfloat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0$be = 0, $$0$ph = 0, $$0133 = 0, $$0143 = 0, $$0151 = 0, $$0154 = 0.0, $$0155 = 0.0, $$0158 = 0.0, $$0163 = 0, $$0169 = 0.0, $$0170 = 0, $$0170173 = 0, $$0170174 = 0, $$1149 = 0, $$1149$ph = 0, $$1152 = 0, $$1156 = 0.0, $$1159 = 0.0, $$1164 = 0;
 var $$2150 = 0, $$2153 = 0, $$2157 = 0.0, $$2160 = 0.0, $$2165 = 0, $$3 = 0, $$3$be = 0, $$3$lcssa = 0, $$3$ph = 0, $$3146 = 0, $$3146$ph = 0, $$3161$lcssa = 0.0, $$3161181 = 0.0, $$3166$lcssa = 0, $$3166185 = 0, $$4147 = 0, $$4162 = 0.0, $$4167$lcssa = 0, $$4167180 = 0, $$5 = 0.0;
 var $$5168 = 0, $$6 = 0, $$pn = 0.0, $$pre = 0, $$pre$phi204Z2D = 0.0, $$pre203 = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0.0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0.0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0;
 var $not$ = 0, $or$cond = 0, $or$cond172 = 0, $or$cond4 = 0, $or$cond6 = 0, $spec$select175 = 0.0, $spec$select176 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 100|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  $10 = ((($6)) + 1|0);
  HEAP32[$5>>2] = $10;
  $11 = HEAP8[$6>>0]|0;
  $12 = $11&255;
  $$0$ph = $12;
 } else {
  $13 = (___shgetc($0)|0);
  $$0$ph = $13;
 }
 $$0 = $$0$ph;$$0143 = 0;
 L5: while(1) {
  switch ($$0|0) {
  case 46:  {
   label = 10;
   break L5;
   break;
  }
  case 48:  {
   break;
  }
  default: {
   $$1149$ph = 0;$$3$ph = $$0;$$3146$ph = $$0143;$212 = 0;$213 = 0;
   break L5;
  }
  }
  $14 = HEAP32[$5>>2]|0;
  $15 = HEAP32[$7>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if ($16) {
   $17 = ((($14)) + 1|0);
   HEAP32[$5>>2] = $17;
   $18 = HEAP8[$14>>0]|0;
   $19 = $18&255;
   $$0$be = $19;
  } else {
   $20 = (___shgetc($0)|0);
   $$0$be = $20;
  }
  $$0 = $$0$be;$$0143 = 1;
 }
 if ((label|0) == 10) {
  $21 = HEAP32[$5>>2]|0;
  $22 = HEAP32[$7>>2]|0;
  $23 = ($21>>>0)<($22>>>0);
  if ($23) {
   $24 = ((($21)) + 1|0);
   HEAP32[$5>>2] = $24;
   $25 = HEAP8[$21>>0]|0;
   $26 = $25&255;
   $29 = $26;
  } else {
   $27 = (___shgetc($0)|0);
   $29 = $27;
  }
  $28 = ($29|0)==(48);
  if ($28) {
   $37 = 0;$38 = 0;
   while(1) {
    $30 = HEAP32[$5>>2]|0;
    $31 = HEAP32[$7>>2]|0;
    $32 = ($30>>>0)<($31>>>0);
    if ($32) {
     $33 = ((($30)) + 1|0);
     HEAP32[$5>>2] = $33;
     $34 = HEAP8[$30>>0]|0;
     $35 = $34&255;
     $42 = $35;
    } else {
     $36 = (___shgetc($0)|0);
     $42 = $36;
    }
    $39 = (_i64Add(($37|0),($38|0),-1,-1)|0);
    $40 = (getTempRet0() | 0);
    $41 = ($42|0)==(48);
    if ($41) {
     $37 = $39;$38 = $40;
    } else {
     $$1149$ph = 1;$$3$ph = $42;$$3146$ph = 1;$212 = $39;$213 = $40;
     break;
    }
   }
  } else {
   $$1149$ph = 1;$$3$ph = $29;$$3146$ph = $$0143;$212 = 0;$213 = 0;
  }
 }
 $$0151 = 0;$$0155 = 1.0;$$0158 = 0.0;$$0163 = 0;$$1149 = $$1149$ph;$$3 = $$3$ph;$$3146 = $$3146$ph;$52 = 0;$54 = 0;$97 = $212;$99 = $213;
 while(1) {
  $43 = (($$3) + -48)|0;
  $44 = ($43>>>0)<(10);
  $$pre = $$3 | 32;
  if ($44) {
   label = 24;
  } else {
   $45 = (($$pre) + -97)|0;
   $46 = ($45>>>0)<(6);
   $47 = ($$3|0)==(46);
   $or$cond6 = $47 | $46;
   if (!($or$cond6)) {
    $$3$lcssa = $$3;
    break;
   }
   if ($47) {
    $48 = ($$1149|0)==(0);
    if ($48) {
     $$2150 = 1;$$2153 = $$0151;$$2157 = $$0155;$$2160 = $$0158;$$2165 = $$0163;$$4147 = $$3146;$214 = $54;$215 = $52;$216 = $54;$217 = $52;
    } else {
     $$3$lcssa = 46;
     break;
    }
   } else {
    label = 24;
   }
  }
  if ((label|0) == 24) {
   label = 0;
   $49 = ($$3|0)>(57);
   $50 = (($$pre) + -87)|0;
   $$0133 = $49 ? $50 : $43;
   $51 = ($52|0)<(0);
   $53 = ($54>>>0)<(8);
   $55 = ($52|0)==(0);
   $56 = $55 & $53;
   $57 = $51 | $56;
   do {
    if ($57) {
     $58 = $$0163 << 4;
     $59 = (($$0133) + ($58))|0;
     $$1152 = $$0151;$$1156 = $$0155;$$1159 = $$0158;$$1164 = $59;
    } else {
     $60 = ($52|0)<(0);
     $61 = ($54>>>0)<(14);
     $62 = ($52|0)==(0);
     $63 = $62 & $61;
     $64 = $60 | $63;
     if ($64) {
      $65 = (+($$0133|0));
      $66 = $$0155 * 0.0625;
      $67 = $66 * $65;
      $68 = $$0158 + $67;
      $$1152 = $$0151;$$1156 = $66;$$1159 = $68;$$1164 = $$0163;
      break;
     } else {
      $69 = ($$0133|0)==(0);
      $70 = ($$0151|0)!=(0);
      $or$cond = $70 | $69;
      $71 = $$0155 * 0.5;
      $72 = $$0158 + $71;
      $spec$select175 = $or$cond ? $$0158 : $72;
      $spec$select176 = $or$cond ? $$0151 : 1;
      $$1152 = $spec$select176;$$1156 = $$0155;$$1159 = $spec$select175;$$1164 = $$0163;
      break;
     }
    }
   } while(0);
   $73 = (_i64Add(($54|0),($52|0),1,0)|0);
   $74 = (getTempRet0() | 0);
   $$2150 = $$1149;$$2153 = $$1152;$$2157 = $$1156;$$2160 = $$1159;$$2165 = $$1164;$$4147 = 1;$214 = $97;$215 = $99;$216 = $73;$217 = $74;
  }
  $75 = HEAP32[$5>>2]|0;
  $76 = HEAP32[$7>>2]|0;
  $77 = ($75>>>0)<($76>>>0);
  if ($77) {
   $78 = ((($75)) + 1|0);
   HEAP32[$5>>2] = $78;
   $79 = HEAP8[$75>>0]|0;
   $80 = $79&255;
   $$3$be = $80;
  } else {
   $81 = (___shgetc($0)|0);
   $$3$be = $81;
  }
  $$0151 = $$2153;$$0155 = $$2157;$$0158 = $$2160;$$0163 = $$2165;$$1149 = $$2150;$$3 = $$3$be;$$3146 = $$4147;$52 = $217;$54 = $216;$97 = $214;$99 = $215;
 }
 $82 = ($$3146|0)==(0);
 do {
  if ($82) {
   $83 = HEAP32[$7>>2]|0;
   $84 = ($83|0)==(0|0);
   if (!($84)) {
    $85 = HEAP32[$5>>2]|0;
    $86 = ((($85)) + -1|0);
    HEAP32[$5>>2] = $86;
   }
   $87 = ($4|0)==(0);
   if ($87) {
    ___shlim($0,0);
   } else {
    if (!($84)) {
     $88 = HEAP32[$5>>2]|0;
     $89 = ((($88)) + -1|0);
     HEAP32[$5>>2] = $89;
     $90 = ($$1149|0)==(0);
     $brmerge = $90 | $84;
     if (!($brmerge)) {
      $91 = HEAP32[$5>>2]|0;
      $92 = ((($91)) + -1|0);
      HEAP32[$5>>2] = $92;
     }
    }
   }
   $93 = (+($3|0));
   $94 = $93 * 0.0;
   $$0169 = $94;
  } else {
   $95 = ($$1149|0)==(0);
   $96 = $95 ? $54 : $97;
   $98 = $95 ? $52 : $99;
   $100 = ($52|0)<(0);
   $101 = ($54>>>0)<(8);
   $102 = ($52|0)==(0);
   $103 = $102 & $101;
   $104 = $100 | $103;
   if ($104) {
    $$3166185 = $$0163;$106 = $54;$107 = $52;
    while(1) {
     $105 = $$3166185 << 4;
     $108 = (_i64Add(($106|0),($107|0),1,0)|0);
     $109 = (getTempRet0() | 0);
     $110 = ($107|0)<(0);
     $111 = ($106>>>0)<(7);
     $112 = ($107|0)==(0);
     $113 = $112 & $111;
     $114 = $110 | $113;
     if ($114) {
      $$3166185 = $105;$106 = $108;$107 = $109;
     } else {
      $$3166$lcssa = $105;
      break;
     }
    }
   } else {
    $$3166$lcssa = $$0163;
   }
   $115 = $$3$lcssa | 32;
   $116 = ($115|0)==(112);
   if ($116) {
    $117 = (_scanexp($0,$4)|0);
    $118 = (getTempRet0() | 0);
    $119 = ($117|0)==(0);
    $120 = ($118|0)==(-2147483648);
    $121 = $119 & $120;
    if ($121) {
     $122 = ($4|0)==(0);
     if ($122) {
      ___shlim($0,0);
      $$0169 = 0.0;
      break;
     }
     $123 = HEAP32[$7>>2]|0;
     $124 = ($123|0)==(0|0);
     if ($124) {
      $135 = 0;$136 = 0;
     } else {
      $125 = HEAP32[$5>>2]|0;
      $126 = ((($125)) + -1|0);
      HEAP32[$5>>2] = $126;
      $135 = 0;$136 = 0;
     }
    } else {
     $135 = $117;$136 = $118;
    }
   } else {
    $127 = HEAP32[$7>>2]|0;
    $128 = ($127|0)==(0|0);
    if ($128) {
     $135 = 0;$136 = 0;
    } else {
     $129 = HEAP32[$5>>2]|0;
     $130 = ((($129)) + -1|0);
     HEAP32[$5>>2] = $130;
     $135 = 0;$136 = 0;
    }
   }
   $131 = (_bitshift64Shl(($96|0),($98|0),2)|0);
   $132 = (getTempRet0() | 0);
   $133 = (_i64Add(($131|0),($132|0),-32,-1)|0);
   $134 = (getTempRet0() | 0);
   $137 = (_i64Add(($133|0),($134|0),($135|0),($136|0))|0);
   $138 = (getTempRet0() | 0);
   $139 = ($$3166$lcssa|0)==(0);
   if ($139) {
    $140 = (+($3|0));
    $141 = $140 * 0.0;
    $$0169 = $141;
    break;
   }
   $142 = (0 - ($2))|0;
   $143 = ($142|0)<(0);
   $144 = $143 << 31 >> 31;
   $145 = ($138|0)>($144|0);
   $146 = ($137>>>0)>($142>>>0);
   $147 = ($138|0)==($144|0);
   $148 = $147 & $146;
   $149 = $145 | $148;
   if ($149) {
    $150 = (___errno_location()|0);
    HEAP32[$150>>2] = 34;
    $151 = (+($3|0));
    $152 = $151 * 1.7976931348623157E+308;
    $153 = $152 * 1.7976931348623157E+308;
    $$0169 = $153;
    break;
   }
   $154 = (($2) + -106)|0;
   $155 = ($154|0)<(0);
   $156 = $155 << 31 >> 31;
   $157 = ($138|0)<($156|0);
   $158 = ($137>>>0)<($154>>>0);
   $159 = ($138|0)==($156|0);
   $160 = $159 & $158;
   $161 = $157 | $160;
   if ($161) {
    $162 = (___errno_location()|0);
    HEAP32[$162>>2] = 34;
    $163 = (+($3|0));
    $164 = $163 * 2.2250738585072014E-308;
    $165 = $164 * 2.2250738585072014E-308;
    $$0169 = $165;
    break;
   }
   $166 = ($$3166$lcssa|0)>(-1);
   if ($166) {
    $$3161181 = $$0158;$$4167180 = $$3166$lcssa;$171 = $137;$172 = $138;
    while(1) {
     $167 = !($$3161181 >= 0.5);
     $168 = $$4167180 << 1;
     $169 = $$3161181 + -1.0;
     $not$ = $167 ^ 1;
     $170 = $not$&1;
     $$5168 = $168 | $170;
     $$pn = $167 ? $$3161181 : $169;
     $$4162 = $$3161181 + $$pn;
     $173 = (_i64Add(($171|0),($172|0),-1,-1)|0);
     $174 = (getTempRet0() | 0);
     $175 = ($$5168|0)>(-1);
     if ($175) {
      $$3161181 = $$4162;$$4167180 = $$5168;$171 = $173;$172 = $174;
     } else {
      $$3161$lcssa = $$4162;$$4167$lcssa = $$5168;$182 = $173;$183 = $174;
      break;
     }
    }
   } else {
    $$3161$lcssa = $$0158;$$4167$lcssa = $$3166$lcssa;$182 = $137;$183 = $138;
   }
   $176 = ($1|0)<(0);
   $177 = $176 << 31 >> 31;
   $178 = ($2|0)<(0);
   $179 = $178 << 31 >> 31;
   $180 = (_i64Subtract(32,0,($2|0),($179|0))|0);
   $181 = (getTempRet0() | 0);
   $184 = (_i64Add(($180|0),($181|0),($182|0),($183|0))|0);
   $185 = (getTempRet0() | 0);
   $186 = ($185|0)<($177|0);
   $187 = ($184>>>0)<($1>>>0);
   $188 = ($185|0)==($177|0);
   $189 = $188 & $187;
   $190 = $186 | $189;
   if ($190) {
    $191 = ($184|0)>(0);
    if ($191) {
     $$0170 = $184;
     label = 65;
    } else {
     $$0170174 = 0;$195 = 84;
     label = 67;
    }
   } else {
    $$0170 = $1;
    label = 65;
   }
   if ((label|0) == 65) {
    $192 = ($$0170|0)<(53);
    $193 = (84 - ($$0170))|0;
    if ($192) {
     $$0170174 = $$0170;$195 = $193;
     label = 67;
    } else {
     $$pre203 = (+($3|0));
     $$0154 = 0.0;$$0170173 = $$0170;$$pre$phi204Z2D = $$pre203;
    }
   }
   if ((label|0) == 67) {
    $194 = (+($3|0));
    $196 = (+_scalbn(1.0,$195));
    $197 = (+_copysignl($196,$194));
    $$0154 = $197;$$0170173 = $$0170174;$$pre$phi204Z2D = $194;
   }
   $198 = ($$0170173|0)<(32);
   $199 = $$3161$lcssa != 0.0;
   $or$cond4 = $199 & $198;
   $200 = $$4167$lcssa & 1;
   $201 = ($200|0)==(0);
   $or$cond172 = $201 & $or$cond4;
   $202 = $or$cond172&1;
   $$6 = (($$4167$lcssa) + ($202))|0;
   $$5 = $or$cond172 ? 0.0 : $$3161$lcssa;
   $203 = (+($$6>>>0));
   $204 = $$pre$phi204Z2D * $203;
   $205 = $$0154 + $204;
   $206 = $$5 * $$pre$phi204Z2D;
   $207 = $206 + $205;
   $208 = $207 - $$0154;
   $209 = $208 != 0.0;
   if (!($209)) {
    $210 = (___errno_location()|0);
    HEAP32[$210>>2] = 34;
   }
   $211 = (+_scalbnl($208,$182));
   $$0169 = $211;
  }
 } while(0);
 return (+$$0169);
}
function _decfloat($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0324 = 0, $$0324$be = 0, $$0327480 = 0, $$0328 = 0, $$0329 = 0, $$0331476 = 0, $$0335486 = 0, $$0336$lcssa = 0, $$0336453 = 0, $$0336454 = 0, $$0336455 = 0, $$0336503 = 0, $$0340$lcssa = 0, $$0340457 = 0, $$0340458 = 0, $$0340459 = 0, $$0340502 = 0, $$0345$lcssa540 = 0, $$0345484 = 0, $$0355 = 0.0;
 var $$0356 = 0.0, $$0360474 = 0.0, $$0367 = 0, $$0376 = 0, $$0376$ph = 0, $$0381$lcssa539 = 0, $$0381483 = 0, $$0390 = 0, $$0393 = 0, $$0398$lcssa = 0, $$0398463 = 0, $$0398464 = 0, $$0398465 = 0, $$0398499 = 0, $$1 = 0.0, $$10473 = 0, $$11 = 0, $$1330 = 0, $$1357 = 0.0, $$1361 = 0.0;
 var $$1377 = 0, $$1377$ph = 0, $$1377$ph$ph = 0, $$1391$lcssa = 0, $$1391501 = 0, $$2 = 0, $$2338 = 0, $$2342 = 0, $$2362 = 0.0, $$2366$v = 0, $$2369 = 0, $$2369$ph = 0, $$2369$ph579 = 0, $$2392 = 0, $$2395 = 0, $$2400 = 0, $$3$lcssa = 0, $$3339493 = 0, $$3343 = 0, $$3348$ph = 0;
 var $$3348$ph580 = 0, $$3359 = 0.0, $$3363 = 0.0, $$3370 = 0, $$3379 = 0, $$3384$ph = 0, $$3384$ph578 = 0, $$3396$lcssa = 0, $$3396500 = 0, $$3504 = 0, $$4344485 = 0, $$4380 = 0, $$4397 = 0, $$4475 = 0, $$5 = 0, $$5$in = 0, $$5350 = 0, $$5350$ph = 0, $$5350$ph$ph = 0, $$5372 = 0;
 var $$5386$ph = 0, $$5386$ph576 = 0, $$5386$ph576$ph = 0, $$6351478 = 0, $$6387477 = 0, $$6479 = 0, $$7374$ph$ph = 0, $$neg447 = 0, $$neg448 = 0, $$pre = 0, $$promoted = 0, $$sink$off0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0;
 var $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0, $185 = 0, $186 = 0, $187 = 0.0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0, $314 = 0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0.0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0.0, $327 = 0.0, $328 = 0, $329 = 0.0, $33 = 0, $330 = 0.0, $331 = 0.0, $332 = 0.0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0.0, $344 = 0.0, $345 = 0, $346 = 0.0, $347 = 0.0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0.0, $352 = 0.0, $353 = 0.0, $354 = 0.0, $355 = 0, $356 = 0, $357 = 0.0, $358 = 0, $359 = 0.0, $36 = 0, $360 = 0.0;
 var $361 = 0.0, $362 = 0, $363 = 0, $364 = 0, $365 = 0.0, $366 = 0, $367 = 0.0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0.0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $cond = 0, $exitcond = 0, $narrow = 0, $not$ = 0, $or$cond = 0, $or$cond3 = 0, $or$cond414 = 0, $or$cond416 = 0, $or$cond417 = 0, $or$cond418 = 0, $or$cond421 = 0, $or$cond559 = 0, $or$cond9 = 0, $spec$select = 0, $spec$select410 = 0, $spec$select411 = 0, $spec$select419 = 0, $spec$select420 = 0, $spec$select439 = 0;
 var $spec$select440 = 0, $spec$select441 = 0, $spec$select442 = 0, $spec$select443 = 0, $spec$store$select = 0, $storemerge446 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(512|0);
 $6 = sp;
 $7 = (($3) + ($2))|0;
 $8 = (0 - ($7))|0;
 $9 = ((($0)) + 4|0);
 $10 = ((($0)) + 100|0);
 $$0324 = $1;$$0393 = 0;
 L1: while(1) {
  switch ($$0324|0) {
  case 46:  {
   label = 7;
   break L1;
   break;
  }
  case 48:  {
   break;
  }
  default: {
   $$0390 = 0;$$2 = $$0324;$$2395 = $$0393;$375 = 0;$376 = 0;
   break L1;
  }
  }
  $11 = HEAP32[$9>>2]|0;
  $12 = HEAP32[$10>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $14 = ((($11)) + 1|0);
   HEAP32[$9>>2] = $14;
   $15 = HEAP8[$11>>0]|0;
   $16 = $15&255;
   $$0324$be = $16;
  } else {
   $17 = (___shgetc($0)|0);
   $$0324$be = $17;
  }
  $$0324 = $$0324$be;$$0393 = 1;
 }
 if ((label|0) == 7) {
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$10>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $21 = ((($18)) + 1|0);
   HEAP32[$9>>2] = $21;
   $22 = HEAP8[$18>>0]|0;
   $23 = $22&255;
   $26 = $23;
  } else {
   $24 = (___shgetc($0)|0);
   $26 = $24;
  }
  $25 = ($26|0)==(48);
  if ($25) {
   $27 = 0;$28 = 0;
   while(1) {
    $29 = (_i64Add(($27|0),($28|0),-1,-1)|0);
    $30 = (getTempRet0() | 0);
    $31 = HEAP32[$9>>2]|0;
    $32 = HEAP32[$10>>2]|0;
    $33 = ($31>>>0)<($32>>>0);
    if ($33) {
     $34 = ((($31)) + 1|0);
     HEAP32[$9>>2] = $34;
     $35 = HEAP8[$31>>0]|0;
     $36 = $35&255;
     $39 = $36;
    } else {
     $37 = (___shgetc($0)|0);
     $39 = $37;
    }
    $38 = ($39|0)==(48);
    if ($38) {
     $27 = $29;$28 = $30;
    } else {
     $$0390 = 1;$$2 = $39;$$2395 = 1;$375 = $29;$376 = $30;
     break;
    }
   }
  } else {
   $$0390 = 1;$$2 = $26;$$2395 = $$0393;$375 = 0;$376 = 0;
  }
 }
 HEAP32[$6>>2] = 0;
 $40 = (($$2) + -48)|0;
 $41 = ($40>>>0)<(10);
 $42 = ($$2|0)==(46);
 $43 = $42 | $41;
 L22: do {
  if ($43) {
   $44 = ((($6)) + 496|0);
   $$0336503 = 0;$$0340502 = 0;$$0398499 = 0;$$1391501 = $$0390;$$3396500 = $$2395;$$3504 = $$2;$377 = $42;$378 = $40;$379 = $375;$380 = $376;$47 = 0;$48 = 0;
   L24: while(1) {
    do {
     if ($377) {
      $cond = ($$1391501|0)==(0);
      if ($cond) {
       $$2338 = $$0336503;$$2342 = $$0340502;$$2392 = 1;$$2400 = $$0398499;$$4397 = $$3396500;$381 = $47;$382 = $48;$383 = $47;$384 = $48;
      } else {
       break L24;
      }
     } else {
      $46 = ($$0340502|0)<(125);
      $49 = (_i64Add(($47|0),($48|0),1,0)|0);
      $50 = (getTempRet0() | 0);
      $51 = ($$3504|0)!=(48);
      if (!($46)) {
       if (!($51)) {
        $$2338 = $$0336503;$$2342 = $$0340502;$$2392 = $$1391501;$$2400 = $$0398499;$$4397 = $$3396500;$381 = $379;$382 = $380;$383 = $49;$384 = $50;
        break;
       }
       $61 = HEAP32[$44>>2]|0;
       $62 = $61 | 1;
       HEAP32[$44>>2] = $62;
       $$2338 = $$0336503;$$2342 = $$0340502;$$2392 = $$1391501;$$2400 = $$0398499;$$4397 = $$3396500;$381 = $379;$382 = $380;$383 = $49;$384 = $50;
       break;
      }
      $spec$select = $51 ? $49 : $$0398499;
      $52 = ($$0336503|0)==(0);
      $53 = (($6) + ($$0340502<<2)|0);
      if ($52) {
       $storemerge446 = $378;
      } else {
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54*10)|0;
       $56 = (($$3504) + -48)|0;
       $57 = (($56) + ($55))|0;
       $storemerge446 = $57;
      }
      HEAP32[$53>>2] = $storemerge446;
      $58 = (($$0336503) + 1)|0;
      $59 = ($58|0)==(9);
      $60 = $59&1;
      $spec$select410 = (($$0340502) + ($60))|0;
      $spec$select411 = $59 ? 0 : $58;
      $$2338 = $spec$select411;$$2342 = $spec$select410;$$2392 = $$1391501;$$2400 = $spec$select;$$4397 = 1;$381 = $379;$382 = $380;$383 = $49;$384 = $50;
     }
    } while(0);
    $63 = HEAP32[$9>>2]|0;
    $64 = HEAP32[$10>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $66 = ((($63)) + 1|0);
     HEAP32[$9>>2] = $66;
     $67 = HEAP8[$63>>0]|0;
     $68 = $67&255;
     $71 = $68;
    } else {
     $69 = (___shgetc($0)|0);
     $71 = $69;
    }
    $70 = (($71) + -48)|0;
    $72 = ($70>>>0)<(10);
    $73 = ($71|0)==(46);
    $74 = $73 | $72;
    if ($74) {
     $$0336503 = $$2338;$$0340502 = $$2342;$$0398499 = $$2400;$$1391501 = $$2392;$$3396500 = $$4397;$$3504 = $71;$377 = $73;$378 = $70;$379 = $381;$380 = $382;$47 = $383;$48 = $384;
    } else {
     $$0336$lcssa = $$2338;$$0340$lcssa = $$2342;$$0398$lcssa = $$2400;$$1391$lcssa = $$2392;$$3$lcssa = $71;$$3396$lcssa = $$4397;$77 = $383;$78 = $381;$80 = $384;$81 = $382;
     label = 31;
     break L22;
    }
   }
   $45 = ($$3396500|0)!=(0);
   $$0336455 = $$0336503;$$0340459 = $$0340502;$$0398465 = $$0398499;$385 = $47;$386 = $48;$387 = $379;$388 = $380;$389 = $45;
   label = 39;
  } else {
   $$0336$lcssa = 0;$$0340$lcssa = 0;$$0398$lcssa = 0;$$1391$lcssa = $$0390;$$3$lcssa = $$2;$$3396$lcssa = $$2395;$77 = 0;$78 = $375;$80 = 0;$81 = $376;
   label = 31;
  }
 } while(0);
 do {
  if ((label|0) == 31) {
   $75 = ($$1391$lcssa|0)==(0);
   $76 = $75 ? $77 : $78;
   $79 = $75 ? $80 : $81;
   $82 = ($$3396$lcssa|0)!=(0);
   $83 = $$3$lcssa | 32;
   $84 = ($83|0)==(101);
   $or$cond414 = $82 & $84;
   if (!($or$cond414)) {
    $99 = ($$3$lcssa|0)>(-1);
    if ($99) {
     $$0336455 = $$0336$lcssa;$$0340459 = $$0340$lcssa;$$0398465 = $$0398$lcssa;$385 = $77;$386 = $80;$387 = $76;$388 = $79;$389 = $82;
     label = 39;
     break;
    } else {
     $$0336454 = $$0336$lcssa;$$0340458 = $$0340$lcssa;$$0398464 = $$0398$lcssa;$390 = $77;$391 = $80;$392 = $82;$393 = $76;$394 = $79;
     label = 41;
     break;
    }
   }
   $85 = (_scanexp($0,$5)|0);
   $86 = (getTempRet0() | 0);
   $87 = ($85|0)==(0);
   $88 = ($86|0)==(-2147483648);
   $89 = $87 & $88;
   if ($89) {
    $90 = ($5|0)==(0);
    if ($90) {
     ___shlim($0,0);
     $$1 = 0.0;
     break;
    }
    $91 = HEAP32[$10>>2]|0;
    $92 = ($91|0)==(0|0);
    if ($92) {
     $95 = 0;$96 = 0;
    } else {
     $93 = HEAP32[$9>>2]|0;
     $94 = ((($93)) + -1|0);
     HEAP32[$9>>2] = $94;
     $95 = 0;$96 = 0;
    }
   } else {
    $95 = $85;$96 = $86;
   }
   $97 = (_i64Add(($95|0),($96|0),($76|0),($79|0))|0);
   $98 = (getTempRet0() | 0);
   $$0336453 = $$0336$lcssa;$$0340457 = $$0340$lcssa;$$0398463 = $$0398$lcssa;$110 = $97;$111 = $77;$113 = $98;$114 = $80;
   label = 43;
  }
 } while(0);
 if ((label|0) == 39) {
  $100 = HEAP32[$10>>2]|0;
  $101 = ($100|0)==(0|0);
  if ($101) {
   $$0336454 = $$0336455;$$0340458 = $$0340459;$$0398464 = $$0398465;$390 = $385;$391 = $386;$392 = $389;$393 = $387;$394 = $388;
   label = 41;
  } else {
   $102 = HEAP32[$9>>2]|0;
   $103 = ((($102)) + -1|0);
   HEAP32[$9>>2] = $103;
   if ($389) {
    $$0336453 = $$0336455;$$0340457 = $$0340459;$$0398463 = $$0398465;$110 = $387;$111 = $385;$113 = $388;$114 = $386;
    label = 43;
   } else {
    label = 42;
   }
  }
 }
 if ((label|0) == 41) {
  if ($392) {
   $$0336453 = $$0336454;$$0340457 = $$0340458;$$0398463 = $$0398464;$110 = $393;$111 = $390;$113 = $394;$114 = $391;
   label = 43;
  } else {
   label = 42;
  }
 }
 do {
  if ((label|0) == 42) {
   $104 = (___errno_location()|0);
   HEAP32[$104>>2] = 22;
   ___shlim($0,0);
   $$1 = 0.0;
  }
  else if ((label|0) == 43) {
   $105 = HEAP32[$6>>2]|0;
   $106 = ($105|0)==(0);
   if ($106) {
    $107 = (+($4|0));
    $108 = $107 * 0.0;
    $$1 = $108;
    break;
   }
   $109 = ($110|0)==($111|0);
   $112 = ($113|0)==($114|0);
   $115 = $109 & $112;
   $116 = ($114|0)<(0);
   $117 = ($111>>>0)<(10);
   $118 = ($114|0)==(0);
   $119 = $118 & $117;
   $120 = $116 | $119;
   $or$cond = $120 & $115;
   if ($or$cond) {
    $121 = ($2|0)>(30);
    $122 = $105 >>> $2;
    $123 = ($122|0)==(0);
    $or$cond416 = $121 | $123;
    if ($or$cond416) {
     $124 = (+($4|0));
     $125 = (+($105>>>0));
     $126 = $124 * $125;
     $$1 = $126;
     break;
    }
   }
   $127 = (($3|0) / -2)&-1;
   $128 = ($127|0)<(0);
   $129 = $128 << 31 >> 31;
   $130 = ($113|0)>($129|0);
   $131 = ($110>>>0)>($127>>>0);
   $132 = ($113|0)==($129|0);
   $133 = $132 & $131;
   $134 = $130 | $133;
   if ($134) {
    $135 = (___errno_location()|0);
    HEAP32[$135>>2] = 34;
    $136 = (+($4|0));
    $137 = $136 * 1.7976931348623157E+308;
    $138 = $137 * 1.7976931348623157E+308;
    $$1 = $138;
    break;
   }
   $139 = (($3) + -106)|0;
   $140 = ($139|0)<(0);
   $141 = $140 << 31 >> 31;
   $142 = ($113|0)<($141|0);
   $143 = ($110>>>0)<($139>>>0);
   $144 = ($113|0)==($141|0);
   $145 = $144 & $143;
   $146 = $142 | $145;
   if ($146) {
    $147 = (___errno_location()|0);
    HEAP32[$147>>2] = 34;
    $148 = (+($4|0));
    $149 = $148 * 2.2250738585072014E-308;
    $150 = $149 * 2.2250738585072014E-308;
    $$1 = $150;
    break;
   }
   $151 = ($$0336453|0)==(0);
   if ($151) {
    $$3343 = $$0340457;
   } else {
    $152 = ($$0336453|0)<(9);
    if ($152) {
     $153 = (($6) + ($$0340457<<2)|0);
     $$promoted = HEAP32[$153>>2]|0;
     $$3339493 = $$0336453;$155 = $$promoted;
     while(1) {
      $154 = ($155*10)|0;
      $156 = (($$3339493) + 1)|0;
      $157 = ($$3339493|0)<(8);
      if ($157) {
       $$3339493 = $156;$155 = $154;
      } else {
       break;
      }
     }
     HEAP32[$153>>2] = $154;
    }
    $158 = (($$0340457) + 1)|0;
    $$3343 = $158;
   }
   $159 = ($$0398463|0)<(9);
   if ($159) {
    $160 = ($$0398463|0)<=($110|0);
    $161 = ($110|0)<(18);
    $or$cond3 = $160 & $161;
    if ($or$cond3) {
     $162 = ($110|0)==(9);
     if ($162) {
      $163 = (+($4|0));
      $164 = HEAP32[$6>>2]|0;
      $165 = (+($164>>>0));
      $166 = $163 * $165;
      $$1 = $166;
      break;
     }
     $167 = ($110|0)<(9);
     if ($167) {
      $168 = (+($4|0));
      $169 = HEAP32[$6>>2]|0;
      $170 = (+($169>>>0));
      $171 = $168 * $170;
      $172 = (8 - ($110))|0;
      $173 = ((gb + (152688) | 0) + ($172<<2)|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = (+($174|0));
      $176 = $171 / $175;
      $$1 = $176;
      break;
     }
     $$neg447 = Math_imul($110, -3)|0;
     $$neg448 = (($2) + 27)|0;
     $177 = (($$neg448) + ($$neg447))|0;
     $178 = ($177|0)>(30);
     $$pre = HEAP32[$6>>2]|0;
     $179 = $$pre >>> $177;
     $180 = ($179|0)==(0);
     $or$cond559 = $178 | $180;
     if ($or$cond559) {
      $181 = (+($4|0));
      $182 = (+($$pre>>>0));
      $183 = $181 * $182;
      $184 = (($110) + -10)|0;
      $185 = ((gb + (152688) | 0) + ($184<<2)|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = (+($186|0));
      $188 = $183 * $187;
      $$1 = $188;
      break;
     }
    }
   }
   $189 = (($110|0) % 9)&-1;
   $190 = ($189|0)==(0);
   if ($190) {
    $$2369$ph = $$3343;$$3348$ph = 0;$$3384$ph = $110;
   } else {
    $191 = ($110|0)>(-1);
    $192 = (($189) + 9)|0;
    $193 = $191 ? $189 : $192;
    $194 = (8 - ($193))|0;
    $195 = ((gb + (152688) | 0) + ($194<<2)|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = ($$3343|0)==(0);
    if ($197) {
     $$0345$lcssa540 = 0;$$0367 = 0;$$0381$lcssa539 = $110;
    } else {
     $198 = (1000000000 / ($196|0))&-1;
     $$0335486 = 0;$$0345484 = 0;$$0381483 = $110;$$4344485 = 0;
     while(1) {
      $199 = (($6) + ($$4344485<<2)|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = (($200>>>0) / ($196>>>0))&-1;
      $202 = Math_imul($201, $196)|0;
      $203 = (($200) - ($202))|0;
      $204 = (($201) + ($$0335486))|0;
      HEAP32[$199>>2] = $204;
      $205 = Math_imul($198, $203)|0;
      $206 = ($$4344485|0)==($$0345484|0);
      $207 = ($204|0)==(0);
      $or$cond417 = $206 & $207;
      $208 = (($$0345484) + 1)|0;
      $209 = $208 & 127;
      $210 = (($$0381483) + -9)|0;
      $spec$select439 = $or$cond417 ? $210 : $$0381483;
      $spec$select440 = $or$cond417 ? $209 : $$0345484;
      $211 = (($$4344485) + 1)|0;
      $212 = ($211|0)==($$3343|0);
      if ($212) {
       break;
      } else {
       $$0335486 = $205;$$0345484 = $spec$select440;$$0381483 = $spec$select439;$$4344485 = $211;
      }
     }
     $213 = ($205|0)==(0);
     if ($213) {
      $$0345$lcssa540 = $spec$select440;$$0367 = $$3343;$$0381$lcssa539 = $spec$select439;
     } else {
      $214 = (($6) + ($$3343<<2)|0);
      $215 = (($$3343) + 1)|0;
      HEAP32[$214>>2] = $205;
      $$0345$lcssa540 = $spec$select440;$$0367 = $215;$$0381$lcssa539 = $spec$select439;
     }
    }
    $216 = (9 - ($193))|0;
    $217 = (($216) + ($$0381$lcssa539))|0;
    $$2369$ph = $$0367;$$3348$ph = $$0345$lcssa540;$$3384$ph = $217;
   }
   $$0376$ph = 0;$$2369$ph579 = $$2369$ph;$$3348$ph580 = $$3348$ph;$$3384$ph578 = $$3384$ph;
   L104: while(1) {
    $218 = ($$3384$ph578|0)<(18);
    $219 = ($$3384$ph578|0)==(18);
    $220 = (($6) + ($$3348$ph580<<2)|0);
    $$0376 = $$0376$ph;$$2369 = $$2369$ph579;
    while(1) {
     if (!($218)) {
      if (!($219)) {
       $$5386$ph = $$3384$ph578;
       break L104;
      }
      $221 = HEAP32[$220>>2]|0;
      $222 = ($221>>>0)<(9007199);
      if (!($222)) {
       $$5386$ph = 18;
       break L104;
      }
     }
     $223 = (($$2369) + 127)|0;
     $$0329 = 0;$$3370 = $$2369;$$5$in = $223;
     while(1) {
      $$5 = $$5$in & 127;
      $224 = (($6) + ($$5<<2)|0);
      $225 = HEAP32[$224>>2]|0;
      $226 = (_bitshift64Shl(($225|0),0,29)|0);
      $227 = (getTempRet0() | 0);
      $228 = (_i64Add(($226|0),($227|0),($$0329|0),0)|0);
      $229 = (getTempRet0() | 0);
      $230 = ($229>>>0)>(0);
      $231 = ($228>>>0)>(1000000000);
      $232 = ($229|0)==(0);
      $233 = $232 & $231;
      $234 = $230 | $233;
      if ($234) {
       $235 = (___udivdi3(($228|0),($229|0),1000000000,0)|0);
       $236 = (getTempRet0() | 0);
       $237 = (___muldi3(($235|0),($236|0),1000000000,0)|0);
       $238 = (getTempRet0() | 0);
       $239 = (_i64Subtract(($228|0),($229|0),($237|0),($238|0))|0);
       $240 = (getTempRet0() | 0);
       $$1330 = $235;$$sink$off0 = $239;
      } else {
       $$1330 = 0;$$sink$off0 = $228;
      }
      HEAP32[$224>>2] = $$sink$off0;
      $241 = (($$3370) + 127)|0;
      $242 = $241 & 127;
      $243 = ($$5|0)!=($242|0);
      $244 = ($$5|0)==($$3348$ph580|0);
      $or$cond418 = $243 | $244;
      $245 = ($$sink$off0|0)==(0);
      $spec$select419 = $245 ? $$5 : $$3370;
      $spec$select441 = $or$cond418 ? $$3370 : $spec$select419;
      $246 = (($$5) + -1)|0;
      if ($244) {
       break;
      } else {
       $$0329 = $$1330;$$3370 = $spec$select441;$$5$in = $246;
      }
     }
     $247 = (($$0376) + -29)|0;
     $248 = ($$1330|0)==(0);
     if ($248) {
      $$0376 = $247;$$2369 = $$3370;
     } else {
      break;
     }
    }
    $249 = (($$3384$ph578) + 9)|0;
    $250 = (($$3348$ph580) + 127)|0;
    $251 = $250 & 127;
    $252 = ($251|0)==($spec$select441|0);
    $253 = (($spec$select441) + 127)|0;
    $254 = $253 & 127;
    $255 = (($spec$select441) + 126)|0;
    $256 = $255 & 127;
    $257 = (($6) + ($256<<2)|0);
    if ($252) {
     $258 = (($6) + ($254<<2)|0);
     $259 = HEAP32[$258>>2]|0;
     $260 = HEAP32[$257>>2]|0;
     $261 = $260 | $259;
     HEAP32[$257>>2] = $261;
     $$5372 = $254;
    } else {
     $$5372 = $$3370;
    }
    $262 = (($6) + ($251<<2)|0);
    HEAP32[$262>>2] = $$1330;
    $$0376$ph = $247;$$2369$ph579 = $$5372;$$3348$ph580 = $251;$$3384$ph578 = $249;
   }
   $$1377$ph$ph = $$0376;$$5350$ph$ph = $$3348$ph580;$$5386$ph576$ph = $$5386$ph;$$7374$ph$ph = $$2369;
   L123: while(1) {
    $299 = (($$7374$ph$ph) + 1)|0;
    $297 = $299 & 127;
    $300 = (($$7374$ph$ph) + 127)|0;
    $301 = $300 & 127;
    $302 = (($6) + ($301<<2)|0);
    $$1377$ph = $$1377$ph$ph;$$5350$ph = $$5350$ph$ph;$$5386$ph576 = $$5386$ph576$ph;
    while(1) {
     $294 = ($$5386$ph576|0)==(18);
     $295 = ($$5386$ph576|0)>(27);
     $spec$select420 = $295 ? 9 : 1;
     $$1377 = $$1377$ph;$$5350 = $$5350$ph;
     while(1) {
      $$0331476 = 0;
      while(1) {
       $263 = (($$0331476) + ($$5350))|0;
       $264 = $263 & 127;
       $265 = ($264|0)==($$7374$ph$ph|0);
       if ($265) {
        label = 92;
        break;
       }
       $266 = (($6) + ($264<<2)|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = ((gb + (166308) | 0) + ($$0331476<<2)|0);
       $269 = HEAP32[$268>>2]|0;
       $270 = ($267>>>0)<($269>>>0);
       if ($270) {
        label = 92;
        break;
       }
       $271 = ($267>>>0)>($269>>>0);
       if ($271) {
        break;
       }
       $272 = (($$0331476) + 1)|0;
       $273 = ($272>>>0)<(2);
       if ($273) {
        $$0331476 = 1;
       } else {
        label = 92;
        break;
       }
      }
      if ((label|0) == 92) {
       label = 0;
       if ($294) {
        break L123;
       }
      }
      $274 = (($spec$select420) + ($$1377))|0;
      $275 = ($$5350|0)==($$7374$ph$ph|0);
      if ($275) {
       $$1377 = $274;$$5350 = $$7374$ph$ph;
      } else {
       break;
      }
     }
     $276 = 1 << $spec$select420;
     $277 = (($276) + -1)|0;
     $278 = 1000000000 >>> $spec$select420;
     $$0327480 = 0;$$6351478 = $$5350;$$6387477 = $$5386$ph576;$$6479 = $$5350;
     while(1) {
      $279 = (($6) + ($$6479<<2)|0);
      $280 = HEAP32[$279>>2]|0;
      $281 = $280 & $277;
      $282 = $280 >>> $spec$select420;
      $283 = (($282) + ($$0327480))|0;
      HEAP32[$279>>2] = $283;
      $284 = Math_imul($281, $278)|0;
      $285 = ($$6479|0)==($$6351478|0);
      $286 = ($283|0)==(0);
      $or$cond421 = $285 & $286;
      $287 = (($$6351478) + 1)|0;
      $288 = $287 & 127;
      $289 = (($$6387477) + -9)|0;
      $spec$select442 = $or$cond421 ? $289 : $$6387477;
      $spec$select443 = $or$cond421 ? $288 : $$6351478;
      $290 = (($$6479) + 1)|0;
      $291 = $290 & 127;
      $292 = ($291|0)==($$7374$ph$ph|0);
      if ($292) {
       break;
      } else {
       $$0327480 = $284;$$6351478 = $spec$select443;$$6387477 = $spec$select442;$$6479 = $291;
      }
     }
     $293 = ($284|0)==(0);
     if (!($293)) {
      $296 = ($297|0)==($spec$select443|0);
      if (!($296)) {
       break;
      }
      $303 = HEAP32[$302>>2]|0;
      $304 = $303 | 1;
      HEAP32[$302>>2] = $304;
     }
     $$1377$ph = $274;$$5350$ph = $spec$select443;$$5386$ph576 = $spec$select442;
    }
    $298 = (($6) + ($$7374$ph$ph<<2)|0);
    HEAP32[$298>>2] = $284;
    $$1377$ph$ph = $274;$$5350$ph$ph = $spec$select443;$$5386$ph576$ph = $spec$select442;$$7374$ph$ph = $297;
   }
   $$0360474 = 0.0;$$10473 = $$7374$ph$ph;$$4475 = 0;
   while(1) {
    $305 = (($$4475) + ($$5350))|0;
    $306 = $305 & 127;
    $307 = ($306|0)==($$10473|0);
    $308 = (($$10473) + 1)|0;
    $309 = $308 & 127;
    if ($307) {
     $310 = (($309) + -1)|0;
     $311 = (($6) + ($310<<2)|0);
     HEAP32[$311>>2] = 0;
     $$11 = $309;
    } else {
     $$11 = $$10473;
    }
    $312 = $$0360474 * 1.0E+9;
    $313 = (($6) + ($306<<2)|0);
    $314 = HEAP32[$313>>2]|0;
    $315 = (+($314>>>0));
    $316 = $312 + $315;
    $317 = (($$4475) + 1)|0;
    $exitcond = ($317|0)==(2);
    if ($exitcond) {
     break;
    } else {
     $$0360474 = $316;$$10473 = $$11;$$4475 = $317;
    }
   }
   $318 = (+($4|0));
   $319 = $316 * $318;
   $320 = (($$1377) + 53)|0;
   $321 = (($320) - ($3))|0;
   $322 = ($321|0)<($2|0);
   $323 = ($321|0)>(0);
   $spec$store$select = $323 ? $321 : 0;
   $$0328 = $322 ? $spec$store$select : $2;
   $324 = ($$0328|0)<(53);
   if ($324) {
    $325 = (105 - ($$0328))|0;
    $326 = (+_scalbn(1.0,$325));
    $327 = (+_copysignl($326,$319));
    $328 = (53 - ($$0328))|0;
    $329 = (+_scalbn(1.0,$328));
    $330 = (+_fmodl($319,$329));
    $331 = $319 - $330;
    $332 = $327 + $331;
    $$0355 = $327;$$0356 = $330;$$1361 = $332;
   } else {
    $$0355 = 0.0;$$0356 = 0.0;$$1361 = $319;
   }
   $333 = (($$5350) + 2)|0;
   $334 = $333 & 127;
   $335 = ($334|0)==($$11|0);
   if ($335) {
    $$3359 = $$0356;
   } else {
    $336 = (($6) + ($334<<2)|0);
    $337 = HEAP32[$336>>2]|0;
    $338 = ($337>>>0)<(500000000);
    do {
     if ($338) {
      $339 = ($337|0)==(0);
      if ($339) {
       $340 = (($$5350) + 3)|0;
       $341 = $340 & 127;
       $342 = ($341|0)==($$11|0);
       if ($342) {
        $$1357 = $$0356;
        break;
       }
      }
      $343 = $318 * 0.25;
      $344 = $343 + $$0356;
      $$1357 = $344;
     } else {
      $345 = ($337|0)==(500000000);
      if (!($345)) {
       $346 = $318 * 0.75;
       $347 = $346 + $$0356;
       $$1357 = $347;
       break;
      }
      $348 = (($$5350) + 3)|0;
      $349 = $348 & 127;
      $350 = ($349|0)==($$11|0);
      if ($350) {
       $351 = $318 * 0.5;
       $352 = $351 + $$0356;
       $$1357 = $352;
       break;
      } else {
       $353 = $318 * 0.75;
       $354 = $353 + $$0356;
       $$1357 = $354;
       break;
      }
     }
    } while(0);
    $355 = (53 - ($$0328))|0;
    $356 = ($355|0)>(1);
    if ($356) {
     $357 = (+_fmodl($$1357,1.0));
     $358 = $357 != 0.0;
     if ($358) {
      $$3359 = $$1357;
     } else {
      $359 = $$1357 + 1.0;
      $$3359 = $359;
     }
    } else {
     $$3359 = $$1357;
    }
   }
   $360 = $$1361 + $$3359;
   $361 = $360 - $$0355;
   $362 = $320 & 2147483647;
   $363 = (-2 - ($7))|0;
   $364 = ($362|0)>($363|0);
   do {
    if ($364) {
     $365 = (+Math_abs((+$361)));
     $366 = !($365 >= 9007199254740992.0);
     $367 = $361 * 0.5;
     $not$ = $366 ^ 1;
     $368 = $not$&1;
     $$3379 = (($$1377) + ($368))|0;
     $$2362 = $366 ? $361 : $367;
     $369 = (($$3379) + 50)|0;
     $370 = ($369|0)>($8|0);
     if (!($370)) {
      $371 = ($$0328|0)!=($321|0);
      $narrow = $371 | $366;
      $$2366$v = $322 & $narrow;
      $372 = $$3359 != 0.0;
      $or$cond9 = $372 & $$2366$v;
      if (!($or$cond9)) {
       $$3363 = $$2362;$$4380 = $$3379;
       break;
      }
     }
     $373 = (___errno_location()|0);
     HEAP32[$373>>2] = 34;
     $$3363 = $$2362;$$4380 = $$3379;
    } else {
     $$3363 = $361;$$4380 = $$1377;
    }
   } while(0);
   $374 = (+_scalbnl($$3363,$$4380));
   $$1 = $374;
  }
 } while(0);
 STACKTOP = sp;return (+$$1);
}
function _scanexp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$04858 = 0, $$049 = 0, $$157 = 0, $$251 = 0, $$pr = 0, $$pre = 0, $$pre$phi69Z2D = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 100|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = ((($3)) + 1|0);
  HEAP32[$2>>2] = $7;
  $8 = HEAP8[$3>>0]|0;
  $9 = $8&255;
  $11 = $9;
 } else {
  $10 = (___shgetc($0)|0);
  $11 = $10;
 }
 switch ($11|0) {
 case 43: case 45:  {
  $12 = ($11|0)==(45);
  $13 = $12&1;
  $14 = HEAP32[$2>>2]|0;
  $15 = HEAP32[$4>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if ($16) {
   $17 = ((($14)) + 1|0);
   HEAP32[$2>>2] = $17;
   $18 = HEAP8[$14>>0]|0;
   $19 = $18&255;
   $22 = $19;
  } else {
   $20 = (___shgetc($0)|0);
   $22 = $20;
  }
  $21 = (($22) + -48)|0;
  $23 = ($21>>>0)>(9);
  $24 = ($1|0)!=(0);
  $or$cond3 = $24 & $23;
  if ($or$cond3) {
   $25 = HEAP32[$4>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $100 = 0;$99 = -2147483648;
   } else {
    $27 = HEAP32[$2>>2]|0;
    $28 = ((($27)) + -1|0);
    HEAP32[$2>>2] = $28;
    label = 14;
   }
  } else {
   $$0 = $13;$$049 = $22;$$pre$phi69Z2D = $21;
   label = 12;
  }
  break;
 }
 default: {
  $$pre = (($11) + -48)|0;
  $$0 = 0;$$049 = $11;$$pre$phi69Z2D = $$pre;
  label = 12;
 }
 }
 if ((label|0) == 12) {
  $29 = ($$pre$phi69Z2D>>>0)>(9);
  if ($29) {
   label = 14;
  } else {
   $$04858 = 0;$$157 = $$049;
   while(1) {
    $33 = ($$04858*10)|0;
    $34 = (($$157) + -48)|0;
    $35 = (($34) + ($33))|0;
    $36 = HEAP32[$2>>2]|0;
    $37 = HEAP32[$4>>2]|0;
    $38 = ($36>>>0)<($37>>>0);
    if ($38) {
     $39 = ((($36)) + 1|0);
     HEAP32[$2>>2] = $39;
     $40 = HEAP8[$36>>0]|0;
     $41 = $40&255;
     $44 = $41;
    } else {
     $42 = (___shgetc($0)|0);
     $44 = $42;
    }
    $43 = (($44) + -48)|0;
    $45 = ($43>>>0)<(10);
    $46 = ($35|0)<(214748364);
    $47 = $45 & $46;
    if ($47) {
     $$04858 = $35;$$157 = $44;
    } else {
     break;
    }
   }
   $48 = ($35|0)<(0);
   $49 = $48 << 31 >> 31;
   $50 = ($43>>>0)<(10);
   if ($50) {
    $$251 = $44;$51 = $35;$52 = $49;
    while(1) {
     $53 = (___muldi3(($51|0),($52|0),10,0)|0);
     $54 = (getTempRet0() | 0);
     $55 = ($$251|0)<(0);
     $56 = $55 << 31 >> 31;
     $57 = (_i64Add(($$251|0),($56|0),-48,-1)|0);
     $58 = (getTempRet0() | 0);
     $59 = (_i64Add(($57|0),($58|0),($53|0),($54|0))|0);
     $60 = (getTempRet0() | 0);
     $61 = HEAP32[$2>>2]|0;
     $62 = HEAP32[$4>>2]|0;
     $63 = ($61>>>0)<($62>>>0);
     if ($63) {
      $64 = ((($61)) + 1|0);
      HEAP32[$2>>2] = $64;
      $65 = HEAP8[$61>>0]|0;
      $66 = $65&255;
      $69 = $66;
     } else {
      $67 = (___shgetc($0)|0);
      $69 = $67;
     }
     $68 = (($69) + -48)|0;
     $70 = ($68>>>0)<(10);
     $71 = ($60|0)<(21474836);
     $72 = ($59>>>0)<(2061584302);
     $73 = ($60|0)==(21474836);
     $74 = $73 & $72;
     $75 = $71 | $74;
     $76 = $70 & $75;
     if ($76) {
      $$251 = $69;$51 = $59;$52 = $60;
     } else {
      break;
     }
    }
    $77 = ($68>>>0)<(10);
    if ($77) {
     while(1) {
      $78 = HEAP32[$2>>2]|0;
      $79 = HEAP32[$4>>2]|0;
      $80 = ($78>>>0)<($79>>>0);
      if ($80) {
       $81 = ((($78)) + 1|0);
       HEAP32[$2>>2] = $81;
       $82 = HEAP8[$78>>0]|0;
       $83 = $82&255;
       $86 = $83;
      } else {
       $84 = (___shgetc($0)|0);
       $86 = $84;
      }
      $85 = (($86) + -48)|0;
      $87 = ($85>>>0)<(10);
      if (!($87)) {
       $93 = $59;$94 = $60;
       break;
      }
     }
    } else {
     $93 = $59;$94 = $60;
    }
   } else {
    $93 = $35;$94 = $49;
   }
   $88 = HEAP32[$4>>2]|0;
   $89 = ($88|0)==(0|0);
   if (!($89)) {
    $90 = HEAP32[$2>>2]|0;
    $91 = ((($90)) + -1|0);
    HEAP32[$2>>2] = $91;
   }
   $92 = ($$0|0)==(0);
   $95 = (_i64Subtract(0,0,($93|0),($94|0))|0);
   $96 = (getTempRet0() | 0);
   $97 = $92 ? $93 : $95;
   $98 = $92 ? $94 : $96;
   $100 = $97;$99 = $98;
  }
 }
 if ((label|0) == 14) {
  $$pr = HEAP32[$4>>2]|0;
  $30 = ($$pr|0)==(0|0);
  if ($30) {
   $100 = 0;$99 = -2147483648;
  } else {
   $31 = HEAP32[$2>>2]|0;
   $32 = ((($31)) + -1|0);
   HEAP32[$2>>2] = $32;
   $100 = 0;$99 = -2147483648;
  }
 }
 setTempRet0(($99) | 0);
 return ($100|0);
}
function _strtod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox($0,$1,1));
 return (+$2);
}
function _strtold($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_strtox($0,$1,2));
 return (+$2);
}
function _strtof_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtof($0,$1));
 return (+$3);
}
function _strtod_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtod($0,$1));
 return (+$3);
}
function _strtold_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (+_strtold($0,$1));
 return (+$3);
}
function _fcvt($0,$1,$2,$3) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$020 = 0, $$op = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $spec$select = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1520|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1520|0);
 $vararg_buffer = sp + 1504|0;
 $4 = sp;
 $5 = ($1>>>0)<(1400);
 $spec$select = $5 ? $1 : 1400;
 HEAP32[$vararg_buffer>>2] = $spec$select;
 $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
 HEAPF64[$vararg_ptr1>>3] = $0;
 (_sprintf($4,(gb + (167256) | 0),$vararg_buffer)|0);
 $6 = HEAP8[$4>>0]|0;
 $7 = ($6<<24>>24)==(45);
 $8 = $7&1;
 $9 = (($4) + ($8)|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(48);
 if ($11) {
  $12 = ((($9)) + 2|0);
  $13 = (_strspn($12,(gb + (167304) | 0))|0);
  $$0 = $13;
 } else {
  $14 = (_strcspn($9,(gb + (167711) | 0))|0);
  $15 = (0 - ($14))|0;
  $$0 = $15;
 }
 $16 = ($spec$select|0)>($$0|0);
 if ($16) {
  $20 = (($spec$select) - ($$0))|0;
  $21 = (_ecvt($0,$20,$2,$3)|0);
  $$020 = $21;
 } else {
  HEAP32[$3>>2] = $8;
  HEAP32[$2>>2] = 1;
  $17 = ($spec$select>>>0)<(14);
  $$op = (0 - ($1))|0;
  $18 = $17 ? $$op : -14;
  $19 = (((((gb + (167261) | 0)) + 14|0)) + ($18)|0);
  $$020 = $19;
 }
 STACKTOP = sp;return ($$020|0);
}
function _strcspn($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01823 = 0, $$019$lcssa$sink = 0, $$01920 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $2 = sp;
 $3 = HEAP8[$1>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L1: do {
  if ($4) {
   label = 3;
  } else {
   $5 = ((($1)) + 1|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    (_memset(($2|0),0,32)|0);
    $10 = HEAP8[$1>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if (!($11)) {
     $$01823 = $1;$13 = $10;
     while(1) {
      $12 = $13&255;
      $14 = $12 & 31;
      $15 = 1 << $14;
      $16 = $12 >>> 5;
      $17 = (($2) + ($16<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = $18 | $15;
      HEAP32[$17>>2] = $19;
      $20 = ((($$01823)) + 1|0);
      $21 = HEAP8[$20>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if ($22) {
       break;
      } else {
       $$01823 = $20;$13 = $21;
      }
     }
    }
    $23 = HEAP8[$0>>0]|0;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     $$019$lcssa$sink = $0;
    } else {
     $$01920 = $0;$26 = $23;
     while(1) {
      $25 = $26&255;
      $27 = $25 >>> 5;
      $28 = (($2) + ($27<<2)|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = $25 & 31;
      $31 = 1 << $30;
      $32 = $29 & $31;
      $33 = ($32|0)==(0);
      if (!($33)) {
       $$019$lcssa$sink = $$01920;
       break L1;
      }
      $34 = ((($$01920)) + 1|0);
      $35 = HEAP8[$34>>0]|0;
      $36 = ($35<<24>>24)==(0);
      if ($36) {
       $$019$lcssa$sink = $34;
       break;
      } else {
       $$01920 = $34;$26 = $35;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $8 = $3 << 24 >> 24;
  $9 = (___strchrnul($0,$8)|0);
  $$019$lcssa$sink = $9;
 }
 $37 = $$019$lcssa$sink;
 $38 = $0;
 $39 = (($37) - ($38))|0;
 STACKTOP = sp;return ($39|0);
}
function _ecvt($0,$1,$2,$3) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$01417 = 0, $$018 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer = sp + 32|0;
 $4 = sp;
 $5 = (($1) + -1)|0;
 $6 = ($5>>>0)>(15);
 $7 = $6 ? 14 : $5;
 HEAP32[$vararg_buffer>>2] = $7;
 $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
 HEAPF64[$vararg_ptr1>>3] = $0;
 (_sprintf($4,(gb + (167277) | 0),$vararg_buffer)|0);
 $8 = HEAP8[$4>>0]|0;
 $9 = ($8<<24>>24)==(45);
 $10 = $9&1;
 HEAP32[$3>>2] = $10;
 $11 = (($4) + ($10)|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(101);
 if ($13) {
  $$lcssa = (gb + (170256) | 0);$25 = $10;
 } else {
  $$01417 = $10;$$018 = 0;$14 = $12;$15 = (gb + (170256) | 0);
  while(1) {
   HEAP8[$15>>0] = $14;
   $16 = (($$01417) + 1)|0;
   $17 = ($14<<24>>24)!=(46);
   $18 = $17&1;
   $19 = (($$018) + ($18))|0;
   $20 = (($4) + ($16)|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(101);
   $23 = ((gb + (170256) | 0) + ($19)|0);
   if ($22) {
    $$lcssa = $23;$25 = $16;
    break;
   } else {
    $$01417 = $16;$$018 = $19;$14 = $21;$15 = $23;
   }
  }
 }
 $24 = (($4) + ($25)|0);
 HEAP8[$$lcssa>>0] = 0;
 $26 = ((($24)) + 1|0);
 $27 = (_atoi($26)|0);
 $28 = (($27) + 1)|0;
 HEAP32[$2>>2] = $28;
 STACKTOP = sp;return ((gb + (170256) | 0)|0);
}
function _atoi($0) {
 $0 = $0|0;
 var $$0 = 0, $$010$lcssa = 0, $$01015 = 0, $$011 = 0, $$1 = 0, $$112 = 0, $$214 = 0, $$neg13 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $0;
 while(1) {
  $1 = HEAP8[$$011>>0]|0;
  $2 = $1 << 24 >> 24;
  $3 = (_isspace($2)|0);
  $4 = ($3|0)==(0);
  $5 = ((($$011)) + 1|0);
  if ($4) {
   break;
  } else {
   $$011 = $5;
  }
 }
 $6 = HEAP8[$$011>>0]|0;
 $7 = $6 << 24 >> 24;
 switch ($7|0) {
 case 45:  {
  $$0 = 1;
  label = 5;
  break;
 }
 case 43:  {
  $$0 = 0;
  label = 5;
  break;
 }
 default: {
  $$1 = 0;$$112 = $$011;$$pre$phiZ2D = $7;
 }
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$5>>0]|0;
  $$pre16 = $$pre << 24 >> 24;
  $$1 = $$0;$$112 = $5;$$pre$phiZ2D = $$pre16;
 }
 $8 = (_isdigit($$pre$phiZ2D)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  $$010$lcssa = 0;
 } else {
  $$01015 = 0;$$214 = $$112;
  while(1) {
   $10 = ($$01015*10)|0;
   $11 = ((($$214)) + 1|0);
   $12 = HEAP8[$$214>>0]|0;
   $13 = $12 << 24 >> 24;
   $$neg13 = (($10) + 48)|0;
   $14 = (($$neg13) - ($13))|0;
   $15 = HEAP8[$11>>0]|0;
   $16 = $15 << 24 >> 24;
   $17 = (_isdigit($16)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $$010$lcssa = $14;
    break;
   } else {
    $$01015 = $14;$$214 = $11;
   }
  }
 }
 $19 = ($$1|0)==(0);
 $20 = (0 - ($$010$lcssa))|0;
 $21 = $19 ? $20 : $$010$lcssa;
 return ($21|0);
}
function _strtoll($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox_327($0,$1,$2,0,-2147483648)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _strtol($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtox_327($0,$1,$2,-2147483648,0)|0);
 $4 = (getTempRet0() | 0);
 return ($3|0);
}
function _strtoimax($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtoll($0,$1,$2)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _strtoumax($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strtoull($0,$1,$2)|0);
 $4 = (getTempRet0() | 0);
 setTempRet0(($4) | 0);
 return ($3|0);
}
function _wcstof($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_wcstox_330($0,$1,0));
 $3 = $2;
 return (+$3);
}
function _wcstox_330($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $3 = sp;
 $4 = sp + 64|0;
 $5 = ((($4)) + 8|0);
 $6 = ((($4)) + 4|0);
 $7 = ((($3)) + 4|0);
 $8 = ((($4)) + 44|0);
 dest=$4; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$8>>2] = $7;
 $9 = ((($4)) + 48|0);
 HEAP32[$9>>2] = 60;
 $10 = ((($4)) + 76|0);
 HEAP32[$10>>2] = -1;
 $11 = ((($4)) + 32|0);
 HEAP32[$11>>2] = (fb + (19) | 0);
 $$0 = $0;
 while(1) {
  $12 = HEAP32[$$0>>2]|0;
  $13 = (_iswspace($12)|0);
  $14 = ($13|0)==(0);
  $15 = ((($$0)) + 4|0);
  if ($14) {
   break;
  } else {
   $$0 = $15;
  }
 }
 $16 = ((($4)) + 84|0);
 HEAP32[$16>>2] = $$0;
 ___shlim($4,0);
 $17 = (+___floatscan($4,$2,1));
 $18 = ($1|0)==(0|0);
 if (!($18)) {
  $19 = ((($4)) + 108|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$6>>2]|0;
  $22 = HEAP32[$5>>2]|0;
  $23 = (($21) - ($22))|0;
  $24 = (($23) + ($20))|0;
  $25 = ($24|0)==(0);
  $26 = (($$0) + ($24<<2)|0);
  $27 = $25 ? $0 : $26;
  HEAP32[$1>>2] = $27;
 }
 STACKTOP = sp;return (+$17);
}
function _do_read_331($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$029 = 0, $$030 = 0, $$cast = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 $spec$store$select = $6 ? (gb + (166316) | 0) : $4;
 $7 = ((($0)) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 $$pre = ((($0)) + 44|0);
 L1: do {
  if ($9) {
   $$0$lcssa = 0;
  } else {
   $$030 = 0;
   while(1) {
    $10 = (($spec$store$select) + ($$030<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0);
    if ($12) {
     $$0$lcssa = $$030;
     break L1;
    }
    $13 = ($11|0)<(128);
    $14 = $11&255;
    $15 = $13 ? $14 : 64;
    $16 = HEAP32[$$pre>>2]|0;
    $17 = (($16) + ($$030)|0);
    HEAP8[$17>>0] = $15;
    $18 = (($$030) + 1)|0;
    $19 = HEAP32[$7>>2]|0;
    $20 = ($18>>>0)<($19>>>0);
    if ($20) {
     $$030 = $18;
    } else {
     $$0$lcssa = $18;
     break;
    }
   }
  }
 } while(0);
 $21 = HEAP32[$$pre>>2]|0;
 $22 = ((($0)) + 4|0);
 HEAP32[$22>>2] = $21;
 $$cast = $21;
 $23 = (($$cast) + ($$0$lcssa)|0);
 $24 = ((($0)) + 8|0);
 HEAP32[$24>>2] = $23;
 $25 = (($spec$store$select) + ($$0$lcssa<<2)|0);
 HEAP32[$3>>2] = $25;
 $26 = ($$0$lcssa|0)!=(0);
 $27 = ($2|0)!=(0);
 $or$cond = $27 & $26;
 if ($or$cond) {
  $28 = ((($$cast)) + 1|0);
  HEAP32[$22>>2] = $28;
  $29 = HEAP8[$$cast>>0]|0;
  HEAP8[$1>>0] = $29;
  $$029 = 1;
 } else {
  $$029 = 0;
 }
 return ($$029|0);
}
function _wcstod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_wcstox_330($0,$1,1));
 return (+$2);
}
function _wcstold($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (+_wcstox_330($0,$1,2));
 return (+$2);
}
function _gcvt($0,$1,$2) {
 $0 = +$0;
 $1 = $1|0;
 $2 = $2|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $1;
 $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
 HEAPF64[$vararg_ptr1>>3] = $0;
 (_sprintf($2,(gb + (167282) | 0),$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function _imaxdiv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (___divdi3(($1|0),($2|0),($3|0),($4|0))|0);
 $6 = (getTempRet0() | 0);
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $5;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 $11 = ((($0)) + 8|0);
 $12 = (___muldi3(($5|0),($6|0),($3|0),($4|0))|0);
 $13 = (getTempRet0() | 0);
 $14 = (_i64Subtract(($1|0),($2|0),($12|0),($13|0))|0);
 $15 = (getTempRet0() | 0);
 $16 = $11;
 $17 = $16;
 HEAP32[$17>>2] = $14;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 return;
}
function _imaxabs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)>(0);
 $3 = ($0>>>0)>(0);
 $4 = ($1|0)==(0);
 $5 = $4 & $3;
 $6 = $2 | $5;
 $7 = (_i64Subtract(0,0,($0|0),($1|0))|0);
 $8 = (getTempRet0() | 0);
 $9 = $6 ? $0 : $7;
 $10 = $6 ? $1 : $8;
 setTempRet0(($10) | 0);
 return ($9|0);
}
function _lldiv($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (___divdi3(($1|0),($2|0),($3|0),($4|0))|0);
 $6 = (getTempRet0() | 0);
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $5;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 $11 = ((($0)) + 8|0);
 $12 = (___muldi3(($5|0),($6|0),($3|0),($4|0))|0);
 $13 = (getTempRet0() | 0);
 $14 = (_i64Subtract(($1|0),($2|0),($12|0),($13|0))|0);
 $15 = (getTempRet0() | 0);
 $16 = $11;
 $17 = $16;
 HEAP32[$17>>2] = $14;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 return;
}
function _bsearch($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$01822 = 0, $$01921 = 0, $$1 = 0, $$120 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)==(0);
 L1: do {
  if ($5) {
   $$0 = 0;
  } else {
   $$01822 = $1;$$01921 = $2;
   while(1) {
    $6 = $$01921 >>> 1;
    $7 = Math_imul($6, $3)|0;
    $8 = (($$01822) + ($7)|0);
    $9 = (mftCall_iii($4|0,($0|0),($8|0))|0);
    $10 = ($9|0)==(0);
    if ($10) {
     $$0 = $8;
     break L1;
    }
    $11 = ($$01921|0)==(1);
    if ($11) {
     $$0 = 0;
     break L1;
    }
    $12 = ($9|0)<(0);
    $13 = (($$01921) - ($6))|0;
    $$120 = $12 ? $6 : $13;
    $$1 = $12 ? $$01822 : $8;
    $14 = ($$120|0)==(0);
    if ($14) {
     $$0 = 0;
     break;
    } else {
     $$01822 = $$1;$$01921 = $$120;
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _atof($0) {
 $0 = $0|0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (+_strtod($0,0));
 return (+$1);
}
function _atoll($0) {
 $0 = $0|0;
 var $$0 = 0, $$011 = 0, $$1 = 0, $$112 = 0, $$213 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre15 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $0;
 while(1) {
  $1 = HEAP8[$$011>>0]|0;
  $2 = $1 << 24 >> 24;
  $3 = (_isspace($2)|0);
  $4 = ($3|0)==(0);
  $5 = ((($$011)) + 1|0);
  if ($4) {
   break;
  } else {
   $$011 = $5;
  }
 }
 $6 = HEAP8[$$011>>0]|0;
 $7 = $6 << 24 >> 24;
 switch ($7|0) {
 case 45:  {
  $$0 = 1;
  label = 5;
  break;
 }
 case 43:  {
  $$0 = 0;
  label = 5;
  break;
 }
 default: {
  $$1 = 0;$$112 = $$011;$$pre$phiZ2D = $7;
 }
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$5>>0]|0;
  $$pre15 = $$pre << 24 >> 24;
  $$1 = $$0;$$112 = $5;$$pre$phiZ2D = $$pre15;
 }
 $8 = (_isdigit($$pre$phiZ2D)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  $27 = 0;$28 = 0;
 } else {
  $$213 = $$112;$10 = 0;$11 = 0;
  while(1) {
   $12 = (___muldi3(($10|0),($11|0),10,0)|0);
   $13 = (getTempRet0() | 0);
   $14 = ((($$213)) + 1|0);
   $15 = HEAP8[$$213>>0]|0;
   $16 = $15 << 24 >> 24;
   $17 = (($16) + -48)|0;
   $18 = ($17|0)<(0);
   $19 = $18 << 31 >> 31;
   $20 = (_i64Subtract(($12|0),($13|0),($17|0),($19|0))|0);
   $21 = (getTempRet0() | 0);
   $22 = HEAP8[$14>>0]|0;
   $23 = $22 << 24 >> 24;
   $24 = (_isdigit($23)|0);
   $25 = ($24|0)==(0);
   if ($25) {
    $27 = $20;$28 = $21;
    break;
   } else {
    $$213 = $14;$10 = $20;$11 = $21;
   }
  }
 }
 $26 = ($$1|0)==(0);
 $29 = (_i64Subtract(0,0,($27|0),($28|0))|0);
 $30 = (getTempRet0() | 0);
 $31 = $26 ? $29 : $27;
 $32 = $26 ? $30 : $28;
 setTempRet0(($32) | 0);
 return ($31|0);
}
function _labs($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)>(0);
 $2 = (0 - ($0))|0;
 $3 = $1 ? $0 : $2;
 return ($3|0);
}
function _div($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($1|0) / ($2|0))&-1;
 HEAP32[$0>>2] = $3;
 $4 = ((($0)) + 4|0);
 $5 = Math_imul($3, $2)|0;
 $6 = (($1) - ($5))|0;
 HEAP32[$4>>2] = $6;
 return;
}
function _ldiv($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($1|0) / ($2|0))&-1;
 HEAP32[$0>>2] = $3;
 $4 = ((($0)) + 4|0);
 $5 = Math_imul($3, $2)|0;
 $6 = (($1) - ($5))|0;
 HEAP32[$4>>2] = $6;
 return;
}
function _llabs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)>(0);
 $3 = ($0>>>0)>(0);
 $4 = ($1|0)==(0);
 $5 = $4 & $3;
 $6 = $2 | $5;
 $7 = (_i64Subtract(0,0,($0|0),($1|0))|0);
 $8 = (getTempRet0() | 0);
 $9 = $6 ? $0 : $7;
 $10 = $6 ? $1 : $8;
 setTempRet0(($10) | 0);
 return ($9|0);
}
function _atol($0) {
 $0 = $0|0;
 var $$0 = 0, $$010$lcssa = 0, $$01015 = 0, $$011 = 0, $$1 = 0, $$112 = 0, $$214 = 0, $$neg13 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$011 = $0;
 while(1) {
  $1 = HEAP8[$$011>>0]|0;
  $2 = $1 << 24 >> 24;
  $3 = (_isspace($2)|0);
  $4 = ($3|0)==(0);
  $5 = ((($$011)) + 1|0);
  if ($4) {
   break;
  } else {
   $$011 = $5;
  }
 }
 $6 = HEAP8[$$011>>0]|0;
 $7 = $6 << 24 >> 24;
 switch ($7|0) {
 case 45:  {
  $$0 = 1;
  label = 5;
  break;
 }
 case 43:  {
  $$0 = 0;
  label = 5;
  break;
 }
 default: {
  $$1 = 0;$$112 = $$011;$$pre$phiZ2D = $7;
 }
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$5>>0]|0;
  $$pre16 = $$pre << 24 >> 24;
  $$1 = $$0;$$112 = $5;$$pre$phiZ2D = $$pre16;
 }
 $8 = (_isdigit($$pre$phiZ2D)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  $$010$lcssa = 0;
 } else {
  $$01015 = 0;$$214 = $$112;
  while(1) {
   $10 = ($$01015*10)|0;
   $11 = ((($$214)) + 1|0);
   $12 = HEAP8[$$214>>0]|0;
   $13 = $12 << 24 >> 24;
   $$neg13 = (($10) + 48)|0;
   $14 = (($$neg13) - ($13))|0;
   $15 = HEAP8[$11>>0]|0;
   $16 = $15 << 24 >> 24;
   $17 = (_isdigit($16)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $$010$lcssa = $14;
    break;
   } else {
    $$01015 = $14;$$214 = $11;
   }
  }
 }
 $19 = ($$1|0)==(0);
 $20 = (0 - ($$010$lcssa))|0;
 $21 = $19 ? $20 : $$010$lcssa;
 return ($21|0);
}
function _cfmakeraw($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -1516;
 HEAP32[$0>>2] = $2;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & -2;
 HEAP32[$3>>2] = $5;
 $6 = ((($0)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & -32844;
 HEAP32[$6>>2] = $8;
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & -305;
 $12 = $11 | 48;
 HEAP32[$9>>2] = $12;
 $13 = ((($0)) + 23|0);
 HEAP8[$13>>0] = 1;
 $14 = ((($0)) + 22|0);
 HEAP8[$14>>0] = 0;
 return;
}
function _tcsendbreak($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 0;
 $2 = (_ioctl($0,21513,$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function _tcgetattr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,21505,$vararg_buffer)|0);
 $3 = ($2|0)!=(0);
 $$ = $3 << 31 >> 31;
 STACKTOP = sp;return ($$|0);
}
function _tcdrain($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 21513;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 1;
 $1 = (___syscall54(54,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function _cfsetospeed($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 & -4112;
 $3 = ($2|0)==(0);
 if ($3) {
  $5 = ((($0)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & -4112;
  $8 = $7 | $1;
  HEAP32[$5>>2] = $8;
  $$0 = 0;
 } else {
  $4 = (___errno_location()|0);
  HEAP32[$4>>2] = 22;
  $$0 = -1;
 }
 return ($$0|0);
}
function _cfsetispeed($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 if ($2) {
  $4 = 0;
 } else {
  $3 = (_cfsetospeed($0,$1)|0);
  $4 = $3;
 }
 return ($4|0);
}
function _tcsetattr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = ($1>>>0)>(2);
 if ($3) {
  $4 = (___errno_location()|0);
  HEAP32[$4>>2] = 22;
  $$0 = -1;
 } else {
  $5 = (($1) + 21506)|0;
  HEAP32[$vararg_buffer>>2] = $2;
  $6 = (_ioctl($0,$5,$vararg_buffer)|0);
  $$0 = $6;
 }
 STACKTOP = sp;return ($$0|0);
}
function _cfgetospeed($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4111;
 return ($3|0);
}
function _cfgetispeed($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_cfgetospeed($0)|0);
 return ($1|0);
}
function _tcflow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,21514,$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function _tcgetsid($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,21545,$vararg_buffer)|0);
 $3 = ($2|0)<(0);
 $4 = HEAP32[$1>>2]|0;
 $$0 = $3 ? -1 : $4;
 STACKTOP = sp;return ($$0|0);
}
function _tcflush($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,21515,$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function ___ofl_add($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___ofl_lock()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 56|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($4)) + 52|0);
  HEAP32[$6>>2] = $0;
 }
 HEAP32[$1>>2] = $0;
 ___ofl_unlock();
 return ($0|0);
}
function ___ofl_lock() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___lock(((gb + (172040) | 0)|0));
 return ((gb + (172048) | 0)|0);
}
function ___ofl_unlock() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___unlock(((gb + (172040) | 0)|0));
 return;
}
function _vwprintf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $3 = (_vfwprintf($2,$0,$1)|0);
 return ($3|0);
}
function _vfwprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0;
 var $spec$store$select = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(144|0);
 $3 = sp + 128|0;
 $4 = sp + 80|0;
 $5 = sp;
 dest=$4; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $vacopy_currentptr;
 $6 = (_wprintf_core(0,$1,$3,$5,$4)|0);
 $7 = ($6|0)<(0);
 if ($7) {
  $$0 = -1;
 } else {
  $8 = ((($0)) + 76|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)>(-1);
  if ($10) {
   $11 = (___lockfile($0)|0);
   $phitmp = ($11|0)!=(0);
   $20 = $phitmp;
  } else {
   $20 = 0;
  }
  (_fwide($0,1)|0);
  $12 = HEAP32[$0>>2]|0;
  $13 = $12 & 32;
  $14 = $12 & -33;
  HEAP32[$0>>2] = $14;
  $15 = (_wprintf_core($0,$1,$3,$5,$4)|0);
  $16 = HEAP32[$0>>2]|0;
  $17 = $16 & 32;
  $18 = ($17|0)==(0);
  $spec$store$select = $18 ? $15 : -1;
  $19 = $16 | $13;
  HEAP32[$0>>2] = $19;
  if ($20) {
   ___unlockfile($0);
  }
  $$0 = $spec$store$select;
 }
 STACKTOP = sp;return ($$0|0);
}
function _wprintf_core($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$0170235 = 0, $$0171 = 0, $$0174 = 0, $$0174$be = 0, $$0178 = 0, $$0180 = 0, $$0181 = 0, $$0182 = 0, $$0185 = 0, $$0189214 = 0, $$0189231 = 0, $$0191 = 0, $$0191$be = 0, $$1175220 = 0, $$1175234 = 0, $$1179 = 0, $$1183 = 0, $$1186 = 0, $$1190 = 0;
 var $$1192 = 0, $$1239 = 0, $$2176238 = 0, $$2193 = 0, $$2229 = 0, $$3194 = 0, $$3226 = 0, $$lobit = 0, $$lobit196 = 0, $$lobit197 = 0, $$lobit198 = 0, $$pre = 0, $$pre260 = 0, $$pre261 = 0, $$pre262 = 0, $$pre262$pre = 0, $$pre263 = 0, $$pre265 = 0, $$sink = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0.0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0, $arglist_next3 = 0, $expanded = 0, $expanded36 = 0, $expanded38 = 0, $expanded39 = 0, $expanded40 = 0, $expanded42 = 0, $expanded43 = 0, $expanded45 = 0, $expanded46 = 0, $expanded47 = 0, $or$cond = 0, $spec$select = 0, $spec$select202 = 0, $spec$select203 = 0;
 var $spec$select207 = 0, $spec$select208 = 0, $storemerge195230 = 0, $storemerge199 = 0, $trunc = 0, $vararg_buffer = 0, $vararg_buffer13 = 0, $vararg_buffer17 = 0, $vararg_buffer26 = 0, $vararg_buffer31 = 0, $vararg_buffer5 = 0, $vararg_buffer9 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0;
 var $vararg_ptr29 = 0, $vararg_ptr30 = 0, $vararg_ptr34 = 0, $vararg_ptr35 = 0, $vararg_ptr4 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $vararg_buffer31 = sp + 104|0;
 $vararg_buffer26 = sp + 88|0;
 $vararg_buffer17 = sp + 56|0;
 $vararg_buffer13 = sp + 48|0;
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer5 = sp + 32|0;
 $vararg_buffer = sp + 24|0;
 $5 = sp + 124|0;
 $6 = sp + 16|0;
 $7 = sp;
 $8 = sp + 120|0;
 HEAP32[$5>>2] = $1;
 $9 = ($0|0)!=(0|0);
 $$0174 = 0;$$0178 = 0;$$0191 = 0;
 L1: while(1) {
  $10 = ($$0178|0)>(-1);
  do {
   if ($10) {
    $11 = (2147483647 - ($$0178))|0;
    $12 = ($$0174|0)>($11|0);
    if (!($12)) {
     $17 = (($$0174) + ($$0178))|0;
     $$1179 = $17;
     break;
    }
    $13 = HEAP32[$0>>2]|0;
    $14 = $13 & 32;
    $15 = ($14|0)==(0);
    if ($15) {
     $16 = (___errno_location()|0);
     HEAP32[$16>>2] = 75;
     $$1179 = -1;
    } else {
     $$1179 = -1;
    }
   } else {
    $$1179 = $$0178;
   }
  } while(0);
  $18 = HEAP32[$5>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0);
  if ($20) {
   label = 87;
   break;
  }
  $21 = $19;$23 = $18;
  L11: while(1) {
   switch ($21|0) {
   case 37: case 0:  {
    break L11;
    break;
   }
   default: {
   }
   }
   $22 = ((($23)) + 4|0);
   HEAP32[$5>>2] = $22;
   $$pre = HEAP32[$22>>2]|0;
   $21 = $$pre;$23 = $22;
  }
  $24 = (_wcsspn($23,(gb + (166324) | 0))|0);
  $25 = $24 >>> 1;
  $26 = HEAP32[$5>>2]|0;
  $27 = (($26) + ($25<<2)|0);
  $28 = $24 & -2;
  $29 = (($26) + ($28<<2)|0);
  HEAP32[$5>>2] = $29;
  $30 = $27;
  $31 = $18;
  $32 = (($30) - ($31))|0;
  $33 = $32 >> 2;
  if ($9) {
   _out($0,$18,$33);
  }
  $34 = ($32|0)==(0);
  L18: do {
   if ($34) {
    $35 = HEAP32[$5>>2]|0;
    $36 = ((($35)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (_iswdigit($37)|0);
    $39 = ($38|0)==(0);
    $$pre260 = HEAP32[$5>>2]|0;
    if ($39) {
     $$0181 = -1;$$1192 = $$0191;$$sink = 1;
    } else {
     $40 = ((($$pre260)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(36);
     if ($42) {
      $43 = ((($$pre260)) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (($44) + -48)|0;
      $$0181 = $45;$$1192 = 1;$$sink = 3;
     } else {
      $$0181 = -1;$$1192 = $$0191;$$sink = 1;
     }
    }
    $46 = (($$pre260) + ($$sink<<2)|0);
    HEAP32[$5>>2] = $46;
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + -32)|0;
    $49 = ($48>>>0)<(32);
    L24: do {
     if ($49) {
      $$0189231 = 0;$51 = $48;$60 = $47;$storemerge195230 = $46;
      while(1) {
       $50 = 1 << $51;
       $52 = $50 & 75913;
       $53 = ($52|0)==(0);
       if ($53) {
        break;
       }
       $54 = $50 | $$0189231;
       $55 = ((($storemerge195230)) + 4|0);
       HEAP32[$5>>2] = $55;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($56) + -32)|0;
       $58 = ($57>>>0)<(32);
       if ($58) {
        $$0189231 = $54;$51 = $57;$60 = $56;$storemerge195230 = $55;
       } else {
        $$0189214 = $54;
        label = 30;
        break L24;
       }
      }
      $59 = ($60|0)==(42);
      if ($59) {
       $61 = ((($storemerge195230)) + 4|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (_iswdigit($62)|0);
       $64 = ($63|0)==(0);
       if ($64) {
        label = 25;
       } else {
        $65 = HEAP32[$5>>2]|0;
        $66 = ((($65)) + 8|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($67|0)==(36);
        if ($68) {
         $69 = ((($65)) + 4|0);
         $70 = HEAP32[$69>>2]|0;
         $71 = (($70) + -48)|0;
         $72 = (($4) + ($71<<2)|0);
         HEAP32[$72>>2] = 10;
         $73 = HEAP32[$69>>2]|0;
         $74 = (($73) + -48)|0;
         $75 = (($3) + ($74<<3)|0);
         $76 = $75;
         $77 = $76;
         $78 = HEAP32[$77>>2]|0;
         $79 = (($76) + 4)|0;
         $80 = $79;
         $81 = HEAP32[$80>>2]|0;
         $82 = ((($65)) + 12|0);
         $$0185 = $78;$$2193 = 1;$storemerge199 = $82;
        } else {
         label = 25;
        }
       }
       if ((label|0) == 25) {
        label = 0;
        $83 = ($$1192|0)==(0);
        if (!($83)) {
         $$0 = -1;
         break L1;
        }
        if ($9) {
         $arglist_current = HEAP32[$2>>2]|0;
         $84 = $arglist_current;
         $85 = ((0) + 4|0);
         $expanded36 = $85;
         $expanded = (($expanded36) - 1)|0;
         $86 = (($84) + ($expanded))|0;
         $87 = ((0) + 4|0);
         $expanded40 = $87;
         $expanded39 = (($expanded40) - 1)|0;
         $expanded38 = $expanded39 ^ -1;
         $88 = $86 & $expanded38;
         $89 = $88;
         $90 = HEAP32[$89>>2]|0;
         $arglist_next = ((($89)) + 4|0);
         HEAP32[$2>>2] = $arglist_next;
         $285 = $90;
        } else {
         $285 = 0;
        }
        $91 = HEAP32[$5>>2]|0;
        $92 = ((($91)) + 4|0);
        $$0185 = $285;$$2193 = 0;$storemerge199 = $92;
       }
       HEAP32[$5>>2] = $storemerge199;
       $93 = ($$0185|0)<(0);
       $94 = $$0189231 | 8192;
       $95 = (0 - ($$0185))|0;
       $spec$select207 = $93 ? $94 : $$0189231;
       $spec$select208 = $93 ? $95 : $$0185;
       $$1186 = $spec$select208;$$1190 = $spec$select207;$$3194 = $$2193;$99 = $storemerge199;
      } else {
       $$0189214 = $$0189231;
       label = 30;
      }
     } else {
      $$0189214 = 0;
      label = 30;
     }
    } while(0);
    if ((label|0) == 30) {
     label = 0;
     $96 = (_getint($5)|0);
     $97 = ($96|0)<(0);
     if ($97) {
      $$0 = -1;
      break L1;
     }
     $$pre261 = HEAP32[$5>>2]|0;
     $$1186 = $96;$$1190 = $$0189214;$$3194 = $$1192;$99 = $$pre261;
    }
    $98 = HEAP32[$99>>2]|0;
    $100 = ($98|0)==(46);
    do {
     if ($100) {
      $101 = ((($99)) + 4|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==(42);
      if (!($103)) {
       HEAP32[$5>>2] = $101;
       $136 = (_getint($5)|0);
       $$pre262$pre = HEAP32[$5>>2]|0;
       $$0182 = $136;$$pre262 = $$pre262$pre;
       break;
      }
      $104 = ((($99)) + 8|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (_isdigit($105)|0);
      $107 = ($106|0)==(0);
      if (!($107)) {
       $108 = HEAP32[$5>>2]|0;
       $109 = ((($108)) + 12|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = ($110|0)==(36);
       if ($111) {
        $112 = ((($108)) + 8|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = (($113) + -48)|0;
        $115 = (($4) + ($114<<2)|0);
        HEAP32[$115>>2] = 10;
        $116 = HEAP32[$112>>2]|0;
        $117 = (($116) + -48)|0;
        $118 = (($3) + ($117<<3)|0);
        $119 = $118;
        $120 = $119;
        $121 = HEAP32[$120>>2]|0;
        $122 = (($119) + 4)|0;
        $123 = $122;
        $124 = HEAP32[$123>>2]|0;
        $125 = ((($108)) + 16|0);
        HEAP32[$5>>2] = $125;
        $$0182 = $121;$$pre262 = $125;
        break;
       }
      }
      $126 = ($$3194|0)==(0);
      if (!($126)) {
       $$0 = -1;
       break L1;
      }
      if ($9) {
       $arglist_current2 = HEAP32[$2>>2]|0;
       $127 = $arglist_current2;
       $128 = ((0) + 4|0);
       $expanded43 = $128;
       $expanded42 = (($expanded43) - 1)|0;
       $129 = (($127) + ($expanded42))|0;
       $130 = ((0) + 4|0);
       $expanded47 = $130;
       $expanded46 = (($expanded47) - 1)|0;
       $expanded45 = $expanded46 ^ -1;
       $131 = $129 & $expanded45;
       $132 = $131;
       $133 = HEAP32[$132>>2]|0;
       $arglist_next3 = ((($132)) + 4|0);
       HEAP32[$2>>2] = $arglist_next3;
       $286 = $133;
      } else {
       $286 = 0;
      }
      $134 = HEAP32[$5>>2]|0;
      $135 = ((($134)) + 8|0);
      HEAP32[$5>>2] = $135;
      $$0182 = $286;$$pre262 = $135;
     } else {
      $$0182 = -1;$$pre262 = $99;
     }
    } while(0);
    $$0180 = 0;$138 = $$pre262;
    while(1) {
     $137 = HEAP32[$138>>2]|0;
     $139 = (($137) + -65)|0;
     $140 = ($139>>>0)>(57);
     if ($140) {
      $$0 = -1;
      break L1;
     }
     $141 = ((($138)) + 4|0);
     HEAP32[$5>>2] = $141;
     $142 = (((gb + (152720) | 0) + (($$0180*58)|0)|0) + ($139)|0);
     $143 = HEAP8[$142>>0]|0;
     $144 = $143&255;
     $145 = (($144) + -1)|0;
     $146 = ($145>>>0)<(8);
     if ($146) {
      $$0180 = $144;$138 = $141;
     } else {
      break;
     }
    }
    $147 = ($143<<24>>24)==(0);
    if ($147) {
     $$0 = -1;
     break L1;
    }
    $148 = ($143<<24>>24)==(19);
    $149 = ($$0181|0)>(-1);
    do {
     if ($148) {
      if ($149) {
       $$0 = -1;
       break L1;
      } else {
       label = 52;
      }
     } else {
      if ($149) {
       $150 = (($4) + ($$0181<<2)|0);
       HEAP32[$150>>2] = $144;
       $151 = (($3) + ($$0181<<3)|0);
       $152 = $151;
       $153 = $152;
       $154 = HEAP32[$153>>2]|0;
       $155 = (($152) + 4)|0;
       $156 = $155;
       $157 = HEAP32[$156>>2]|0;
       $158 = $6;
       $159 = $158;
       HEAP32[$159>>2] = $154;
       $160 = (($158) + 4)|0;
       $161 = $160;
       HEAP32[$161>>2] = $157;
       label = 52;
       break;
      }
      if (!($9)) {
       $$0 = 0;
       break L1;
      }
      _pop_arg($6,$144,$2);
      $$pre263 = HEAP32[$5>>2]|0;
      $163 = $$pre263;
     }
    } while(0);
    if ((label|0) == 52) {
     label = 0;
     if ($9) {
      $163 = $141;
     } else {
      $$0174$be = $33;$$0191$be = $$3194;
      break;
     }
    }
    $162 = ((($163)) + -4|0);
    $164 = HEAP32[$162>>2]|0;
    $165 = ($$0180|0)!=(0);
    $166 = $164 & 15;
    $167 = ($166|0)==(3);
    $or$cond = $165 & $167;
    $168 = $164 & -33;
    $$0171 = $or$cond ? $168 : $164;
    switch ($$0171|0) {
    case 110:  {
     $trunc = $$0180&255;
     switch ($trunc<<24>>24) {
     case 0:  {
      $169 = HEAP32[$6>>2]|0;
      HEAP32[$169>>2] = $$1179;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 1:  {
      $170 = HEAP32[$6>>2]|0;
      HEAP32[$170>>2] = $$1179;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 2:  {
      $171 = ($$1179|0)<(0);
      $172 = $171 << 31 >> 31;
      $173 = HEAP32[$6>>2]|0;
      $174 = $173;
      $175 = $174;
      HEAP32[$175>>2] = $$1179;
      $176 = (($174) + 4)|0;
      $177 = $176;
      HEAP32[$177>>2] = $172;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 3:  {
      $178 = $$1179&65535;
      $179 = HEAP32[$6>>2]|0;
      HEAP16[$179>>1] = $178;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 4:  {
      $180 = $$1179&255;
      $181 = HEAP32[$6>>2]|0;
      HEAP8[$181>>0] = $180;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 6:  {
      $182 = HEAP32[$6>>2]|0;
      HEAP32[$182>>2] = $$1179;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 7:  {
      $183 = ($$1179|0)<(0);
      $184 = $183 << 31 >> 31;
      $185 = HEAP32[$6>>2]|0;
      $186 = $185;
      $187 = $186;
      HEAP32[$187>>2] = $$1179;
      $188 = (($186) + 4)|0;
      $189 = $188;
      HEAP32[$189>>2] = $184;
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
      break;
     }
     default: {
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
     }
     }
     break;
    }
    case 99:  {
     $190 = $6;
     $191 = $190;
     $192 = HEAP32[$191>>2]|0;
     $193 = (($190) + 4)|0;
     $194 = $193;
     $195 = HEAP32[$194>>2]|0;
     $196 = (_btowc($192)|0);
     (_fputwc($196,$0)|0);
     $$0174$be = 1;$$0191$be = $$3194;
     break L18;
     break;
    }
    case 67:  {
     $197 = $6;
     $198 = $197;
     $199 = HEAP32[$198>>2]|0;
     $200 = (($197) + 4)|0;
     $201 = $200;
     $202 = HEAP32[$201>>2]|0;
     (_fputwc($199,$0)|0);
     $$0174$be = 1;$$0191$be = $$3194;
     break L18;
     break;
    }
    case 83:  {
     $203 = HEAP32[$6>>2]|0;
     $204 = (_wmemchr($203,0,$$0182)|0);
     $205 = ($204|0)==(0|0);
     $206 = $204;
     $207 = $203;
     $208 = (($206) - ($207))|0;
     $209 = $208 >> 2;
     $$1183 = $205 ? $$0182 : $209;
     $210 = ($$1186|0)<($$1183|0);
     $spec$select = $210 ? $$1183 : $$1186;
     $211 = $$1190 & 8192;
     $212 = ($211|0)==(0);
     if ($212) {
      $213 = (($spec$select) - ($$1183))|0;
      HEAP32[$vararg_buffer>>2] = $213;
      $vararg_ptr4 = ((($vararg_buffer)) + 4|0);
      HEAP32[$vararg_ptr4>>2] = (gb + (172139) | 0);
      (_fprintf($0,(gb + (167287) | 0),$vararg_buffer)|0);
      _out($0,$203,$$1183);
      $$0174$be = $spec$select;$$0191$be = $$3194;
      break L18;
     } else {
      _out($0,$203,$$1183);
      $214 = (($spec$select) - ($$1183))|0;
      HEAP32[$vararg_buffer5>>2] = $214;
      $vararg_ptr8 = ((($vararg_buffer5)) + 4|0);
      HEAP32[$vararg_ptr8>>2] = (gb + (172139) | 0);
      (_fprintf($0,(gb + (167287) | 0),$vararg_buffer5)|0);
      $$0174$be = $spec$select;$$0191$be = $$3194;
      break L18;
     }
     break;
    }
    case 109:  {
     $215 = (___errno_location()|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = (_strerror($216)|0);
     HEAP32[$6>>2] = $217;
     $219 = $217;
     break;
    }
    case 115:  {
     $$pre265 = HEAP32[$6>>2]|0;
     $219 = $$pre265;
     break;
    }
    default: {
     $239 = $$1190 >>> 3;
     $$lobit = $239 & 1;
     $240 = $$lobit ^ 1;
     $241 = ((gb + (167298) | 0) + ($240)|0);
     $242 = $$1190 >>> 11;
     $$lobit196 = $242 & 1;
     $243 = $$lobit196 ^ 1;
     $244 = ((gb + (167300) | 0) + ($243)|0);
     $245 = $$1190 >>> 13;
     $$lobit197 = $245 & 1;
     $246 = $$lobit197 ^ 1;
     $247 = ((gb + (167302) | 0) + ($246)|0);
     $248 = $$1190 & 1;
     $249 = $248 ^ 1;
     $250 = ((gb + (167591) | 0) + ($249)|0);
     $251 = $$1190 >>> 16;
     $$lobit198 = $251 & 1;
     $252 = $$lobit198 ^ 1;
     $253 = ((gb + (167304) | 0) + ($252)|0);
     $254 = $$0171 | 32;
     $255 = (($254) + -97)|0;
     $256 = ((gb + (153184) | 0) + ($255)|0);
     $257 = HEAP8[$256>>0]|0;
     $258 = $257 << 24 >> 24;
     HEAP32[$vararg_buffer17>>2] = $241;
     $vararg_ptr20 = ((($vararg_buffer17)) + 4|0);
     HEAP32[$vararg_ptr20>>2] = $244;
     $vararg_ptr21 = ((($vararg_buffer17)) + 8|0);
     HEAP32[$vararg_ptr21>>2] = $247;
     $vararg_ptr22 = ((($vararg_buffer17)) + 12|0);
     HEAP32[$vararg_ptr22>>2] = $250;
     $vararg_ptr23 = ((($vararg_buffer17)) + 16|0);
     HEAP32[$vararg_ptr23>>2] = $253;
     $vararg_ptr24 = ((($vararg_buffer17)) + 20|0);
     HEAP32[$vararg_ptr24>>2] = $258;
     $vararg_ptr25 = ((($vararg_buffer17)) + 24|0);
     HEAP32[$vararg_ptr25>>2] = $$0171;
     (_snprintf($7,16,(gb + (167306) | 0),$vararg_buffer17)|0);
     switch ($254|0) {
     case 103: case 102: case 101: case 97:  {
      $259 = +HEAPF64[$6>>3];
      HEAP32[$vararg_buffer26>>2] = $$1186;
      $vararg_ptr29 = ((($vararg_buffer26)) + 4|0);
      HEAP32[$vararg_ptr29>>2] = $$0182;
      $vararg_ptr30 = ((($vararg_buffer26)) + 8|0);
      HEAPF64[$vararg_ptr30>>3] = $259;
      $260 = (_fprintf($0,$7,$vararg_buffer26)|0);
      $$0174$be = $260;$$0191$be = $$3194;
      break L18;
      break;
     }
     case 112: case 120: case 117: case 111: case 105: case 100:  {
      $261 = $6;
      $262 = $261;
      $263 = HEAP32[$262>>2]|0;
      $264 = (($261) + 4)|0;
      $265 = $264;
      $266 = HEAP32[$265>>2]|0;
      HEAP32[$vararg_buffer31>>2] = $$1186;
      $vararg_ptr34 = ((($vararg_buffer31)) + 4|0);
      HEAP32[$vararg_ptr34>>2] = $$0182;
      $vararg_ptr35 = ((($vararg_buffer31)) + 8|0);
      $267 = $vararg_ptr35;
      $268 = $267;
      HEAP32[$268>>2] = $263;
      $269 = (($267) + 4)|0;
      $270 = $269;
      HEAP32[$270>>2] = $266;
      $271 = (_fprintf($0,$7,$vararg_buffer31)|0);
      $$0174$be = $271;$$0191$be = $$3194;
      break L18;
      break;
     }
     default: {
      $$0174$be = $33;$$0191$be = $$3194;
      break L18;
     }
     }
    }
    }
    $218 = ($219|0)==(0|0);
    if ($218) {
     HEAP32[$6>>2] = (gb + (167291) | 0);
     $287 = (gb + (167291) | 0);
    } else {
     $287 = $219;
    }
    $220 = ($$0182>>>0)<(2147483647);
    $spec$select202 = $220 ? $$0182 : 2147483647;
    $221 = ($spec$select202|0)>(0);
    L100: do {
     if ($221) {
      $$0170235 = $287;$$1175234 = 0;
      while(1) {
       $222 = (_mbtowc($8,$$0170235,4)|0);
       $223 = ($222|0)>(0);
       if (!($223)) {
        break;
       }
       $224 = (($$0170235) + ($222)|0);
       $225 = (($$1175234) + 1)|0;
       $226 = ($225>>>0)<($spec$select202>>>0);
       if ($226) {
        $$0170235 = $224;$$1175234 = $225;
       } else {
        $$1175220 = $225;
        break L100;
       }
      }
      $227 = ($222|0)<(0);
      if ($227) {
       $$0 = -1;
       break L1;
      } else {
       $$1175220 = $$1175234;
      }
     } else {
      $$1175220 = 0;
     }
    } while(0);
    $228 = ($$1186|0)<($$1175220|0);
    $spec$select203 = $228 ? $$1175220 : $$1186;
    $229 = $$1190 & 8192;
    $230 = ($229|0)!=(0);
    if (!($230)) {
     $231 = (($spec$select203) - ($$1175220))|0;
     HEAP32[$vararg_buffer9>>2] = $231;
     $vararg_ptr12 = ((($vararg_buffer9)) + 4|0);
     HEAP32[$vararg_ptr12>>2] = (gb + (172139) | 0);
     (_fprintf($0,(gb + (167287) | 0),$vararg_buffer9)|0);
    }
    $232 = ($$1175220|0)==(0);
    if (!($232)) {
     $$1239 = $287;$$2176238 = $$1175220;
     while(1) {
      $233 = (($$2176238) + -1)|0;
      $234 = (_mbtowc($8,$$1239,4)|0);
      $235 = (($$1239) + ($234)|0);
      $236 = HEAP32[$8>>2]|0;
      (_fputwc($236,$0)|0);
      $237 = ($233|0)==(0);
      if ($237) {
       break;
      } else {
       $$1239 = $235;$$2176238 = $233;
      }
     }
    }
    if ($230) {
     $238 = (($spec$select203) - ($$1175220))|0;
     HEAP32[$vararg_buffer13>>2] = $238;
     $vararg_ptr16 = ((($vararg_buffer13)) + 4|0);
     HEAP32[$vararg_ptr16>>2] = (gb + (172139) | 0);
     (_fprintf($0,(gb + (167287) | 0),$vararg_buffer13)|0);
     $$0174$be = $spec$select203;$$0191$be = $$3194;
    } else {
     $$0174$be = $spec$select203;$$0191$be = $$3194;
    }
   } else {
    $$0174$be = $33;$$0191$be = $$0191;
   }
  } while(0);
  $$0174 = $$0174$be;$$0178 = $$1179;$$0191 = $$0191$be;
 }
 L117: do {
  if ((label|0) == 87) {
   $272 = ($0|0)==(0|0);
   if ($272) {
    $273 = ($$0191|0)==(0);
    if ($273) {
     $$0 = 0;
    } else {
     $$2229 = 1;
     while(1) {
      $274 = (($4) + ($$2229<<2)|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = ($275|0)==(0);
      if ($276) {
       break;
      }
      $277 = (($3) + ($$2229<<3)|0);
      _pop_arg($277,$275,$2);
      $278 = (($$2229) + 1)|0;
      $279 = ($278>>>0)<(10);
      if ($279) {
       $$2229 = $278;
      } else {
       $$0 = 1;
       break L117;
      }
     }
     $$3226 = $$2229;
     while(1) {
      $282 = (($4) + ($$3226<<2)|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = ($283|0)==(0);
      $281 = (($$3226) + 1)|0;
      if (!($284)) {
       $$0 = -1;
       break L117;
      }
      $280 = ($281>>>0)<(10);
      if ($280) {
       $$3226 = $281;
      } else {
       $$0 = 1;
       break;
      }
     }
    }
   } else {
    $$0 = $$1179;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _fwide($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(-1);
 if ($4) {
  $5 = (___lockfile($0)|0);
  $24 = $5;
 } else {
  $24 = 0;
 }
 $6 = ($1|0)==(0);
 if ($6) {
  $$phi$trans$insert = ((($0)) + 74|0);
  $$pre = HEAP8[$$phi$trans$insert>>0]|0;
  $22 = $$pre;
 } else {
  $7 = ((($0)) + 120|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (___pthread_self_390()|0);
   $11 = ((($10)) + 188|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   $15 = $14 ? (gb + (171132) | 0) : (gb + (161260) | 0);
   HEAP32[$7>>2] = $15;
  }
  $16 = ((($0)) + 74|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $19 = ($1|0)>(0);
   $20 = $19 ? 1 : -1;
   HEAP8[$16>>0] = $20;
   $22 = $20;
  } else {
   $22 = $17;
  }
 }
 $21 = $22 << 24 >> 24;
 $23 = ($24|0)==(0);
 if (!($23)) {
  ___unlockfile($0);
 }
 return ($21|0);
}
function ___pthread_self_390() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _wcsspn($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$lcssa = 0, $$08 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$0$lcssa = $0;
  } else {
   $$08 = $0;$4 = $2;
   while(1) {
    $5 = (_wcschr($1,$4)|0);
    $6 = ($5|0)==(0|0);
    if ($6) {
     $$0$lcssa = $$08;
     break L1;
    }
    $7 = ((($$08)) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0);
    if ($9) {
     $$0$lcssa = $7;
     break;
    } else {
     $$08 = $7;$4 = $8;
    }
   }
  }
 } while(0);
 $10 = $$0$lcssa;
 $11 = $0;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 return ($13|0);
}
function _out($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$034 = 0, $$in = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $$034 = $1;$$in = $2;
   while(1) {
    $4 = (($$in) + -1)|0;
    $5 = HEAP32[$0>>2]|0;
    $6 = $5 & 32;
    $7 = ($6|0)==(0);
    if (!($7)) {
     break L1;
    }
    $8 = ((($$034)) + 4|0);
    $9 = HEAP32[$$034>>2]|0;
    (_fputwc($9,$0)|0);
    $10 = ($4|0)==(0);
    if ($10) {
     break;
    } else {
     $$034 = $8;$$in = $4;
    }
   }
  }
 } while(0);
 return;
}
function _getint($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$04 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (_iswdigit($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $$0$lcssa = 0;
 } else {
  $$04 = 0;
  while(1) {
   $5 = ($$04*10)|0;
   $6 = HEAP32[$0>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + -48)|0;
   $9 = (($8) + ($7))|0;
   $10 = ((($6)) + 4|0);
   HEAP32[$0>>2] = $10;
   $11 = HEAP32[$10>>2]|0;
   $12 = (_iswdigit($11)|0);
   $13 = ($12|0)==(0);
   if ($13) {
    $$0$lcssa = $9;
    break;
   } else {
    $$04 = $9;
   }
  }
 }
 return ($$0$lcssa|0);
}
function _pop_arg($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$mask = 0, $$mask31 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0;
 var $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0, $arglist_current26 = 0, $arglist_current5 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0, $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next6 = 0, $arglist_next9 = 0, $expanded = 0, $expanded28 = 0, $expanded30 = 0, $expanded31 = 0;
 var $expanded32 = 0, $expanded34 = 0, $expanded35 = 0, $expanded37 = 0, $expanded38 = 0, $expanded39 = 0, $expanded41 = 0, $expanded42 = 0, $expanded44 = 0, $expanded45 = 0, $expanded46 = 0, $expanded48 = 0, $expanded49 = 0, $expanded51 = 0, $expanded52 = 0, $expanded53 = 0, $expanded55 = 0, $expanded56 = 0, $expanded58 = 0, $expanded59 = 0;
 var $expanded60 = 0, $expanded62 = 0, $expanded63 = 0, $expanded65 = 0, $expanded66 = 0, $expanded67 = 0, $expanded69 = 0, $expanded70 = 0, $expanded72 = 0, $expanded73 = 0, $expanded74 = 0, $expanded76 = 0, $expanded77 = 0, $expanded79 = 0, $expanded80 = 0, $expanded81 = 0, $expanded83 = 0, $expanded84 = 0, $expanded86 = 0, $expanded87 = 0;
 var $expanded88 = 0, $expanded90 = 0, $expanded91 = 0, $expanded93 = 0, $expanded94 = 0, $expanded95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1>>>0)>(20);
 L1: do {
  if (!($3)) {
   do {
    switch ($1|0) {
    case 9:  {
     $arglist_current = HEAP32[$2>>2]|0;
     $4 = $arglist_current;
     $5 = ((0) + 4|0);
     $expanded28 = $5;
     $expanded = (($expanded28) - 1)|0;
     $6 = (($4) + ($expanded))|0;
     $7 = ((0) + 4|0);
     $expanded32 = $7;
     $expanded31 = (($expanded32) - 1)|0;
     $expanded30 = $expanded31 ^ -1;
     $8 = $6 & $expanded30;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $arglist_next = ((($9)) + 4|0);
     HEAP32[$2>>2] = $arglist_next;
     HEAP32[$0>>2] = $10;
     break L1;
     break;
    }
    case 10:  {
     $arglist_current2 = HEAP32[$2>>2]|0;
     $11 = $arglist_current2;
     $12 = ((0) + 4|0);
     $expanded35 = $12;
     $expanded34 = (($expanded35) - 1)|0;
     $13 = (($11) + ($expanded34))|0;
     $14 = ((0) + 4|0);
     $expanded39 = $14;
     $expanded38 = (($expanded39) - 1)|0;
     $expanded37 = $expanded38 ^ -1;
     $15 = $13 & $expanded37;
     $16 = $15;
     $17 = HEAP32[$16>>2]|0;
     $arglist_next3 = ((($16)) + 4|0);
     HEAP32[$2>>2] = $arglist_next3;
     $18 = ($17|0)<(0);
     $19 = $18 << 31 >> 31;
     $20 = $0;
     $21 = $20;
     HEAP32[$21>>2] = $17;
     $22 = (($20) + 4)|0;
     $23 = $22;
     HEAP32[$23>>2] = $19;
     break L1;
     break;
    }
    case 11:  {
     $arglist_current5 = HEAP32[$2>>2]|0;
     $24 = $arglist_current5;
     $25 = ((0) + 4|0);
     $expanded42 = $25;
     $expanded41 = (($expanded42) - 1)|0;
     $26 = (($24) + ($expanded41))|0;
     $27 = ((0) + 4|0);
     $expanded46 = $27;
     $expanded45 = (($expanded46) - 1)|0;
     $expanded44 = $expanded45 ^ -1;
     $28 = $26 & $expanded44;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $arglist_next6 = ((($29)) + 4|0);
     HEAP32[$2>>2] = $arglist_next6;
     $31 = $0;
     $32 = $31;
     HEAP32[$32>>2] = $30;
     $33 = (($31) + 4)|0;
     $34 = $33;
     HEAP32[$34>>2] = 0;
     break L1;
     break;
    }
    case 12:  {
     $arglist_current8 = HEAP32[$2>>2]|0;
     $35 = $arglist_current8;
     $36 = ((0) + 8|0);
     $expanded49 = $36;
     $expanded48 = (($expanded49) - 1)|0;
     $37 = (($35) + ($expanded48))|0;
     $38 = ((0) + 8|0);
     $expanded53 = $38;
     $expanded52 = (($expanded53) - 1)|0;
     $expanded51 = $expanded52 ^ -1;
     $39 = $37 & $expanded51;
     $40 = $39;
     $41 = $40;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = (($41) + 4)|0;
     $45 = $44;
     $46 = HEAP32[$45>>2]|0;
     $arglist_next9 = ((($40)) + 8|0);
     HEAP32[$2>>2] = $arglist_next9;
     $47 = $0;
     $48 = $47;
     HEAP32[$48>>2] = $43;
     $49 = (($47) + 4)|0;
     $50 = $49;
     HEAP32[$50>>2] = $46;
     break L1;
     break;
    }
    case 13:  {
     $arglist_current11 = HEAP32[$2>>2]|0;
     $51 = $arglist_current11;
     $52 = ((0) + 4|0);
     $expanded56 = $52;
     $expanded55 = (($expanded56) - 1)|0;
     $53 = (($51) + ($expanded55))|0;
     $54 = ((0) + 4|0);
     $expanded60 = $54;
     $expanded59 = (($expanded60) - 1)|0;
     $expanded58 = $expanded59 ^ -1;
     $55 = $53 & $expanded58;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $arglist_next12 = ((($56)) + 4|0);
     HEAP32[$2>>2] = $arglist_next12;
     $58 = $57&65535;
     $59 = $58 << 16 >> 16;
     $60 = ($59|0)<(0);
     $61 = $60 << 31 >> 31;
     $62 = $0;
     $63 = $62;
     HEAP32[$63>>2] = $59;
     $64 = (($62) + 4)|0;
     $65 = $64;
     HEAP32[$65>>2] = $61;
     break L1;
     break;
    }
    case 14:  {
     $arglist_current14 = HEAP32[$2>>2]|0;
     $66 = $arglist_current14;
     $67 = ((0) + 4|0);
     $expanded63 = $67;
     $expanded62 = (($expanded63) - 1)|0;
     $68 = (($66) + ($expanded62))|0;
     $69 = ((0) + 4|0);
     $expanded67 = $69;
     $expanded66 = (($expanded67) - 1)|0;
     $expanded65 = $expanded66 ^ -1;
     $70 = $68 & $expanded65;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $arglist_next15 = ((($71)) + 4|0);
     HEAP32[$2>>2] = $arglist_next15;
     $$mask31 = $72 & 65535;
     $73 = $0;
     $74 = $73;
     HEAP32[$74>>2] = $$mask31;
     $75 = (($73) + 4)|0;
     $76 = $75;
     HEAP32[$76>>2] = 0;
     break L1;
     break;
    }
    case 15:  {
     $arglist_current17 = HEAP32[$2>>2]|0;
     $77 = $arglist_current17;
     $78 = ((0) + 4|0);
     $expanded70 = $78;
     $expanded69 = (($expanded70) - 1)|0;
     $79 = (($77) + ($expanded69))|0;
     $80 = ((0) + 4|0);
     $expanded74 = $80;
     $expanded73 = (($expanded74) - 1)|0;
     $expanded72 = $expanded73 ^ -1;
     $81 = $79 & $expanded72;
     $82 = $81;
     $83 = HEAP32[$82>>2]|0;
     $arglist_next18 = ((($82)) + 4|0);
     HEAP32[$2>>2] = $arglist_next18;
     $84 = $83&255;
     $85 = $84 << 24 >> 24;
     $86 = ($85|0)<(0);
     $87 = $86 << 31 >> 31;
     $88 = $0;
     $89 = $88;
     HEAP32[$89>>2] = $85;
     $90 = (($88) + 4)|0;
     $91 = $90;
     HEAP32[$91>>2] = $87;
     break L1;
     break;
    }
    case 16:  {
     $arglist_current20 = HEAP32[$2>>2]|0;
     $92 = $arglist_current20;
     $93 = ((0) + 4|0);
     $expanded77 = $93;
     $expanded76 = (($expanded77) - 1)|0;
     $94 = (($92) + ($expanded76))|0;
     $95 = ((0) + 4|0);
     $expanded81 = $95;
     $expanded80 = (($expanded81) - 1)|0;
     $expanded79 = $expanded80 ^ -1;
     $96 = $94 & $expanded79;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $arglist_next21 = ((($97)) + 4|0);
     HEAP32[$2>>2] = $arglist_next21;
     $$mask = $98 & 255;
     $99 = $0;
     $100 = $99;
     HEAP32[$100>>2] = $$mask;
     $101 = (($99) + 4)|0;
     $102 = $101;
     HEAP32[$102>>2] = 0;
     break L1;
     break;
    }
    case 17:  {
     $arglist_current23 = HEAP32[$2>>2]|0;
     $103 = $arglist_current23;
     $104 = ((0) + 8|0);
     $expanded84 = $104;
     $expanded83 = (($expanded84) - 1)|0;
     $105 = (($103) + ($expanded83))|0;
     $106 = ((0) + 8|0);
     $expanded88 = $106;
     $expanded87 = (($expanded88) - 1)|0;
     $expanded86 = $expanded87 ^ -1;
     $107 = $105 & $expanded86;
     $108 = $107;
     $109 = +HEAPF64[$108>>3];
     $arglist_next24 = ((($108)) + 8|0);
     HEAP32[$2>>2] = $arglist_next24;
     HEAPF64[$0>>3] = $109;
     break L1;
     break;
    }
    case 18:  {
     $arglist_current26 = HEAP32[$2>>2]|0;
     $110 = $arglist_current26;
     $111 = ((0) + 8|0);
     $expanded91 = $111;
     $expanded90 = (($expanded91) - 1)|0;
     $112 = (($110) + ($expanded90))|0;
     $113 = ((0) + 8|0);
     $expanded95 = $113;
     $expanded94 = (($expanded95) - 1)|0;
     $expanded93 = $expanded94 ^ -1;
     $114 = $112 & $expanded93;
     $115 = $114;
     $116 = +HEAPF64[$115>>3];
     $arglist_next27 = ((($115)) + 8|0);
     HEAP32[$2>>2] = $arglist_next27;
     HEAPF64[$0>>3] = $116;
     break L1;
     break;
    }
    default: {
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 return;
}
function _btowc($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $sext = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 & 255;
 $2 = ($1>>>0)<(128);
 if ($2) {
  return ($1|0);
 } else {
  $3 = (___pthread_self_506()|0);
  $4 = ((($3)) + 188|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  $8 = ($0|0)!=(-1);
  $or$cond = $8 & $7;
  $sext = $0 << 24;
  $9 = $sext >> 24;
  $10 = $9 & 57343;
  $spec$select = $or$cond ? $10 : -1;
  return ($spec$select|0);
 }
 return (0)|0;
}
function _fputwc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(-1);
 if ($4) {
  $6 = (___lockfile($1)|0);
  $phitmp = ($6|0)==(0);
  $7 = (___fputwc_unlocked($0,$1)|0);
  if ($phitmp) {
   $8 = $7;
  } else {
   ___unlockfile($1);
   $8 = $7;
  }
 } else {
  $5 = (___fputwc_unlocked($0,$1)|0);
  $8 = $5;
 }
 return ($8|0);
}
function _wmemchr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$067 = 0, $$08 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $9 = 0;
  } else {
   $$067 = $0;$$08 = $2;
   while(1) {
    $4 = HEAP32[$$067>>2]|0;
    $5 = ($4|0)==($1|0);
    if ($5) {
     $9 = $$067;
     break L1;
    }
    $6 = (($$08) + -1)|0;
    $7 = ((($$067)) + 4|0);
    $8 = ($6|0)==(0);
    if ($8) {
     $9 = 0;
     break;
    } else {
     $$067 = $7;$$08 = $6;
    }
   }
  }
 } while(0);
 return ($9|0);
}
function _mbtowc($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0|0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = ($2|0)==(0);
   do {
    if (!($5)) {
     $6 = ($0|0)==(0|0);
     $spec$select = $6 ? $3 : $0;
     $7 = HEAP8[$1>>0]|0;
     $8 = ($7<<24>>24)>(-1);
     if ($8) {
      $9 = $7&255;
      HEAP32[$spec$select>>2] = $9;
      $10 = ($7<<24>>24)!=(0);
      $11 = $10&1;
      $$0 = $11;
      break L1;
     }
     $12 = (___pthread_self_498()|0);
     $13 = ((($12)) + 188|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     $17 = HEAP8[$1>>0]|0;
     if ($16) {
      $18 = $17 << 24 >> 24;
      $19 = $18 & 57343;
      HEAP32[$spec$select>>2] = $19;
      $$0 = 1;
      break L1;
     }
     $20 = $17&255;
     $21 = (($20) + -194)|0;
     $22 = ($21>>>0)>(50);
     if (!($22)) {
      $23 = ((($1)) + 1|0);
      $24 = ((gb + (160) | 0) + ($21<<2)|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($2>>>0)<(4);
      if ($26) {
       $27 = ($2*6)|0;
       $28 = (($27) + -6)|0;
       $29 = -2147483648 >>> $28;
       $30 = $25 & $29;
       $31 = ($30|0)==(0);
       if (!($31)) {
        break;
       }
      }
      $32 = HEAP8[$23>>0]|0;
      $33 = $32&255;
      $34 = $33 >>> 3;
      $35 = (($34) + -16)|0;
      $36 = $25 >> 26;
      $37 = (($34) + ($36))|0;
      $38 = $35 | $37;
      $39 = ($38>>>0)>(7);
      if (!($39)) {
       $40 = $25 << 6;
       $41 = (($33) + -128)|0;
       $42 = $41 | $40;
       $43 = ($42|0)<(0);
       if (!($43)) {
        HEAP32[$spec$select>>2] = $42;
        $$0 = 2;
        break L1;
       }
       $44 = ((($1)) + 2|0);
       $45 = HEAP8[$44>>0]|0;
       $46 = $45&255;
       $47 = (($46) + -128)|0;
       $48 = ($47>>>0)>(63);
       if (!($48)) {
        $49 = $42 << 6;
        $50 = $47 | $49;
        $51 = ($50|0)<(0);
        if (!($51)) {
         HEAP32[$spec$select>>2] = $50;
         $$0 = 3;
         break L1;
        }
        $52 = ((($1)) + 3|0);
        $53 = HEAP8[$52>>0]|0;
        $54 = $53&255;
        $55 = (($54) + -128)|0;
        $56 = ($55>>>0)>(63);
        if (!($56)) {
         $57 = $50 << 6;
         $58 = $55 | $57;
         HEAP32[$spec$select>>2] = $58;
         $$0 = 4;
         break L1;
        }
       }
      }
     }
    }
   } while(0);
   $59 = (___errno_location()|0);
   HEAP32[$59>>2] = 84;
   $$0 = -1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___pthread_self_498() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___fputwc_unlocked($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$035 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (___pthread_self_453()|0);
 $4 = ((($3)) + 188|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 74|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)<(1);
 if ($8) {
  (_fwide($1,1)|0);
 }
 $9 = ((($1)) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$4>>2] = $10;
 $11 = ($0>>>0)<(128);
 do {
  if ($11) {
   $12 = $0&255;
   $13 = $0 & 255;
   $14 = ((($1)) + 75|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15 << 24 >> 24;
   $17 = ($13|0)==($16|0);
   if (!($17)) {
    $18 = ((($1)) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($1)) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19>>>0)<($21>>>0);
    if ($22) {
     $23 = ((($19)) + 1|0);
     HEAP32[$18>>2] = $23;
     HEAP8[$19>>0] = $12;
     $$035 = $13;
     break;
    }
   }
   $24 = (___overflow($1,$0)|0);
   $$0 = $24;
   label = 13;
  } else {
   $25 = ((($1)) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26)) + 4|0);
   $28 = ((($1)) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27>>>0)<($29>>>0);
   if ($30) {
    $31 = (_wctomb($26,$0)|0);
    $32 = ($31|0)<(0);
    if ($32) {
     label = 14;
     break;
    }
    $33 = HEAP32[$25>>2]|0;
    $34 = (($33) + ($31)|0);
    HEAP32[$25>>2] = $34;
    $$0 = $0;
    label = 13;
    break;
   } else {
    $35 = (_wctomb($2,$0)|0);
    $36 = ($35|0)<(0);
    if ($36) {
     label = 14;
     break;
    }
    $37 = (___fwritex($2,$35,$1)|0);
    $38 = ($37>>>0)<($35>>>0);
    if ($38) {
     label = 14;
     break;
    } else {
     $$0 = $0;
     label = 13;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $39 = ($$0|0)==(-1);
  if ($39) {
   label = 14;
  } else {
   $$035 = $$0;
  }
 }
 if ((label|0) == 14) {
  $40 = HEAP32[$1>>2]|0;
  $41 = $40 | 32;
  HEAP32[$1>>2] = $41;
  $$035 = -1;
 }
 HEAP32[$4>>2] = $5;
 STACKTOP = sp;return ($$035|0);
}
function ___pthread_self_453() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___overflow($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = $1&255;
 HEAP8[$2>>0] = $3;
 $4 = ((($0)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (___towrite($0)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$pre = HEAP32[$4>>2]|0;
   $12 = $$pre;
   label = 4;
  } else {
   $$0 = -1;
  }
 } else {
  $12 = $5;
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $9 = ((($0)) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)<($12>>>0);
   if ($11) {
    $13 = $1 & 255;
    $14 = ((($0)) + 75|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15 << 24 >> 24;
    $17 = ($13|0)==($16|0);
    if (!($17)) {
     $18 = ((($10)) + 1|0);
     HEAP32[$9>>2] = $18;
     HEAP8[$10>>0] = $3;
     $$0 = $13;
     break;
    }
   }
   $19 = ((($0)) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (mftCall_iiii($20|0,($0|0),($2|0),1)|0);
   $22 = ($21|0)==(1);
   if ($22) {
    $23 = HEAP8[$2>>0]|0;
    $24 = $23&255;
    $$0 = $24;
   } else {
    $$0 = -1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___pthread_self_506() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _swprintf($0,$1,$2,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $varargs = $varargs|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $varargs;
 $4 = (_vswprintf($0,$1,$2,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function _vswprintf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(400|0);
 $4 = sp + 264|0;
 $5 = sp;
 $6 = sp + 256|0;
 HEAP32[$6>>2] = $0;
 $7 = ((($6)) + 4|0);
 $8 = (($1) + -1)|0;
 HEAP32[$7>>2] = $8;
 (_memset(($4|0),0,124)|0);
 $9 = ((($4)) + 75|0);
 HEAP8[$9>>0] = -1;
 $10 = ((($4)) + 36|0);
 HEAP32[$10>>2] = (fb + (20) | 0);
 $11 = ((($4)) + 48|0);
 HEAP32[$11>>2] = 256;
 $12 = ((($4)) + 44|0);
 HEAP32[$12>>2] = $5;
 $13 = ((($4)) + 76|0);
 HEAP32[$13>>2] = -1;
 $14 = ((($4)) + 84|0);
 HEAP32[$14>>2] = $6;
 $15 = ($1|0)==(0);
 do {
  if ($15) {
   $$0 = -1;
  } else {
   $16 = ($1|0)<(0);
   if ($16) {
    $17 = (___errno_location()|0);
    HEAP32[$17>>2] = 75;
    $$0 = -1;
    break;
   } else {
    $18 = (_vfwprintf($4,$2,$3)|0);
    (_sw_write($4,0,0)|0);
    $19 = ($18>>>0)<($1>>>0);
    $20 = $19 ? $18 : -1;
    $$0 = $20;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _sw_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0$ph = 0, $$03034 = 0, $$03133 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond32 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($1|0);
 if ($7) {
  label = 3;
 } else {
  $8 = ((($0)) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $6;
  $11 = (($9) - ($10))|0;
  $12 = (_sw_write($0,$6,$11)|0);
  $13 = ($12|0)==(-1);
  if ($13) {
   $$0 = -1;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $14 = ((($4)) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)!=(0);
  $17 = ($2|0)!=(0);
  $or$cond32 = $17 & $16;
  L5: do {
   if ($or$cond32) {
    $$pre = HEAP32[$4>>2]|0;
    $$03034 = $1;$$03133 = $2;$18 = $$pre;
    while(1) {
     $19 = (_mbtowc($18,$$03034,$$03133)|0);
     $20 = ($19|0)>(-1);
     if (!($20)) {
      $$0$ph = $19;
      break L5;
     }
     $21 = (($$03034) + ($19)|0);
     $22 = (($$03133) - ($19))|0;
     $23 = HEAP32[$14>>2]|0;
     $24 = (($23) + -1)|0;
     HEAP32[$14>>2] = $24;
     $25 = HEAP32[$4>>2]|0;
     $26 = ((($25)) + 4|0);
     HEAP32[$4>>2] = $26;
     $27 = ($24|0)!=(0);
     $28 = ($22|0)!=(0);
     $or$cond = $28 & $27;
     if ($or$cond) {
      $$03034 = $21;$$03133 = $22;$18 = $26;
     } else {
      $$0$ph = $2;
      break;
     }
    }
   } else {
    $$0$ph = $2;
   }
  } while(0);
  $29 = HEAP32[$4>>2]|0;
  HEAP32[$29>>2] = 0;
  $$0 = $$0$ph;
 }
 return ($$0|0);
}
function _getwchar() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $1 = (_fgetwc($0)|0);
 return ($1|0);
}
function _fgetwc($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $5 = (___lockfile($0)|0);
  $phitmp = ($5|0)==(0);
  $6 = (___fgetwc_unlocked($0)|0);
  if ($phitmp) {
   $7 = $6;
  } else {
   ___unlockfile($0);
   $7 = $6;
  }
 } else {
  $4 = (___fgetwc_unlocked($0)|0);
  $7 = $4;
 }
 return ($7|0);
}
function ___fgetwc_unlocked($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_391()|0);
 $2 = ((($1)) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 74|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(1);
 if ($6) {
  (_fwide($0,1)|0);
 }
 $7 = ((($0)) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$2>>2] = $8;
 $9 = (___fgetwc_unlocked_internal($0)|0);
 HEAP32[$2>>2] = $3;
 return ($9|0);
}
function ___pthread_self_391() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___fgetwc_unlocked_internal($0) {
 $0 = $0|0;
 var $$019 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = $1;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = ((($0)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = $11;
   $14 = $9;
   $15 = (($13) - ($14))|0;
   $16 = (_mbrtowc($2,$9,$15,$1)|0);
   $17 = ($16>>>0)<(4294967294);
   if ($17) {
    $18 = ($16|0)==(0);
    $19 = $18&1;
    $20 = (($16) + ($19))|0;
    $21 = HEAP32[$8>>2]|0;
    $22 = (($21) + ($20)|0);
    HEAP32[$8>>2] = $22;
    $23 = HEAP32[$2>>2]|0;
    $$019 = $23;
    break;
   }
   $24 = ($16|0)==(-1);
   if ($24) {
    $25 = HEAP32[$8>>2]|0;
    $26 = ((($25)) + 1|0);
    HEAP32[$8>>2] = $26;
    $$019 = -1;
   } else {
    label = 5;
   }
  } else {
   label = 5;
  }
 } while(0);
 L7: do {
  if ((label|0) == 5) {
   L9: while(1) {
    $27 = HEAP32[$8>>2]|0;
    $28 = HEAP32[$10>>2]|0;
    $29 = ($27>>>0)<($28>>>0);
    if ($29) {
     $30 = ((($27)) + 1|0);
     HEAP32[$8>>2] = $30;
     $31 = HEAP8[$27>>0]|0;
     HEAP8[$3>>0] = $31;
    } else {
     $32 = (___uflow($0)|0);
     $33 = $32&255;
     HEAP8[$3>>0] = $33;
     $34 = ($32|0)<(0);
     if ($34) {
      break;
     }
    }
    $38 = (_mbrtowc($2,$3,1,$1)|0);
    switch ($38|0) {
    case -1:  {
     $$019 = $38;
     break L7;
     break;
    }
    case -2:  {
     break;
    }
    default: {
     label = 13;
     break L9;
    }
    }
   }
   if ((label|0) == 13) {
    $39 = HEAP32[$2>>2]|0;
    $$019 = $39;
    break;
   }
   $35 = (_mbsinit($1)|0);
   $36 = ($35|0)==(0);
   if ($36) {
    $37 = (___errno_location()|0);
    HEAP32[$37>>2] = 84;
    $$019 = -1;
   } else {
    $$019 = -1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$019|0);
}
function _mbsinit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(0);
  $phitmp = $3&1;
  $4 = $phitmp;
 }
 return ($4|0);
}
function _open_wmemstream($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_malloc(156)|0);
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (_malloc(4)|0);
   $5 = ($4|0)==(0|0);
   if ($5) {
    _free($2);
    $$0 = 0;
    break;
   }
   (_memset(($2|0),0,156)|0);
   $6 = ((($2)) + 124|0);
   $7 = ((($2)) + 84|0);
   HEAP32[$7>>2] = $6;
   HEAP32[$6>>2] = $0;
   $8 = ((($2)) + 128|0);
   HEAP32[$8>>2] = $1;
   HEAP32[$1>>2] = 0;
   $9 = ((($2)) + 144|0);
   HEAP32[$9>>2] = 0;
   $10 = ((($2)) + 140|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($2)) + 132|0);
   HEAP32[$11>>2] = 0;
   HEAP32[$0>>2] = $4;
   $12 = ((($2)) + 136|0);
   HEAP32[$12>>2] = $4;
   HEAP32[$4>>2] = 0;
   HEAP32[$2>>2] = 4;
   $13 = ((($2)) + 60|0);
   HEAP32[$13>>2] = -1;
   $14 = ((($2)) + 156|0);
   $15 = ((($2)) + 44|0);
   HEAP32[$15>>2] = $14;
   $16 = ((($2)) + 48|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($2)) + 75|0);
   HEAP8[$17>>0] = -1;
   $18 = ((($2)) + 36|0);
   HEAP32[$18>>2] = (fb + (21) | 0);
   $19 = ((($2)) + 40|0);
   HEAP32[$19>>2] = (fb + (22) | 0);
   $20 = ((($2)) + 12|0);
   HEAP32[$20>>2] = (fb + (23) | 0);
   $21 = HEAP32[((((gb + (171204) | 0)) + 4|0))>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = ((($2)) + 76|0);
    HEAP32[$23>>2] = -1;
   }
   $24 = (___ofl_add($2)|0);
   $$0 = $2;
  }
 } while(0);
 return ($$0|0);
}
function _wms_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre41 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($2))|0;
 $9 = ((($5)) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $$pre41 = ((($5)) + 12|0);
  $$pre$phiZ2D = $$pre41;$30 = $7;$32 = $10;
  label = 6;
 } else {
  $12 = $10 << 1;
  $13 = (($8) + 1)|0;
  $14 = $13 | $12;
  $15 = $14 | 1;
  $16 = ($15>>>0)>(536870911);
  if ($16) {
   $$0 = 0;
  } else {
   $17 = ((($5)) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $15 << 2;
   $20 = (_realloc($18,$19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0 = 0;
   } else {
    HEAP32[$17>>2] = $20;
    $22 = HEAP32[$5>>2]|0;
    HEAP32[$22>>2] = $20;
    $23 = HEAP32[$17>>2]|0;
    $24 = HEAP32[$9>>2]|0;
    $25 = (($23) + ($24<<2)|0);
    $26 = (($15) - ($24))|0;
    $27 = $26 << 2;
    (_memset(($25|0),0,($27|0))|0);
    HEAP32[$9>>2] = $15;
    $$pre = HEAP32[$6>>2]|0;
    $$pre$phiZ2D = $17;$30 = $$pre;$32 = $15;
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $28 = HEAP32[$$pre$phiZ2D>>2]|0;
  $29 = (($28) + ($30<<2)|0);
  $31 = (($32) - ($30))|0;
  $33 = ((($5)) + 24|0);
  $34 = (_mbsnrtowcs($29,$3,$2,$31,$33)|0);
  $35 = ($34|0)==(-1);
  if ($35) {
   $$0 = 0;
  } else {
   $36 = HEAP32[$6>>2]|0;
   $37 = (($36) + ($34))|0;
   HEAP32[$6>>2] = $37;
   $38 = ((($5)) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37>>>0)<($39>>>0);
   if (!($40)) {
    HEAP32[$38>>2] = $37;
   }
   $41 = ((($5)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$42>>2] = $37;
   $$0 = $2;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _wms_seek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2>>>0)>(2);
 if ($6) {
  label = 2;
 } else {
  HEAP32[$3>>2] = 0;
  $8 = ((($3)) + 4|0);
  $9 = ((($5)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($3)) + 8|0);
  $12 = ((($5)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $13;
  $14 = (($3) + ($2<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (0 - ($15))|0;
  $17 = ($16|0)>($1|0);
  $18 = (536870911 - ($15))|0;
  $19 = ($18|0)<($1|0);
  $or$cond = $17 | $19;
  if ($or$cond) {
   label = 2;
  } else {
   $20 = ((($5)) + 24|0);
   (_memset(($20|0),0,8)|0);
   $21 = (($15) + ($1))|0;
   HEAP32[$9>>2] = $21;
   $$0 = $21;
  }
 }
 if ((label|0) == 2) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _wms_close($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _mbsnrtowcs($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$04975 = 0, $$05374 = 0, $$056 = 0, $$150 = 0, $$154 = 0, $$15773 = 0, $$164 = 0, $$176 = 0, $$2 = 0, $$25170 = 0, $$25569 = 0, $$258 = 0, $$352 = 0, $$359 = 0, $$371 = 0, $$468 = 0, $$cast = 0, $$pr$pre = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond72 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1040|0);
 $5 = sp;
 $6 = sp + 1024|0;
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $7;
 $8 = ($0|0)!=(0|0);
 $$056 = $8 ? $3 : 256;
 $$0 = $8 ? $0 : $5;
 $$cast = $7;
 $9 = ($7|0)!=(0);
 $10 = ($$056|0)!=(0);
 $or$cond72 = $10 & $9;
 L1: do {
  if ($or$cond72) {
   $$04975 = 0;$$05374 = $2;$$15773 = $$056;$$176 = $$0;$44 = $$cast;
   while(1) {
    $11 = $$05374 >>> 2;
    $12 = ($11>>>0)>=($$15773>>>0);
    $13 = ($$05374>>>0)>(131);
    $14 = $13 | $12;
    if (!($14)) {
     $$150 = $$04975;$$154 = $$05374;$$164 = $$176;$$359 = $$15773;$26 = $44;
     break L1;
    }
    $spec$select = $12 ? $$15773 : $11;
    $15 = (($$05374) - ($spec$select))|0;
    $16 = (_mbsrtowcs($$176,$6,$spec$select,$4)|0);
    $17 = ($16|0)==(-1);
    if ($17) {
     break;
    }
    $18 = ($$176|0)==($5|0);
    $19 = (($$176) + ($16<<2)|0);
    $20 = $18 ? 0 : $16;
    $$258 = (($$15773) - ($20))|0;
    $$2 = $18 ? $$176 : $19;
    $21 = (($16) + ($$04975))|0;
    $22 = HEAP32[$6>>2]|0;
    $23 = ($22|0)!=(0|0);
    $24 = ($$258|0)!=(0);
    $or$cond = $24 & $23;
    if ($or$cond) {
     $$04975 = $21;$$05374 = $15;$$15773 = $$258;$$176 = $$2;$44 = $22;
    } else {
     $$150 = $21;$$154 = $15;$$164 = $$2;$$359 = $$258;$26 = $22;
     break L1;
    }
   }
   $$pr$pre = HEAP32[$6>>2]|0;
   $$150 = -1;$$154 = $15;$$164 = $$176;$$359 = 0;$26 = $$pr$pre;
  } else {
   $$150 = 0;$$154 = $2;$$164 = $$0;$$359 = $$056;$26 = $$cast;
  }
 } while(0);
 $25 = ($26|0)==(0|0);
 L9: do {
  if ($25) {
   $$352 = $$150;
  } else {
   $27 = ($$359|0)!=(0);
   $28 = ($$154|0)!=(0);
   $29 = $27 & $28;
   if ($29) {
    $$25170 = $$150;$$25569 = $$154;$$371 = $$164;$$468 = $$359;$30 = $26;
    while(1) {
     $31 = (_mbrtowc($$371,$30,$$25569,$4)|0);
     $32 = (($31) + 2)|0;
     $33 = ($32>>>0)<(3);
     if ($33) {
      break;
     }
     $34 = HEAP32[$6>>2]|0;
     $35 = (($34) + ($31)|0);
     HEAP32[$6>>2] = $35;
     $36 = (($$25569) - ($31))|0;
     $37 = ((($$371)) + 4|0);
     $38 = (($$468) + -1)|0;
     $39 = (($$25170) + 1)|0;
     $40 = ($38|0)!=(0);
     $41 = ($36|0)!=(0);
     $42 = $40 & $41;
     if ($42) {
      $$25170 = $39;$$25569 = $36;$$371 = $37;$$468 = $38;$30 = $35;
     } else {
      $$352 = $39;
      break L9;
     }
    }
    switch ($31|0) {
    case -1:  {
     $$352 = $31;
     break L9;
     break;
    }
    case 0:  {
     HEAP32[$6>>2] = 0;
     $$352 = $$25170;
     break L9;
     break;
    }
    default: {
     HEAP32[$4>>2] = 0;
     $$352 = $$25170;
     break L9;
    }
    }
   } else {
    $$352 = $$150;
   }
  }
 } while(0);
 if ($8) {
  $43 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $43;
 }
 STACKTOP = sp;return ($$352|0);
}
function ___ftello_unlocked($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = $3 & 128;
 $5 = ($4|0)==(0);
 if ($5) {
  $11 = 1;
 } else {
  $6 = ((($0)) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($0)) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7>>>0)>($9>>>0);
  $phitmp = $10 ? 2 : 1;
  $11 = $phitmp;
 }
 $12 = (mftCall_iiii($2|0,($0|0),0,($11|0))|0);
 $13 = ($12|0)<(0);
 if ($13) {
  $$0 = $12;
 } else {
  $14 = ((($0)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($0)) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($0)) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($12) - ($15))|0;
  $23 = (($22) + ($17))|0;
  $24 = (($23) + ($19))|0;
  $25 = (($24) - ($21))|0;
  $$0 = $25;
 }
 return ($$0|0);
}
function ___ftello($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $5 = (___lockfile($0)|0);
  $phitmp = ($5|0)==(0);
  $6 = (___ftello_unlocked($0)|0);
  if ($phitmp) {
   $7 = $6;
  } else {
   $7 = $6;
  }
 } else {
  $4 = (___ftello_unlocked($0)|0);
  $7 = $4;
 }
 return ($7|0);
}
function _ftell($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___ftello($0)|0);
 return ($1|0);
}
function _rename($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall38(38,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _getw($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 $2 = (_fread($1,4,1,$0)|0);
 $3 = ($2|0)==(0);
 $4 = HEAP32[$1>>2]|0;
 $5 = $3 ? -1 : $4;
 STACKTOP = sp;return ($5|0);
}
function _fread($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $$054 = 0, $$056 = 0, $$15759 = 0, $$160 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = Math_imul($2, $1)|0;
 $5 = ($1|0)==(0);
 $spec$select = $5 ? 0 : $2;
 $6 = ((($3)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $9 = (___lockfile($3)|0);
  $37 = $9;
 } else {
  $37 = 0;
 }
 $10 = ((($3)) + 74|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11 << 24 >> 24;
 $13 = (($12) + 255)|0;
 $14 = $13 | $12;
 $15 = $14&255;
 HEAP8[$10>>0] = $15;
 $16 = ((($3)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($3)) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) - ($19))|0;
 $21 = ($20|0)>(0);
 if ($21) {
  $22 = $19;
  $23 = ($20>>>0)<($4>>>0);
  $$ = $23 ? $20 : $4;
  (_memcpy(($0|0),($22|0),($$|0))|0);
  $24 = HEAP32[$18>>2]|0;
  $25 = (($24) + ($$)|0);
  HEAP32[$18>>2] = $25;
  $26 = (($0) + ($$)|0);
  $27 = (($4) - ($$))|0;
  $$054 = $27;$$056 = $26;
 } else {
  $$054 = $4;$$056 = $0;
 }
 $28 = ($$054|0)==(0);
 L7: do {
  if ($28) {
   label = 13;
  } else {
   $29 = ((($3)) + 32|0);
   $$15759 = $$056;$$160 = $$054;
   while(1) {
    $30 = (___toread($3)|0);
    $31 = ($30|0)==(0);
    if (!($31)) {
     break;
    }
    $32 = HEAP32[$29>>2]|0;
    $33 = (mftCall_iiii($32|0,($3|0),($$15759|0),($$160|0))|0);
    $34 = (($33) + 1)|0;
    $35 = ($34>>>0)<(2);
    if ($35) {
     break;
    }
    $40 = (($$160) - ($33))|0;
    $41 = (($$15759) + ($33)|0);
    $42 = ($40|0)==(0);
    if ($42) {
     label = 13;
     break L7;
    } else {
     $$15759 = $41;$$160 = $40;
    }
   }
   $36 = ($37|0)==(0);
   if (!($36)) {
    ___unlockfile($3);
   }
   $38 = (($4) - ($$160))|0;
   $39 = (($38>>>0) / ($1>>>0))&-1;
   $$0 = $39;
  }
 } while(0);
 if ((label|0) == 13) {
  $43 = ($37|0)==(0);
  if ($43) {
   $$0 = $spec$select;
  } else {
   ___unlockfile($3);
   $$0 = $spec$select;
  }
 }
 return ($$0|0);
}
function _setlinebuf($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_setvbuf($0,0,1,0)|0);
 return;
}
function _setvbuf($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($0)) + 75|0);
 HEAP8[$4>>0] = -1;
 switch ($2|0) {
 case 2:  {
  $5 = ((($0)) + 48|0);
  HEAP32[$5>>2] = 0;
  break;
 }
 case 1:  {
  HEAP8[$4>>0] = 10;
  break;
 }
 default: {
 }
 }
 $6 = HEAP32[$0>>2]|0;
 $7 = $6 | 64;
 HEAP32[$0>>2] = $7;
 return 0;
}
function _vprintf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $3 = (_vfprintf($2,$0,$1)|0);
 return ($3|0);
}
function _getline($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_getdelim($0,$1,10,$2)|0);
 return ($3|0);
}
function _getdelim($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$087 = 0, $$088 = 0, $$089 = 0, $$1 = 0, $$190 = 0, $$pre = 0, $$pre97 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond3 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ((($3)) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 if ($6) {
  $7 = (___lockfile($3)|0);
  $13 = $7;
 } else {
  $13 = 0;
 }
 $8 = ($1|0)!=(0|0);
 $9 = ($0|0)!=(0|0);
 $or$cond = $9 & $8;
 L4: do {
  if ($or$cond) {
   $15 = HEAP32[$0>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    HEAP32[$1>>2] = 0;
   }
   $17 = ((($3)) + 4|0);
   $18 = ((($3)) + 8|0);
   $$089 = 0;
   while(1) {
    $19 = HEAP32[$17>>2]|0;
    $20 = HEAP32[$18>>2]|0;
    $21 = $19;
    $22 = (($20) - ($21))|0;
    $23 = (_memchr($19,$2,$22)|0);
    $24 = ($23|0)!=(0|0);
    $25 = $23;
    $26 = (1 - ($21))|0;
    $27 = (($26) + ($25))|0;
    $28 = $24 ? $27 : $22;
    $29 = (($28) + ($$089))|0;
    $30 = (($29) + 1)|0;
    $31 = HEAP32[$1>>2]|0;
    $32 = ($30>>>0)<($31>>>0);
    if ($32) {
     $$pre = HEAP32[$0>>2]|0;
     $47 = $$pre;$48 = $19;
    } else {
     $33 = (2147483647 - ($$089))|0;
     $34 = ($28>>>0)<($33>>>0);
     if (!($34)) {
      label = 27;
      break;
     }
     $35 = (($29) + 2)|0;
     $36 = ($23|0)==(0|0);
     $37 = ($35>>>0)<(1073741823);
     $or$cond3 = $36 & $37;
     $38 = $35 >>> 1;
     $39 = $or$cond3 ? $38 : 0;
     $$0 = (($39) + ($35))|0;
     $40 = HEAP32[$0>>2]|0;
     $41 = (_realloc($40,$$0)|0);
     $42 = ($41|0)==(0|0);
     if ($42) {
      $43 = HEAP32[$0>>2]|0;
      $44 = (_realloc($43,$35)|0);
      $45 = ($44|0)==(0|0);
      if ($45) {
       label = 27;
       break;
      } else {
       $$088 = $44;$$1 = $35;
      }
     } else {
      $$088 = $41;$$1 = $$0;
     }
     HEAP32[$0>>2] = $$088;
     HEAP32[$1>>2] = $$1;
     $$pre97 = HEAP32[$17>>2]|0;
     $47 = $$088;$48 = $$pre97;
    }
    $46 = (($47) + ($$089)|0);
    (_memcpy(($46|0),($48|0),($28|0))|0);
    $49 = HEAP32[$17>>2]|0;
    $50 = (($49) + ($28)|0);
    HEAP32[$17>>2] = $50;
    if ($24) {
     $$190 = $29;
     break;
    }
    $51 = HEAP32[$18>>2]|0;
    $52 = ($50>>>0)<($51>>>0);
    if ($52) {
     $53 = ((($50)) + 1|0);
     HEAP32[$17>>2] = $53;
     $54 = HEAP8[$50>>0]|0;
     $55 = $54&255;
     $64 = $55;
    } else {
     $56 = (___uflow($3)|0);
     $57 = ($56|0)==(-1);
     if ($57) {
      label = 20;
      break;
     } else {
      $64 = $56;
     }
    }
    $63 = $64&255;
    $65 = HEAP32[$0>>2]|0;
    $66 = (($65) + ($29)|0);
    HEAP8[$66>>0] = $63;
    $sext = $64 << 24;
    $67 = $sext >> 24;
    $68 = ($67|0)==($2|0);
    if ($68) {
     $$190 = $30;
     break;
    } else {
     $$089 = $30;
    }
   }
   if ((label|0) == 27) {
    $72 = HEAP32[$3>>2]|0;
    $73 = $72 | 32;
    HEAP32[$3>>2] = $73;
    $74 = ($13|0)==(0);
    if (!($74)) {
     ___unlockfile($3);
    }
    $75 = (___errno_location()|0);
    HEAP32[$75>>2] = 12;
    $$087 = -1;
    break;
   }
   do {
    if ((label|0) == 20) {
     $58 = ($29|0)==(0);
     if (!($58)) {
      $59 = HEAP32[$3>>2]|0;
      $60 = $59 & 16;
      $61 = ($60|0)==(0);
      if (!($61)) {
       $$190 = $29;
       break;
      }
     }
     $62 = ($13|0)==(0);
     if ($62) {
      $$087 = -1;
      break L4;
     }
     ___unlockfile($3);
     $$087 = -1;
     break L4;
    }
   } while(0);
   $69 = HEAP32[$0>>2]|0;
   $70 = (($69) + ($$190)|0);
   HEAP8[$70>>0] = 0;
   $71 = ($13|0)==(0);
   if ($71) {
    $$087 = $$190;
   } else {
    ___unlockfile($3);
    $$087 = $$190;
   }
  } else {
   $10 = HEAP32[$3>>2]|0;
   $11 = $10 | 32;
   HEAP32[$3>>2] = $11;
   $12 = ($13|0)==(0);
   if (!($12)) {
    ___unlockfile($3);
   }
   $14 = (___errno_location()|0);
   HEAP32[$14>>2] = 22;
   $$087 = -1;
  }
 } while(0);
 return ($$087|0);
}
function _fmemopen($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$op = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strchr($2,43)|0);
 $4 = ($3|0)==(0|0);
 $5 = ($1|0)==(0);
 do {
  if ($5) {
   label = 3;
  } else {
   $6 = HEAP8[$2>>0]|0;
   $7 = $6 << 24 >> 24;
   $8 = (_strchr((gb + (167347) | 0),$7)|0);
   $9 = ($8|0)==(0|0);
   if ($9) {
    label = 3;
   } else {
    $11 = ($0|0)==(0|0);
    $12 = ($1>>>0)>(4294966139);
    $or$cond = $11 & $12;
    if ($or$cond) {
     $13 = (___errno_location()|0);
     HEAP32[$13>>2] = 12;
     $$0 = 0;
     break;
    }
    $14 = ($0|0)!=(0|0);
    $$op = (($1) + 1176)|0;
    $15 = $14 ? 1176 : $$op;
    $16 = (_calloc($15,1)|0);
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0 = 0;
    } else {
     $18 = ((($16)) + 124|0);
     $19 = ((($16)) + 84|0);
     HEAP32[$19>>2] = $18;
     $20 = ((($16)) + 60|0);
     HEAP32[$20>>2] = -1;
     $21 = ((($16)) + 75|0);
     HEAP8[$21>>0] = -1;
     $22 = ((($16)) + 152|0);
     $23 = ((($16)) + 44|0);
     HEAP32[$23>>2] = $22;
     $24 = ((($16)) + 48|0);
     HEAP32[$24>>2] = 1024;
     $25 = ((($16)) + 1176|0);
     $spec$select = $14 ? $0 : $25;
     $26 = ((($16)) + 136|0);
     HEAP32[$26>>2] = $spec$select;
     $27 = ((($16)) + 132|0);
     HEAP32[$27>>2] = $1;
     $28 = HEAP8[$2>>0]|0;
     $29 = $28 << 24 >> 24;
     $30 = ((($16)) + 140|0);
     HEAP32[$30>>2] = $29;
     if ($4) {
      $31 = ($28<<24>>24)==(114);
      $32 = $31 ? 8 : 4;
      HEAP32[$16>>2] = $32;
     }
     switch ($28<<24>>24) {
     case 114:  {
      $$sink = $1;
      label = 11;
      break;
     }
     case 97:  {
      $33 = (_strnlen($spec$select,$1)|0);
      HEAP32[$18>>2] = $33;
      $$sink = $33;
      label = 11;
      break;
     }
     default: {
     }
     }
     if ((label|0) == 11) {
      $34 = ((($16)) + 128|0);
      HEAP32[$34>>2] = $$sink;
     }
     $35 = ((($16)) + 32|0);
     HEAP32[$35>>2] = (fb + (24) | 0);
     $36 = ((($16)) + 36|0);
     HEAP32[$36>>2] = (fb + (25) | 0);
     $37 = ((($16)) + 40|0);
     HEAP32[$37>>2] = (fb + (26) | 0);
     $38 = ((($16)) + 12|0);
     HEAP32[$38>>2] = (fb + (27) | 0);
     $39 = HEAP32[((((gb + (171204) | 0)) + 4|0))>>2]|0;
     $40 = ($39|0)==(0);
     if ($40) {
      $41 = ((($16)) + 76|0);
      HEAP32[$41>>2] = -1;
     }
     $42 = (___ofl_add($16)|0);
     $$0 = $16;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $10 = (___errno_location()|0);
  HEAP32[$10>>2] = 22;
  $$0 = 0;
 }
 return ($$0|0);
}
function _mread($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$034 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = ($6>>>0)<($7>>>0);
 $spec$store$select = $9 ? 0 : $8;
 $10 = ($spec$store$select>>>0)<($2>>>0);
 if ($10) {
  $11 = HEAP32[$0>>2]|0;
  $12 = $11 | 16;
  HEAP32[$0>>2] = $12;
  $$034 = $spec$store$select;
 } else {
  $$034 = $2;
 }
 $13 = ((($4)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($7)|0);
 (_memcpy(($1|0),($15|0),($$034|0))|0);
 $16 = HEAP32[$4>>2]|0;
 $17 = (($16) + ($$034))|0;
 HEAP32[$4>>2] = $17;
 $18 = (($spec$store$select) - ($$034))|0;
 $19 = ((($0)) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 $spec$select = $21 ? $20 : $18;
 $22 = ((($0)) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($0)) + 4|0);
 HEAP32[$24>>2] = $23;
 $$cast = $23;
 $25 = (($$cast) + ($spec$select)|0);
 $26 = ((($0)) + 8|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$13>>2]|0;
 $28 = (($27) + ($17)|0);
 (_memcpy(($$cast|0),($28|0),($spec$select|0))|0);
 $29 = HEAP32[$4>>2]|0;
 $30 = (($29) + ($spec$select))|0;
 HEAP32[$4>>2] = $30;
 return ($$034|0);
}
function _mwrite($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $$pre$phi44Z2D = 0, $$pre$phiZ2D = 0, $$pre43 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = (($6) - ($9))|0;
 $11 = ($10|0)==(0);
 if ($11) {
  label = 3;
 } else {
  HEAP32[$5>>2] = $8;
  $12 = (_mwrite($0,$8,$10)|0);
  $13 = ($12>>>0)<($10>>>0);
  if ($13) {
   $$0 = 0;
  } else {
   label = 3;
  }
 }
 do {
  if ((label|0) == 3) {
   $14 = ((($4)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(97);
   if ($16) {
    $17 = ((($4)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$4>>2] = $18;
    $$pre$phi44Z2D = $17;$$pre$phiZ2D = $4;$22 = $18;
   } else {
    $$pre = HEAP32[$4>>2]|0;
    $$pre43 = ((($4)) + 4|0);
    $$pre$phi44Z2D = $$pre43;$$pre$phiZ2D = $4;$22 = $$pre;
   }
   $19 = ((($4)) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) - ($22))|0;
   $23 = ($21>>>0)<($2>>>0);
   $spec$select = $23 ? $21 : $2;
   $24 = ((($4)) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + ($22)|0);
   (_memcpy(($26|0),($1|0),($spec$select|0))|0);
   $27 = HEAP32[$$pre$phiZ2D>>2]|0;
   $28 = (($27) + ($spec$select))|0;
   HEAP32[$$pre$phiZ2D>>2] = $28;
   $29 = HEAP32[$$pre$phi44Z2D>>2]|0;
   $30 = ($28>>>0)>($29>>>0);
   if ($30) {
    HEAP32[$$pre$phi44Z2D>>2] = $28;
    $31 = HEAP32[$19>>2]|0;
    $32 = ($28>>>0)<($31>>>0);
    if ($32) {
     $33 = HEAP32[$24>>2]|0;
     $34 = (($33) + ($28)|0);
     HEAP8[$34>>0] = 0;
     $$0 = $spec$select;
     break;
    }
    $35 = HEAP32[$0>>2]|0;
    $36 = $35 & 4;
    $37 = ($36|0)==(0);
    $38 = ($31|0)==(0);
    $or$cond = $38 | $37;
    if ($or$cond) {
     $$0 = $spec$select;
    } else {
     $39 = (($31) + -1)|0;
     $40 = HEAP32[$24>>2]|0;
     $41 = (($40) + ($39)|0);
     HEAP8[$41>>0] = 0;
     $$0 = $spec$select;
    }
   } else {
    $$0 = $spec$select;
   }
  }
 } while(0);
 return ($$0|0);
}
function _mseek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2>>>0)>(2);
 if ($6) {
  label = 2;
 } else {
  HEAP32[$3>>2] = 0;
  $8 = ((($3)) + 4|0);
  $9 = HEAP32[$5>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = ((($3)) + 8|0);
  $11 = ((($5)) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$10>>2] = $12;
  $13 = (($3) + ($2<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (0 - ($14))|0;
  $16 = ($15|0)>($1|0);
  if ($16) {
   label = 2;
  } else {
   $17 = ((($5)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) - ($14))|0;
   $20 = ($19|0)<($1|0);
   if ($20) {
    label = 2;
   } else {
    $21 = (($14) + ($1))|0;
    HEAP32[$5>>2] = $21;
    $$0 = $21;
   }
  }
 }
 if ((label|0) == 2) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _mclose($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __flushlbf() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_fflush(0)|0);
 return;
}
function _fflush($0) {
 $0 = $0|0;
 var $$0 = 0, $$023 = 0, $$02325 = 0, $$02327 = 0, $$024$lcssa = 0, $$02426 = 0, $$1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $8 = HEAP32[(gb + (161692) | 0)>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $29 = 0;
   } else {
    $10 = HEAP32[(gb + (161692) | 0)>>2]|0;
    $11 = (_fflush($10)|0);
    $29 = $11;
   }
   $12 = (___ofl_lock()|0);
   $$02325 = HEAP32[$12>>2]|0;
   $13 = ($$02325|0)==(0|0);
   if ($13) {
    $$024$lcssa = $29;
   } else {
    $$02327 = $$02325;$$02426 = $29;
    while(1) {
     $14 = ((($$02327)) + 76|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)>(-1);
     if ($16) {
      $17 = (___lockfile($$02327)|0);
      $26 = $17;
     } else {
      $26 = 0;
     }
     $18 = ((($$02327)) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ((($$02327)) + 28|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if ($22) {
      $23 = (___fflush_unlocked($$02327)|0);
      $24 = $23 | $$02426;
      $$1 = $24;
     } else {
      $$1 = $$02426;
     }
     $25 = ($26|0)==(0);
     if (!($25)) {
      ___unlockfile($$02327);
     }
     $27 = ((($$02327)) + 56|0);
     $$023 = HEAP32[$27>>2]|0;
     $28 = ($$023|0)==(0|0);
     if ($28) {
      $$024$lcssa = $$1;
      break;
     } else {
      $$02327 = $$023;$$02426 = $$1;
     }
    }
   }
   ___ofl_unlock();
   $$0 = $$024$lcssa;
  } else {
   $2 = ((($0)) + 76|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $5 = (___fflush_unlocked($0)|0);
    $$0 = $5;
    break;
   }
   $6 = (___lockfile($0)|0);
   $phitmp = ($6|0)==(0);
   $7 = (___fflush_unlocked($0)|0);
   if ($phitmp) {
    $$0 = $7;
   } else {
    ___unlockfile($0);
    $$0 = $7;
   }
  }
 } while(0);
 return ($$0|0);
}
function ___fflush_unlocked($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  $6 = ((($0)) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  (mftCall_iiii($7|0,($0|0),(0|0),0)|0);
  $8 = HEAP32[$1>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$0 = -1;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = ((($0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = $11;
   $16 = $13;
   $17 = (($15) - ($16))|0;
   $18 = ((($0)) + 40|0);
   $19 = HEAP32[$18>>2]|0;
   (mftCall_iiii($19|0,($0|0),($17|0),1)|0);
  }
  $20 = ((($0)) + 16|0);
  HEAP32[$20>>2] = 0;
  HEAP32[$3>>2] = 0;
  HEAP32[$1>>2] = 0;
  HEAP32[$12>>2] = 0;
  HEAP32[$10>>2] = 0;
  $$0 = 0;
 }
 return ($$0|0);
}
function ___fsetlocking($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function ___fwriting($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = ((($0)) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)!=(0|0);
  $phitmp = $6&1;
  $7 = $phitmp;
 } else {
  $7 = 1;
 }
 return ($7|0);
}
function ___freading($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = ((($0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)!=(0|0);
  $phitmp = $6&1;
  $7 = $phitmp;
 } else {
  $7 = 1;
 }
 return ($7|0);
}
function ___freadable($0) {
 $0 = $0|0;
 var $$lobit = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 2;
 $$lobit = $2 & 1;
 $3 = $$lobit ^ 1;
 return ($3|0);
}
function ___fwritable($0) {
 $0 = $0|0;
 var $$lobit = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 3;
 $$lobit = $2 & 1;
 $3 = $$lobit ^ 1;
 return ($3|0);
}
function ___flbf($0) {
 $0 = $0|0;
 var $$lobit = 0, $$not = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 75|0);
 $2 = HEAP8[$1>>0]|0;
 $$lobit = ($2&255) >>> 7;
 $3 = $$lobit ^ 1;
 $$not = $3&255;
 return ($$not|0);
}
function ___fbufsize($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function ___fpending($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $9 = 0;
 } else {
  $4 = ((($0)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) - ($7))|0;
  $9 = $8;
 }
 return ($9|0);
}
function ___fpurge($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = 0;
 return 0;
}
function _fwrite($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = Math_imul($2, $1)|0;
 $5 = ($1|0)==(0);
 $spec$select = $5 ? 0 : $2;
 $6 = ((($3)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $10 = (___lockfile($3)|0);
  $phitmp = ($10|0)==(0);
  $11 = (___fwritex($0,$4,$3)|0);
  if ($phitmp) {
   $13 = $11;
  } else {
   ___unlockfile($3);
   $13 = $11;
  }
 } else {
  $9 = (___fwritex($0,$4,$3)|0);
  $13 = $9;
 }
 $12 = ($13|0)==($4|0);
 if ($12) {
  $15 = $spec$select;
 } else {
  $14 = (($13>>>0) / ($1>>>0))&-1;
  $15 = $14;
 }
 return ($15|0);
}
function _fwscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vfwscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _vfwscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$$3302409 = 0, $$0245$lcssa = 0, $$0245444 = 0, $$0249 = 0, $$0251451 = 0, $$0252 = 0, $$0255473 = 0, $$0261472 = 0, $$0269381 = 0, $$0269449 = 0, $$0272 = 0, $$0273471 = 0, $$0281464 = 0, $$0285 = 0, $$0287 = 0, $$0299462 = 0, $$10 = 0, $$10309 = 0, $$11 = 0, $$11310 = 0;
 var $$12 = 0, $$1253 = 0, $$1256 = 0, $$1262 = 0, $$1274 = 0, $$1282 = 0, $$1286 = 0, $$1300 = 0, $$1313 = 0, $$1313338 = 0, $$2 = 0, $$2254 = 0, $$2257 = 0, $$2263375 = 0, $$2263450 = 0, $$2271 = 0, $$2275 = 0, $$2283 = 0, $$2290 = 0, $$2301 = 0;
 var $$3258$lcssa = 0, $$3258443 = 0, $$3276 = 0, $$3276339 = 0, $$3284 = 0, $$3291393 = 0, $$3291447 = 0, $$3302409 = 0, $$3302446 = 0, $$4259 = 0, $$4277342 = 0, $$4316$ph351 = 0, $$4452 = 0, $$5260 = 0, $$5266 = 0, $$5278387 = 0, $$5278448 = 0, $$5293 = 0, $$6 = 0, $$6267 = 0;
 var $$6279 = 0, $$7268 = 0, $$7280 = 0, $$7306 = 0, $$8 = 0, $$8307 = 0, $$9 = 0, $$9308 = 0, $$old10 = 0, $$pr = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre559 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_next = 0;
 var $expanded = 0, $expanded11 = 0, $expanded12 = 0, $expanded13 = 0, $expanded9 = 0, $factor = 0, $factor354 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond3 = 0, $or$cond323 = 0, $or$cond325 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $spec$select = 0, $spec$select319 = 0, $spec$select320 = 0, $spec$select321 = 0, $spec$select322 = 0;
 var $spec$select326 = 0, $spec$select327 = 0, $spec$select328 = 0, $spec$select329 = 0, $spec$select330 = 0, $spec$select331 = 0, $vararg_buffer = 0, $vararg_buffer5 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $vararg_buffer5 = sp + 48|0;
 $vararg_buffer = sp + 24|0;
 $3 = sp + 144|0;
 $4 = sp;
 $5 = sp + 56|0;
 $6 = ((($0)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $9 = (___lockfile($0)|0);
  $256 = $9;
 } else {
  $256 = 0;
 }
 (_fwide($0,1)|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = ($10|0)==(0);
 L4: do {
  if ($11) {
   $$3284 = 0;
  } else {
   $12 = ((($0)) + 4|0);
   $13 = ((($0)) + 8|0);
   $14 = ((($5)) + 4|0);
   $15 = ((($5)) + 8|0);
   $16 = ((($5)) + 12|0);
   $17 = ((($5)) + 16|0);
   $18 = ((($5)) + 20|0);
   $19 = ((($5)) + 24|0);
   $20 = ((($5)) + 28|0);
   $21 = ((($5)) + 32|0);
   $22 = ((($5)) + 36|0);
   $23 = ((($5)) + 40|0);
   $24 = ((($5)) + 44|0);
   $25 = ((($5)) + 48|0);
   $26 = ((($5)) + 52|0);
   $27 = ((($5)) + 56|0);
   $28 = ((($5)) + 60|0);
   $29 = ((($5)) + 64|0);
   $30 = ((($5)) + 68|0);
   $31 = ((($5)) + 72|0);
   $32 = ((($5)) + 76|0);
   $33 = ((($5)) + 80|0);
   $34 = ((($5)) + 84|0);
   $$0255473 = $1;$$0261472 = 0;$$0273471 = 0;$$0281464 = 0;$$0299462 = 0;$257 = 0;$35 = $10;
   L6: while(1) {
    $36 = (_iswspace($35)|0);
    $37 = ($36|0)==(0);
    L8: do {
     if ($37) {
      $60 = HEAP32[$$0255473>>2]|0;
      $61 = ($60|0)==(37);
      L10: do {
       if ($61) {
        $62 = ((($$0255473)) + 4|0);
        $63 = HEAP32[$62>>2]|0;
        L12: do {
         switch ($63|0) {
         case 37:  {
          break L10;
          break;
         }
         case 42:  {
          $86 = ((($$0255473)) + 8|0);
          $$0287 = 0;$$2257 = $86;
          break;
         }
         default: {
          $87 = (_iswdigit($63)|0);
          $88 = ($87|0)==(0);
          if (!($88)) {
           $89 = ((($$0255473)) + 8|0);
           $90 = HEAP32[$89>>2]|0;
           $91 = ($90|0)==(36);
           if ($91) {
            $92 = HEAP32[$62>>2]|0;
            $93 = (($92) + -48)|0;
            $94 = (_arg_n($2,$93)|0);
            $95 = ((($$0255473)) + 12|0);
            $$0287 = $94;$$2257 = $95;
            break L12;
           }
          }
          $arglist_current = HEAP32[$2>>2]|0;
          $96 = $arglist_current;
          $97 = ((0) + 4|0);
          $expanded9 = $97;
          $expanded = (($expanded9) - 1)|0;
          $98 = (($96) + ($expanded))|0;
          $99 = ((0) + 4|0);
          $expanded13 = $99;
          $expanded12 = (($expanded13) - 1)|0;
          $expanded11 = $expanded12 ^ -1;
          $100 = $98 & $expanded11;
          $101 = $100;
          $102 = HEAP32[$101>>2]|0;
          $arglist_next = ((($101)) + 4|0);
          HEAP32[$2>>2] = $arglist_next;
          $$0287 = $102;$$2257 = $62;
         }
         }
        } while(0);
        $103 = HEAP32[$$2257>>2]|0;
        $104 = (_iswdigit($103)|0);
        $105 = ($104|0)==(0);
        if ($105) {
         $$0245$lcssa = 0;$$3258$lcssa = $$2257;
        } else {
         $$0245444 = 0;$$3258443 = $$2257;
         while(1) {
          $106 = ($$0245444*10)|0;
          $107 = HEAP32[$$3258443>>2]|0;
          $108 = (($106) + -48)|0;
          $109 = (($108) + ($107))|0;
          $110 = ((($$3258443)) + 4|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = (_iswdigit($111)|0);
          $113 = ($112|0)==(0);
          if ($113) {
           $$0245$lcssa = $109;$$3258$lcssa = $110;
           break;
          } else {
           $$0245444 = $109;$$3258443 = $110;
          }
         }
        }
        $114 = HEAP32[$$3258$lcssa>>2]|0;
        $115 = ($114|0)==(109);
        $116 = ((($$3258$lcssa)) + 4|0);
        if ($115) {
         $117 = ($$0287|0)!=(0|0);
         $118 = $117&1;
         $$pr = HEAP32[$116>>2]|0;
         $$pre559 = ((($$3258$lcssa)) + 8|0);
         $$0252 = $118;$$1300 = 0;$$4259 = $116;$$pre$phiZ2D = $$pre559;$119 = $$pr;$260 = 0;
        } else {
         $$0252 = 0;$$1300 = $$0299462;$$4259 = $$3258$lcssa;$$pre$phiZ2D = $116;$119 = $114;$260 = $257;
        }
        switch ($119|0) {
        case 104:  {
         $120 = HEAP32[$$pre$phiZ2D>>2]|0;
         $121 = ($120|0)==(104);
         $122 = ((($$4259)) + 8|0);
         $spec$select328 = $121 ? $122 : $$pre$phiZ2D;
         $spec$select329 = $121 ? -2 : -1;
         $$0249 = $spec$select329;$$5260 = $spec$select328;
         break;
        }
        case 108:  {
         $123 = HEAP32[$$pre$phiZ2D>>2]|0;
         $124 = ($123|0)==(108);
         $125 = ((($$4259)) + 8|0);
         $spec$select330 = $124 ? $125 : $$pre$phiZ2D;
         $spec$select331 = $124 ? 3 : 1;
         $$0249 = $spec$select331;$$5260 = $spec$select330;
         break;
        }
        case 106:  {
         $$0249 = 3;$$5260 = $$pre$phiZ2D;
         break;
        }
        case 116: case 122:  {
         $$0249 = 1;$$5260 = $$pre$phiZ2D;
         break;
        }
        case 76:  {
         $$0249 = 2;$$5260 = $$pre$phiZ2D;
         break;
        }
        case 110: case 112: case 67: case 83: case 91: case 99: case 115: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
         $$0249 = 0;$$5260 = $$4259;
         break;
        }
        default: {
         $$10309 = $$1300;$261 = $260;
         label = 105;
         break L6;
        }
        }
        $126 = HEAP32[$$5260>>2]|0;
        $127 = $126 & 47;
        $128 = ($127|0)==(3);
        $129 = $126 | 32;
        $spec$select = $128 ? $129 : $126;
        $spec$select319 = $128 ? 1 : $$0249;
        switch ($spec$select|0) {
        case 110:  {
         $$4277342 = $$0273471;
         break;
        }
        case 91:  {
         label = 52;
         break;
        }
        default: {
         $130 = ($129|0)==(99);
         if ($130) {
          label = 52;
         } else {
          $$2275 = $$0273471;
          while(1) {
           $131 = HEAP32[$12>>2]|0;
           $132 = HEAP32[$13>>2]|0;
           $133 = ($131>>>0)<($132>>>0);
           if ($133) {
            $134 = HEAP8[$131>>0]|0;
            $135 = ($134<<24>>24)>(-1);
            if ($135) {
             $136 = ((($131)) + 1|0);
             HEAP32[$12>>2] = $136;
             $137 = HEAP8[$131>>0]|0;
             $138 = $137&255;
             $140 = $138;
            } else {
             label = 50;
            }
           } else {
            label = 50;
           }
           if ((label|0) == 50) {
            label = 0;
            $139 = (_getwc($0)|0);
            $140 = $139;
           }
           $141 = (_iswspace($140)|0);
           $142 = ($141|0)==(0);
           $143 = (($$2275) + 1)|0;
           if ($142) {
            $$1313 = $140;$$3276 = $$2275;
            label = 56;
            break;
           } else {
            $$2275 = $143;
           }
          }
         }
        }
        }
        do {
         if ((label|0) == 52) {
          label = 0;
          $144 = HEAP32[$12>>2]|0;
          $145 = HEAP32[$13>>2]|0;
          $146 = ($144>>>0)<($145>>>0);
          if ($146) {
           $147 = HEAP8[$144>>0]|0;
           $148 = ($147<<24>>24)>(-1);
           if ($148) {
            $149 = ((($144)) + 1|0);
            HEAP32[$12>>2] = $149;
            $150 = HEAP8[$144>>0]|0;
            $151 = $150&255;
            $$1313338 = $151;$$3276339 = $$0273471;$155 = $145;
            label = 58;
            break;
           }
          }
          $152 = (_getwc($0)|0);
          $$1313 = $152;$$3276 = $$0273471;
          label = 56;
         }
        } while(0);
        if ((label|0) == 56) {
         label = 0;
         $153 = ($$1313|0)<(0);
         if ($153) {
          $$10309 = $$1300;$261 = $260;
          label = 105;
          break L6;
         }
         $$pre = HEAP32[$13>>2]|0;
         $$1313338 = $$1313;$$3276339 = $$3276;$155 = $$pre;
         label = 58;
        }
        L55: do {
         if ((label|0) == 58) {
          label = 0;
          $154 = ($155|0)!=(0|0);
          $156 = ($$1313338>>>0)<(128);
          $or$cond5 = $156 & $154;
          if ($or$cond5) {
           $157 = HEAP32[$12>>2]|0;
           $158 = ((($157)) + -1|0);
           HEAP32[$12>>2] = $158;
          } else {
           (_ungetwc($$1313338,$0)|0);
          }
          switch ($spec$select|0) {
          case 110:  {
           $$4277342 = $$3276339;
           break L55;
           break;
          }
          case 91: case 99: case 115:  {
           $161 = ($spec$select|0)==(99);
           L63: do {
            if ($161) {
             $162 = ($$0245$lcssa|0)>(1);
             $spec$select320 = $162 ? $$0245$lcssa : 1;
             $$0272 = (gb + (172052) | 0);$$1286 = 1;$$2 = $spec$select320;$$9 = $$5260;
            } else {
             $163 = ($spec$select|0)==(115);
             if ($163) {
              HEAP32[$5>>2] = 32;
              HEAP32[$14>>2] = 9;
              HEAP32[$15>>2] = 10;
              HEAP32[$16>>2] = 13;
              HEAP32[$17>>2] = 11;
              HEAP32[$18>>2] = 12;
              HEAP32[$19>>2] = 133;
              HEAP32[$20>>2] = 8192;
              HEAP32[$21>>2] = 8193;
              HEAP32[$22>>2] = 8194;
              HEAP32[$23>>2] = 8195;
              HEAP32[$24>>2] = 8196;
              HEAP32[$25>>2] = 8197;
              HEAP32[$26>>2] = 8198;
              HEAP32[$27>>2] = 8200;
              HEAP32[$28>>2] = 8201;
              HEAP32[$29>>2] = 8202;
              HEAP32[$30>>2] = 8232;
              HEAP32[$31>>2] = 8233;
              HEAP32[$32>>2] = 8287;
              HEAP32[$33>>2] = 12288;
              HEAP32[$34>>2] = 0;
              $$0272 = $5;$$1286 = 1;$$2 = $$0245$lcssa;$$9 = $$5260;
              break;
             }
             $164 = ((($$5260)) + 4|0);
             $165 = HEAP32[$164>>2]|0;
             $166 = ($165|0)==(94);
             $167 = ((($$5260)) + 8|0);
             $$0285 = $166&1;
             $$6 = $166 ? $167 : $164;
             $168 = HEAP32[$$6>>2]|0;
             $169 = ($168|0)==(93);
             $170 = ((($$6)) + 4|0);
             $spec$select321 = $169 ? $170 : $$6;
             $$8 = $spec$select321;
             while(1) {
              $171 = HEAP32[$$8>>2]|0;
              switch ($171|0) {
              case 0:  {
               $$10309 = $$1300;$261 = $260;
               label = 105;
               break L6;
               break;
              }
              case 93:  {
               $$0272 = $$6;$$1286 = $$0285;$$2 = $$0245$lcssa;$$9 = $$8;
               break L63;
               break;
              }
              default: {
              }
              }
              $172 = ((($$8)) + 4|0);
              $$8 = $172;
             }
            }
           } while(0);
           $173 = ($spec$select319|0)==(0);
           $174 = $173 ? $$0287 : 0;
           $175 = ($spec$select319|0)==(1);
           $176 = $175 ? $$0287 : 0;
           $177 = ($$2|0)<(1);
           $spec$select322 = $177 ? -1 : $$2;
           $178 = ($$0252|0)!=(0);
           do {
            if ($178) {
             $179 = (($spec$select322) + 1)|0;
             $180 = $161 ? $179 : 31;
             if ($175) {
              $181 = $180 << 2;
              $182 = (_malloc($181)|0);
              $183 = ($182|0)==(0|0);
              if ($183) {
               $$10309 = $174;$261 = 0;
               label = 105;
               break L6;
              } else {
               $$1262 = $180;$$2290 = $182;$$2301 = $174;$262 = $182;
               break;
              }
             } else {
              $184 = (_malloc($180)|0);
              $185 = ($184|0)==(0|0);
              if ($185) {
               $$10309 = 0;$261 = 0;
               label = 105;
               break L6;
              } else {
               $$1262 = $180;$$2290 = $176;$$2301 = $184;$262 = 0;
               break;
              }
             }
            } else {
             $$1262 = $$0261472;$$2290 = $176;$$2301 = $174;$262 = $176;
            }
           } while(0);
           $186 = ($spec$select322|0)==(0);
           L79: do {
            if ($186) {
             $$0269381 = 0;$$2263375 = $$1262;$$3291393 = $$2290;$$3302409 = $$2301;$$5278387 = $$3276339;$232 = $262;$263 = $262;
            } else {
             $$0251451 = 0;$$0269449 = 0;$$2263450 = $$1262;$$3291447 = $$2290;$$3302446 = $$2301;$$4452 = $spec$select322;$$5278448 = $$3276339;$206 = $262;$264 = $262;
             while(1) {
              $187 = HEAP32[$12>>2]|0;
              $188 = HEAP32[$13>>2]|0;
              $189 = ($187>>>0)<($188>>>0);
              do {
               if ($189) {
                $190 = HEAP8[$187>>0]|0;
                $191 = ($190<<24>>24)>(-1);
                if (!($191)) {
                 label = 79;
                 break;
                }
                $192 = ((($187)) + 1|0);
                HEAP32[$12>>2] = $192;
                $193 = HEAP8[$187>>0]|0;
                $194 = $193&255;
                $197 = $194;
               } else {
                label = 79;
               }
              } while(0);
              if ((label|0) == 79) {
               label = 0;
               $195 = (_getwc($0)|0);
               $196 = ($195|0)<(0);
               if ($196) {
                $$4316$ph351 = $195;
                label = 91;
                break;
               } else {
                $197 = $195;
               }
              }
              $198 = (_in_set($$0272,$197)|0);
              $199 = ($198|0)==($$1286|0);
              if ($199) {
               label = 89;
               break;
              }
              $200 = ($$3291447|0)==(0|0);
              do {
               if ($200) {
                if ($175) {
                 $$2271 = $$0269449;$$5266 = $$2263450;$$5293 = 0;$$7306 = $$3302446;$265 = $264;$266 = $206;
                 break;
                }
                $209 = ($$3302446|0)==(0|0);
                $210 = (($$3302446) + ($$0269449)|0);
                $211 = $209 ? $4 : $210;
                $212 = (_wctomb($211,$197)|0);
                $213 = ($212|0)<(0);
                if ($213) {
                 $$10309 = $$3302446;$261 = $264;
                 label = 105;
                 break L6;
                }
                $214 = (($212) + ($$0269449))|0;
                $215 = (($$2263450) + -4)|0;
                $216 = ($214>>>0)>($215>>>0);
                $or$cond325 = $178 & $216;
                if (!($or$cond325)) {
                 $$2271 = $214;$$5266 = $$2263450;$$5293 = 0;$$7306 = $$3302446;$265 = $264;$266 = $206;
                 break;
                }
                $factor354 = $$2263450 << 1;
                $217 = $factor354 | 1;
                $218 = (_realloc($$3302446,$217)|0);
                $219 = ($218|0)==(0|0);
                if ($219) {
                 $$10309 = $$3302446;$261 = $264;
                 label = 105;
                 break L6;
                } else {
                 $$2271 = $214;$$5266 = $217;$$5293 = 0;$$7306 = $218;$265 = $264;$266 = $206;
                }
               } else {
                $201 = (($$0269449) + 1)|0;
                $202 = (($$3291447) + ($$0269449<<2)|0);
                HEAP32[$202>>2] = $197;
                $203 = ($201|0)==($$2263450|0);
                $or$cond323 = $178 & $203;
                if (!($or$cond323)) {
                 $$2271 = $201;$$5266 = $$2263450;$$5293 = $$3291447;$$7306 = $$3302446;$265 = $264;$266 = $206;
                 break;
                }
                $factor = $$2263450 << 1;
                $204 = $factor | 1;
                $205 = $204 << 2;
                $207 = (_realloc($206,$205)|0);
                $208 = ($207|0)==(0|0);
                if ($208) {
                 $$10309 = $$3302446;$261 = $264;
                 label = 105;
                 break L6;
                } else {
                 $$2271 = $$2263450;$$5266 = $204;$$5293 = $207;$$7306 = $$3302446;$265 = $207;$266 = $207;
                }
               }
              } while(0);
              $220 = (($$5278448) + 1)|0;
              $221 = ($$4452|0)>(0);
              $222 = $221&1;
              $223 = (($$4452) - ($222))|0;
              $224 = ($223|0)==(0);
              if ($224) {
               $$0269381 = $$2271;$$2263375 = $$5266;$$3291393 = $$5293;$$3302409 = $$7306;$$5278387 = $220;$232 = $266;$263 = $265;
               break L79;
              } else {
               $$0251451 = 1;$$0269449 = $$2271;$$2263450 = $$5266;$$3291447 = $$5293;$$3302446 = $$7306;$$4452 = $223;$$5278448 = $220;$206 = $266;$264 = $265;
              }
             }
             if ((label|0) == 89) {
              label = 0;
              $225 = HEAP32[$13>>2]|0;
              $226 = ($225|0)!=(0|0);
              $227 = ($197>>>0)<(128);
              $or$cond7 = $227 & $226;
              if ($or$cond7) {
               $228 = HEAP32[$12>>2]|0;
               $229 = ((($228)) + -1|0);
               HEAP32[$12>>2] = $229;
              } else {
               $$4316$ph351 = $197;
               label = 91;
              }
             }
             if ((label|0) == 91) {
              label = 0;
              (_ungetwc($$4316$ph351,$0)|0);
             }
             $230 = ($spec$select|0)!=(99);
             $231 = ($$0251451|0)!=(0);
             $or$cond9 = $230 & $231;
             if ($or$cond9) {
              $$0269381 = $$0269449;$$2263375 = $$2263450;$$3291393 = $$3291447;$$3302409 = $$3302446;$$5278387 = $$5278448;$232 = $206;$263 = $264;
             } else {
              $$12 = $$3302446;$$2254 = $$0252;$$2283 = $$0281464;$254 = $264;
              break L6;
             }
            }
           } while(0);
           if ($178) {
            $$$3302409 = $175 ? $232 : $$3302409;
            HEAP32[$$0287>>2] = $$$3302409;
           }
           if ($161) {
            $$10 = $$9;$$6267 = $$2263375;$$6279 = $$5278387;$$8307 = $$3302409;$267 = $263;
           } else {
            $233 = ($$3291393|0)==(0|0);
            if (!($233)) {
             $234 = (($$3291393) + ($$0269381<<2)|0);
             HEAP32[$234>>2] = 0;
            }
            $235 = ($$3302409|0)==(0|0);
            if ($235) {
             $$10 = $$9;$$6267 = $$2263375;$$6279 = $$5278387;$$8307 = 0;$267 = $263;
            } else {
             $236 = (($$3302409) + ($$0269381)|0);
             HEAP8[$236>>0] = 0;
             $$10 = $$9;$$6267 = $$2263375;$$6279 = $$5278387;$$8307 = $$3302409;$267 = $263;
            }
           }
           break;
          }
          case 112: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
           $237 = ($$0245$lcssa|0)>(0);
           $spec$select326 = $237 ? $$0245$lcssa : 0;
           $238 = ($$0287|0)!=(0|0);
           $239 = $238 ? 1 : 2;
           $240 = (($spec$select319) + 2)|0;
           $241 = ((gb + (153216) | 0) + (($240*3)|0)|0);
           HEAP32[$vararg_buffer>>2] = $239;
           $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
           HEAP32[$vararg_ptr1>>2] = (gb + (167344) | 0);
           $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
           HEAP32[$vararg_ptr2>>2] = $spec$select326;
           $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
           HEAP32[$vararg_ptr3>>2] = $241;
           $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
           HEAP32[$vararg_ptr4>>2] = $spec$select;
           (_snprintf($4,22,(gb + (167326) | 0),$vararg_buffer)|0);
           HEAP32[$3>>2] = 0;
           $242 = $238 ? $$0287 : $3;
           HEAP32[$vararg_buffer5>>2] = $242;
           $vararg_ptr8 = ((($vararg_buffer5)) + 4|0);
           HEAP32[$vararg_ptr8>>2] = $3;
           $243 = (_fscanf($0,$4,$vararg_buffer5)|0);
           $244 = ($243|0)==(-1);
           if ($244) {
            $$10309 = $$1300;$261 = $260;
            label = 105;
            break L6;
           }
           $245 = HEAP32[$3>>2]|0;
           $246 = ($245|0)==(0);
           if ($246) {
            $$12 = $$1300;$$2254 = $$0252;$$2283 = $$0281464;$254 = $260;
            break L6;
           }
           $247 = (($245) + ($$3276339))|0;
           $$10 = $$5260;$$6267 = $$0261472;$$6279 = $247;$$8307 = $$1300;$267 = $260;
           break;
          }
          default: {
           $$10309 = $$1300;$261 = $260;
           label = 105;
           break L6;
          }
          }
          $248 = ($$0287|0)!=(0|0);
          $249 = $248&1;
          $spec$select327 = (($$0281464) + ($249))|0;
          $$11 = $$10;$$1282 = $spec$select327;$$7268 = $$6267;$$7280 = $$6279;$$9308 = $$8307;$258 = $267;
          break L8;
         }
        } while(0);
        $159 = ($$4277342|0)<(0);
        $160 = $159 << 31 >> 31;
        _store_int($$0287,$spec$select319,$$4277342,$160);
        $$11 = $$5260;$$1282 = $$0281464;$$7268 = $$0261472;$$7280 = $$4277342;$$9308 = $$1300;$258 = $260;
        break L8;
       }
      } while(0);
      $64 = $61&1;
      $65 = (($$0255473) + ($64<<2)|0);
      $66 = HEAP32[$12>>2]|0;
      $67 = HEAP32[$13>>2]|0;
      $68 = ($66>>>0)<($67>>>0);
      if ($68) {
       $69 = HEAP8[$66>>0]|0;
       $70 = ($69<<24>>24)>(-1);
       if ($70) {
        $71 = ((($66)) + 1|0);
        HEAP32[$12>>2] = $71;
        $72 = HEAP8[$66>>0]|0;
        $73 = $72&255;
        $77 = $73;
       } else {
        label = 22;
       }
      } else {
       label = 22;
      }
      if ((label|0) == 22) {
       label = 0;
       $74 = (_getwc($0)|0);
       $77 = $74;
      }
      $75 = HEAP32[$65>>2]|0;
      $76 = ($77|0)==($75|0);
      if (!($76)) {
       label = 24;
       break L6;
      }
      $85 = (($$0273471) + 1)|0;
      $$11 = $65;$$1282 = $$0281464;$$7268 = $$0261472;$$7280 = $85;$$9308 = $$0299462;$258 = $257;
     } else {
      $$1256 = $$0255473;
      while(1) {
       $38 = ((($$1256)) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = (_iswspace($39)|0);
       $41 = ($40|0)==(0);
       if ($41) {
        break;
       } else {
        $$1256 = $38;
       }
      }
      $$1274 = $$0273471;
      while(1) {
       $42 = HEAP32[$12>>2]|0;
       $43 = HEAP32[$13>>2]|0;
       $44 = ($42>>>0)<($43>>>0);
       if ($44) {
        $45 = HEAP8[$42>>0]|0;
        $46 = ($45<<24>>24)>(-1);
        if ($46) {
         $47 = ((($42)) + 1|0);
         HEAP32[$12>>2] = $47;
         $48 = HEAP8[$42>>0]|0;
         $49 = $48&255;
         $51 = $49;
        } else {
         label = 12;
        }
       } else {
        label = 12;
       }
       if ((label|0) == 12) {
        label = 0;
        $50 = (_getwc($0)|0);
        $51 = $50;
       }
       $52 = (_iswspace($51)|0);
       $53 = ($52|0)==(0);
       $54 = (($$1274) + 1)|0;
       if ($53) {
        break;
       } else {
        $$1274 = $54;
       }
      }
      $55 = HEAP32[$13>>2]|0;
      $56 = ($55|0)!=(0|0);
      $57 = ($51>>>0)<(128);
      $or$cond = $57 & $56;
      if ($or$cond) {
       $58 = HEAP32[$12>>2]|0;
       $59 = ((($58)) + -1|0);
       HEAP32[$12>>2] = $59;
       $$11 = $$1256;$$1282 = $$0281464;$$7268 = $$0261472;$$7280 = $$1274;$$9308 = $$0299462;$258 = $257;
       break;
      } else {
       (_ungetwc($51,$0)|0);
       $$11 = $$1256;$$1282 = $$0281464;$$7268 = $$0261472;$$7280 = $$1274;$$9308 = $$0299462;$258 = $257;
       break;
      }
     }
    } while(0);
    $250 = ((($$11)) + 4|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = ($251|0)==(0);
    if ($252) {
     $$3284 = $$1282;
     break L4;
    } else {
     $$0255473 = $250;$$0261472 = $$7268;$$0273471 = $$7280;$$0281464 = $$1282;$$0299462 = $$9308;$257 = $258;$35 = $251;
    }
   }
   do {
    if ((label|0) == 24) {
     $78 = HEAP32[$13>>2]|0;
     $79 = ($78|0)!=(0|0);
     $80 = ($77>>>0)<(128);
     $or$cond3 = $80 & $79;
     if ($or$cond3) {
      $81 = HEAP32[$12>>2]|0;
      $82 = ((($81)) + -1|0);
      HEAP32[$12>>2] = $82;
      $$3284 = $$0281464;
      break L4;
     } else {
      (_ungetwc($77,$0)|0);
      $83 = ($77|0)>(-1);
      $84 = ($$0281464|0)!=(0);
      $or$cond11 = $84 | $83;
      if ($or$cond11) {
       $$3284 = $$0281464;
       break L4;
      } else {
       $$11310 = $$0299462;$$1253 = 0;$259 = $257;
       label = 106;
       break;
      }
     }
    }
    else if ((label|0) == 105) {
     $$old10 = ($$0281464|0)==(0);
     if ($$old10) {
      $$11310 = $$10309;$$1253 = $$0252;$259 = $261;
      label = 106;
     } else {
      $$12 = $$10309;$$2254 = $$0252;$$2283 = $$0281464;$254 = $261;
     }
    }
   } while(0);
   if ((label|0) == 106) {
    $$12 = $$11310;$$2254 = $$1253;$$2283 = -1;$254 = $259;
   }
   $253 = ($$2254|0)==(0);
   if ($253) {
    $$3284 = $$2283;
   } else {
    _free($$12);
    _free($254);
    $$3284 = $$2283;
   }
  }
 } while(0);
 $255 = ($256|0)==(0);
 if (!($255)) {
  ___unlockfile($0);
 }
 STACKTOP = sp;return ($$3284|0);
}
function _getwc($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_fgetwc($0)|0);
 return ($1|0);
}
function _ungetwc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (___pthread_self_443()|0);
 $4 = ((($3)) + 188|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1)) + 76|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $9 = (___lockfile($1)|0);
  $30 = $9;
 } else {
  $30 = 0;
 }
 $10 = ((($1)) + 74|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)<(1);
 if ($12) {
  (_fwide($1,1)|0);
 }
 $13 = ((($1)) + 120|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$4>>2] = $14;
 $15 = ((($1)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  (___toread($1)|0);
  $$pre = HEAP32[$15>>2]|0;
  $19 = $$pre;
 } else {
  $19 = $16;
 }
 $18 = ($19|0)==(0|0);
 $20 = ($0|0)==(-1);
 $or$cond = $20 | $18;
 if ($or$cond) {
  label = 10;
 } else {
  $21 = (_wcrtomb($2,$0,0)|0);
  $22 = ($21|0)<(0);
  if ($22) {
   label = 10;
  } else {
   $23 = HEAP32[$15>>2]|0;
   $24 = ((($1)) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25)) + -8|0);
   $27 = (($26) + ($21)|0);
   $28 = ($23>>>0)<($27>>>0);
   if ($28) {
    label = 10;
   } else {
    $31 = ($0>>>0)<(128);
    if ($31) {
     $32 = $0&255;
     $33 = ((($23)) + -1|0);
     HEAP32[$15>>2] = $33;
     HEAP8[$33>>0] = $32;
    } else {
     $34 = (0 - ($21))|0;
     $35 = (($23) + ($34)|0);
     HEAP32[$15>>2] = $35;
     (_memcpy(($35|0),($2|0),($21|0))|0);
    }
    $36 = HEAP32[$1>>2]|0;
    $37 = $36 & -17;
    HEAP32[$1>>2] = $37;
    $38 = ($30|0)==(0);
    if ($38) {
     $$0 = $0;
    } else {
     ___unlockfile($1);
     $$0 = $0;
    }
   }
  }
 }
 if ((label|0) == 10) {
  $29 = ($30|0)==(0);
  if ($29) {
   $$0 = -1;
  } else {
   ___unlockfile($1);
   $$0 = -1;
  }
 }
 HEAP32[$4>>2] = $5;
 STACKTOP = sp;return ($$0|0);
}
function _arg_n($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded1 = 0, $expanded3 = 0, $expanded4 = 0, $expanded5 = 0, $vacopy_currentptr = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $vacopy_currentptr = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $vacopy_currentptr;
 $$0 = $1;
 while(1) {
  $3 = ($$0>>>0)>(1);
  $arglist_current = HEAP32[$2>>2]|0;
  $4 = $arglist_current;
  $5 = ((0) + 4|0);
  $expanded1 = $5;
  $expanded = (($expanded1) - 1)|0;
  $6 = (($4) + ($expanded))|0;
  $7 = ((0) + 4|0);
  $expanded5 = $7;
  $expanded4 = (($expanded5) - 1)|0;
  $expanded3 = $expanded4 ^ -1;
  $8 = $6 & $expanded3;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $arglist_next = ((($9)) + 4|0);
  HEAP32[$2>>2] = $arglist_next;
  $11 = (($$0) + -1)|0;
  if ($3) {
   $$0 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($10|0);
}
function _store_int($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0|0);
 L1: do {
  if (!($4)) {
   switch ($1|0) {
   case -2:  {
    $5 = $2&255;
    HEAP8[$0>>0] = $5;
    break L1;
    break;
   }
   case -1:  {
    $6 = $2&65535;
    HEAP16[$0>>1] = $6;
    break L1;
    break;
   }
   case 0:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 1:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 3:  {
    $7 = $0;
    $8 = $7;
    HEAP32[$8>>2] = $2;
    $9 = (($7) + 4)|0;
    $10 = $9;
    HEAP32[$10>>2] = $3;
    break L1;
    break;
   }
   default: {
    break L1;
   }
   }
  }
 } while(0);
 return;
}
function _in_set($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$02427 = 0, $$025 = 0, $$1 = 0, $$1$ph = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 switch ($2|0) {
 case 45:  {
  $3 = ($1|0)==(45);
  if ($3) {
   $$025 = 1;
  } else {
   $4 = ((($0)) + 4|0);
   $$1$ph = $4;
   label = 6;
  }
  break;
 }
 case 93:  {
  $5 = ($1|0)==(93);
  if ($5) {
   $$025 = 1;
  } else {
   $6 = ((($0)) + 4|0);
   $$1$ph = $6;
   label = 6;
  }
  break;
 }
 default: {
  $$1$ph = $0;
  label = 6;
 }
 }
 L6: do {
  if ((label|0) == 6) {
   $$1 = $$1$ph;
   while(1) {
    $7 = HEAP32[$$1>>2]|0;
    L10: do {
     switch ($7|0) {
     case 93: case 0:  {
      $$025 = 0;
      break L6;
      break;
     }
     case 45:  {
      $8 = ((($$1)) + 4|0);
      $9 = HEAP32[$8>>2]|0;
      switch ($9|0) {
      case 93: case 0:  {
       $$2 = $$1;
       break L10;
       break;
      }
      default: {
      }
      }
      $10 = ((($$1)) + -4|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)<($9|0);
      if ($12) {
       $$02427 = $11;
       while(1) {
        $15 = ($$02427|0)==($1|0);
        $14 = (($$02427) + 1)|0;
        if ($15) {
         $$025 = 1;
         break L6;
        }
        $13 = ($14|0)<($9|0);
        if ($13) {
         $$02427 = $14;
        } else {
         $$2 = $8;
         break;
        }
       }
      } else {
       $$2 = $8;
      }
      break;
     }
     default: {
      $$2 = $$1;
     }
     }
    } while(0);
    $16 = HEAP32[$$2>>2]|0;
    $17 = ($16|0)==($1|0);
    $18 = ((($$2)) + 4|0);
    if ($17) {
     $$025 = 1;
     break L6;
    } else {
     $$1 = $18;
    }
   }
  }
 } while(0);
 return ($$025|0);
}
function _fscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vfscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _vfscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0266$lcssa = 0, $$0266409 = 0, $$0268 = 0, $$0270 = 0, $$0272 = 0, $$0273420 = 0, $$0276$ph$ph = 0, $$0280$ph = 0, $$0280$ph$ph = 0, $$0285419 = 0, $$0288411 = 0, $$0290416 = 0, $$0294 = 0, $$0295 = 0, $$0308414 = 0, $$10 = 0, $$10318 = 0, $$11 = 0, $$12 = 0, $$1267 = 0;
 var $$1271 = 0, $$1274 = 0, $$1281 = 0, $$1286 = 0, $$1291 = 0, $$1309 = 0, $$2 = 0, $$2275 = 0, $$2278$ph = 0, $$2282 = 0, $$2282$ph = 0, $$2287 = 0, $$2292 = 0, $$2310$ph = 0, $$3$lcssa = 0, $$3283 = 0, $$3293 = 0, $$3408 = 0, $$4 = 0, $$4284 = 0;
 var $$5 = 0, $$5313 = 0, $$6 = 0, $$6302 = 0, $$6314 = 0, $$7 = 0, $$7315 = 0, $$8 = 0, $$8316 = 0, $$9 = 0, $$9317 = 0, $$not = 0, $$old4 = 0, $$ph$ph = 0, $$pr = 0, $$pr332 = 0, $$pre = 0, $$pre$phi493Z2D = 0, $$pre$phiZ2D = 0, $$pre485 = 0;
 var $$pre487 = 0, $$pre488 = 0, $$pre490 = 0, $$pre492 = 0, $$sroa$2$0$$sroa_idx13 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0.0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0.0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded1 = 0, $expanded3 = 0, $expanded4 = 0, $expanded5 = 0, $factor = 0, $factor335 = 0;
 var $or$cond = 0, $or$cond3 = 0, $or$cond321 = 0, $or$cond5 = 0, $spec$select = 0, $spec$select319 = 0, $spec$select320 = 0, $spec$select322 = 0, $spec$select323 = 0, $spec$select324 = 0, $spec$select325 = 0, $spec$select326 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $3 = sp + 264|0;
 $4 = sp;
 $5 = sp + 260|0;
 $6 = sp + 272|0;
 $7 = ((($0)) + 76|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(-1);
 if ($9) {
  $10 = (___lockfile($0)|0);
  $320 = $10;
 } else {
  $320 = 0;
 }
 $11 = HEAP8[$1>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L4: do {
  if ($12) {
   $$3293 = 0;
  } else {
   $13 = ((($0)) + 4|0);
   $14 = ((($0)) + 100|0);
   $15 = ((($0)) + 108|0);
   $16 = ((($0)) + 8|0);
   $17 = ((($4)) + 10|0);
   $18 = ((($4)) + 33|0);
   $19 = ((($4)) + 46|0);
   $20 = ((($4)) + 94|0);
   $$sroa$2$0$$sroa_idx13 = ((($3)) + 4|0);
   $$0273420 = $1;$$0285419 = 0;$$0290416 = 0;$$0308414 = 0;$22 = $11;$321 = 0;
   L6: while(1) {
    $21 = $22&255;
    $23 = (_isspace($21)|0);
    $24 = ($23|0)==(0);
    L8: do {
     if ($24) {
      $51 = HEAP8[$$0273420>>0]|0;
      $52 = ($51<<24>>24)==(37);
      L10: do {
       if ($52) {
        $53 = ((($$0273420)) + 1|0);
        $54 = HEAP8[$53>>0]|0;
        L12: do {
         switch ($54<<24>>24) {
         case 37:  {
          break L10;
          break;
         }
         case 42:  {
          $75 = ((($$0273420)) + 2|0);
          $$0295 = 0;$$2275 = $75;
          break;
         }
         default: {
          $76 = $54&255;
          $77 = (_isdigit($76)|0);
          $78 = ($77|0)==(0);
          if (!($78)) {
           $79 = ((($$0273420)) + 2|0);
           $80 = HEAP8[$79>>0]|0;
           $81 = ($80<<24>>24)==(36);
           if ($81) {
            $82 = HEAP8[$53>>0]|0;
            $83 = $82&255;
            $84 = (($83) + -48)|0;
            $85 = (_arg_n_464($2,$84)|0);
            $86 = ((($$0273420)) + 3|0);
            $$0295 = $85;$$2275 = $86;
            break L12;
           }
          }
          $arglist_current = HEAP32[$2>>2]|0;
          $87 = $arglist_current;
          $88 = ((0) + 4|0);
          $expanded1 = $88;
          $expanded = (($expanded1) - 1)|0;
          $89 = (($87) + ($expanded))|0;
          $90 = ((0) + 4|0);
          $expanded5 = $90;
          $expanded4 = (($expanded5) - 1)|0;
          $expanded3 = $expanded4 ^ -1;
          $91 = $89 & $expanded3;
          $92 = $91;
          $93 = HEAP32[$92>>2]|0;
          $arglist_next = ((($92)) + 4|0);
          HEAP32[$2>>2] = $arglist_next;
          $$0295 = $93;$$2275 = $53;
         }
         }
        } while(0);
        $94 = HEAP8[$$2275>>0]|0;
        $95 = $94&255;
        $96 = (_isdigit($95)|0);
        $97 = ($96|0)==(0);
        if ($97) {
         $$0266$lcssa = 0;$$3$lcssa = $$2275;
        } else {
         $$0266409 = 0;$$3408 = $$2275;
         while(1) {
          $98 = ($$0266409*10)|0;
          $99 = HEAP8[$$3408>>0]|0;
          $100 = $99&255;
          $101 = (($98) + -48)|0;
          $102 = (($101) + ($100))|0;
          $103 = ((($$3408)) + 1|0);
          $104 = HEAP8[$103>>0]|0;
          $105 = $104&255;
          $106 = (_isdigit($105)|0);
          $107 = ($106|0)==(0);
          if ($107) {
           $$0266$lcssa = $102;$$3$lcssa = $103;
           break;
          } else {
           $$0266409 = $102;$$3408 = $103;
          }
         }
        }
        $108 = HEAP8[$$3$lcssa>>0]|0;
        $109 = ($108<<24>>24)==(109);
        $110 = ((($$3$lcssa)) + 1|0);
        if ($109) {
         $111 = ($$0295|0)!=(0|0);
         $112 = $111&1;
         $$pr = HEAP8[$110>>0]|0;
         $$pre488 = ((($$3$lcssa)) + 2|0);
         $$0270 = $112;$$1309 = 0;$$4 = $110;$$pre$phiZ2D = $$pre488;$113 = $$pr;$324 = 0;
        } else {
         $$0270 = 0;$$1309 = $$0308414;$$4 = $$3$lcssa;$$pre$phiZ2D = $110;$113 = $108;$324 = $321;
        }
        switch ($113<<24>>24) {
        case 104:  {
         $114 = HEAP8[$$pre$phiZ2D>>0]|0;
         $115 = ($114<<24>>24)==(104);
         $116 = ((($$4)) + 2|0);
         $spec$select323 = $115 ? $116 : $$pre$phiZ2D;
         $spec$select324 = $115 ? -2 : -1;
         $$0268 = $spec$select324;$$5 = $spec$select323;
         break;
        }
        case 108:  {
         $117 = HEAP8[$$pre$phiZ2D>>0]|0;
         $118 = ($117<<24>>24)==(108);
         $119 = ((($$4)) + 2|0);
         $spec$select325 = $118 ? $119 : $$pre$phiZ2D;
         $spec$select326 = $118 ? 3 : 1;
         $$0268 = $spec$select326;$$5 = $spec$select325;
         break;
        }
        case 106:  {
         $$0268 = 3;$$5 = $$pre$phiZ2D;
         break;
        }
        case 116: case 122:  {
         $$0268 = 1;$$5 = $$pre$phiZ2D;
         break;
        }
        case 76:  {
         $$0268 = 2;$$5 = $$pre$phiZ2D;
         break;
        }
        case 110: case 112: case 67: case 83: case 91: case 99: case 115: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
         $$0268 = 0;$$5 = $$4;
         break;
        }
        default: {
         $$8316 = $$1309;$325 = $324;
         label = 143;
         break L6;
        }
        }
        $120 = HEAP8[$$5>>0]|0;
        $121 = $120&255;
        $122 = $121 & 47;
        $123 = ($122|0)==(3);
        $124 = $121 | 32;
        $spec$select = $123 ? $124 : $121;
        $spec$select319 = $123 ? 1 : $$0268;
        $trunc = $spec$select&255;
        switch ($trunc<<24>>24) {
        case 99:  {
         $125 = ($$0266$lcssa|0)>(1);
         $spec$select320 = $125 ? $$0266$lcssa : 1;
         $$1267 = $spec$select320;$$1286 = $$0285419;
         break;
        }
        case 91:  {
         $$1267 = $$0266$lcssa;$$1286 = $$0285419;
         break;
        }
        case 110:  {
         $126 = ($$0285419|0)<(0);
         $127 = $126 << 31 >> 31;
         _store_int_465($$0295,$spec$select319,$$0285419,$127);
         $$12 = $$5;$$1291 = $$0290416;$$2287 = $$0285419;$$7315 = $$1309;$322 = $324;
         break L8;
         break;
        }
        default: {
         ___shlim($0,0);
         while(1) {
          $128 = HEAP32[$13>>2]|0;
          $129 = HEAP32[$14>>2]|0;
          $130 = ($128>>>0)<($129>>>0);
          if ($130) {
           $131 = ((($128)) + 1|0);
           HEAP32[$13>>2] = $131;
           $132 = HEAP8[$128>>0]|0;
           $133 = $132&255;
           $135 = $133;
          } else {
           $134 = (___shgetc($0)|0);
           $135 = $134;
          }
          $136 = (_isspace($135)|0);
          $137 = ($136|0)==(0);
          if ($137) {
           break;
          }
         }
         $138 = HEAP32[$14>>2]|0;
         $139 = ($138|0)==(0|0);
         if ($139) {
          $$pre485 = HEAP32[$13>>2]|0;
          $147 = $$pre485;
         } else {
          $140 = HEAP32[$13>>2]|0;
          $141 = ((($140)) + -1|0);
          HEAP32[$13>>2] = $141;
          $142 = $141;
          $147 = $142;
         }
         $143 = HEAP32[$15>>2]|0;
         $144 = HEAP32[$16>>2]|0;
         $145 = (($143) + ($$0285419))|0;
         $146 = (($145) + ($147))|0;
         $148 = (($146) - ($144))|0;
         $$1267 = $$0266$lcssa;$$1286 = $148;
        }
        }
        ___shlim($0,$$1267);
        $149 = HEAP32[$13>>2]|0;
        $150 = HEAP32[$14>>2]|0;
        $151 = ($149>>>0)<($150>>>0);
        if ($151) {
         $152 = ((($149)) + 1|0);
         HEAP32[$13>>2] = $152;
         $156 = $150;
        } else {
         $153 = (___shgetc($0)|0);
         $154 = ($153|0)<(0);
         if ($154) {
          $$8316 = $$1309;$325 = $324;
          label = 143;
          break L6;
         }
         $$pr332 = HEAP32[$14>>2]|0;
         $156 = $$pr332;
        }
        $155 = ($156|0)==(0|0);
        if (!($155)) {
         $157 = HEAP32[$13>>2]|0;
         $158 = ((($157)) + -1|0);
         HEAP32[$13>>2] = $158;
        }
        L59: do {
         switch ($trunc<<24>>24) {
         case 91: case 99: case 115:  {
          $159 = ($spec$select|0)==(99);
          $160 = $spec$select | 16;
          $161 = ($160|0)==(115);
          L61: do {
           if ($161) {
            $162 = ($spec$select|0)==(115);
            (_memset(($4|0),-1,257)|0);
            HEAP8[$4>>0] = 0;
            if ($162) {
             HEAP8[$18>>0] = 0;
             ;HEAP16[$17>>1]=0|0;HEAP16[$17+2>>1]=0|0;HEAP8[$17+4>>0]=0|0;
             $$10 = $$5;
            } else {
             $$10 = $$5;
            }
           } else {
            $163 = ((($$5)) + 1|0);
            $164 = HEAP8[$163>>0]|0;
            $165 = ($164<<24>>24)==(94);
            $166 = ((($$5)) + 2|0);
            $$0294 = $165&1;
            $$6 = $165 ? $166 : $163;
            (_memset(($4|0),($$0294|0),257)|0);
            HEAP8[$4>>0] = 0;
            $167 = HEAP8[$$6>>0]|0;
            switch ($167<<24>>24) {
            case 45:  {
             $168 = ((($$6)) + 1|0);
             $169 = $$0294 ^ 1;
             $170 = $169&255;
             HEAP8[$19>>0] = $170;
             $$7 = $168;$$pre$phi493Z2D = $170;
             break;
            }
            case 93:  {
             $171 = ((($$6)) + 1|0);
             $172 = $$0294 ^ 1;
             $173 = $172&255;
             HEAP8[$20>>0] = $173;
             $$7 = $171;$$pre$phi493Z2D = $173;
             break;
            }
            default: {
             $$pre490 = $$0294 ^ 1;
             $$pre492 = $$pre490&255;
             $$7 = $$6;$$pre$phi493Z2D = $$pre492;
            }
            }
            $$8 = $$7;
            while(1) {
             $174 = HEAP8[$$8>>0]|0;
             L72: do {
              switch ($174<<24>>24) {
              case 0:  {
               $$8316 = $$1309;$325 = $324;
               label = 143;
               break L6;
               break;
              }
              case 93:  {
               $$10 = $$8;
               break L61;
               break;
              }
              case 45:  {
               $175 = ((($$8)) + 1|0);
               $176 = HEAP8[$175>>0]|0;
               switch ($176<<24>>24) {
               case 93: case 0:  {
                $$9 = $$8;$187 = 45;
                break L72;
                break;
               }
               default: {
               }
               }
               $177 = ((($$8)) + -1|0);
               $178 = HEAP8[$177>>0]|0;
               $179 = ($178&255)<($176&255);
               if ($179) {
                $180 = $178&255;
                $$0288411 = $180;
                while(1) {
                 $181 = (($$0288411) + 1)|0;
                 $182 = (($4) + ($181)|0);
                 HEAP8[$182>>0] = $$pre$phi493Z2D;
                 $183 = HEAP8[$175>>0]|0;
                 $184 = $183&255;
                 $185 = ($181>>>0)<($184>>>0);
                 if ($185) {
                  $$0288411 = $181;
                 } else {
                  $$9 = $175;$187 = $183;
                  break;
                 }
                }
               } else {
                $$9 = $175;$187 = $176;
               }
               break;
              }
              default: {
               $$9 = $$8;$187 = $174;
              }
              }
             } while(0);
             $186 = $187&255;
             $188 = (($186) + 1)|0;
             $189 = (($4) + ($188)|0);
             HEAP8[$189>>0] = $$pre$phi493Z2D;
             $190 = ((($$9)) + 1|0);
             $$8 = $190;
            }
           }
          } while(0);
          $191 = (($$1267) + 1)|0;
          $192 = $159 ? $191 : 31;
          $193 = ($spec$select319|0)==(1);
          $194 = ($$0270|0)!=(0);
          L80: do {
           if ($193) {
            if ($194) {
             $195 = $192 << 2;
             $196 = (_malloc($195)|0);
             $197 = ($196|0)==(0|0);
             if ($197) {
              $$8316 = 0;$325 = 0;
              label = 143;
              break L6;
             } else {
              $327 = $196;
             }
            } else {
             $327 = $$0295;
            }
            HEAP32[$3>>2] = 0;
            HEAP32[$$sroa$2$0$$sroa_idx13>>2] = 0;
            $$0276$ph$ph = $192;$$0280$ph$ph = 0;$$ph$ph = $327;
            L85: while(1) {
             $198 = ($$ph$ph|0)==(0|0);
             $$0280$ph = $$0280$ph$ph;
             while(1) {
              L89: while(1) {
               $199 = HEAP32[$13>>2]|0;
               $200 = HEAP32[$14>>2]|0;
               $201 = ($199>>>0)<($200>>>0);
               if ($201) {
                $202 = ((($199)) + 1|0);
                HEAP32[$13>>2] = $202;
                $203 = HEAP8[$199>>0]|0;
                $204 = $203&255;
                $207 = $204;
               } else {
                $205 = (___shgetc($0)|0);
                $207 = $205;
               }
               $206 = (($207) + 1)|0;
               $208 = (($4) + ($206)|0);
               $209 = HEAP8[$208>>0]|0;
               $210 = ($209<<24>>24)==(0);
               if ($210) {
                break L85;
               }
               $211 = $207&255;
               HEAP8[$6>>0] = $211;
               $212 = (_mbrtowc($5,$6,1,$3)|0);
               switch ($212|0) {
               case -1:  {
                $$8316 = 0;$325 = $$ph$ph;
                label = 143;
                break L6;
                break;
               }
               case -2:  {
                break;
               }
               default: {
                break L89;
               }
               }
              }
              if ($198) {
               $$1281 = $$0280$ph;
              } else {
               $213 = (($$ph$ph) + ($$0280$ph<<2)|0);
               $214 = (($$0280$ph) + 1)|0;
               $215 = HEAP32[$5>>2]|0;
               HEAP32[$213>>2] = $215;
               $$1281 = $214;
              }
              $216 = ($$1281|0)==($$0276$ph$ph|0);
              $or$cond = $194 & $216;
              if ($or$cond) {
               break;
              } else {
               $$0280$ph = $$1281;
              }
             }
             $factor335 = $$0276$ph$ph << 1;
             $217 = $factor335 | 1;
             $218 = $217 << 2;
             $219 = (_realloc($$ph$ph,$218)|0);
             $220 = ($219|0)==(0|0);
             if ($220) {
              $$8316 = 0;$325 = $$ph$ph;
              label = 143;
              break L6;
             } else {
              $$0276$ph$ph = $217;$$0280$ph$ph = $$1281;$$ph$ph = $219;
             }
            }
            $221 = (_mbsinit($3)|0);
            $222 = ($221|0)==(0);
            if ($222) {
             $$8316 = 0;$325 = $$ph$ph;
             label = 143;
             break L6;
            } else {
             $$4284 = $$0280$ph;$$5313 = 0;$$6302 = $$ph$ph;$328 = $$ph$ph;
            }
           } else {
            if ($194) {
             $223 = (_malloc($192)|0);
             $224 = ($223|0)==(0|0);
             if ($224) {
              $$8316 = 0;$325 = 0;
              label = 143;
              break L6;
             }
             $$2278$ph = $192;$$2282$ph = 0;$$2310$ph = $223;
             while(1) {
              $$2282 = $$2282$ph;
              while(1) {
               $225 = HEAP32[$13>>2]|0;
               $226 = HEAP32[$14>>2]|0;
               $227 = ($225>>>0)<($226>>>0);
               if ($227) {
                $228 = ((($225)) + 1|0);
                HEAP32[$13>>2] = $228;
                $229 = HEAP8[$225>>0]|0;
                $230 = $229&255;
                $233 = $230;
               } else {
                $231 = (___shgetc($0)|0);
                $233 = $231;
               }
               $232 = (($233) + 1)|0;
               $234 = (($4) + ($232)|0);
               $235 = HEAP8[$234>>0]|0;
               $236 = ($235<<24>>24)==(0);
               if ($236) {
                $$4284 = $$2282;$$5313 = $$2310$ph;$$6302 = 0;$328 = 0;
                break L80;
               }
               $237 = $233&255;
               $238 = (($$2282) + 1)|0;
               $239 = (($$2310$ph) + ($$2282)|0);
               HEAP8[$239>>0] = $237;
               $240 = ($238|0)==($$2278$ph|0);
               if ($240) {
                break;
               } else {
                $$2282 = $238;
               }
              }
              $factor = $$2278$ph << 1;
              $241 = $factor | 1;
              $242 = (_realloc($$2310$ph,$241)|0);
              $243 = ($242|0)==(0|0);
              if ($243) {
               $$8316 = $$2310$ph;$325 = 0;
               label = 143;
               break L6;
              } else {
               $$2278$ph = $241;$$2282$ph = $238;$$2310$ph = $242;
              }
             }
            }
            $244 = ($$0295|0)==(0|0);
            if ($244) {
             while(1) {
              $260 = HEAP32[$13>>2]|0;
              $261 = HEAP32[$14>>2]|0;
              $262 = ($260>>>0)<($261>>>0);
              if ($262) {
               $263 = ((($260)) + 1|0);
               HEAP32[$13>>2] = $263;
               $264 = HEAP8[$260>>0]|0;
               $265 = $264&255;
               $268 = $265;
              } else {
               $266 = (___shgetc($0)|0);
               $268 = $266;
              }
              $267 = (($268) + 1)|0;
              $269 = (($4) + ($267)|0);
              $270 = HEAP8[$269>>0]|0;
              $271 = ($270<<24>>24)==(0);
              if ($271) {
               $$4284 = 0;$$5313 = 0;$$6302 = 0;$328 = 0;
               break L80;
              }
             }
            }
            $$3283 = 0;
            while(1) {
             $245 = HEAP32[$13>>2]|0;
             $246 = HEAP32[$14>>2]|0;
             $247 = ($245>>>0)<($246>>>0);
             if ($247) {
              $248 = ((($245)) + 1|0);
              HEAP32[$13>>2] = $248;
              $249 = HEAP8[$245>>0]|0;
              $250 = $249&255;
              $253 = $250;
             } else {
              $251 = (___shgetc($0)|0);
              $253 = $251;
             }
             $252 = (($253) + 1)|0;
             $254 = (($4) + ($252)|0);
             $255 = HEAP8[$254>>0]|0;
             $256 = ($255<<24>>24)==(0);
             if ($256) {
              $$4284 = $$3283;$$5313 = $$0295;$$6302 = 0;$328 = 0;
              break L80;
             }
             $257 = $253&255;
             $258 = (($$3283) + 1)|0;
             $259 = (($$0295) + ($$3283)|0);
             HEAP8[$259>>0] = $257;
             $$3283 = $258;
            }
           }
          } while(0);
          $272 = HEAP32[$14>>2]|0;
          $273 = ($272|0)==(0|0);
          if ($273) {
           $$pre487 = HEAP32[$13>>2]|0;
           $280 = $$pre487;
          } else {
           $274 = HEAP32[$13>>2]|0;
           $275 = ((($274)) + -1|0);
           HEAP32[$13>>2] = $275;
           $276 = $275;
           $280 = $276;
          }
          $277 = HEAP32[$15>>2]|0;
          $278 = HEAP32[$16>>2]|0;
          $279 = (($280) - ($278))|0;
          $281 = (($279) + ($277))|0;
          $282 = ($281|0)==(0);
          if ($282) {
           $$10318 = $$5313;$$2 = $$0270;$$2292 = $$0290416;$318 = $328;
           break L6;
          }
          $$not = $159 ^ 1;
          $283 = ($281|0)==($$1267|0);
          $or$cond321 = $283 | $$not;
          if (!($or$cond321)) {
           $$10318 = $$5313;$$2 = $$0270;$$2292 = $$0290416;$318 = $328;
           break L6;
          }
          do {
           if ($194) {
            if ($193) {
             HEAP32[$$0295>>2] = $$6302;
             break;
            } else {
             HEAP32[$$0295>>2] = $$5313;
             break;
            }
           }
          } while(0);
          if ($159) {
           $$11 = $$10;$$6314 = $$5313;$326 = $328;
          } else {
           $284 = ($$6302|0)==(0|0);
           if (!($284)) {
            $285 = (($$6302) + ($$4284<<2)|0);
            HEAP32[$285>>2] = 0;
           }
           $286 = ($$5313|0)==(0|0);
           if ($286) {
            $$11 = $$10;$$6314 = 0;$326 = $328;
            break L59;
           }
           $287 = (($$5313) + ($$4284)|0);
           HEAP8[$287>>0] = 0;
           $$11 = $$10;$$6314 = $$5313;$326 = $328;
          }
          break;
         }
         case 120: case 88: case 112:  {
          $$0272 = 16;
          label = 131;
          break;
         }
         case 111:  {
          $$0272 = 8;
          label = 131;
          break;
         }
         case 117: case 100:  {
          $$0272 = 10;
          label = 131;
          break;
         }
         case 105:  {
          $$0272 = 0;
          label = 131;
          break;
         }
         case 71: case 103: case 70: case 102: case 69: case 101: case 65: case 97:  {
          $298 = (+___floatscan($0,$spec$select319,0));
          $299 = HEAP32[$15>>2]|0;
          $300 = HEAP32[$13>>2]|0;
          $301 = HEAP32[$16>>2]|0;
          $302 = (($301) - ($300))|0;
          $303 = ($299|0)==($302|0);
          if ($303) {
           $$10318 = $$1309;$$2 = $$0270;$$2292 = $$0290416;$318 = $324;
           break L6;
          }
          $304 = ($$0295|0)==(0|0);
          if ($304) {
           $$11 = $$5;$$6314 = $$1309;$326 = $324;
          } else {
           switch ($spec$select319|0) {
           case 0:  {
            $305 = $298;
            HEAPF32[$$0295>>2] = $305;
            $$11 = $$5;$$6314 = $$1309;$326 = $324;
            break L59;
            break;
           }
           case 1:  {
            HEAPF64[$$0295>>3] = $298;
            $$11 = $$5;$$6314 = $$1309;$326 = $324;
            break L59;
            break;
           }
           case 2:  {
            HEAPF64[$$0295>>3] = $298;
            $$11 = $$5;$$6314 = $$1309;$326 = $324;
            break L59;
            break;
           }
           default: {
            $$11 = $$5;$$6314 = $$1309;$326 = $324;
            break L59;
           }
           }
          }
          break;
         }
         default: {
          $$11 = $$5;$$6314 = $$1309;$326 = $324;
         }
         }
        } while(0);
        do {
         if ((label|0) == 131) {
          label = 0;
          $288 = (___intscan($0,$$0272,0,-1,-1)|0);
          $289 = (getTempRet0() | 0);
          $290 = HEAP32[$15>>2]|0;
          $291 = HEAP32[$13>>2]|0;
          $292 = HEAP32[$16>>2]|0;
          $293 = (($292) - ($291))|0;
          $294 = ($290|0)==($293|0);
          if ($294) {
           $$10318 = $$1309;$$2 = $$0270;$$2292 = $$0290416;$318 = $324;
           break L6;
          }
          $295 = ($spec$select|0)==(112);
          $296 = ($$0295|0)!=(0|0);
          $or$cond3 = $296 & $295;
          if ($or$cond3) {
           $297 = $288;
           HEAP32[$$0295>>2] = $297;
           $$11 = $$5;$$6314 = $$1309;$326 = $324;
           break;
          } else {
           _store_int_465($$0295,$spec$select319,$288,$289);
           $$11 = $$5;$$6314 = $$1309;$326 = $324;
           break;
          }
         }
        } while(0);
        $306 = HEAP32[$15>>2]|0;
        $307 = HEAP32[$13>>2]|0;
        $308 = HEAP32[$16>>2]|0;
        $309 = (($306) + ($$1286))|0;
        $310 = (($309) + ($307))|0;
        $311 = (($310) - ($308))|0;
        $312 = ($$0295|0)!=(0|0);
        $313 = $312&1;
        $spec$select322 = (($$0290416) + ($313))|0;
        $$12 = $$11;$$1291 = $spec$select322;$$2287 = $311;$$7315 = $$6314;$322 = $326;
        break L8;
       }
      } while(0);
      $55 = $52&1;
      $56 = (($$0273420) + ($55)|0);
      ___shlim($0,0);
      $57 = HEAP32[$13>>2]|0;
      $58 = HEAP32[$14>>2]|0;
      $59 = ($57>>>0)<($58>>>0);
      if ($59) {
       $60 = ((($57)) + 1|0);
       HEAP32[$13>>2] = $60;
       $61 = HEAP8[$57>>0]|0;
       $62 = $61&255;
       $67 = $62;
      } else {
       $63 = (___shgetc($0)|0);
       $67 = $63;
      }
      $64 = HEAP8[$56>>0]|0;
      $65 = $64&255;
      $66 = ($67|0)==($65|0);
      if (!($66)) {
       label = 23;
       break L6;
      }
      $74 = (($$0285419) + 1)|0;
      $$12 = $56;$$1291 = $$0290416;$$2287 = $74;$$7315 = $$0308414;$322 = $321;
     } else {
      $$1274 = $$0273420;
      while(1) {
       $25 = ((($$1274)) + 1|0);
       $26 = HEAP8[$25>>0]|0;
       $27 = $26&255;
       $28 = (_isspace($27)|0);
       $29 = ($28|0)==(0);
       if ($29) {
        break;
       } else {
        $$1274 = $25;
       }
      }
      ___shlim($0,0);
      while(1) {
       $30 = HEAP32[$13>>2]|0;
       $31 = HEAP32[$14>>2]|0;
       $32 = ($30>>>0)<($31>>>0);
       if ($32) {
        $33 = ((($30)) + 1|0);
        HEAP32[$13>>2] = $33;
        $34 = HEAP8[$30>>0]|0;
        $35 = $34&255;
        $37 = $35;
       } else {
        $36 = (___shgetc($0)|0);
        $37 = $36;
       }
       $38 = (_isspace($37)|0);
       $39 = ($38|0)==(0);
       if ($39) {
        break;
       }
      }
      $40 = HEAP32[$14>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       $$pre = HEAP32[$13>>2]|0;
       $49 = $$pre;
      } else {
       $42 = HEAP32[$13>>2]|0;
       $43 = ((($42)) + -1|0);
       HEAP32[$13>>2] = $43;
       $44 = $43;
       $49 = $44;
      }
      $45 = HEAP32[$15>>2]|0;
      $46 = HEAP32[$16>>2]|0;
      $47 = (($45) + ($$0285419))|0;
      $48 = (($47) + ($49))|0;
      $50 = (($48) - ($46))|0;
      $$12 = $$1274;$$1291 = $$0290416;$$2287 = $50;$$7315 = $$0308414;$322 = $321;
     }
    } while(0);
    $314 = ((($$12)) + 1|0);
    $315 = HEAP8[$314>>0]|0;
    $316 = ($315<<24>>24)==(0);
    if ($316) {
     $$3293 = $$1291;
     break L4;
    } else {
     $$0273420 = $314;$$0285419 = $$2287;$$0290416 = $$1291;$$0308414 = $$7315;$22 = $315;$321 = $322;
    }
   }
   if ((label|0) == 23) {
    $68 = HEAP32[$14>>2]|0;
    $69 = ($68|0)==(0|0);
    if (!($69)) {
     $70 = HEAP32[$13>>2]|0;
     $71 = ((($70)) + -1|0);
     HEAP32[$13>>2] = $71;
    }
    $72 = ($67|0)>(-1);
    $73 = ($$0290416|0)!=(0);
    $or$cond5 = $73 | $72;
    if ($or$cond5) {
     $$3293 = $$0290416;
     break;
    } else {
     $$1271 = 0;$$9317 = $$0308414;$323 = $321;
     label = 144;
    }
   }
   else if ((label|0) == 143) {
    $$old4 = ($$0290416|0)==(0);
    if ($$old4) {
     $$1271 = $$0270;$$9317 = $$8316;$323 = $325;
     label = 144;
    } else {
     $$10318 = $$8316;$$2 = $$0270;$$2292 = $$0290416;$318 = $325;
    }
   }
   if ((label|0) == 144) {
    $$10318 = $$9317;$$2 = $$1271;$$2292 = -1;$318 = $323;
   }
   $317 = ($$2|0)==(0);
   if ($317) {
    $$3293 = $$2292;
   } else {
    _free($$10318);
    _free($318);
    $$3293 = $$2292;
   }
  }
 } while(0);
 $319 = ($320|0)==(0);
 if (!($319)) {
  ___unlockfile($0);
 }
 STACKTOP = sp;return ($$3293|0);
}
function _arg_n_464($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_next = 0, $expanded = 0, $expanded1 = 0, $expanded3 = 0, $expanded4 = 0, $expanded5 = 0, $vacopy_currentptr = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $vacopy_currentptr = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $vacopy_currentptr;
 $$0 = $1;
 while(1) {
  $3 = ($$0>>>0)>(1);
  $arglist_current = HEAP32[$2>>2]|0;
  $4 = $arglist_current;
  $5 = ((0) + 4|0);
  $expanded1 = $5;
  $expanded = (($expanded1) - 1)|0;
  $6 = (($4) + ($expanded))|0;
  $7 = ((0) + 4|0);
  $expanded5 = $7;
  $expanded4 = (($expanded5) - 1)|0;
  $expanded3 = $expanded4 ^ -1;
  $8 = $6 & $expanded3;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $arglist_next = ((($9)) + 4|0);
  HEAP32[$2>>2] = $arglist_next;
  $11 = (($$0) + -1)|0;
  if ($3) {
   $$0 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($10|0);
}
function _store_int_465($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)==(0|0);
 L1: do {
  if (!($4)) {
   switch ($1|0) {
   case -2:  {
    $5 = $2&255;
    HEAP8[$0>>0] = $5;
    break L1;
    break;
   }
   case -1:  {
    $6 = $2&65535;
    HEAP16[$0>>1] = $6;
    break L1;
    break;
   }
   case 0:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 1:  {
    HEAP32[$0>>2] = $2;
    break L1;
    break;
   }
   case 3:  {
    $7 = $0;
    $8 = $7;
    HEAP32[$8>>2] = $2;
    $9 = (($7) + 4)|0;
    $10 = $9;
    HEAP32[$10>>2] = $3;
    break L1;
    break;
   }
   default: {
    break L1;
   }
   }
  }
 } while(0);
 return;
}
function ___pthread_self_443() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _vswscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(384|0);
 $3 = sp;
 $4 = sp + 256|0;
 dest=$4; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $5 = ((($4)) + 32|0);
 HEAP32[$5>>2] = (fb + (28) | 0);
 $6 = ((($4)) + 44|0);
 HEAP32[$6>>2] = $3;
 $7 = ((($4)) + 48|0);
 HEAP32[$7>>2] = 256;
 $8 = ((($4)) + 76|0);
 HEAP32[$8>>2] = -1;
 $9 = ((($4)) + 84|0);
 HEAP32[$9>>2] = $0;
 $10 = (_vfwscanf($4,$1,$2)|0);
 STACKTOP = sp;return ($10|0);
}
function _wstring_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$cast = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $$0 = 0;
  } else {
   $7 = ((($0)) + 44|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($0)) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_wcsrtombs($8,$3,$10,0)|0);
   $12 = ($11|0)==(-1);
   if ($12) {
    $13 = ((($0)) + 8|0);
    HEAP32[$13>>2] = 0;
    $14 = ((($0)) + 4|0);
    HEAP32[$14>>2] = 0;
    $$0 = 0;
    break;
   }
   $15 = HEAP32[$7>>2]|0;
   $16 = ((($0)) + 4|0);
   HEAP32[$16>>2] = $15;
   $$cast = $15;
   $17 = (($$cast) + ($11)|0);
   $18 = ((($0)) + 8|0);
   HEAP32[$18>>2] = $17;
   $19 = HEAP32[$3>>2]|0;
   HEAP32[$4>>2] = $19;
   $20 = ($2|0)!=(0);
   $21 = ($11|0)!=(0);
   $or$cond = $20 & $21;
   if ($or$cond) {
    $22 = ((($$cast)) + 1|0);
    HEAP32[$16>>2] = $22;
    $23 = HEAP8[$$cast>>0]|0;
    HEAP8[$1>>0] = $23;
    $$0 = 1;
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _wcsrtombs($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$05674 = 0, $$057$lcssa = 0, $$05784 = 0, $$05873 = 0, $$1 = 0, $$159 = 0, $$260$lcssa = 0, $$26083 = 0, $$278 = 0, $$3 = 0, $$361 = 0, $$477 = 0, $$5 = 0, $$pn = 0, $$pre = 0, $$pre100 = 0, $$pre101 = 0, $$pre99 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($0|0)==(0|0);
 L1: do {
  if ($5) {
   $6 = HEAP32[$1>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    $$0 = 0;
   } else {
    $$05674 = $6;$$05873 = 0;$10 = $7;
    while(1) {
     $9 = ($10>>>0)>(127);
     if ($9) {
      $11 = (_wcrtomb($4,$10,0)|0);
      $12 = ($11|0)==(-1);
      if ($12) {
       $$0 = -1;
       break L1;
      } else {
       $$pn = $11;
      }
     } else {
      $$pn = 1;
     }
     $$159 = (($$pn) + ($$05873))|0;
     $13 = ((($$05674)) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0);
     if ($15) {
      $$0 = $$159;
      break;
     } else {
      $$05674 = $13;$$05873 = $$159;$10 = $14;
     }
    }
   }
  } else {
   $16 = ($2>>>0)>(3);
   L10: do {
    if ($16) {
     $$pre = HEAP32[$1>>2]|0;
     $$05784 = $0;$$26083 = $2;$18 = $$pre;
     while(1) {
      $17 = HEAP32[$18>>2]|0;
      $19 = (($17) + -1)|0;
      $20 = ($19>>>0)>(126);
      if ($20) {
       $21 = ($17|0)==(0);
       if ($21) {
        break;
       }
       $23 = (_wcrtomb($$05784,$17,0)|0);
       $24 = ($23|0)==(-1);
       if ($24) {
        $$0 = -1;
        break L1;
       }
       $25 = (($$05784) + ($23)|0);
       $26 = (($$26083) - ($23))|0;
       $$1 = $25;$$361 = $26;$31 = $18;
      } else {
       $27 = $17&255;
       $28 = ((($$05784)) + 1|0);
       HEAP8[$$05784>>0] = $27;
       $29 = (($$26083) + -1)|0;
       $$pre99 = HEAP32[$1>>2]|0;
       $$1 = $28;$$361 = $29;$31 = $$pre99;
      }
      $30 = ((($31)) + 4|0);
      HEAP32[$1>>2] = $30;
      $32 = ($$361>>>0)>(3);
      if ($32) {
       $$05784 = $$1;$$26083 = $$361;$18 = $30;
      } else {
       $$057$lcssa = $$1;$$260$lcssa = $$361;
       break L10;
      }
     }
     HEAP8[$$05784>>0] = 0;
     HEAP32[$1>>2] = 0;
     $22 = (($2) - ($$26083))|0;
     $$0 = $22;
     break L1;
    } else {
     $$057$lcssa = $0;$$260$lcssa = $2;
    }
   } while(0);
   $33 = ($$260$lcssa|0)==(0);
   if ($33) {
    $$0 = $2;
   } else {
    $$pre100 = HEAP32[$1>>2]|0;
    $$278 = $$057$lcssa;$$477 = $$260$lcssa;$35 = $$pre100;
    while(1) {
     $34 = HEAP32[$35>>2]|0;
     $36 = (($34) + -1)|0;
     $37 = ($36>>>0)>(126);
     if ($37) {
      $38 = ($34|0)==(0);
      if ($38) {
       label = 20;
       break;
      }
      $40 = (_wcrtomb($4,$34,0)|0);
      $41 = ($40|0)==(-1);
      if ($41) {
       $$0 = -1;
       break L1;
      }
      $42 = ($$477>>>0)<($40>>>0);
      if ($42) {
       label = 23;
       break;
      }
      $44 = HEAP32[$35>>2]|0;
      (_wcrtomb($$278,$44,0)|0);
      $45 = (($$278) + ($40)|0);
      $46 = (($$477) - ($40))|0;
      $$3 = $45;$$5 = $46;$51 = $35;
     } else {
      $47 = $34&255;
      $48 = ((($$278)) + 1|0);
      HEAP8[$$278>>0] = $47;
      $49 = (($$477) + -1)|0;
      $$pre101 = HEAP32[$1>>2]|0;
      $$3 = $48;$$5 = $49;$51 = $$pre101;
     }
     $50 = ((($51)) + 4|0);
     HEAP32[$1>>2] = $50;
     $52 = ($$5|0)==(0);
     if ($52) {
      $$0 = $2;
      break L1;
     } else {
      $$278 = $$3;$$477 = $$5;$35 = $50;
     }
    }
    if ((label|0) == 20) {
     HEAP8[$$278>>0] = 0;
     HEAP32[$1>>2] = 0;
     $39 = (($2) - ($$477))|0;
     $$0 = $39;
     break;
    }
    else if ((label|0) == 23) {
     $43 = (($2) - ($$477))|0;
     $$0 = $43;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___fdopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer12 = 0, $vararg_buffer3 = 0, $vararg_buffer7 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = sp + 56|0;
 $3 = HEAP8[$1>>0]|0;
 $4 = $3 << 24 >> 24;
 $5 = (_strchr((gb + (167347) | 0),$4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$0 = 0;
 } else {
  $8 = (_malloc(1156)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$0 = 0;
  } else {
   (_memset(($8|0),0,124)|0);
   $10 = (_strchr($1,43)|0);
   $11 = ($10|0)==(0|0);
   if ($11) {
    $12 = HEAP8[$1>>0]|0;
    $13 = ($12<<24>>24)==(114);
    $14 = $13 ? 8 : 4;
    HEAP32[$8>>2] = $14;
   }
   $15 = (_strchr($1,101)|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    HEAP32[$vararg_buffer>>2] = $0;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 2;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 1;
    (___syscall221(221,($vararg_buffer|0))|0);
   }
   $17 = HEAP8[$1>>0]|0;
   $18 = ($17<<24>>24)==(97);
   if ($18) {
    HEAP32[$vararg_buffer3>>2] = $0;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = 3;
    $19 = (___syscall221(221,($vararg_buffer3|0))|0);
    $20 = $19 & 1024;
    $21 = ($20|0)==(0);
    if ($21) {
     $22 = $19 | 1024;
     HEAP32[$vararg_buffer7>>2] = $0;
     $vararg_ptr10 = ((($vararg_buffer7)) + 4|0);
     HEAP32[$vararg_ptr10>>2] = 4;
     $vararg_ptr11 = ((($vararg_buffer7)) + 8|0);
     HEAP32[$vararg_ptr11>>2] = $22;
     (___syscall221(221,($vararg_buffer7|0))|0);
    }
    $23 = HEAP32[$8>>2]|0;
    $24 = $23 | 128;
    HEAP32[$8>>2] = $24;
    $31 = $24;
   } else {
    $$pre = HEAP32[$8>>2]|0;
    $31 = $$pre;
   }
   $25 = ((($8)) + 60|0);
   HEAP32[$25>>2] = $0;
   $26 = ((($8)) + 132|0);
   $27 = ((($8)) + 44|0);
   HEAP32[$27>>2] = $26;
   $28 = ((($8)) + 48|0);
   HEAP32[$28>>2] = 1024;
   $29 = ((($8)) + 75|0);
   HEAP8[$29>>0] = -1;
   $30 = $31 & 8;
   $32 = ($30|0)==(0);
   if ($32) {
    $33 = $2;
    HEAP32[$vararg_buffer12>>2] = $0;
    $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
    HEAP32[$vararg_ptr15>>2] = 21523;
    $vararg_ptr16 = ((($vararg_buffer12)) + 8|0);
    HEAP32[$vararg_ptr16>>2] = $33;
    $34 = (___syscall54(54,($vararg_buffer12|0))|0);
    $35 = ($34|0)==(0);
    if ($35) {
     HEAP8[$29>>0] = 10;
    }
   }
   $36 = ((($8)) + 32|0);
   HEAP32[$36>>2] = (fb + (4) | 0);
   $37 = ((($8)) + 36|0);
   HEAP32[$37>>2] = (fb + (2) | 0);
   $38 = ((($8)) + 40|0);
   HEAP32[$38>>2] = (fb + (3) | 0);
   $39 = ((($8)) + 12|0);
   HEAP32[$39>>2] = (fb + (1) | 0);
   $40 = HEAP32[((((gb + (171204) | 0)) + 4|0))>>2]|0;
   $41 = ($40|0)==(0);
   if ($41) {
    $42 = ((($8)) + 76|0);
    HEAP32[$42>>2] = -1;
   }
   $43 = (___ofl_add($8)|0);
   $$0 = $8;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _open_memstream($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_malloc(1172)|0);
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (_malloc(1)|0);
   $5 = ($4|0)==(0|0);
   if ($5) {
    _free($2);
    $$0 = 0;
    break;
   }
   (_memset(($2|0),0,148)|0);
   $6 = ((($2)) + 124|0);
   $7 = ((($2)) + 84|0);
   HEAP32[$7>>2] = $6;
   HEAP32[$6>>2] = $0;
   $8 = ((($2)) + 128|0);
   HEAP32[$8>>2] = $1;
   HEAP32[$1>>2] = 0;
   $9 = ((($2)) + 144|0);
   HEAP32[$9>>2] = 0;
   $10 = ((($2)) + 140|0);
   HEAP32[$10>>2] = 0;
   $11 = ((($2)) + 132|0);
   HEAP32[$11>>2] = 0;
   HEAP32[$0>>2] = $4;
   $12 = ((($2)) + 136|0);
   HEAP32[$12>>2] = $4;
   HEAP8[$4>>0] = 0;
   HEAP32[$2>>2] = 4;
   $13 = ((($2)) + 60|0);
   HEAP32[$13>>2] = -1;
   $14 = ((($2)) + 148|0);
   $15 = ((($2)) + 44|0);
   HEAP32[$15>>2] = $14;
   $16 = ((($2)) + 48|0);
   HEAP32[$16>>2] = 1024;
   $17 = ((($2)) + 75|0);
   HEAP8[$17>>0] = -1;
   $18 = ((($2)) + 36|0);
   HEAP32[$18>>2] = (fb + (29) | 0);
   $19 = ((($2)) + 40|0);
   HEAP32[$19>>2] = (fb + (30) | 0);
   $20 = ((($2)) + 12|0);
   HEAP32[$20>>2] = (fb + (31) | 0);
   $21 = HEAP32[((((gb + (171204) | 0)) + 4|0))>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = ((($2)) + 76|0);
    HEAP32[$23>>2] = -1;
   }
   $24 = (___ofl_add($2)|0);
   $$0 = $2;
  }
 } while(0);
 return ($$0|0);
}
function _ms_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre46 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($0)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = (($6) - ($9))|0;
 $11 = ($10|0)==(0);
 if ($11) {
  label = 3;
 } else {
  HEAP32[$5>>2] = $8;
  $12 = (_ms_write($0,$8,$10)|0);
  $13 = ($12>>>0)<($10>>>0);
  if ($13) {
   $$0 = 0;
  } else {
   label = 3;
  }
 }
 do {
  if ((label|0) == 3) {
   $14 = ((($4)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($2))|0;
   $17 = ((($4)) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16>>>0)<($18>>>0);
   if ($19) {
    $$pre46 = ((($4)) + 12|0);
    $$pre$phiZ2D = $$pre46;$35 = $15;
   } else {
    $20 = $18 << 1;
    $21 = (($16) + 1)|0;
    $22 = $21 | $20;
    $23 = $22 | 1;
    $24 = ((($4)) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (_realloc($25,$23)|0);
    $27 = ($26|0)==(0|0);
    if ($27) {
     $$0 = 0;
     break;
    }
    HEAP32[$24>>2] = $26;
    $28 = HEAP32[$4>>2]|0;
    HEAP32[$28>>2] = $26;
    $29 = HEAP32[$24>>2]|0;
    $30 = HEAP32[$17>>2]|0;
    $31 = (($29) + ($30)|0);
    $32 = (($23) - ($30))|0;
    (_memset(($31|0),0,($32|0))|0);
    HEAP32[$17>>2] = $23;
    $$pre = HEAP32[$14>>2]|0;
    $$pre$phiZ2D = $24;$35 = $$pre;
   }
   $33 = HEAP32[$$pre$phiZ2D>>2]|0;
   $34 = (($33) + ($35)|0);
   (_memcpy(($34|0),($1|0),($2|0))|0);
   $36 = HEAP32[$14>>2]|0;
   $37 = (($36) + ($2))|0;
   HEAP32[$14>>2] = $37;
   $38 = ((($4)) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37>>>0)<($39>>>0);
   if (!($40)) {
    HEAP32[$38>>2] = $37;
   }
   $41 = ((($4)) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$42>>2] = $37;
   $$0 = $2;
  }
 } while(0);
 return ($$0|0);
}
function _ms_seek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ((($0)) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2>>>0)>(2);
 if ($6) {
  label = 2;
 } else {
  HEAP32[$3>>2] = 0;
  $8 = ((($3)) + 4|0);
  $9 = ((($5)) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = ((($3)) + 8|0);
  $12 = ((($5)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $13;
  $14 = (($3) + ($2<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (0 - ($15))|0;
  $17 = ($16|0)>($1|0);
  $18 = (2147483647 - ($15))|0;
  $19 = ($18|0)<($1|0);
  $or$cond = $17 | $19;
  if ($or$cond) {
   label = 2;
  } else {
   $20 = (($15) + ($1))|0;
   HEAP32[$9>>2] = $20;
   $$0 = $20;
  }
 }
 if ((label|0) == 2) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _ms_close($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _fopen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer8 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (_strchr((gb + (167347) | 0),$3)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (___errno_location()|0);
  HEAP32[$6>>2] = 22;
  $$0 = 0;
 } else {
  $7 = (___fmodeflags($1)|0);
  $8 = $0;
  $9 = $7 | 32768;
  HEAP32[$vararg_buffer>>2] = $8;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $9;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 438;
  $10 = (___syscall5(5,($vararg_buffer|0))|0);
  $11 = (___syscall_ret($10)|0);
  $12 = ($11|0)<(0);
  if ($12) {
   $$0 = 0;
  } else {
   $13 = $7 & 524288;
   $14 = ($13|0)==(0);
   if (!($14)) {
    HEAP32[$vararg_buffer3>>2] = $11;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = 2;
    $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
    HEAP32[$vararg_ptr7>>2] = 1;
    (___syscall221(221,($vararg_buffer3|0))|0);
   }
   $15 = (___fdopen($11,$1)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    HEAP32[$vararg_buffer8>>2] = $11;
    (___syscall6(6,($vararg_buffer8|0))|0);
    $$0 = 0;
   } else {
    $$0 = $15;
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fmodeflags($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $$2 = 0, $$4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $spec$select = 0, $spec$select13 = 0, $spec$select14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_strchr($0,43)|0);
 $2 = ($1|0)==(0|0);
 $3 = HEAP8[$0>>0]|0;
 $4 = ($3<<24>>24)!=(114);
 $$ = $4&1;
 $$0 = $2 ? $$ : 2;
 $5 = (_strchr($0,120)|0);
 $6 = ($5|0)==(0|0);
 $7 = $$0 | 128;
 $spec$select = $6 ? $$0 : $7;
 $8 = (_strchr($0,101)|0);
 $9 = ($8|0)==(0|0);
 $10 = $spec$select | 524288;
 $$2 = $9 ? $spec$select : $10;
 $11 = ($3<<24>>24)==(114);
 $12 = $$2 | 64;
 $spec$select13 = $11 ? $$2 : $12;
 $13 = ($3<<24>>24)==(119);
 $14 = $spec$select13 | 512;
 $$4 = $13 ? $14 : $spec$select13;
 $15 = ($3<<24>>24)==(97);
 $16 = $$4 | 1024;
 $spec$select14 = $15 ? $16 : $$4;
 return ($spec$select14|0);
}
function _putwchar($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $2 = (_fputwc($0,$1)|0);
 return ($2|0);
}
function _fsetpos($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = (___fseeko($0,$2,0)|0);
 return ($3|0);
}
function ___fseeko($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $7 = (___lockfile($0)|0);
  $phitmp = ($7|0)==(0);
  $8 = (___fseeko_unlocked($0,$1,$2)|0);
  if ($phitmp) {
   $9 = $8;
  } else {
   ___unlockfile($0);
   $9 = $8;
  }
 } else {
  $6 = (___fseeko_unlocked($0,$1,$2)|0);
  $9 = $6;
 }
 return ($9|0);
}
function ___fseeko_unlocked($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(1);
 if ($3) {
  $4 = ((($0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($0)) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($1) - ($5))|0;
  $9 = (($8) + ($7))|0;
  $$019 = $9;
 } else {
  $$019 = $1;
 }
 $10 = ((($0)) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  $15 = ((($0)) + 36|0);
  $16 = HEAP32[$15>>2]|0;
  (mftCall_iiii($16|0,($0|0),(0|0),0)|0);
  $17 = HEAP32[$10>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$0 = -1;
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ((($0)) + 16|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$12>>2] = 0;
  HEAP32[$10>>2] = 0;
  $20 = ((($0)) + 40|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (mftCall_iiii($21|0,($0|0),($$019|0),($2|0))|0);
  $23 = ($22|0)<(0);
  if ($23) {
   $$0 = -1;
  } else {
   $24 = ((($0)) + 8|0);
   HEAP32[$24>>2] = 0;
   $25 = ((($0)) + 4|0);
   HEAP32[$25>>2] = 0;
   $26 = HEAP32[$0>>2]|0;
   $27 = $26 & -17;
   HEAP32[$0>>2] = $27;
   $$0 = 0;
  }
 }
 return ($$0|0);
}
function _putw($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $0;
 $3 = (_fwrite($2,4,1,$1)|0);
 $4 = (($3) + -1)|0;
 STACKTOP = sp;return ($4|0);
}
function _flockfile($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_ftrylockfile($0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ((($0)) + 76|0);
  $4 = ((($0)) + 80|0);
  while(1) {
   $5 = HEAP32[$3>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    ___wait(($3|0),($4|0),($5|0),1);
   }
   $7 = (_ftrylockfile($0)|0);
   $8 = ($7|0)==(0);
   if ($8) {
    break;
   }
  }
 }
 return;
}
function _ftrylockfile($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___pthread_self_431()|0);
 $2 = ((($1)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $7 = ((($0)) + 68|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(2147483647);
  if ($9) {
   $$0 = -1;
  } else {
   $10 = (($8) + 1)|0;
   HEAP32[$7>>2] = $10;
   $$0 = 0;
  }
 } else {
  $11 = HEAP32[$4>>2]|0;
  $12 = ($11|0)<(0);
  if ($12) {
   HEAP32[$4>>2] = 0;
  }
  $13 = HEAP32[$4>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   _a_cas($4,$3);
   $15 = ((($0)) + 68|0);
   HEAP32[$15>>2] = 1;
   $16 = ((($0)) + 112|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($1)) + 232|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($0)) + 116|0);
   HEAP32[$19>>2] = $18;
   $20 = ($18|0)==(0|0);
   if (!($20)) {
    $21 = ((($18)) + 112|0);
    HEAP32[$21>>2] = $0;
   }
   HEAP32[$17>>2] = $0;
   $$0 = 0;
  } else {
   $$0 = -1;
  }
 }
 return ($$0|0);
}
function ___pthread_self_431() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _a_cas($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$0>>2] = $1;
 }
 return;
}
function _setbuf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0|0);
 $3 = $2 ? 2 : 0;
 (_setvbuf($0,$1,$3,1024)|0);
 return;
}
function _puts($0) {
 $0 = $0|0;
 var $$lobit = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(-1);
 if ($4) {
  $5 = (___lockfile($1)|0);
  $19 = $5;
 } else {
  $19 = 0;
 }
 $6 = (_fputs($0,$1)|0);
 $7 = ($6|0)<(0);
 do {
  if ($7) {
   $20 = -1;
  } else {
   $8 = ((($1)) + 75|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(10);
   if (!($10)) {
    $11 = ((($1)) + 20|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($1)) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12>>>0)<($14>>>0);
    if ($15) {
     $16 = ((($12)) + 1|0);
     HEAP32[$11>>2] = $16;
     HEAP8[$12>>0] = 10;
     $20 = 0;
     break;
    }
   }
   $17 = (___overflow($1,10)|0);
   $$lobit = $17 >> 31;
   $20 = $$lobit;
  }
 } while(0);
 $18 = ($19|0)==(0);
 if (!($18)) {
  ___unlockfile($1);
 }
 return ($20|0);
}
function _fputs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($0)|0);
 $3 = (_fwrite($0,1,$2,$1)|0);
 $4 = ($3|0)!=($2|0);
 $5 = $4 << 31 >> 31;
 return ($5|0);
}
function _vasprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vacopy_currentptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $vacopy_currentptr = HEAP32[$2>>2]|0;
 HEAP32[$3>>2] = $vacopy_currentptr;
 $4 = (_vsnprintf(0,0,$1,$3)|0);
 $5 = ($4|0)<(0);
 if ($5) {
  $$0 = -1;
 } else {
  $6 = (($4) + 1)|0;
  $7 = (_malloc($6)|0);
  HEAP32[$0>>2] = $7;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = -1;
  } else {
   $9 = (_vsnprintf($7,$6,$1,$2)|0);
   $$0 = $9;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _dprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vdprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _vdprintf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 dest=$3; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = ((($3)) + 36|0);
 HEAP32[$4>>2] = (fb + (32) | 0);
 $5 = ((($3)) + 44|0);
 HEAP32[$5>>2] = $1;
 $6 = ((($3)) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($3)) + 60|0);
 HEAP32[$7>>2] = $0;
 $8 = ((($3)) + 75|0);
 HEAP8[$8>>0] = -1;
 $9 = ((($3)) + 76|0);
 HEAP32[$9>>2] = -1;
 $10 = (_vfprintf($3,$1,$2)|0);
 STACKTOP = sp;return ($10|0);
}
function _wrap_write($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___stdio_write($0,$1,$2)|0);
 return ($3|0);
}
function _wprintf($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = (_vwprintf($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function _putc_unlocked($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0&255;
 $3 = $0 & 255;
 $4 = ((($1)) + 75|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 << 24 >> 24;
 $7 = ($3|0)==($6|0);
 if ($7) {
  label = 4;
 } else {
  $8 = ((($1)) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($1)) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)<($11>>>0);
  if ($12) {
   $13 = ((($9)) + 1|0);
   HEAP32[$8>>2] = $13;
   HEAP8[$9>>0] = $2;
   $15 = $3;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $14 = (___overflow($1,$0)|0);
  $15 = $14;
 }
 return ($15|0);
}
function _printf($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $3 = (_vfprintf($2,$0,$1)|0);
 STACKTOP = sp;return ($3|0);
}
function _scanf($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = (_vscanf($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function _vscanf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $3 = (_vfscanf($2,$0,$1)|0);
 return ($3|0);
}
function _swscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vswscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _gets($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $2 = (_fgets($0,2147483647,$1)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (_strlen($0)|0);
  $5 = (($4) + -1)|0;
  $6 = (($0) + ($5)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(10);
  if ($8) {
   HEAP8[$6>>0] = 0;
  }
 }
 return ($2|0);
}
function _fputc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)<(0);
 if ($4) {
  label = 3;
 } else {
  $5 = (___lockfile($1)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   label = 3;
  } else {
   $20 = $0&255;
   $21 = $0 & 255;
   $22 = ((($1)) + 75|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23 << 24 >> 24;
   $25 = ($21|0)==($24|0);
   if ($25) {
    label = 10;
   } else {
    $26 = ((($1)) + 20|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($1)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27>>>0)<($29>>>0);
    if ($30) {
     $31 = ((($27)) + 1|0);
     HEAP32[$26>>2] = $31;
     HEAP8[$27>>0] = $20;
     $33 = $21;
    } else {
     label = 10;
    }
   }
   if ((label|0) == 10) {
    $32 = (___overflow($1,$0)|0);
    $33 = $32;
   }
   ___unlockfile($1);
   $$0 = $33;
  }
 }
 do {
  if ((label|0) == 3) {
   $7 = $0&255;
   $8 = $0 & 255;
   $9 = ((($1)) + 75|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 << 24 >> 24;
   $12 = ($8|0)==($11|0);
   if (!($12)) {
    $13 = ((($1)) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($1)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14>>>0)<($16>>>0);
    if ($17) {
     $18 = ((($14)) + 1|0);
     HEAP32[$13>>2] = $18;
     HEAP8[$14>>0] = $7;
     $$0 = $8;
     break;
    }
   }
   $19 = (___overflow($1,$0)|0);
   $$0 = $19;
  }
 } while(0);
 return ($$0|0);
}
function _putchar_unlocked($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0&255;
 $2 = $0 & 255;
 $3 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $4 = ((($3)) + 75|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 << 24 >> 24;
 $7 = ($2|0)==($6|0);
 if ($7) {
  label = 4;
 } else {
  $8 = ((($3)) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($3)) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)<($11>>>0);
  if ($12) {
   $13 = ((($9)) + 1|0);
   HEAP32[$8>>2] = $13;
   HEAP8[$9>>0] = $1;
   $15 = $2;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $14 = (___overflow($3,$0)|0);
  $15 = $14;
 }
 return ($15|0);
}
function _asprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vasprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _getchar() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $1 = (_fgetc($0)|0);
 return ($1|0);
}
function _fgetc($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(0);
 if ($3) {
  label = 3;
 } else {
  $4 = (___lockfile($0)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   label = 3;
  } else {
   $15 = ((($0)) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($0)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16>>>0)<($18>>>0);
   if ($19) {
    $20 = ((($16)) + 1|0);
    HEAP32[$15>>2] = $20;
    $21 = HEAP8[$16>>0]|0;
    $22 = $21&255;
    $24 = $22;
   } else {
    $23 = (___uflow($0)|0);
    $24 = $23;
   }
   $$0 = $24;
  }
 }
 do {
  if ((label|0) == 3) {
   $6 = ((($0)) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($0)) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7>>>0)<($9>>>0);
   if ($10) {
    $11 = ((($7)) + 1|0);
    HEAP32[$6>>2] = $11;
    $12 = HEAP8[$7>>0]|0;
    $13 = $12&255;
    $$0 = $13;
    break;
   } else {
    $14 = (___uflow($0)|0);
    $$0 = $14;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _pclose($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $1 = sp + 16|0;
 $2 = ((($0)) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 (_fclose($0)|0);
 $4 = $1;
 while(1) {
  HEAP32[$vararg_buffer>>2] = $3;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $4;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 0;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 0;
  $5 = (___syscall114(114,($vararg_buffer|0))|0);
  $6 = ($5|0)==(-4);
  if (!($6)) {
   break;
  }
 }
 $7 = ($5|0)<(0);
 if ($7) {
  $8 = (___syscall_ret($5)|0);
  $$0 = $8;
 } else {
  $9 = HEAP32[$1>>2]|0;
  $$0 = $9;
 }
 STACKTOP = sp;return ($$0|0);
}
function _fclose($0) {
 $0 = $0|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (___lockfile($0)|0);
  $30 = $4;
 } else {
  $30 = 0;
 }
 ___unlist_locked_file($0);
 $5 = HEAP32[$0>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)!=(0);
 if (!($7)) {
  $8 = (___ofl_lock()|0);
  $9 = ((($0)) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $12 = $10;
  $$pre = ((($0)) + 56|0);
  if (!($11)) {
   $13 = HEAP32[$$pre>>2]|0;
   $14 = ((($10)) + 56|0);
   HEAP32[$14>>2] = $13;
  }
  $15 = HEAP32[$$pre>>2]|0;
  $16 = ($15|0)==(0|0);
  $17 = $15;
  if (!($16)) {
   $18 = ((($15)) + 52|0);
   HEAP32[$18>>2] = $12;
  }
  $19 = HEAP32[$8>>2]|0;
  $20 = ($19|0)==($0|0);
  if ($20) {
   HEAP32[$8>>2] = $17;
  }
  ___ofl_unlock();
 }
 $21 = (_fflush($0)|0);
 $22 = ((($0)) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (mftCall_ii($23|0,($0|0))|0);
 $25 = $24 | $21;
 $26 = ((($0)) + 92|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  _free($27);
 }
 if ($7) {
  $29 = ($30|0)==(0);
  if (!($29)) {
   ___unlockfile($0);
  }
 } else {
  _free($0);
 }
 return ($25|0);
}
function ___unlist_locked_file($0) {
 $0 = $0|0;
 var $$pre = 0, $$sink = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ((($0)) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  $7 = $5;
  $$pre = ((($0)) + 112|0);
  if (!($6)) {
   $8 = HEAP32[$$pre>>2]|0;
   $9 = ((($5)) + 112|0);
   HEAP32[$9>>2] = $8;
  }
  $10 = HEAP32[$$pre>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $13 = (___pthread_self_431()|0);
   $14 = ((($13)) + 232|0);
   $$sink = $14;
  } else {
   $12 = ((($10)) + 116|0);
   $$sink = $12;
  }
  HEAP32[$$sink>>2] = $7;
 }
 return;
}
function ___toread_needs_stdio_exit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 mftCall_v((fb + (33) | 0)|0);
 return;
}
function ___stdio_exit() {
 var $$0 = 0, $$04 = 0, $$05 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___ofl_lock()|0);
 $$04 = HEAP32[$0>>2]|0;
 $1 = ($$04|0)==(0|0);
 if (!($1)) {
  $$05 = $$04;
  while(1) {
   _close_file($$05);
   $2 = ((($$05)) + 56|0);
   $$0 = HEAP32[$2>>2]|0;
   $3 = ($$0|0)==(0|0);
   if ($3) {
    break;
   } else {
    $$05 = $$0;
   }
  }
 }
 $4 = HEAP32[(gb + (161560) | 0)>>2]|0;
 _close_file($4);
 $5 = HEAP32[(gb + (161692) | 0)>>2]|0;
 _close_file($5);
 return;
}
function _close_file($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = ((($0)) + 76|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)>(-1);
  if ($4) {
   (___lockfile($0)|0);
  }
  $5 = ((($0)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($0)) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6>>>0)>($8>>>0);
  if ($9) {
   $10 = ((($0)) + 36|0);
   $11 = HEAP32[$10>>2]|0;
   (mftCall_iiii($11|0,($0|0),(0|0),0)|0);
  }
  $12 = ((($0)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($0)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($13>>>0)<($15>>>0);
  if ($16) {
   $17 = $13;
   $18 = $15;
   $19 = (($17) - ($18))|0;
   $20 = ((($0)) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   (mftCall_iiii($21|0,($0|0),($19|0),1)|0);
  }
 }
 return;
}
function _fwprintf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vfwprintf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _ferror($0) {
 $0 = $0|0;
 var $$lobit = 0, $$lobit8 = 0, $$lobit9 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $6 = (___lockfile($0)|0);
  $phitmp = ($6|0)==(0);
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 >>> 5;
  $$lobit = $8 & 1;
  if ($phitmp) {
   $$lobit9 = $$lobit;
  } else {
   $$lobit9 = $$lobit;
  }
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = $4 >>> 5;
  $$lobit8 = $5 & 1;
  $$lobit9 = $$lobit8;
 }
 return ($$lobit9|0);
}
function ___string_read($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$027 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($0)) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 256)|0;
 $6 = (_memchr($4,0,$5)|0);
 $7 = ($6|0)==(0|0);
 $8 = $6;
 $9 = $4;
 $10 = (($8) - ($9))|0;
 $$027 = $7 ? $5 : $10;
 $11 = ($$027>>>0)<($2>>>0);
 $spec$select = $11 ? $$027 : $2;
 (_memcpy(($1|0),($4|0),($spec$select|0))|0);
 $12 = (($4) + ($spec$select)|0);
 $13 = ((($0)) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($4) + ($$027)|0);
 $15 = ((($0)) + 8|0);
 HEAP32[$15>>2] = $14;
 HEAP32[$3>>2] = $14;
 return ($spec$select|0);
}
function _rewind($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (___lockfile($0)|0);
  $phitmp = ($4|0)==(0);
  (___fseeko_unlocked($0,0,0)|0);
  $5 = HEAP32[$0>>2]|0;
  $6 = $5 & -33;
  HEAP32[$0>>2] = $6;
  if (!($phitmp)) {
   ___unlockfile($0);
  }
 } else {
  (___fseeko_unlocked($0,0,0)|0);
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 & -33;
  HEAP32[$0>>2] = $8;
 }
 return;
}
function _vsscanf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(128|0);
 $3 = sp;
 dest=$3; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = ((($3)) + 32|0);
 HEAP32[$4>>2] = (fb + (34) | 0);
 $5 = ((($3)) + 44|0);
 HEAP32[$5>>2] = $0;
 $6 = ((($3)) + 76|0);
 HEAP32[$6>>2] = -1;
 $7 = ((($3)) + 84|0);
 HEAP32[$7>>2] = $0;
 $8 = (_vfscanf($3,$1,$2)|0);
 STACKTOP = sp;return ($8|0);
}
function _do_read_418($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___string_read($0,$1,$2)|0);
 return ($3|0);
}
function _getchar_unlocked() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = ((($2)) + 1|0);
  HEAP32[$1>>2] = $6;
  $7 = HEAP8[$2>>0]|0;
  $8 = $7&255;
  $10 = $8;
 } else {
  $9 = (___uflow($0)|0);
  $10 = $9;
 }
 return ($10|0);
}
function ___do_orphaned_stdio_locks() {
 var $$0 = 0, $$04 = 0, $$05 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___pthread_self_431()|0);
 $1 = ((($0)) + 232|0);
 $$04 = HEAP32[$1>>2]|0;
 $2 = ($$04|0)==(0|0);
 if (!($2)) {
  $$05 = $$04;
  while(1) {
   $3 = ((($$05)) + 76|0);
   _a_store_432($3);
   $4 = ((($$05)) + 116|0);
   $$0 = HEAP32[$4>>2]|0;
   $5 = ($$0|0)==(0|0);
   if ($5) {
    break;
   } else {
    $$05 = $$0;
   }
  }
 }
 return;
}
function _a_store_432($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$0>>2] = 1073741824;
 return;
}
function _fgetln($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $6 = (___lockfile($0)|0);
  $31 = $6;
 } else {
  $31 = 0;
 }
 $7 = ((($0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ((($8)) + 1|0);
  HEAP32[$7>>2] = $12;
  $13 = HEAP8[$8>>0]|0;
  $14 = $13&255;
  $16 = $14;
 } else {
  $15 = (___uflow($0)|0);
  $16 = $15;
 }
 (_ungetc($16,$0)|0);
 $17 = HEAP32[$7>>2]|0;
 $18 = HEAP32[$9>>2]|0;
 $19 = $17;
 $20 = (($18) - ($19))|0;
 $21 = (_memchr($17,10,$20)|0);
 $22 = ($21|0)==(0|0);
 if ($22) {
  $26 = ((($0)) + 92|0);
  HEAP32[$2>>2] = 0;
  $27 = (_getline($26,$2,$0)|0);
  $28 = ($27|0)>(0);
  if ($28) {
   HEAP32[$1>>2] = $27;
   $29 = HEAP32[$26>>2]|0;
   $$0 = $29;
  } else {
   $$0 = 0;
  }
 } else {
  $23 = ((($21)) + 1|0);
  $24 = $23;
  $25 = (($24) - ($19))|0;
  HEAP32[$1>>2] = $25;
  HEAP32[$7>>2] = $23;
  $$0 = $17;
 }
 $30 = ($31|0)==(0);
 if (!($30)) {
  ___unlockfile($0);
 }
 STACKTOP = sp;return ($$0|0);
}
function _ungetc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$pr = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(-1);
 do {
  if ($2) {
   $$1 = -1;
  } else {
   $3 = ((($1)) + 76|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)>(-1);
   if ($5) {
    $6 = (___lockfile($1)|0);
    $17 = $6;
   } else {
    $17 = 0;
   }
   $7 = ((($1)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    (___toread($1)|0);
    $$pr = HEAP32[$7>>2]|0;
    $10 = ($$pr|0)==(0|0);
    if (!($10)) {
     $15 = $$pr;
     label = 6;
    }
   } else {
    $15 = $8;
    label = 6;
   }
   if ((label|0) == 6) {
    $11 = ((($1)) + 44|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12)) + -8|0);
    $14 = ($15>>>0)>($13>>>0);
    if ($14) {
     $18 = $0&255;
     $19 = ((($15)) + -1|0);
     HEAP32[$7>>2] = $19;
     HEAP8[$19>>0] = $18;
     $20 = HEAP32[$1>>2]|0;
     $21 = $20 & -17;
     HEAP32[$1>>2] = $21;
     $22 = ($17|0)==(0);
     if ($22) {
      $$1 = $0;
      break;
     }
     ___unlockfile($1);
     $$1 = $0;
     break;
    }
   }
   $16 = ($17|0)==(0);
   if ($16) {
    $$1 = -1;
   } else {
    ___unlockfile($1);
    $$1 = -1;
   }
  }
 } while(0);
 return ($$1|0);
}
function _fileno($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (___lockfile($0)|0);
  $phitmp = ($4|0)==(0);
  if (!($phitmp)) {
  }
 }
 $5 = ((($0)) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 return ($6|0);
}
function ___freadahead($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 return ($5|0);
}
function ___freadptr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
 } else {
  $8 = $5;
  HEAP32[$1>>2] = $6;
  $$0 = $8;
 }
 return ($$0|0);
}
function ___freadptrinc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1)|0);
 HEAP32[$2>>2] = $4;
 return;
}
function ___fseterr($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 | 32;
 HEAP32[$0>>2] = $2;
 return;
}
function _remove($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = $0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (___syscall10(10,($vararg_buffer|0))|0);
 $3 = ($2|0)==(-21);
 if ($3) {
  HEAP32[$vararg_buffer1>>2] = $1;
  $4 = (___syscall40(40,($vararg_buffer1|0))|0);
  $$0 = $4;
 } else {
  $$0 = $2;
 }
 $5 = (___syscall_ret($$0)|0);
 STACKTOP = sp;return ($5|0);
}
function _tmpfile() {
 var $$012 = 0, $$014 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer6 = sp + 48|0;
 $vararg_buffer3 = sp + 40|0;
 $vararg_buffer = sp + 24|0;
 $0 = sp;
 ;HEAP32[$0>>2]=HEAP32[(gb + (153248) | 0)>>2]|0;HEAP32[$0+4>>2]=HEAP32[(gb + (153248) | 0)+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[(gb + (153248) | 0)+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[(gb + (153248) | 0)+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[(gb + (153248) | 0)+16>>2]|0;
 $1 = ((($0)) + 13|0);
 $2 = $0;
 $$014 = 0;
 while(1) {
  (___randname($1)|0);
  HEAP32[$vararg_buffer>>2] = $2;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 32962;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 384;
  $5 = (___syscall5(5,($vararg_buffer|0))|0);
  $6 = (___syscall_ret($5)|0);
  $7 = ($6|0)>(-1);
  $4 = (($$014) + 1)|0;
  if ($7) {
   label = 4;
   break;
  }
  $3 = ($4>>>0)<(100);
  if ($3) {
   $$014 = $4;
  } else {
   $$012 = 0;
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$vararg_buffer3>>2] = $2;
  (___syscall10(10,($vararg_buffer3|0))|0);
  $8 = (___fdopen($6,(gb + (167351) | 0))|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   HEAP32[$vararg_buffer6>>2] = $6;
   (___syscall6(6,($vararg_buffer6|0))|0);
   $$012 = 0;
  } else {
   $$012 = $8;
  }
 }
 STACKTOP = sp;return ($$012|0);
}
function _putwc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_fputwc($0,$1)|0);
 return ($2|0);
}
function _putchar($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161564) | 0)>>2]|0;
 $2 = (_fputc($0,$1)|0);
 return ($2|0);
}
function ___towrite_needs_stdio_exit() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 mftCall_v((fb + (33) | 0)|0);
 return;
}
function _wscanf($0,$varargs) {
 $0 = $0|0;
 $varargs = $varargs|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp;
 HEAP32[$1>>2] = $varargs;
 $2 = (_vwscanf($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function _vwscanf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[(gb + (161432) | 0)>>2]|0;
 $3 = (_vfwscanf($2,$0,$1)|0);
 return ($3|0);
}
function _fgetpos($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (___ftello($0)|0);
 $3 = ($2|0)<(0);
 if ($3) {
  $$0 = -1;
 } else {
  HEAP32[$1>>2] = $2;
  $$0 = 0;
 }
 return ($$0|0);
}
function _sscanf($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 $3 = (_vsscanf($0,$1,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function _funlockfile($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1);
 if ($3) {
  ___unlist_locked_file($0);
  HEAP32[$1>>2] = 0;
  ___unlockfile($0);
 } else {
  $4 = (($2) + -1)|0;
  HEAP32[$1>>2] = $4;
 }
 return;
}
function _setbuffer($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 $4 = $3 ? 2 : 0;
 (_setvbuf($0,$1,$4,$2)|0);
 return;
}
function _fgetws($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$026 = 0, $$02629 = 0, $$02631 = 0, $$02830 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0);
 if ($3) {
  $$0 = $0;
 } else {
  $4 = ((($2)) + 76|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)>(-1);
  if ($6) {
   $7 = (___lockfile($2)|0);
   $18 = $7;
  } else {
   $18 = 0;
  }
  $$02629 = (($1) + -1)|0;
  $8 = ($$02629|0)==(0);
  L6: do {
   if ($8) {
    $$2 = $0;
   } else {
    $$02631 = $$02629;$$02830 = $0;
    while(1) {
     $10 = (___fgetwc_unlocked($2)|0);
     $11 = ($10|0)==(-1);
     $12 = ((($$02830)) + 4|0);
     if ($11) {
      $$2 = $$02830;
      break L6;
     }
     $13 = ($10|0)==(10);
     HEAP32[$$02830>>2] = $10;
     if ($13) {
      $$2 = $12;
      break L6;
     }
     $$026 = (($$02631) + -1)|0;
     $9 = ($$026|0)==(0);
     if ($9) {
      $$2 = $12;
      break;
     } else {
      $$02631 = $$026;$$02830 = $12;
     }
    }
   }
  } while(0);
  HEAP32[$$2>>2] = 0;
  $14 = HEAP32[$2>>2]|0;
  $15 = $14 & 32;
  $16 = ($15|0)==(0);
  $spec$select = $16 ? $$2 : $0;
  $17 = ($18|0)==(0);
  if (!($17)) {
   ___unlockfile($2);
  }
  $19 = ($spec$select|0)==($0|0);
  $20 = $19 ? 0 : $0;
  $$0 = $20;
 }
 return ($$0|0);
}
function _putc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($1)) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)<(0);
 if ($4) {
  label = 3;
 } else {
  $5 = (___lockfile($1)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   label = 3;
  } else {
   $20 = $0&255;
   $21 = $0 & 255;
   $22 = ((($1)) + 75|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23 << 24 >> 24;
   $25 = ($21|0)==($24|0);
   if ($25) {
    label = 10;
   } else {
    $26 = ((($1)) + 20|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($1)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27>>>0)<($29>>>0);
    if ($30) {
     $31 = ((($27)) + 1|0);
     HEAP32[$26>>2] = $31;
     HEAP8[$27>>0] = $20;
     $33 = $21;
    } else {
     label = 10;
    }
   }
   if ((label|0) == 10) {
    $32 = (___overflow($1,$0)|0);
    $33 = $32;
   }
   ___unlockfile($1);
   $$0 = $33;
  }
 }
 do {
  if ((label|0) == 3) {
   $7 = $0&255;
   $8 = $0 & 255;
   $9 = ((($1)) + 75|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 << 24 >> 24;
   $12 = ($8|0)==($11|0);
   if (!($12)) {
    $13 = ((($1)) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($1)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14>>>0)<($16>>>0);
    if ($17) {
     $18 = ((($14)) + 1|0);
     HEAP32[$13>>2] = $18;
     HEAP8[$14>>0] = $7;
     $$0 = $8;
     break;
    }
   }
   $19 = (___overflow($1,$0)|0);
   $$0 = $19;
  }
 } while(0);
 return ($$0|0);
}
function _clearerr($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (___lockfile($0)|0);
  $phitmp = ($4|0)==(0);
  $5 = HEAP32[$0>>2]|0;
  $6 = $5 & -49;
  HEAP32[$0>>2] = $6;
  if (!($phitmp)) {
   ___unlockfile($0);
  }
 } else {
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 & -49;
  HEAP32[$0>>2] = $8;
 }
 return;
}
function _getc_unlocked($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = ((($2)) + 1|0);
  HEAP32[$1>>2] = $6;
  $7 = HEAP8[$2>>0]|0;
  $8 = $7&255;
  $10 = $8;
 } else {
  $9 = (___uflow($0)|0);
  $10 = $9;
 }
 return ($10|0);
}
function _fseek($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___fseeko($0,$1,$2)|0);
 return ($3|0);
}
function _tmpnam($0) {
 $0 = $0|0;
 var $$0 = 0, $$089 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $vararg_buffer = sp + 24|0;
 $1 = sp;
 $2 = sp + 32|0;
 ;HEAP32[$1>>2]=HEAP32[(gb + (153280) | 0)>>2]|0;HEAP32[$1+4>>2]=HEAP32[(gb + (153280) | 0)+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[(gb + (153280) | 0)+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[(gb + (153280) | 0)+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[(gb + (153280) | 0)+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[(gb + (153280) | 0)+18>>0]|0;
 $3 = ((($1)) + 12|0);
 $4 = $1;
 $5 = $2;
 $$089 = 0;
 while(1) {
  (___randname($3)|0);
  dest=$2; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$vararg_buffer>>2] = $4;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $5;
  $8 = (___syscall196(196,($vararg_buffer|0))|0);
  $9 = ($8|0)==(-2);
  $7 = (($$089) + 1)|0;
  if ($9) {
   label = 4;
   break;
  }
  $6 = ($7>>>0)<(100);
  if ($6) {
   $$089 = $7;
  } else {
   $$0 = 0;
   break;
  }
 }
 if ((label|0) == 4) {
  $10 = ($0|0)==(0|0);
  $11 = $10 ? (gb + (170272) | 0) : $0;
  $12 = (_strcpy($11,$1)|0);
  $$0 = $11;
 }
 STACKTOP = sp;return ($$0|0);
}
function _tempnam($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$02932 = 0, $$031 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4192|0);
 $vararg_buffer = sp + 4096|0;
 $2 = sp;
 $3 = sp + 4104|0;
 $4 = ($0|0)==(0|0);
 $spec$select = $4 ? (gb + (167354) | 0) : $0;
 $5 = ($1|0)==(0|0);
 $$031 = $5 ? (gb + (167359) | 0) : $1;
 $6 = (_strlen($spec$select)|0);
 $7 = (_strlen($$031)|0);
 $8 = (($6) + 1)|0;
 $9 = (($8) + ($7))|0;
 $10 = (($9) + 7)|0;
 $11 = ($10>>>0)>(4095);
 L1: do {
  if ($11) {
   $12 = (___errno_location()|0);
   HEAP32[$12>>2] = 36;
   $$0 = 0;
  } else {
   (_memcpy(($2|0),($spec$select|0),($6|0))|0);
   $13 = (($2) + ($6)|0);
   HEAP8[$13>>0] = 47;
   $14 = ((($13)) + 1|0);
   (_memcpy(($14|0),($$031|0),($7|0))|0);
   $15 = (($2) + ($9)|0);
   HEAP8[$15>>0] = 95;
   $16 = (($2) + ($10)|0);
   HEAP8[$16>>0] = 0;
   $17 = ((($16)) + -6|0);
   $18 = $2;
   $19 = $3;
   $$02932 = 0;
   while(1) {
    (___randname($17)|0);
    dest=$3; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$vararg_buffer>>2] = $18;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $19;
    $22 = (___syscall196(196,($vararg_buffer|0))|0);
    $23 = ($22|0)==(-2);
    $21 = (($$02932) + 1)|0;
    if ($23) {
     break;
    }
    $20 = ($21>>>0)<(100);
    if ($20) {
     $$02932 = $21;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $24 = (mftCall_ii((fb + (9) | 0)|0,($2|0))|0);
   $$0 = $24;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _fputws($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1040|0);
 $2 = sp + 1024|0;
 $3 = sp;
 HEAP32[$2>>2] = $0;
 $4 = (___pthread_self_480()|0);
 $5 = ((($4)) + 188|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 76|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(-1);
 if ($9) {
  $10 = (___lockfile($1)|0);
  $22 = $10;
 } else {
  $22 = 0;
 }
 (_fwide($1,1)|0);
 $11 = ((($1)) + 120|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$5>>2] = $12;
 $13 = ($0|0)==(0|0);
 L4: do {
  if ($13) {
   $$1 = 0;
   label = 10;
  } else {
   while(1) {
    $16 = (_wcsrtombs($3,$2,1024,0)|0);
    $17 = (($16) + 1)|0;
    $18 = ($17>>>0)>(1);
    if (!($18)) {
     $$1 = $16;
     label = 10;
     break L4;
    }
    $19 = (___fwritex($3,$16,$1)|0);
    $20 = ($19>>>0)<($16>>>0);
    if ($20) {
     break;
    }
    $14 = HEAP32[$2>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     $$1 = $16;
     label = 10;
     break L4;
    }
   }
   $21 = ($22|0)==(0);
   if ($21) {
    $$0 = -1;
   } else {
    ___unlockfile($1);
    $$0 = -1;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $23 = ($22|0)==(0);
  if ($23) {
   $$0 = $$1;
  } else {
   ___unlockfile($1);
   $$0 = $$1;
  }
 }
 HEAP32[$5>>2] = $6;
 STACKTOP = sp;return ($$0|0);
}
function ___pthread_self_480() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _feof($0) {
 $0 = $0|0;
 var $$lobit = 0, $$lobit8 = 0, $$lobit9 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $6 = (___lockfile($0)|0);
  $phitmp = ($6|0)==(0);
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 >>> 4;
  $$lobit = $8 & 1;
  if ($phitmp) {
   $$lobit9 = $$lobit;
  } else {
   $$lobit9 = $$lobit;
  }
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = $4 >>> 4;
  $$lobit8 = $5 & 1;
  $$lobit9 = $$lobit8;
 }
 return ($$lobit9|0);
}
function _perror($0) {
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[(gb + (161300) | 0)>>2]|0;
 $2 = (___errno_location()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_strerror($3)|0);
 $5 = ((($1)) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = (___lockfile($1)|0);
  $15 = $8;
 } else {
  $15 = 0;
 }
 $9 = ($0|0)==(0|0);
 if (!($9)) {
  $10 = HEAP8[$0>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (_strlen($0)|0);
   (_fwrite($0,$12,1,$1)|0);
   (_fputc(58,$1)|0);
   (_fputc(32,$1)|0);
  }
 }
 $13 = (_strlen($4)|0);
 (_fwrite($4,$13,1,$1)|0);
 (_fputc(10,$1)|0);
 $14 = ($15|0)==(0);
 if (!($14)) {
  ___unlockfile($1);
 }
 return;
}
function _freopen($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $3 = (___fmodeflags($1)|0);
 $4 = ((($2)) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 if ($6) {
  $7 = (___lockfile($2)|0);
  $44 = $7;
 } else {
  $44 = 0;
 }
 (_fflush($2)|0);
 $8 = ($0|0)==(0|0);
 do {
  if ($8) {
   $9 = $3 & 524288;
   $10 = ($9|0)==(0);
   $$pre = ((($2)) + 60|0);
   if (!($10)) {
    $11 = HEAP32[$$pre>>2]|0;
    HEAP32[$vararg_buffer>>2] = $11;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 2;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 1;
    (___syscall221(221,($vararg_buffer|0))|0);
   }
   $12 = $3 & -524481;
   $13 = HEAP32[$$pre>>2]|0;
   HEAP32[$vararg_buffer3>>2] = $13;
   $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
   HEAP32[$vararg_ptr6>>2] = 4;
   $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
   HEAP32[$vararg_ptr7>>2] = $12;
   $14 = (___syscall221(221,($vararg_buffer3|0))|0);
   $15 = (___syscall_ret($14)|0);
   $16 = ($15|0)<(0);
   if ($16) {
    label = 15;
   } else {
    label = 12;
   }
  } else {
   $17 = (_fopen($0,$1)|0);
   $18 = ($17|0)==(0|0);
   if ($18) {
    label = 15;
   } else {
    $19 = ((($17)) + 60|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ((($2)) + 60|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($20|0)==($22|0);
    if ($23) {
     HEAP32[$19>>2] = -1;
    } else {
     $24 = $3 & 524288;
     $25 = (___dup3($20,$22,$24)|0);
     $26 = ($25|0)<(0);
     if ($26) {
      (_fclose($17)|0);
      label = 15;
      break;
     }
    }
    $27 = HEAP32[$2>>2]|0;
    $28 = $27 & 1;
    $29 = HEAP32[$17>>2]|0;
    $30 = $28 | $29;
    HEAP32[$2>>2] = $30;
    $31 = ((($17)) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ((($2)) + 32|0);
    HEAP32[$33>>2] = $32;
    $34 = ((($17)) + 36|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ((($2)) + 36|0);
    HEAP32[$36>>2] = $35;
    $37 = ((($17)) + 40|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ((($2)) + 40|0);
    HEAP32[$39>>2] = $38;
    $40 = ((($17)) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($2)) + 12|0);
    HEAP32[$42>>2] = $41;
    (_fclose($17)|0);
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $43 = ($44|0)==(0);
  if ($43) {
   $$0 = $2;
  } else {
   ___unlockfile($2);
   $$0 = $2;
  }
 }
 else if ((label|0) == 15) {
  (_fclose($2)|0);
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function _c32rtomb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcrtomb($0,$1,$2)|0);
 return ($3|0);
}
function _wcsnrtombs($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$04773 = 0, $$05172 = 0, $$054 = 0, $$148 = 0, $$152 = 0, $$15571 = 0, $$162 = 0, $$174 = 0, $$2 = 0, $$24968 = 0, $$25367 = 0, $$256 = 0, $$350 = 0, $$357 = 0, $$369 = 0, $$466 = 0, $$cast = 0, $$pr$pre = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond70 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(272|0);
 $5 = sp;
 $6 = sp + 256|0;
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$6>>2] = $7;
 $8 = ($0|0)!=(0|0);
 $$054 = $8 ? $3 : 256;
 $$0 = $8 ? $0 : $5;
 $$cast = $7;
 $9 = ($7|0)!=(0);
 $10 = ($$054|0)!=(0);
 $or$cond70 = $10 & $9;
 L1: do {
  if ($or$cond70) {
   $$04773 = 0;$$05172 = $2;$$15571 = $$054;$$174 = $$0;$45 = $$cast;
   while(1) {
    $11 = ($$05172>>>0)>=($$15571>>>0);
    $12 = ($$05172>>>0)>(32);
    $13 = $11 | $12;
    if (!($13)) {
     $$148 = $$04773;$$152 = $$05172;$$162 = $$174;$$357 = $$15571;$25 = $45;
     break L1;
    }
    $spec$select = $11 ? $$15571 : $$05172;
    $14 = (($$05172) - ($spec$select))|0;
    $15 = (_wcsrtombs($$174,$6,$spec$select,0)|0);
    $16 = ($15|0)==(-1);
    if ($16) {
     break;
    }
    $17 = ($$174|0)==($5|0);
    $18 = (($$174) + ($15)|0);
    $19 = $17 ? 0 : $15;
    $$256 = (($$15571) - ($19))|0;
    $$2 = $17 ? $$174 : $18;
    $20 = (($15) + ($$04773))|0;
    $21 = HEAP32[$6>>2]|0;
    $22 = ($21|0)!=(0|0);
    $23 = ($$256|0)!=(0);
    $or$cond = $23 & $22;
    if ($or$cond) {
     $$04773 = $20;$$05172 = $14;$$15571 = $$256;$$174 = $$2;$45 = $21;
    } else {
     $$148 = $20;$$152 = $14;$$162 = $$2;$$357 = $$256;$25 = $21;
     break L1;
    }
   }
   $$pr$pre = HEAP32[$6>>2]|0;
   $$148 = -1;$$152 = $14;$$162 = $$174;$$357 = 0;$25 = $$pr$pre;
  } else {
   $$148 = 0;$$152 = $2;$$162 = $$0;$$357 = $$054;$25 = $$cast;
  }
 } while(0);
 $24 = ($25|0)==(0|0);
 L9: do {
  if ($24) {
   $$350 = $$148;
  } else {
   $26 = ($$357|0)!=(0);
   $27 = ($$152|0)!=(0);
   $28 = $26 & $27;
   if ($28) {
    $$24968 = $$148;$$25367 = $$152;$$369 = $$162;$$466 = $$357;$30 = $25;
    while(1) {
     $29 = HEAP32[$30>>2]|0;
     $31 = (_wcrtomb($$369,$29,0)|0);
     $32 = (($31) + 1)|0;
     $33 = ($32>>>0)<(2);
     if ($33) {
      break;
     }
     $35 = HEAP32[$6>>2]|0;
     $36 = ((($35)) + 4|0);
     HEAP32[$6>>2] = $36;
     $37 = (($$25367) + -1)|0;
     $38 = (($$369) + ($31)|0);
     $39 = (($$466) - ($31))|0;
     $40 = (($31) + ($$24968))|0;
     $41 = ($39|0)!=(0);
     $42 = ($37|0)!=(0);
     $43 = $41 & $42;
     if ($43) {
      $$24968 = $40;$$25367 = $37;$$369 = $38;$$466 = $39;$30 = $36;
     } else {
      $$350 = $40;
      break L9;
     }
    }
    $34 = ($31|0)==(0);
    if ($34) {
     HEAP32[$6>>2] = 0;
     $$350 = $$24968;
    } else {
     $$350 = -1;
    }
   } else {
    $$350 = $$148;
   }
  }
 } while(0);
 if ($8) {
  $44 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $44;
 }
 STACKTOP = sp;return ($$350|0);
}
function _wcstombs($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 HEAP32[$3>>2] = $1;
 $4 = (_wcsrtombs($0,$3,$2,0)|0);
 STACKTOP = sp;return ($4|0);
}
function _mblen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_mbtowc(0,$0,$1)|0);
 return ($2|0);
}
function _c16rtomb($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$018 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 $spec$store$select = $3 ? (gb + (172056) | 0) : $2;
 $4 = ($0|0)==(0|0);
 $5 = HEAP32[$spec$store$select>>2]|0;
 $6 = ($5|0)!=(0);
 do {
  if ($4) {
   if ($6) {
    label = 9;
   } else {
    $$018 = 1;
   }
  } else {
   $7 = $1&65535;
   $8 = $7 & 64512;
   if ($6) {
    $12 = ($8|0)==(56320);
    if (!($12)) {
     label = 9;
     break;
    }
    $13 = (($7) + -56320)|0;
    $14 = (($13) + ($5))|0;
    HEAP32[$spec$store$select>>2] = 0;
    $$0 = $14;
   } else {
    $9 = ($8|0)==(55296);
    if ($9) {
     $10 = $7 << 10;
     $11 = (($10) + -56557568)|0;
     HEAP32[$spec$store$select>>2] = $11;
     $$018 = 0;
     break;
    } else {
     $$0 = $7;
    }
   }
   $15 = (_wcrtomb($0,$$0,0)|0);
   $$018 = $15;
  }
 } while(0);
 if ((label|0) == 9) {
  HEAP32[$spec$store$select>>2] = 0;
  $16 = (___errno_location()|0);
  HEAP32[$16>>2] = 84;
  $$018 = -1;
 }
 return ($$018|0);
}
function _mbrtoc16($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($3|0)==(0|0);
 $spec$store$select = $5 ? (gb + (172060) | 0) : $3;
 $6 = ($1|0)==(0|0);
 do {
  if ($6) {
   $7 = (_mbrtoc16(0,(gb + (172139) | 0),1,$spec$store$select)|0);
   $$0 = $7;
  } else {
   $8 = HEAP32[$spec$store$select>>2]|0;
   $9 = ($8|0)>(0);
   if ($9) {
    $10 = ($0|0)==(0|0);
    if (!($10)) {
     $11 = $8&65535;
     HEAP16[$0>>1] = $11;
    }
    HEAP32[$spec$store$select>>2] = 0;
    $$0 = -3;
    break;
   }
   $12 = (_mbrtowc($4,$1,$2,$spec$store$select)|0);
   $13 = ($12>>>0)<(5);
   if ($13) {
    $14 = HEAP32[$4>>2]|0;
    $15 = ($14|0)>(65535);
    if ($15) {
     $16 = $14 >>> 10;
     $17 = (($16) + 55232)|0;
     $18 = $14 & 1023;
     $19 = $18 | 56320;
     HEAP32[$spec$store$select>>2] = $19;
     HEAP32[$4>>2] = $17;
     $22 = $17;
    } else {
     $22 = $14;
    }
    $20 = ($0|0)==(0|0);
    if (!($20)) {
     $21 = $22&65535;
     HEAP16[$0>>1] = $21;
    }
   }
   $$0 = $12;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _mbrtoc32($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($3|0)==(0|0);
 $spec$store$select = $5 ? (gb + (172064) | 0) : $3;
 $6 = ($1|0)==(0|0);
 if ($6) {
  $7 = (_mbrtoc32(0,(gb + (172139) | 0),1,$spec$store$select)|0);
  $$0 = $7;
 } else {
  $8 = (_mbrtowc($4,$1,$2,$spec$store$select)|0);
  $9 = ($8>>>0)<(5);
  $10 = ($0|0)!=(0|0);
  $or$cond = $10 & $9;
  if ($or$cond) {
   $11 = HEAP32[$4>>2]|0;
   HEAP32[$0>>2] = $11;
  }
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _wctob($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(128);
 if ($1) {
  return ($0|0);
 } else {
  $2 = (___pthread_self_518()|0);
  $3 = ((($2)) + 188|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  $7 = $0 & -128;
  $8 = ($7|0)==(57216);
  $or$cond = $8 & $6;
  $9 = $0 & 255;
  $spec$select = $or$cond ? $9 : -1;
  return ($spec$select|0);
 }
 return (0)|0;
}
function ___pthread_self_518() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _mbrlen($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0|0);
 $4 = $3 ? (gb + (172068) | 0) : $2;
 $5 = (_mbrtowc(0,$0,$1,$4)|0);
 return ($5|0);
}
function _fstatat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $2;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $6 = (___syscall300(300,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _umask($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $1 = (___syscall60(60,($vararg_buffer|0))|0);
 $2 = (___syscall_ret($1)|0);
 STACKTOP = sp;return ($2|0);
}
function ___statfs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 dest=$1; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 64;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $3;
 $4 = (___syscall268(268,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___fstatfs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $1;
 dest=$1; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 64;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $3 = (___syscall269(269,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _statvfs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $2 = sp;
 $3 = (___statfs($0,$2)|0);
 $4 = ($3|0)<(0);
 if ($4) {
  $$0 = -1;
 } else {
  _fixup($1,$2);
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function _fixup($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sroa$3$0$$sroa_idx = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $$sroa$3$0$$sroa_idx = ((($0)) + 4|0);
 $2 = ((($1)) + 4|0);
 $3 = ((($0)) + 36|0);
 dest=$3; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = ((($1)) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 $spec$select = $7 ? $4 : $6;
 HEAP32[$$sroa$3$0$$sroa_idx>>2] = $spec$select;
 $8 = ((($1)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($0)) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($1)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($0)) + 12|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($1)) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($0)) + 16|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($1)) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ((($0)) + 20|0);
 HEAP32[$19>>2] = $18;
 $20 = ((($1)) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($0)) + 24|0);
 HEAP32[$22>>2] = $21;
 $23 = ((($0)) + 28|0);
 HEAP32[$23>>2] = $21;
 $24 = ((($1)) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($0)) + 32|0);
 HEAP32[$26>>2] = $25;
 $27 = ((($1)) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($0)) + 40|0);
 HEAP32[$29>>2] = $28;
 $30 = ((($1)) + 36|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($0)) + 44|0);
 HEAP32[$32>>2] = $31;
 return;
}
function _fstatvfs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $2 = sp;
 $3 = (___fstatfs($0,$2)|0);
 $4 = ($3|0)<(0);
 if ($4) {
  $$0 = -1;
 } else {
  _fixup($1,$2);
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fxstat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_fstat($1,$2)|0);
 return ($3|0);
}
function _fstat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer6 = sp + 48|0;
 $vararg_buffer2 = sp + 40|0;
 $vararg_buffer = sp + 32|0;
 $2 = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall197(197,($vararg_buffer|0))|0);
 $5 = ($4|0)==(-9);
 if ($5) {
  HEAP32[$vararg_buffer2>>2] = $0;
  $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
  HEAP32[$vararg_ptr5>>2] = 1;
  $6 = (___syscall221(221,($vararg_buffer2|0))|0);
  $7 = ($6|0)<(0);
  if ($7) {
   label = 3;
  } else {
   ___procfdname($2,$0);
   $9 = $2;
   HEAP32[$vararg_buffer6>>2] = $9;
   $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $3;
   $10 = (___syscall195(195,($vararg_buffer6|0))|0);
   $11 = (___syscall_ret($10)|0);
   $$0 = $11;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (___syscall_ret($4)|0);
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fxstatat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (_fstatat($1,$2,$3,$4)|0);
 return ($5|0);
}
function ___lxstat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_lstat($1,$2)|0);
 return ($3|0);
}
function _lstat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $4 = (___syscall196(196,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___xstat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_stat($1,$2)|0);
 return ($3|0);
}
function ___xmknod($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_mknod($1,$2,$4)|0);
 return ($5|0);
}
function _mknod($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall14(14,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function ___xmknodat($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_mknodat($1,$2,$3,$5)|0);
 return ($6|0);
}
function _mknodat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $5 = (___syscall297(297,($vararg_buffer|0))|0);
 $6 = (___syscall_ret($5)|0);
 STACKTOP = sp;return ($6|0);
}
function _utimensat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = $1;
 $5 = $2;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $6 = (___syscall320(320,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _fchmodat($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$022 = 0, $$022$sink = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer15 = 0, $vararg_buffer21 = 0, $vararg_buffer26 = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr18 = 0, $vararg_ptr19 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(192|0);
 $vararg_buffer26 = sp + 112|0;
 $vararg_buffer21 = sp + 96|0;
 $vararg_buffer15 = sp + 80|0;
 $vararg_buffer10 = sp + 64|0;
 $vararg_buffer4 = sp + 48|0;
 $vararg_buffer = sp + 32|0;
 $4 = sp + 116|0;
 $5 = sp;
 switch ($3|0) {
 case 0:  {
  $6 = $1;
  HEAP32[$vararg_buffer>>2] = $0;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $6;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $2;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = 0;
  $7 = (___syscall306(306,($vararg_buffer|0))|0);
  $8 = (___syscall_ret($7)|0);
  $$1 = $8;
  break;
 }
 case 256:  {
  $10 = $1;
  $11 = $4;
  HEAP32[$vararg_buffer4>>2] = $0;
  $vararg_ptr7 = ((($vararg_buffer4)) + 4|0);
  HEAP32[$vararg_ptr7>>2] = $10;
  $vararg_ptr8 = ((($vararg_buffer4)) + 8|0);
  HEAP32[$vararg_ptr8>>2] = $11;
  $vararg_ptr9 = ((($vararg_buffer4)) + 12|0);
  HEAP32[$vararg_ptr9>>2] = 256;
  $12 = (___syscall300(300,($vararg_buffer4|0))|0);
  $13 = ($12|0)==(0);
  do {
   if ($13) {
    $14 = ((($4)) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & 61440;
    $17 = ($16|0)==(40960);
    if ($17) {
     $$022$sink = -95;
    } else {
     HEAP32[$vararg_buffer10>>2] = $0;
     $vararg_ptr13 = ((($vararg_buffer10)) + 4|0);
     HEAP32[$vararg_ptr13>>2] = $10;
     $vararg_ptr14 = ((($vararg_buffer10)) + 8|0);
     HEAP32[$vararg_ptr14>>2] = 2752768;
     $18 = (___syscall295(295,($vararg_buffer10|0))|0);
     $19 = ($18|0)<(0);
     if ($19) {
      $20 = ($18|0)==(-40);
      $$ = $20 ? -95 : $18;
      $$022$sink = $$;
      break;
     }
     ___procfdname($5,$18);
     $21 = $5;
     HEAP32[$vararg_buffer15>>2] = -100;
     $vararg_ptr18 = ((($vararg_buffer15)) + 4|0);
     HEAP32[$vararg_ptr18>>2] = $21;
     $vararg_ptr19 = ((($vararg_buffer15)) + 8|0);
     HEAP32[$vararg_ptr19>>2] = $11;
     $vararg_ptr20 = ((($vararg_buffer15)) + 12|0);
     HEAP32[$vararg_ptr20>>2] = 0;
     $22 = (___syscall300(300,($vararg_buffer15|0))|0);
     $23 = ($22|0)==(0);
     if ($23) {
      $24 = HEAP32[$14>>2]|0;
      $25 = $24 & 61440;
      $26 = ($25|0)==(40960);
      if ($26) {
       $$022 = -95;
      } else {
       HEAP32[$vararg_buffer21>>2] = -100;
       $vararg_ptr24 = ((($vararg_buffer21)) + 4|0);
       HEAP32[$vararg_ptr24>>2] = $21;
       $vararg_ptr25 = ((($vararg_buffer21)) + 8|0);
       HEAP32[$vararg_ptr25>>2] = $2;
       $27 = (___syscall306(306,($vararg_buffer21|0))|0);
       $$022 = $27;
      }
     } else {
      $$022 = $22;
     }
     HEAP32[$vararg_buffer26>>2] = $18;
     (___syscall6(6,($vararg_buffer26|0))|0);
     $$022$sink = $$022;
    }
   } else {
    $$022$sink = $12;
   }
  } while(0);
  $28 = (___syscall_ret($$022$sink)|0);
  $$1 = $28;
  break;
 }
 default: {
  $9 = (___syscall_ret(-22)|0);
  $$1 = $9;
 }
 }
 STACKTOP = sp;return ($$1|0);
}
function _mkdirat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall296(296,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _mkfifo($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $1 | 4096;
 $3 = (_mknod($0,$2,0)|0);
 return ($3|0);
}
function _lchmod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_fchmodat(-100,$0,$1,256)|0);
 return ($2|0);
}
function _futimens($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_utimensat($0,0,$1,0)|0);
 return ($2|0);
}
function _chmod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall15(15,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _mkfifoat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $2 | 4096;
 $4 = (_mknodat($0,$1,$3,0)|0);
 return ($4|0);
}
function ___futimesat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01618 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($2|0)!=(0|0);
 L1: do {
  if ($4) {
   $$01618 = 0;
   while(1) {
    $5 = (((($2) + ($$01618<<3)|0)) + 4|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)>(999999);
    if ($7) {
     break;
    }
    $8 = (($2) + ($$01618<<3)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($3) + ($$01618<<3)|0);
    HEAP32[$10>>2] = $9;
    $11 = ($6*1000)|0;
    $12 = (((($3) + ($$01618<<3)|0)) + 4|0);
    HEAP32[$12>>2] = $11;
    $13 = (($$01618) + 1)|0;
    $14 = ($13>>>0)<(2);
    if ($14) {
     $$01618 = 1;
    } else {
     label = 6;
     break L1;
    }
   }
   $15 = (___syscall_ret(-22)|0);
   $$1 = $15;
  } else {
   label = 6;
  }
 } while(0);
 if ((label|0) == 6) {
  $16 = $4 ? $3 : 0;
  $17 = (_utimensat($0,$1,$16,0)|0);
  $$1 = $17;
 }
 STACKTOP = sp;return ($$1|0);
}
function _fchmod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $vararg_buffer6 = sp + 48|0;
 $vararg_buffer2 = sp + 40|0;
 $vararg_buffer = sp + 32|0;
 $2 = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall94(94,($vararg_buffer|0))|0);
 $4 = ($3|0)==(-9);
 if ($4) {
  HEAP32[$vararg_buffer2>>2] = $0;
  $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
  HEAP32[$vararg_ptr5>>2] = 1;
  $5 = (___syscall221(221,($vararg_buffer2|0))|0);
  $6 = ($5|0)<(0);
  if ($6) {
   label = 3;
  } else {
   ___procfdname($2,$0);
   $8 = $2;
   HEAP32[$vararg_buffer6>>2] = $8;
   $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $1;
   $9 = (___syscall15(15,($vararg_buffer6|0))|0);
   $10 = (___syscall_ret($9)|0);
   $$0 = $10;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $7 = (___syscall_ret($3)|0);
  $$0 = $7;
 }
 STACKTOP = sp;return ($$0|0);
}
function _telldir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function _closedir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = (_close($1)|0);
 _free($0);
 return ($2|0);
}
function _readdir_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$017 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___errno_location()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($0)) + 16|0);
 ___lock(($5|0));
 $6 = (___errno_location()|0);
 HEAP32[$6>>2] = 0;
 $7 = (_readdir($0)|0);
 $8 = (___errno_location()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (___errno_location()|0);
  HEAP32[$11>>2] = $4;
  $12 = ($7|0)==(0|0);
  if ($12) {
   $$017 = 0;
  } else {
   $13 = ((($7)) + 8|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = $14&65535;
   (_memcpy(($1|0),($7|0),($15|0))|0);
   $$017 = $1;
  }
  ___unlock(($5|0));
  HEAP32[$2>>2] = $$017;
  $$0 = 0;
 } else {
  ___unlock(($5|0));
  $$0 = $9;
 }
 return ($$0|0);
}
function _readdir($0) {
 $0 = $0|0;
 var $$1 = 0, $$pre = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)<($4|0);
 L1: do {
  if ($5) {
   $$pre = (((($0)) + 24|0) + ($2)|0);
   $$pre$phiZ2D = $$pre;$17 = $2;
   label = 7;
  } else {
   $6 = HEAP32[$0>>2]|0;
   $7 = ((($0)) + 24|0);
   $8 = $7;
   HEAP32[$vararg_buffer>>2] = $6;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $8;
   $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 2048;
   $9 = (___syscall220(220,($vararg_buffer|0))|0);
   $10 = ($9|0)<(1);
   if (!($10)) {
    HEAP32[$3>>2] = $9;
    HEAP32[$1>>2] = 0;
    $$pre$phiZ2D = $7;$17 = 0;
    label = 7;
    break;
   }
   switch ($9|0) {
   case 0: case -2:  {
    $$1 = 0;
    break L1;
    break;
   }
   default: {
   }
   }
   $11 = (0 - ($9))|0;
   $12 = (___errno_location()|0);
   HEAP32[$12>>2] = $11;
   $$1 = 0;
  }
 } while(0);
 if ((label|0) == 7) {
  $13 = ((($$pre$phiZ2D)) + 8|0);
  $14 = HEAP16[$13>>1]|0;
  $15 = $14&65535;
  $16 = (($17) + ($15))|0;
  HEAP32[$1>>2] = $16;
  $18 = ((($$pre$phiZ2D)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($0)) + 4|0);
  HEAP32[$20>>2] = $19;
  $$1 = $$pre$phiZ2D;
 }
 STACKTOP = sp;return ($$1|0);
}
function _seekdir($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 16|0);
 ___lock(($2|0));
 $3 = HEAP32[$0>>2]|0;
 $4 = (_lseek($3,$1,0)|0);
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($0)) + 8|0);
 HEAP32[$7>>2] = 0;
 ___unlock(($2|0));
 return;
}
function _dirfd($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 return ($1|0);
}
function _fdopendir($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 $2 = (_fstat($0,$1)|0);
 $3 = ($2|0)<(0);
 do {
  if ($3) {
   $$0 = 0;
  } else {
   $4 = ((($1)) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 & 61440;
   $7 = ($6|0)==(16384);
   if (!($7)) {
    $8 = (___errno_location()|0);
    HEAP32[$8>>2] = 20;
    $$0 = 0;
    break;
   }
   $9 = (_calloc(1,2072)|0);
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0 = 0;
   } else {
    HEAP32[$vararg_buffer>>2] = 1;
    (_fcntl($0,2,$vararg_buffer)|0);
    HEAP32[$9>>2] = $0;
    $$0 = $9;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _versionsort($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 11|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 11|0);
 $6 = (_strverscmp($3,$5)|0);
 return ($6|0);
}
function _strverscmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$053$lcssa = 0, $$05377 = 0, $$05674 = 0, $$057$lcssa = 0, $$05776 = 0, $$060$lcssa = 0, $$06075 = 0, $$2 = 0, $$255$ph = 0, $$259$ph = 0, $$lcssa = 0, $$lcssa65 = 0, $$lcssa67 = 0, $$lcssa69 = 0, $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = $2&255;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($2<<24>>24)==($4<<24>>24);
 L1: do {
  if ($5) {
   $$05377 = 1;$$05776 = 0;$$06075 = 0;$7 = $2;$8 = $3;
   while(1) {
    $6 = ($7<<24>>24)==(0);
    if ($6) {
     $$2 = 0;
     break L1;
    }
    $9 = (_isdigit($8)|0);
    $10 = ($9|0)==(0);
    $11 = ($7<<24>>24)==(48);
    $spec$select = $11 ? $$05377 : 0;
    $12 = (($$06075) + 1)|0;
    $$259$ph = $10 ? $12 : $$05776;
    $$255$ph = $10 ? 1 : $spec$select;
    $13 = (($0) + ($12)|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14&255;
    $16 = (($1) + ($12)|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($14<<24>>24)==($17<<24>>24);
    if ($18) {
     $$05377 = $$255$ph;$$05776 = $$259$ph;$$06075 = $12;$7 = $14;$8 = $15;
    } else {
     break;
    }
   }
   $19 = (($0) + ($12)|0);
   $20 = (($1) + ($12)|0);
   $$phi$trans$insert = (($0) + ($$259$ph)|0);
   $$pre = HEAP8[$$phi$trans$insert>>0]|0;
   $$053$lcssa = $$255$ph;$$057$lcssa = $$259$ph;$$060$lcssa = $12;$$lcssa65 = $20;$$lcssa67 = $15;$$lcssa69 = $19;$22 = $$pre;$27 = $14;
   label = 6;
  } else {
   $$053$lcssa = 1;$$057$lcssa = 0;$$060$lcssa = 0;$$lcssa65 = $1;$$lcssa67 = $3;$$lcssa69 = $0;$22 = $2;$27 = $2;
   label = 6;
  }
 } while(0);
 L7: do {
  if ((label|0) == 6) {
   $21 = ($22<<24>>24)==(48);
   if ($21) {
    label = 13;
   } else {
    $23 = (($1) + ($$057$lcssa)|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==(48);
    if ($25) {
     label = 13;
    } else {
     $26 = $27&255;
     $28 = (_isdigit($26)|0);
     $29 = ($28|0)==(0);
     $30 = (($1) + ($$060$lcssa)|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = $31&255;
     $33 = (_isdigit($32)|0);
     $34 = ($33|0)!=(0);
     if ($29) {
      $$lcssa = $34;
     } else {
      $$05674 = $$060$lcssa;$66 = $34;
      while(1) {
       $36 = (($$05674) + 1)|0;
       if (!($66)) {
        $$2 = 1;
        break L7;
       }
       $35 = (($0) + ($36)|0);
       $37 = HEAP8[$35>>0]|0;
       $38 = $37&255;
       $39 = (_isdigit($38)|0);
       $40 = ($39|0)==(0);
       $41 = (($1) + ($36)|0);
       $42 = HEAP8[$41>>0]|0;
       $43 = $42&255;
       $44 = (_isdigit($43)|0);
       $45 = ($44|0)!=(0);
       if ($40) {
        $$lcssa = $45;
        break;
       } else {
        $$05674 = $36;$66 = $45;
       }
      }
     }
     if ($$lcssa) {
      $$2 = -1;
      break;
     }
    }
   }
   do {
    if ((label|0) == 13) {
     $46 = ($$053$lcssa|0)!=(0);
     $47 = ($$057$lcssa>>>0)<($$060$lcssa>>>0);
     $or$cond = $47 & $46;
     if ($or$cond) {
      $48 = (_isdigit($$lcssa67)|0);
      $49 = ($48|0)==(0);
      if ($49) {
       $50 = HEAP8[$$lcssa65>>0]|0;
       $51 = $50&255;
       $52 = (_isdigit($51)|0);
       $53 = ($52|0)==(0);
       if ($53) {
        break;
       }
      }
      $54 = HEAP8[$$lcssa69>>0]|0;
      $55 = (($54) + -48)<<24>>24;
      $56 = $55&255;
      $57 = HEAP8[$$lcssa65>>0]|0;
      $58 = (($57) + -48)<<24>>24;
      $59 = $58&255;
      $60 = (($56) - ($59))|0;
      $$2 = $60;
      break L7;
     }
    }
   } while(0);
   $61 = HEAP8[$$lcssa69>>0]|0;
   $62 = $61&255;
   $63 = HEAP8[$$lcssa65>>0]|0;
   $64 = $63&255;
   $65 = (($62) - ($64))|0;
   $$2 = $65;
  }
 } while(0);
 return ($$2|0);
}
function _opendir($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $1 = (_open($0,589824,$vararg_buffer)|0);
 $2 = ($1|0)<(0);
 do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (_calloc(1,2072)|0);
   $4 = ($3|0)==(0|0);
   if ($4) {
    HEAP32[$vararg_buffer1>>2] = $1;
    (___syscall6(6,($vararg_buffer1|0))|0);
    $$0 = 0;
    break;
   } else {
    HEAP32[$3>>2] = $1;
    $$0 = $3;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function ___getdents($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $4 = (___syscall220(220,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 STACKTOP = sp;return ($5|0);
}
function _alphasort($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ((($2)) + 11|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 11|0);
 $6 = (_strcoll($3,$5)|0);
 return ($6|0);
}
function _scandir($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$050$ph80 = 0, $$051$ph63 = 0, $$051$ph79 = 0, $$053$ph78 = 0, $$1 = 0, $$154 = 0, $$2 = 0, $$in = 0, $$lcssa = 0, $$ph5576 = 0, $$ph5677 = 0, $$ph75 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_opendir($0)|0);
 $5 = (___errno_location()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==(0|0);
 do {
  if ($7) {
   $$0 = -1;
  } else {
   $8 = (___errno_location()|0);
   HEAP32[$8>>2] = 0;
   $9 = (_readdir($4)|0);
   $10 = ($9|0)==(0|0);
   L3: do {
    if ($10) {
     $$051$ph63 = 0;$$2 = 0;$46 = 0;$49 = 0;
    } else {
     $11 = ($2|0)==(0|0);
     $$050$ph80 = 0;$$051$ph79 = 0;$$053$ph78 = 0;$$ph5576 = 0;$$ph5677 = 0;$$ph75 = 0;$50 = $9;
     while(1) {
      $15 = $50;
      while(1) {
       if ($11) {
        $$lcssa = $50;
        break;
       }
       $16 = (mftCall_ii($2|0,($15|0))|0);
       $17 = ($16|0)==(0);
       if (!($17)) {
        $$lcssa = $15;
        break;
       }
       $12 = (___errno_location()|0);
       HEAP32[$12>>2] = 0;
       $13 = (_readdir($4)|0);
       $14 = ($13|0)==(0|0);
       if ($14) {
        $$051$ph63 = $$051$ph79;$$2 = $$053$ph78;$46 = $$ph5576;$49 = $$ph75;
        break L3;
       } else {
        $15 = $13;
       }
      }
      $18 = ($$051$ph79>>>0)<($$050$ph80>>>0);
      if ($18) {
       $$1 = $$050$ph80;$$154 = $$053$ph78;$51 = $$ph75;$52 = $$ph5576;$53 = $$ph5677;
      } else {
       $19 = $$050$ph80 << 1;
       $20 = $19 | 1;
       $21 = ($20>>>0)>(1073741823);
       if ($21) {
        $$051$ph63 = $$051$ph79;$$2 = $$053$ph78;$46 = $$ph5576;$49 = $$ph75;
        break L3;
       }
       $22 = $20 << 2;
       $23 = (_realloc($$ph5677,$22)|0);
       $24 = ($23|0)==(0|0);
       if ($24) {
        $$051$ph63 = $$051$ph79;$$2 = $$053$ph78;$46 = $$ph5576;$49 = $$ph75;
        break L3;
       }
       $$1 = $20;$$154 = $23;$51 = $23;$52 = $23;$53 = $23;
      }
      $25 = ((($$lcssa)) + 8|0);
      $26 = HEAP16[$25>>1]|0;
      $27 = $26&65535;
      $28 = (_malloc($27)|0);
      $29 = (($$154) + ($$051$ph79<<2)|0);
      HEAP32[$29>>2] = $28;
      $30 = ($28|0)==(0|0);
      if ($30) {
       $$051$ph63 = $$051$ph79;$$2 = $$154;$46 = $52;$49 = $51;
       break L3;
      }
      $31 = (($$051$ph79) + 1)|0;
      $32 = HEAP16[$25>>1]|0;
      $33 = $32&65535;
      (_memcpy(($28|0),($$lcssa|0),($33|0))|0);
      $34 = (___errno_location()|0);
      HEAP32[$34>>2] = 0;
      $35 = (_readdir($4)|0);
      $36 = ($35|0)==(0|0);
      if ($36) {
       $$051$ph63 = $31;$$2 = $$154;$46 = $52;$49 = $51;
       break;
      } else {
       $$050$ph80 = $$1;$$051$ph79 = $31;$$053$ph78 = $$154;$$ph5576 = $52;$$ph5677 = $53;$$ph75 = $51;$50 = $35;
      }
     }
    }
   } while(0);
   (_closedir($4)|0);
   $37 = (___errno_location()|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    $47 = (___errno_location()|0);
    HEAP32[$47>>2] = $6;
    $48 = ($3|0)==(0|0);
    if (!($48)) {
     _qsort($49,$$051$ph63,4,$3);
    }
    HEAP32[$1>>2] = $49;
    $$0 = $$051$ph63;
    break;
   }
   $40 = ($$2|0)==(0|0);
   $41 = ($$051$ph63|0)==(0);
   $or$cond = $40 | $41;
   if (!($or$cond)) {
    $$in = $$051$ph63;
    while(1) {
     $42 = (($$in) + -1)|0;
     $43 = (($$2) + ($42<<2)|0);
     $44 = HEAP32[$43>>2]|0;
     _free($44);
     $45 = ($42|0)==(0);
     if ($45) {
      break;
     } else {
      $$in = $42;
     }
    }
   }
   _free($46);
   $$0 = -1;
  }
 } while(0);
 return ($$0|0);
}
function _rewinddir($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 ___lock(($1|0));
 $2 = HEAP32[$0>>2]|0;
 (_lseek($2,0,0)|0);
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = 0;
 ___unlock(($1|0));
 return;
}
function _glob($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$07687108109 = 0, $$07687108110 = 0, $$08195 = 0, $$083 = 0, $$08499 = 0, $$1 = 0, $$178 = 0, $$18090 = 0, $$182 = 0, $$185 = 0, $$cast = 0, $$in = 0, $$in94 = 0, $$pr = 0, $$pre = 0, $$pre$phi107111Z2D = 0, $$pre$phi107112Z2D = 0, $$pre102 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = sp + 8|0;
 $6 = $4;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 HEAP32[$5>>2] = $4;
 $10 = $1 & 8;
 $11 = ($10|0)==(0);
 if ($11) {
  $24 = 0;
 } else {
  $12 = ((($3)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $24 = $13;
 }
 $14 = HEAP8[$0>>0]|0;
 $15 = ($14<<24>>24)==(47);
 if ($15) {
  $$08499 = $0;
  while(1) {
   $16 = ((($$08499)) + 1|0);
   $$pr = HEAP8[$16>>0]|0;
   $17 = ($$pr<<24>>24)==(47);
   if ($17) {
    $$08499 = $16;
   } else {
    $$083 = (gb + (167705) | 0);$$185 = $16;$75 = $$pr;
    break;
   }
  }
 } else {
  $$083 = (gb + (172139) | 0);$$185 = $0;$75 = $14;
 }
 $18 = (_strlen($$185)|0);
 $19 = ($18>>>0)>(4096);
 L9: do {
  if ($19) {
   $$1 = 1;
  } else {
   $20 = ($2|0)==(0|0);
   $spec$select = $20 ? (fb + (35) | 0) : $2;
   $21 = $1 & 32;
   $22 = ($21|0)!=(0);
   if ($22) {
    $27 = $75;
   } else {
    $23 = ((($3)) + 8|0);
    HEAP32[$23>>2] = $24;
    HEAP32[$3>>2] = 0;
    $25 = ((($3)) + 4|0);
    HEAP32[$25>>2] = 0;
    $$pre = HEAP8[$$185>>0]|0;
    $27 = $$pre;
   }
   $26 = ($27<<24>>24)==(0);
   if ($26) {
    HEAP32[$5>>2] = 0;
    $$07687108110 = 0;$$pre$phi107112Z2D = $4;$76 = $5;
    label = 17;
   } else {
    $28 = (_match_in_dir($$083,$$185,$1,$spec$select,$5)|0);
    $29 = ($28|0)==(1);
    if ($29) {
     _freelist($4);
     $$1 = 1;
     break;
    }
    $$pre102 = HEAP32[$4>>2]|0;
    HEAP32[$5>>2] = $$pre102;
    $30 = ($$pre102|0)==(0);
    if ($30) {
     $$07687108110 = $28;$$pre$phi107112Z2D = $4;$76 = $5;
     label = 17;
    } else {
     $$08195 = 0;$$in94 = $$pre102;
     while(1) {
      $31 = $$in94;
      $32 = HEAP32[$31>>2]|0;
      HEAP32[$5>>2] = $32;
      $33 = (($$08195) + 1)|0;
      $34 = ($32|0)==(0);
      if ($34) {
       break;
      } else {
       $$08195 = $33;$$in94 = $32;
      }
     }
     $35 = ($33|0)==(0);
     if ($35) {
      $$07687108110 = $28;$$pre$phi107112Z2D = $4;$76 = $5;
      label = 17;
     } else {
      $$07687108109 = $28;$$182 = $33;$$pre$phi107111Z2D = $4;$59 = $5;
     }
    }
   }
   if ((label|0) == 17) {
    $36 = $1 & 16;
    $37 = ($36|0)==(0);
    if ($37) {
     $$1 = 3;
     break;
    }
    HEAP32[$5>>2] = $4;
    $38 = (_strlen($0)|0);
    $39 = (_append($5,$0,$38,0)|0);
    $40 = ($39|0)==(0);
    if ($40) {
     $$07687108109 = $$07687108110;$$182 = 1;$$pre$phi107111Z2D = $$pre$phi107112Z2D;$59 = $76;
    } else {
     $$1 = 1;
     break;
    }
   }
   do {
    if ($22) {
     $41 = ((($3)) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = HEAP32[$3>>2]|0;
     $44 = (($43) + ($24))|0;
     $45 = (($44) + ($$182))|0;
     $46 = $45 << 2;
     $47 = (($46) + 4)|0;
     $48 = (_realloc($42,$47)|0);
     $49 = ($48|0)==(0|0);
     if ($49) {
      _freelist($4);
      $$1 = 1;
      break L9;
     } else {
      HEAP32[$41>>2] = $48;
      $$178 = $44;$64 = $48;
      break;
     }
    } else {
     $50 = (($$182) + ($24))|0;
     $51 = $50 << 2;
     $52 = (($51) + 4)|0;
     $53 = (_malloc($52)|0);
     $54 = ((($3)) + 4|0);
     HEAP32[$54>>2] = $53;
     $55 = ($53|0)==(0|0);
     if ($55) {
      _freelist($4);
      $$1 = 1;
      break L9;
     }
     $56 = ($24|0)==(0);
     if ($56) {
      $$178 = 0;$64 = $53;
     } else {
      $57 = $24 << 2;
      _memset(($53|0),0,($57|0))|0;
      $$178 = $24;$64 = $53;
     }
    }
   } while(0);
   $58 = HEAP32[$$pre$phi107111Z2D>>2]|0;
   HEAP32[$59>>2] = $58;
   $$18090 = 0;$$in = $58;
   while(1) {
    $60 = $$in;
    $61 = ((($60)) + 4|0);
    $62 = (($$18090) + ($$178))|0;
    $63 = (($64) + ($62<<2)|0);
    HEAP32[$63>>2] = $61;
    $$cast = $$in;
    $65 = HEAP32[$$cast>>2]|0;
    HEAP32[$59>>2] = $65;
    $66 = (($$18090) + 1)|0;
    $67 = ($66>>>0)<($$182>>>0);
    if ($67) {
     $$18090 = $66;$$in = $65;
    } else {
     break;
    }
   }
   $68 = (($$182) + ($$178))|0;
   $69 = (($64) + ($68<<2)|0);
   HEAP32[$69>>2] = 0;
   $70 = HEAP32[$3>>2]|0;
   $71 = (($70) + ($$182))|0;
   HEAP32[$3>>2] = $71;
   $72 = $1 & 4;
   $73 = ($72|0)==(0);
   if ($73) {
    $74 = (($64) + ($$178<<2)|0);
    _qsort($74,$$182,4,(fb + (36) | 0));
    $$1 = $$07687108109;
   } else {
    $$1 = $$07687108109;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _ignore_err($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _match_in_dir($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$0 = 0, $$0$shrunk = 0, $$0100 = 0, $$0102 = 0, $$094 = 0, $$099 = 0, $$1101 = 0, $$4 = 0, $$5 = 0, $$alloca_mul = 0, $$alloca_mul5 = 0, $$lcssa = 0, $$lcssa112 = 0, $$lobit = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $not$ = 0, $not$114 = 0, $spec$select = 0, $spec$select106 = 0, $switch$split2D = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(432|0);
 $5 = sp + 156|0;
 $6 = sp + 152|0;
 $7 = sp + 76|0;
 $8 = sp;
 $9 = (_strlen($1)|0);
 $10 = (($9) + 1)|0;
 $11 = (_llvm_stacksave()|0);
 $$alloca_mul = $10;
 $12 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul)|0)+15)&-16)|0);;
 $13 = (_strlen($0)|0);
 $14 = $2 & 64;
 $15 = $14 >>> 5;
 $16 = $2 >>> 5;
 $17 = $16 & 4;
 $18 = $17 | $15;
 $19 = $18 ^ 4;
 $20 = (_strchr($1,47)|0);
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$099 = $1;$$1101 = 0;
 } else {
  (_strcpy($12,$1)|0);
  $22 = $20;
  $23 = $1;
  $24 = (($22) - ($23))|0;
  $25 = (($12) + ($24)|0);
  HEAP8[$25>>0] = 0;
  $$0100 = $20;
  while(1) {
   $26 = HEAP8[$$0100>>0]|0;
   $27 = ($26<<24>>24)==(47);
   $28 = ((($$0100)) + 1|0);
   if ($27) {
    $$0100 = $28;
   } else {
    $$099 = $12;$$1101 = $$0100;
    break;
   }
  }
 }
 $$lobit = $14 >>> 6;
 $29 = $$lobit ^ 1;
 $30 = (_is_literal($$099,$29)|0);
 $31 = HEAP8[$0>>0]|0;
 $32 = ($31<<24>>24)==(47);
 if ($32) {
  $33 = ((($0)) + 1|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)==(0);
  $spec$select = $35 ? 0 : $13;
  $$0102 = $spec$select;
 } else {
  $$0102 = $13;
 }
 $36 = ($31<<24>>24)==(0);
 $37 = $36 ? (gb + (167711) | 0) : $0;
 $38 = (_opendir($37)|0);
 $39 = (___errno_location()|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($38|0)==(0|0);
 L9: do {
  if ($41) {
   switch ($40|0) {
   case 20:  {
    $$5 = 0;
    break L9;
    break;
   }
   case 13:  {
    $42 = HEAP8[$$099>>0]|0;
    $43 = ($42<<24>>24)==(0);
    if ($43) {
     $44 = (_stat($0,$7)|0);
     $45 = ($44|0)==(0);
     if ($45) {
      $46 = ((($7)) + 12|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = $47 & 61440;
      $49 = ($48|0)==(16384);
      if ($49) {
       $50 = (_append($4,$0,$$0102,$$0102)|0);
       $51 = ($50|0)!=(0);
       $$ = $51&1;
       $$5 = $$;
       break L9;
      }
     }
    }
    break;
   }
   default: {
   }
   }
   $52 = (mftCall_iii($3|0,($0|0),($40|0))|0);
   $53 = $2 & 1;
   $54 = $52 | $53;
   $55 = ($54|0)==(0);
   $spec$select106 = $55 ? 0 : 2;
   $$5 = $spec$select106;
  } else {
   $56 = HEAP8[$$099>>0]|0;
   $57 = ($56<<24>>24)==(0);
   if ($57) {
    $58 = (_append($4,$0,$$0102,$$0102)|0);
    $59 = ($58|0)!=(0);
    $60 = $59&1;
    (_closedir($38)|0);
    $$5 = $60;
    break;
   }
   $61 = (_readdir_r($38,$5,$6)|0);
   $62 = ($61|0)!=(0);
   $63 = HEAP32[$6>>2]|0;
   $64 = ($63|0)!=(0|0);
   $not$114 = $62 ^ 1;
   $65 = $64 & $not$114;
   L23: do {
    if ($65) {
     $66 = (($$0102) + 2)|0;
     $67 = ($30|0)==(0);
     $68 = ($$1101|0)!=(0|0);
     $69 = $2 & 2;
     $70 = ($69|0)==(0);
     $71 = (($$0102) + 1)|0;
     $72 = ((($8)) + 12|0);
     $74 = $63;
     L25: while(1) {
      $73 = ((($74)) + 8|0);
      $75 = HEAP16[$73>>1]|0;
      $76 = $75&65535;
      $77 = (($66) + ($76))|0;
      $78 = (_llvm_stacksave()|0);
      $$alloca_mul5 = $77;
      $79 = STACKTOP; STACKTOP = STACKTOP + ((((1*$$alloca_mul5)|0)+15)&-16)|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(((((1*$$alloca_mul5)|0)+15)&-16)|0);;
      $80 = HEAP32[$6>>2]|0;
      $81 = ((($80)) + 11|0);
      if ($67) {
       $82 = (_fnmatch($$099,$81,$19)|0);
       $83 = ($82|0)==(0);
       if ($83) {
        label = 21;
       }
      } else {
       $84 = (_strcmp($$099,$81)|0);
       $85 = ($84|0)==(0);
       if ($85) {
        label = 21;
       }
      }
      L30: do {
       if ((label|0) == 21) {
        label = 0;
        L32: do {
         if ($68) {
          $86 = HEAP32[$6>>2]|0;
          $87 = ((($86)) + 10|0);
          $88 = HEAP8[$87>>0]|0;
          $89 = ($88<<24>>24)==(0);
          if (!($89)) {
           $90 = $88&255;
           $91 = $90 << 12;
           $trunc = $91&65535;
           $switch$split2D = ($trunc<<16>>16)<(16384);
           if ($switch$split2D) {
            switch ($trunc<<16>>16) {
            case -24576:  {
             break L32;
             break;
            }
            default: {
             break L30;
            }
            }
           } else {
            switch ($trunc<<16>>16) {
            case 16384:  {
             break L32;
             break;
            }
            default: {
             break L30;
            }
            }
           }
          }
         }
        } while(0);
        $92 = HEAP8[$0>>0]|0;
        $93 = ($92<<24>>24)==(0);
        if ($93) {
         $98 = HEAP32[$6>>2]|0;
         $99 = ((($98)) + 11|0);
         $$094 = $99;
        } else {
         (_memcpy(($79|0),($0|0),($$0102|0))|0);
         $94 = (($79) + ($$0102)|0);
         HEAP8[$94>>0] = 47;
         $95 = ((($94)) + 1|0);
         $96 = HEAP32[$6>>2]|0;
         $97 = ((($96)) + 11|0);
         (_strcpy($95,$97)|0);
         $$094 = $79;
        }
        if ($68) {
         $100 = (_match_in_dir($$094,$$1101,$2,$3,$4)|0);
         $101 = ($100|0)==(0);
         if ($101) {
          break;
         } else {
          label = 29;
          break L25;
         }
        }
        do {
         if ($70) {
          $$0$shrunk = 0;
         } else {
          $102 = HEAP32[$6>>2]|0;
          $103 = ((($102)) + 10|0);
          $104 = HEAP8[$103>>0]|0;
          $105 = ($104<<24>>24)==(0);
          if (!($105)) {
           $106 = $104&255;
           $107 = $106 << 12;
           $108 = $107 & 61440;
           $109 = ($108|0)==(40960);
           if (!($109)) {
            $110 = ($108|0)==(16384);
            $$0$shrunk = $110;
            break;
           }
          }
          (_stat($$094,$8)|0);
          $111 = HEAP32[$72>>2]|0;
          $112 = $111 & 61440;
          $113 = ($112|0)==(16384);
          $$0$shrunk = $113;
         }
        } while(0);
        $$0 = $$0$shrunk&1;
        $114 = HEAP32[$6>>2]|0;
        $115 = ((($114)) + 8|0);
        $116 = HEAP16[$115>>1]|0;
        $117 = $116&65535;
        $118 = (($71) + ($117))|0;
        $119 = (_append($4,$$094,$118,$$0)|0);
        $120 = ($119|0)==(0);
        if (!($120)) {
         label = 36;
         break L25;
        }
       }
      } while(0);
      _llvm_stackrestore(($78|0));
      $121 = (_readdir_r($38,$5,$6)|0);
      $122 = ($121|0)!=(0);
      $123 = HEAP32[$6>>2]|0;
      $124 = ($123|0)!=(0|0);
      $not$ = $122 ^ 1;
      $125 = $124 & $not$;
      if ($125) {
       $74 = $123;
      } else {
       $$lcssa = $122;$$lcssa112 = $121;
       break L23;
      }
     }
     if ((label|0) == 29) {
      (_closedir($38)|0);
      $$4 = $100;
     }
     else if ((label|0) == 36) {
      (_closedir($38)|0);
      $$4 = 1;
     }
     _llvm_stackrestore(($78|0));
     $$5 = $$4;
     break L9;
    } else {
     $$lcssa = $62;$$lcssa112 = $61;
    }
   } while(0);
   (_closedir($38)|0);
   if ($$lcssa) {
    $126 = (mftCall_iii($3|0,($0|0),($$lcssa112|0))|0);
    $127 = $2 & 1;
    $128 = $126 | $127;
    $129 = ($128|0)==(0);
    if (!($129)) {
     $$5 = 2;
     break;
    }
   }
   $$5 = 0;
  }
 } while(0);
 _llvm_stackrestore(($11|0));
 STACKTOP = sp;return ($$5|0);
}
function _freelist($0) {
 $0 = $0|0;
 var $$in89 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$in89 = $1;
  while(1) {
   $3 = HEAP32[$$in89>>2]|0;
   _free($$in89);
   $4 = ($3|0)==(0|0);
   if ($4) {
    break;
   } else {
    $$in89 = $3;
   }
  }
 }
 return;
}
function _append($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($2) + 9)|0;
 $5 = (_malloc($4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = -1;
 } else {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$7>>2] = $5;
  HEAP32[$5>>2] = 0;
  $8 = ((($5)) + 4|0);
  (_strcpy($8,$1)|0);
  $9 = ($3|0)==(0);
  if (!($9)) {
   (_strcat($8,(gb + (167705) | 0))|0);
  }
  HEAP32[$0>>2] = $5;
  $$0 = 0;
 }
 return ($$0|0);
}
function _sort($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = (_strcmp($2,$3)|0);
 return ($4|0);
}
function _strcat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($0)|0);
 $3 = (($0) + ($2)|0);
 (_strcpy($3,$1)|0);
 return ($0|0);
}
function _is_literal($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$06 = 0, $$078 = 0, $$09 = 0, $$1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   $$06 = 1;
  } else {
   $4 = ($1|0)==(0);
   $$078 = $0;$$09 = 0;$6 = $2;
   while(1) {
    $5 = $6 << 24 >> 24;
    switch ($5|0) {
    case 42: case 63:  {
     $$06 = 0;
     break L1;
     break;
    }
    case 92:  {
     if ($4) {
      $$1 = $$09;
     } else {
      $$06 = 0;
      break L1;
     }
     break;
    }
    case 91:  {
     $$1 = 1;
     break;
    }
    case 93:  {
     $7 = ($$09|0)==(0);
     if ($7) {
      $$1 = 0;
     } else {
      $$06 = 0;
      break L1;
     }
     break;
    }
    default: {
     $$1 = $$09;
    }
    }
    $8 = ((($$078)) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $$06 = 1;
     break L1;
    } else {
     $$078 = $8;$$09 = $$1;$6 = $9;
    }
   }
  }
 } while(0);
 return ($$06|0);
}
function _fnmatch($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$042 = 0, $$043 = 0, $$044 = 0, $$045 = 0, $$1 = 0, $$mux$le = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $brmerge = 0, $or$cond = 0, $or$cond54 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = $2 & 1;
 $5 = ($4|0)==(0);
 $6 = $2 & 8;
 $7 = ($6|0)==(0);
 L1: do {
  if ($5) {
   L3: do {
    if (!($7)) {
     $29 = $1;
     $$1 = $1;
     while(1) {
      $30 = HEAP8[$$1>>0]|0;
      switch ($30<<24>>24) {
      case 0:  {
       break L3;
       break;
      }
      case 47:  {
       $31 = $$1;
       $32 = (($31) - ($29))|0;
       $33 = (_fnmatch_internal($0,-1,$1,$32,$2)|0);
       $34 = ($33|0)==(0);
       if ($34) {
        $$0 = 0;
        break L1;
       }
       break;
      }
      default: {
      }
      }
      $35 = ((($$1)) + 1|0);
      $$1 = $35;
     }
    }
   } while(0);
   $36 = (_fnmatch_internal($0,-1,$1,-1,$2)|0);
   $$0 = $36;
  } else {
   $$044 = $0;$$045 = $1;
   while(1) {
    $$043 = $$045;
    L14: while(1) {
     $8 = HEAP8[$$043>>0]|0;
     switch ($8<<24>>24) {
     case 47: case 0:  {
      break L14;
      break;
     }
     default: {
     }
     }
     $9 = ((($$043)) + 1|0);
     $$043 = $9;
    }
    $$042 = $$044;
    L18: while(1) {
     $10 = (_pat_next($$042,-1,$3,$2)|0);
     switch ($10|0) {
     case 0: case 47:  {
      break L18;
      break;
     }
     default: {
     }
     }
     $11 = HEAP32[$3>>2]|0;
     $12 = (($$042) + ($11)|0);
     $$042 = $12;
    }
    $13 = HEAP8[$$043>>0]|0;
    $14 = $13 << 24 >> 24;
    $15 = ($10|0)!=($14|0);
    $16 = ($13<<24>>24)==(0);
    $or$cond = $7 | $16;
    $or$cond54 = $15 & $or$cond;
    if ($or$cond54) {
     $$0 = 1;
     break L1;
    }
    $17 = ($10|0)==(0);
    $18 = $$042;
    $19 = $$044;
    $20 = (($18) - ($19))|0;
    $21 = $$043;
    $22 = $$045;
    $23 = (($21) - ($22))|0;
    $24 = (_fnmatch_internal($$044,$20,$$045,$23,$2)|0);
    $25 = ($24|0)!=(0);
    $brmerge = $17 | $25;
    if ($brmerge) {
     break;
    }
    $26 = ((($$043)) + 1|0);
    $27 = HEAP32[$3>>2]|0;
    $28 = (($$042) + ($27)|0);
    $$044 = $28;$$045 = $26;
   }
   $$mux$le = $25&1;
   $$0 = $$mux$le;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _pat_next($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$089 = 0, $$090 = 0, $$094 = 0, $$1 = 0, $$191 = 0, $$2 = 0, $$292109 = 0, $$3 = 0, $$4$lcssa = 0, $$4104 = 0, $$6 = 0, $$pr$pre = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond96 = 0, $spec$select = 0;
 var $spec$select102 = 0, $spec$select103 = 0, $spec$select97 = 0, $spec$select98 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp;
 $5 = ($1|0)==(0);
 L1: do {
  if ($5) {
   label = 3;
  } else {
   $6 = HEAP8[$0>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 3;
   } else {
    HEAP32[$2>>2] = 1;
    $8 = HEAP8[$0>>0]|0;
    switch ($8<<24>>24) {
    case 42:  {
     $$2 = -5;
     break L1;
     break;
    }
    case 92:  {
     $9 = ((($0)) + 1|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = ($10<<24>>24)!=(0);
     $12 = $3 & 2;
     $13 = ($12|0)==(0);
     $or$cond = $13 & $11;
     if ($or$cond) {
      HEAP32[$2>>2] = 2;
      $$pr$pre = HEAP8[$9>>0]|0;
      $$089 = $9;$$094 = 1;$59 = $$pr$pre;
      label = 33;
     } else {
      $65 = 92;
     }
     break;
    }
    case 91:  {
     $14 = ($1>>>0)>(1);
     L8: do {
      if ($14) {
       $15 = ((($0)) + 1|0);
       $16 = HEAP8[$15>>0]|0;
       switch ($16<<24>>24) {
       case 33: case 94:  {
        break;
       }
       default: {
        $$090 = 1;
        break L8;
       }
       }
       $$090 = 2;
      } else {
       $$090 = 1;
      }
     } while(0);
     $17 = ($$090>>>0)<($1>>>0);
     if ($17) {
      $18 = (($0) + ($$090)|0);
      $19 = HEAP8[$18>>0]|0;
      $20 = ($19<<24>>24)==(93);
      $21 = $20&1;
      $spec$select = (($$090) + ($21))|0;
      $$191 = $spec$select;
     } else {
      $$191 = $$090;
     }
     $22 = ($$191>>>0)<($1>>>0);
     L15: do {
      if ($22) {
       $$292109 = $$191;
       while(1) {
        $23 = (($0) + ($$292109)|0);
        $24 = HEAP8[$23>>0]|0;
        switch ($24<<24>>24) {
        case 93: case 0:  {
         $$6 = $$292109;
         label = 29;
         break L15;
         break;
        }
        default: {
        }
        }
        $25 = (($$292109) + 1)|0;
        $26 = ($25>>>0)<($1>>>0);
        L20: do {
         if ($26) {
          $27 = (($0) + ($25)|0);
          $28 = HEAP8[$27>>0]|0;
          $29 = ($28<<24>>24)!=(0);
          $30 = ($24<<24>>24)==(91);
          $or$cond96 = $30 & $29;
          if ($or$cond96) {
           switch ($28<<24>>24) {
           case 61: case 46: case 58:  {
            break;
           }
           default: {
            $$pre$phiZ2D = $25;
            break L20;
           }
           }
           $31 = (($$292109) + 2)|0;
           $32 = ($31>>>0)<($1>>>0);
           if ($32) {
            $33 = (($$292109) + 3)|0;
            $34 = (($0) + ($31)|0);
            $35 = HEAP8[$34>>0]|0;
            $36 = ($35<<24>>24)==(0);
            $spec$select97 = $36 ? $31 : $33;
            $$3 = $spec$select97;
           } else {
            $$3 = $31;
           }
           $37 = ($$3>>>0)<($1>>>0);
           L27: do {
            if ($37) {
             $$4104 = $$3;
             while(1) {
              $38 = (($0) + ($$4104)|0);
              $39 = HEAP8[$38>>0]|0;
              $40 = ($39<<24>>24)==(0);
              if ($40) {
               $$4$lcssa = $$4104;
               break L27;
              }
              $41 = (($$4104) + -1)|0;
              $42 = (($0) + ($41)|0);
              $43 = HEAP8[$42>>0]|0;
              $44 = ($43<<24>>24)!=($28<<24>>24);
              $45 = ($39<<24>>24)!=(93);
              $spec$select98 = $45 | $44;
              if (!($spec$select98)) {
               $$4$lcssa = $$4104;
               break L27;
              }
              $46 = (($$4104) + 1)|0;
              $47 = ($46>>>0)<($1>>>0);
              if ($47) {
               $$4104 = $46;
              } else {
               $$4$lcssa = $46;
               break;
              }
             }
            } else {
             $$4$lcssa = $$3;
            }
           } while(0);
           $48 = ($$4$lcssa|0)==($1|0);
           if ($48) {
            $$0 = 91;$storemerge = 1;
            break L15;
           }
           $49 = (($0) + ($$4$lcssa)|0);
           $50 = HEAP8[$49>>0]|0;
           $51 = ($50<<24>>24)==(0);
           if ($51) {
            $$6 = $$4$lcssa;
            label = 29;
            break L15;
           }
           $$pre = (($$4$lcssa) + 1)|0;
           $$pre$phiZ2D = $$pre;
          } else {
           $$pre$phiZ2D = $25;
          }
         } else {
          $$pre$phiZ2D = $25;
         }
        } while(0);
        $52 = ($$pre$phiZ2D>>>0)<($1>>>0);
        if ($52) {
         $$292109 = $$pre$phiZ2D;
        } else {
         $$6 = $$pre$phiZ2D;
         label = 29;
         break L15;
        }
       }
      } else {
       $$6 = $$191;
       label = 29;
      }
     } while(0);
     if ((label|0) == 29) {
      $53 = ($$6|0)==($1|0);
      if ($53) {
       $$0 = 91;$storemerge = 1;
      } else {
       $54 = (($$6) + 1)|0;
       $55 = (($0) + ($$6)|0);
       $56 = HEAP8[$55>>0]|0;
       $57 = ($56<<24>>24)==(0);
       $spec$select102 = $57 ? 1 : $54;
       $spec$select103 = $57 ? 91 : -3;
       $$0 = $spec$select103;$storemerge = $spec$select102;
      }
     }
     HEAP32[$2>>2] = $storemerge;
     $$2 = $$0;
     break L1;
     break;
    }
    case 63:  {
     $$2 = -4;
     break L1;
     break;
    }
    default: {
     $$089 = $0;$$094 = 0;$59 = $8;
     label = 33;
    }
    }
    if ((label|0) == 33) {
     $58 = ($59<<24>>24)<(0);
     if ($58) {
      $60 = (_mbtowc($4,$$089,$1)|0);
      $61 = ($60|0)<(0);
      if ($61) {
       HEAP32[$2>>2] = 0;
       $$1 = -2;
      } else {
       $62 = (($60) + ($$094))|0;
       HEAP32[$2>>2] = $62;
       $63 = HEAP32[$4>>2]|0;
       $$1 = $63;
      }
      $$2 = $$1;
      break;
     } else {
      $65 = $59;
     }
    }
    $64 = $65 << 24 >> 24;
    $$2 = $64;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  HEAP32[$2>>2] = 0;
  $$2 = 0;
 }
 STACKTOP = sp;return ($$2|0);
}
function _fnmatch_internal($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$0141 = 0, $$0142$lcssa = 0, $$0142207 = 0, $$0145$lcssa$idx = 0, $$0145$lcssa$ptr$pre$phiZZZZ2D = 0, $$0145215$idx = 0, $$0147214$add = 0, $$0147214$add223 = 0, $$0147214$idx = 0, $$0147214$ptr = 0, $$0150 = 0, $$0153 = 0, $$0154 = 0, $$0159 = 0, $$0216 = 0, $$1 = 0, $$1143 = 0, $$1146$idx = 0, $$1148201 = 0;
 var $$1148201$phi = 0, $$1151$ph200 = 0, $$1155$ph199 = 0, $$1155197309 = 0, $$2144 = 0, $$2149191 = 0, $$2149191$phi = 0, $$2156$pn = 0, $$2208 = 0, $$3157 = 0, $$3202 = 0, $$4$lcssa = 0, $$4158 = 0, $$4192 = 0, $$add = 0, $$lcssa = 0, $$lcssa174 = 0, $$lcssa177 = 0, $$pre = 0, $$ptr$ptr = 0;
 var $$ptr222 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond160 = 0, $or$cond161 = 0;
 var $or$cond162 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp + 4|0;
 $6 = sp;
 $7 = $4 & 4;
 $8 = ($7|0)==(0);
 if ($8) {
  label = 4;
 } else {
  $9 = HEAP8[$2>>0]|0;
  $10 = ($9<<24>>24)==(46);
  if ($10) {
   $11 = HEAP8[$0>>0]|0;
   $12 = ($11<<24>>24)==(46);
   if ($12) {
    label = 4;
   } else {
    $$0141 = 1;
   }
  } else {
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $13 = $4 & 16;
   $14 = ($13|0)==(0);
   $$0150 = $0;$$0153 = $3;$$0154 = $2;$$0159 = $1;
   L6: while(1) {
    $15 = (_pat_next($$0150,$$0159,$5,$4)|0);
    switch ($15|0) {
    case -2:  {
     $$0141 = 1;
     break L4;
     break;
    }
    case -5:  {
     break L6;
     break;
    }
    default: {
    }
    }
    $20 = (_str_next($$0154,$$0153,$6)|0);
    $21 = ($20|0)<(1);
    if ($21) {
     label = 9;
     break;
    }
    $24 = HEAP32[$6>>2]|0;
    $25 = (($$0154) + ($24)|0);
    $26 = (($$0153) - ($24))|0;
    if ($14) {
     $28 = $20;
    } else {
     $27 = (_casefold($20)|0);
     $28 = $27;
    }
    switch ($15|0) {
    case -3:  {
     $29 = (_match_bracket($$0150,$20,$28)|0);
     $30 = ($29|0)==(0);
     if ($30) {
      $$0141 = 1;
      break L4;
     }
     break;
    }
    case -4:  {
     break;
    }
    default: {
     $31 = ($20|0)==($15|0);
     $32 = ($28|0)==($15|0);
     $or$cond = $31 | $32;
     if (!($or$cond)) {
      $$0141 = 1;
      break L4;
     }
    }
    }
    $33 = HEAP32[$5>>2]|0;
    $34 = (($$0150) + ($33)|0);
    $35 = (($$0159) - ($33))|0;
    $$0150 = $34;$$0153 = $26;$$0154 = $25;$$0159 = $35;
   }
   if ((label|0) == 9) {
    $22 = ($15|0)!=(0);
    $23 = $22&1;
    $$0141 = $23;
    break;
   }
   $$ptr$ptr = ((($$0150)) + 1|0);
   $16 = (($$0159) + -1)|0;
   $17 = (_strnlen($$ptr$ptr,$16)|0);
   $$add = (($17) + 1)|0;
   $$ptr222 = (($$0150) + ($$add)|0);
   $18 = ($17|0)>(0);
   if ($18) {
    $19 = $$ptr222;
    $$0145215$idx = 1;$$0147214$idx = 1;$$0216 = 0;
    while(1) {
     $$0147214$ptr = (($$0150) + ($$0147214$idx)|0);
     $36 = $$0147214$ptr;
     $37 = (($19) - ($36))|0;
     $38 = (_pat_next($$0147214$ptr,$37,$5,$4)|0);
     switch ($38|0) {
     case -2:  {
      $$0141 = 1;
      break L4;
      break;
     }
     case -5:  {
      $$0147214$add = (($$0147214$idx) + 1)|0;
      $$1 = 0;$$1146$idx = $$0147214$add;
      break;
     }
     default: {
      $39 = (($$0216) + 1)|0;
      $$1 = $39;$$1146$idx = $$0145215$idx;
     }
     }
     $40 = HEAP32[$5>>2]|0;
     $$0147214$add223 = (($$0147214$idx) + ($40))|0;
     $41 = ($$0147214$add223|0)>($17|0);
     if ($41) {
      break;
     } else {
      $$0145215$idx = $$1146$idx;$$0147214$idx = $$0147214$add223;$$0216 = $$1;
     }
    }
    $$pre = (($$0150) + ($$1146$idx)|0);
    $$0$lcssa = $$1;$$0145$lcssa$idx = $$1146$idx;$$0145$lcssa$ptr$pre$phiZZZZ2D = $$pre;
   } else {
    $$0$lcssa = 0;$$0145$lcssa$idx = 1;$$0145$lcssa$ptr$pre$phiZZZZ2D = $$ptr$ptr;
   }
   $42 = (_strnlen($$0154,$$0153)|0);
   $43 = (($$0154) + ($42)|0);
   $44 = ($42>>>0)<($$0$lcssa>>>0);
   if ($44) {
    $$0141 = 1;
   } else {
    $45 = ($42|0)>(0);
    $46 = ($$0$lcssa|0)!=(0);
    $47 = $45 & $46;
    if ($47) {
     $$0142207 = $43;$$2208 = $$0$lcssa;
     while(1) {
      $48 = ((($$0142207)) + -1|0);
      $49 = HEAP8[$48>>0]|0;
      $50 = ($49<<24>>24)>(-1);
      if ($50) {
       $$2144 = $48;
      } else {
       $51 = (___pthread_self_538()|0);
       $52 = ((($51)) + 188|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54|0)==(0|0);
       if ($55) {
        $$2144 = $48;
       } else {
        $$1143 = $$0142207;
        while(1) {
         $56 = ((($$1143)) + -1|0);
         $57 = HEAP8[$56>>0]|0;
         $58 = $57 & -64;
         $59 = ($58<<24>>24)==(-128);
         $60 = ($56>>>0)>($$0154>>>0);
         $or$cond160 = $60 & $59;
         if ($or$cond160) {
          $$1143 = $56;
         } else {
          $$2144 = $56;
          break;
         }
        }
       }
      }
      $61 = (($$2208) + -1)|0;
      $62 = ($$2144>>>0)>($$0154>>>0);
      $63 = ($61|0)!=(0);
      $64 = $62 & $63;
      if ($64) {
       $$0142207 = $$2144;$$2208 = $61;
      } else {
       $$0142$lcssa = $$2144;$$lcssa177 = $63;
       break;
      }
     }
    } else {
     $$0142$lcssa = $43;$$lcssa177 = $46;
    }
    if ($$lcssa177) {
     $$0141 = 1;
    } else {
     $65 = $$ptr222;
     $66 = $$0145$lcssa$ptr$pre$phiZZZZ2D;
     $67 = (($65) - ($66))|0;
     $68 = (_pat_next($$0145$lcssa$ptr$pre$phiZZZZ2D,$67,$5,$4)|0);
     $69 = HEAP32[$5>>2]|0;
     $70 = $43;
     $71 = $$0142$lcssa;
     $72 = (($70) - ($71))|0;
     $73 = (_str_next($$0142$lcssa,$72,$6)|0);
     $74 = ($73|0)<(1);
     L43: do {
      if ($74) {
       $$lcssa174 = $68;
      } else {
       $75 = (($$0145$lcssa$ptr$pre$phiZZZZ2D) + ($69)|0);
       $$1148201 = $$0145$lcssa$ptr$pre$phiZZZZ2D;$$3202 = $$0142$lcssa;$79 = $73;$81 = $68;$88 = $75;
       while(1) {
        $77 = HEAP32[$6>>2]|0;
        $78 = (($$3202) + ($77)|0);
        if ($14) {
         $82 = $79;
        } else {
         $80 = (_casefold($79)|0);
         $82 = $80;
        }
        switch ($81|0) {
        case -3:  {
         $83 = (_match_bracket($$1148201,$79,$82)|0);
         $84 = ($83|0)==(0);
         if ($84) {
          $$0141 = 1;
          break L4;
         }
         break;
        }
        case -4:  {
         break;
        }
        default: {
         $85 = ($79|0)==($81|0);
         $86 = ($82|0)==($81|0);
         $or$cond161 = $85 | $86;
         if (!($or$cond161)) {
          $$0141 = 1;
          break L4;
         }
        }
        }
        $87 = $88;
        $89 = (($65) - ($87))|0;
        $90 = (_pat_next($88,$89,$5,$4)|0);
        $91 = HEAP32[$5>>2]|0;
        $92 = (($88) + ($91)|0);
        $93 = $78;
        $94 = (($70) - ($93))|0;
        $95 = (_str_next($78,$94,$6)|0);
        $96 = ($95|0)<(1);
        if ($96) {
         $$lcssa174 = $90;
         break L43;
        } else {
         $$1148201$phi = $88;$$3202 = $78;$79 = $95;$81 = $90;$88 = $92;$$1148201 = $$1148201$phi;
        }
       }
      }
     } while(0);
     $76 = ($$lcssa174|0)==(0);
     if ($76) {
      $97 = ($$0145$lcssa$idx|0)>(1);
      if ($97) {
       $$1151$ph200 = $$ptr$ptr;$$1155$ph199 = $$0154;
       while(1) {
        $98 = $$1151$ph200;
        $99 = (($66) - ($98))|0;
        $100 = (_pat_next($$1151$ph200,$99,$5,$4)|0);
        $101 = HEAP32[$5>>2]|0;
        $102 = (($$1151$ph200) + ($101)|0);
        $103 = ($100|0)==(-5);
        L59: do {
         if ($103) {
          $$4$lcssa = $$1155$ph199;$$lcssa = $102;
         } else {
          $$1155197309 = $$1155$ph199;$139 = $102;$140 = $100;
          while(1) {
           $$2149191 = $$1151$ph200;$$4192 = $$1155197309;$109 = $140;$118 = $139;
           L63: while(1) {
            $104 = $$4192;
            $105 = (($71) - ($104))|0;
            $106 = (_str_next($$4192,$105,$6)|0);
            $107 = ($106|0)==(0);
            if ($107) {
             $$0141 = 1;
             break L4;
            }
            if ($14) {
             $110 = $106;
            } else {
             $108 = (_casefold($106)|0);
             $110 = $108;
            }
            switch ($109|0) {
            case -3:  {
             $111 = (_match_bracket($$2149191,$106,$110)|0);
             $112 = ($111|0)==(0);
             if ($112) {
              break L63;
             }
             break;
            }
            case -4:  {
             break;
            }
            default: {
             $113 = ($106|0)==($109|0);
             $114 = ($110|0)==($109|0);
             $or$cond162 = $113 | $114;
             if (!($or$cond162)) {
              break L63;
             }
            }
            }
            $115 = HEAP32[$6>>2]|0;
            $116 = (($$4192) + ($115)|0);
            $117 = $118;
            $119 = (($66) - ($117))|0;
            $120 = (_pat_next($118,$119,$5,$4)|0);
            $121 = HEAP32[$5>>2]|0;
            $122 = (($118) + ($121)|0);
            $123 = ($120|0)==(-5);
            if ($123) {
             $$4$lcssa = $116;$$lcssa = $122;
             break L59;
            } else {
             $$2149191$phi = $118;$$4192 = $116;$109 = $120;$118 = $122;$$2149191 = $$2149191$phi;
            }
           }
           $125 = $$1155197309;
           $126 = (($71) - ($125))|0;
           $127 = (_str_next($$1155197309,$126,$6)|0);
           $128 = ($127|0)>(0);
           if ($128) {
            $129 = HEAP32[$6>>2]|0;
            $130 = (($$1155197309) + ($129)|0);
            $$4158 = $130;
           } else {
            $$2156$pn = $$1155197309;
            while(1) {
             $$3157 = ((($$2156$pn)) + 1|0);
             $131 = $$3157;
             $132 = (($71) - ($131))|0;
             $133 = (_str_next($$3157,$132,$6)|0);
             $134 = ($133|0)<(0);
             if ($134) {
              $$2156$pn = $$3157;
             } else {
              $$4158 = $$3157;
              break;
             }
            }
           }
           $135 = (_pat_next($$1151$ph200,$99,$5,$4)|0);
           $136 = HEAP32[$5>>2]|0;
           $137 = (($$1151$ph200) + ($136)|0);
           $138 = ($135|0)==(-5);
           if ($138) {
            $$4$lcssa = $$4158;$$lcssa = $137;
            break;
           } else {
            $$1155197309 = $$4158;$139 = $137;$140 = $135;
           }
          }
         }
        } while(0);
        $124 = ($$lcssa>>>0)<($$0145$lcssa$ptr$pre$phiZZZZ2D>>>0);
        if ($124) {
         $$1151$ph200 = $$lcssa;$$1155$ph199 = $$4$lcssa;
        } else {
         $$0141 = 0;
         break;
        }
       }
      } else {
       $$0141 = 0;
      }
     } else {
      $$0141 = 1;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0141|0);
}
function _str_next($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$1 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = ($1|0)==(0);
 do {
  if ($4) {
   HEAP32[$2>>2] = 0;
   $$1 = 0;
  } else {
   $5 = HEAP8[$0>>0]|0;
   $6 = ($5<<24>>24)<(0);
   if (!($6)) {
    HEAP32[$2>>2] = 1;
    $10 = HEAP8[$0>>0]|0;
    $11 = $10 << 24 >> 24;
    $$1 = $11;
    break;
   }
   $7 = (_mbtowc($3,$0,$1)|0);
   $8 = ($7|0)<(0);
   if ($8) {
    HEAP32[$2>>2] = 1;
    $$0 = -1;
   } else {
    HEAP32[$2>>2] = $7;
    $9 = HEAP32[$3>>2]|0;
    $$0 = $9;
   }
   $$1 = $$0;
  }
 } while(0);
 STACKTOP = sp;return ($$1|0);
}
function _casefold($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_towupper($0)|0);
 $2 = ($1|0)==($0|0);
 if ($2) {
  $3 = (_towlower($0)|0);
  $4 = $3;
 } else {
  $4 = $1;
 }
 return ($4|0);
}
function _match_bracket($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$072 = 0, $$080 = 0, $$1$ph = 0, $$173 = 0, $$274 = 0, $$476 = 0, $$678 = 0, $$779 = 0, $$8 = 0, $$pr = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond86 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = ((($0)) + 1|0);
 $7 = HEAP8[$6>>0]|0;
 switch ($7<<24>>24) {
 case 33: case 94:  {
  $8 = ((($0)) + 2|0);
  $$pr = HEAP8[$8>>0]|0;
  $$072 = $8;$$080 = 1;$9 = $$pr;
  break;
 }
 default: {
  $$072 = $6;$$080 = 0;$9 = $7;
 }
 }
 L4: do {
  switch ($9<<24>>24) {
  case 93:  {
   $10 = ($1|0)==(93);
   if ($10) {
    $11 = $$080 ^ 1;
    $$8 = $11;
    break L4;
   } else {
    $12 = ((($$072)) + 1|0);
    $$173 = $12;
    label = 10;
    break L4;
   }
   break;
  }
  case 45:  {
   $13 = ($1|0)==(45);
   if ($13) {
    $14 = $$080 ^ 1;
    $$8 = $14;
    break L4;
   } else {
    $15 = ((($$072)) + 1|0);
    $$173 = $15;
    label = 10;
    break L4;
   }
   break;
  }
  default: {
   $$173 = $$072;
   label = 10;
  }
  }
 } while(0);
 L13: do {
  if ((label|0) == 10) {
   $16 = ((($$173)) + -1|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = $17 << 24 >> 24;
   HEAP32[$3>>2] = $18;
   $$274 = $$173;
   L15: while(1) {
    $19 = HEAP8[$$274>>0]|0;
    L17: do {
     switch ($19<<24>>24) {
     case 93:  {
      $$8 = $$080;
      break L13;
      break;
     }
     case 45:  {
      $20 = ((($$274)) + 1|0);
      $21 = HEAP8[$20>>0]|0;
      $22 = ($21<<24>>24)==(93);
      if ($22) {
       label = 31;
      } else {
       $23 = (_mbtowc($4,$20,4)|0);
       $24 = ($23|0)<(0);
       if ($24) {
        $$1$ph = 0;
        break L15;
       }
       $25 = HEAP32[$3>>2]|0;
       $26 = HEAP32[$4>>2]|0;
       $27 = ($26|0)<($25|0);
       if (!($27)) {
        $28 = (($1) - ($25))|0;
        $29 = (($26) - ($25))|0;
        $30 = ($28>>>0)>($29>>>0);
        $31 = (($2) - ($25))|0;
        $32 = ($31>>>0)>($29>>>0);
        $or$cond = $30 & $32;
        if (!($or$cond)) {
         label = 16;
         break L15;
        }
       }
       $34 = (($23) + -1)|0;
       $35 = (($$274) + ($34)|0);
       $$779 = $35;
      }
      break;
     }
     case 91:  {
      $36 = ((($$274)) + 1|0);
      $37 = HEAP8[$36>>0]|0;
      switch ($37<<24>>24) {
      case 61: case 46: case 58:  {
       break;
      }
      default: {
       label = 31;
       break L17;
      }
      }
      $38 = ((($$274)) + 3|0);
      $$476 = $38;
      while(1) {
       $39 = ((($$476)) + -1|0);
       $40 = HEAP8[$39>>0]|0;
       $41 = ($40<<24>>24)==($37<<24>>24);
       if ($41) {
        $42 = HEAP8[$$476>>0]|0;
        $43 = ($42<<24>>24)==(93);
        if ($43) {
         break;
        }
       }
       $44 = ((($$476)) + 1|0);
       $$476 = $44;
      }
      $45 = ((($$274)) + 2|0);
      $46 = ($37<<24>>24)==(58);
      if ($46) {
       $47 = ((($$476)) + -1|0);
       $48 = $47;
       $49 = $45;
       $50 = (($48) - ($49))|0;
       $51 = ($50|0)<(16);
       if ($51) {
        (_memcpy(($5|0),($45|0),($50|0))|0);
        $52 = (($5) + ($50)|0);
        HEAP8[$52>>0] = 0;
        $53 = (_wctype($5)|0);
        $54 = (_iswctype($1,$53)|0);
        $55 = ($54|0)==(0);
        if (!($55)) {
         label = 29;
         break L15;
        }
        $56 = (_wctype($5)|0);
        $57 = (_iswctype($2,$56)|0);
        $58 = ($57|0)==(0);
        if (!($58)) {
         label = 29;
         break L15;
        }
        $$779 = $$476;
       } else {
        $$779 = $$476;
       }
      } else {
       $$779 = $$476;
      }
      break;
     }
     default: {
      $60 = ($19<<24>>24)>(-1);
      if ($60) {
       label = 31;
      } else {
       $62 = (_mbtowc($3,$$274,4)|0);
       $63 = ($62|0)<(0);
       if ($63) {
        $$8 = 0;
        break L13;
       }
       $64 = (($62) + -1)|0;
       $65 = (($$274) + ($64)|0);
       $$pre = HEAP32[$3>>2]|0;
       $$678 = $65;$67 = $$pre;
       label = 34;
      }
     }
     }
    } while(0);
    if ((label|0) == 31) {
     label = 0;
     $61 = $19&255;
     HEAP32[$3>>2] = $61;
     $$678 = $$274;$67 = $61;
     label = 34;
    }
    if ((label|0) == 34) {
     label = 0;
     $66 = ($67|0)==($1|0);
     $68 = ($67|0)==($2|0);
     $or$cond86 = $66 | $68;
     if ($or$cond86) {
      label = 35;
      break;
     } else {
      $$779 = $$678;
     }
    }
    $70 = ((($$779)) + 1|0);
    $$274 = $70;
   }
   if ((label|0) == 16) {
    $33 = $$080 ^ 1;
    $$1$ph = $33;
   }
   else if ((label|0) == 29) {
    $59 = $$080 ^ 1;
    $$8 = $59;
    break;
   }
   else if ((label|0) == 35) {
    $69 = $$080 ^ 1;
    $$8 = $69;
    break;
   }
   $$8 = $$1$ph;
  }
 } while(0);
 STACKTOP = sp;return ($$8|0);
}
function ___pthread_self_538() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function _globfree($0) {
 $0 = $0|0;
 var $$010 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $$lcssa = $4;
 } else {
  $5 = ((($0)) + 8|0);
  $$010 = 0;$9 = $4;
  while(1) {
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($$010))|0;
   $8 = (($9) + ($7<<2)|0);
   $10 = HEAP32[$8>>2]|0;
   $11 = ((($10)) + -4|0);
   _free($11);
   $12 = (($$010) + 1)|0;
   $13 = HEAP32[$0>>2]|0;
   $14 = ($12>>>0)<($13>>>0);
   $15 = HEAP32[$3>>2]|0;
   if ($14) {
    $$010 = $12;$9 = $15;
   } else {
    $$lcssa = $15;
    break;
   }
  }
 }
 _free($$lcssa);
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 return;
}
function _regerror($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$lcssa = 0, $$01112 = 0, $$013 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $4 = ($0|0)==(0);
 L1: do {
  if ($4) {
   $$0$lcssa = (gb + (153312) | 0);
  } else {
   $$01112 = $0;$$013 = (gb + (153312) | 0);
   while(1) {
    $5 = HEAP8[$$013>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     $$0$lcssa = $$013;
     break L1;
    }
    $7 = (($$01112) + -1)|0;
    $8 = (_strlen($$013)|0);
    $9 = (($8) + 1)|0;
    $10 = (($$013) + ($9)|0);
    $11 = ($7|0)==(0);
    if ($11) {
     $$0$lcssa = $10;
     break;
    } else {
     $$01112 = $7;$$013 = $10;
    }
   }
  }
 } while(0);
 $12 = HEAP8[$$0$lcssa>>0]|0;
 $13 = ($12<<24>>24)==(0);
 $14 = ((($$0$lcssa)) + 1|0);
 $spec$select = $13 ? $14 : $$0$lcssa;
 $15 = (___lctrans_cur($spec$select)|0);
 HEAP32[$vararg_buffer>>2] = $15;
 $16 = (_snprintf($2,$3,(gb + (167364) | 0),$vararg_buffer)|0);
 $17 = (($16) + 1)|0;
 STACKTOP = sp;return ($17|0);
}
function ___tre_mem_new_impl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0$in = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0);
 if ($2) {
  $3 = (_calloc(1,24)|0);
  $$0$in = $3;
 } else {
  (_memset(($1|0),0,24)|0);
  $$0$in = $1;
 }
 return ($$0$in|0);
}
function ___tre_mem_destroy($0) {
 $0 = $0|0;
 var $$in1011 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$in1011 = $1;
  while(1) {
   $3 = HEAP32[$$in1011>>2]|0;
   _free($3);
   $4 = ((($$in1011)) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   _free($$in1011);
   $6 = ($5|0)==(0|0);
   if ($6) {
    break;
   } else {
    $$in1011 = $5;
   }
  }
 }
 _free($0);
 return;
}
function ___tre_mem_alloc_impl($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$ = 0, $$3 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ((($0)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $8 = ((($0)) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9>>>0)<($4>>>0);
   do {
    if ($10) {
     $12 = ($1|0)==(0);
     if (!($12)) {
      $13 = ($2|0)==(0|0);
      if ($13) {
       HEAP32[$5>>2] = 1;
       $$3 = 0;
       break L1;
      } else {
       $14 = ((($0)) + 8|0);
       HEAP32[$14>>2] = $2;
       HEAP32[$8>>2] = 1024;
       $15 = $2;
       $$pre$phiZ2D = $14;$32 = $15;$38 = $2;$40 = 1024;
       break;
      }
     }
     $16 = $4 << 3;
     $17 = ($16>>>0)>(1024);
     $$ = $17 ? $16 : 1024;
     $18 = (_malloc(8)|0);
     $19 = ($18|0)==(0|0);
     if ($19) {
      HEAP32[$5>>2] = 1;
      $$3 = 0;
      break L1;
     }
     $20 = (_malloc($$)|0);
     HEAP32[$18>>2] = $20;
     $21 = ($20|0)==(0|0);
     $22 = $20;
     if ($21) {
      _free($18);
      HEAP32[$5>>2] = 1;
      $$3 = 0;
      break L1;
     }
     $23 = ((($18)) + 4|0);
     HEAP32[$23>>2] = 0;
     $24 = ((($0)) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = ((($25)) + 4|0);
      HEAP32[$27>>2] = $18;
     }
     $28 = HEAP32[$0>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      HEAP32[$0>>2] = $18;
     }
     HEAP32[$24>>2] = $18;
     $30 = ((($0)) + 8|0);
     HEAP32[$30>>2] = $22;
     HEAP32[$8>>2] = $$;
     $$pre$phiZ2D = $30;$32 = $22;$38 = $20;$40 = $$;
    } else {
     $$phi$trans$insert = ((($0)) + 8|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $11 = $$pre;
     $$pre$phiZ2D = $$phi$trans$insert;$32 = $$pre;$38 = $11;$40 = $9;
    }
   } while(0);
   $31 = (($32) + ($4))|0;
   $33 = $31 & 3;
   $34 = ($33|0)==(0);
   $35 = (4 - ($33))|0;
   $spec$select = $34 ? 0 : $35;
   $36 = (($spec$select) + ($4))|0;
   $37 = (($38) + ($36)|0);
   HEAP32[$$pre$phiZ2D>>2] = $37;
   $39 = (($40) - ($36))|0;
   HEAP32[$8>>2] = $39;
   $41 = ($3|0)==(0);
   if ($41) {
    $$3 = $38;
   } else {
    (_memset(($38|0),0,($36|0))|0);
    $$3 = $38;
   }
  } else {
   $$3 = 0;
  }
 } while(0);
 return ($$3|0);
}
function _regcomp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$0188 = 0, $$0190 = 0, $$0192 = 0, $$0193 = 0, $$0195 = 0, $$0196$lcssa = 0, $$0196209 = 0, $$0201 = 0, $$1191 = 0, $$1194207 = 0, $$1198208 = 0, $$2199 = 0, $$3 = 0, $$3200$lcssa = 0, $$3200206 = 0, $$lobit = 0, $$lobit$not = 0, $$pre = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $3 = sp;
 $4 = (_tre_stack_new()|0);
 $5 = ($4|0)==(0|0);
 L1: do {
  if ($5) {
   $$0188 = 12;
  } else {
   $6 = (___tre_mem_new_impl(0,0)|0);
   $7 = ($6|0)==(0|0);
   if ($7) {
    _tre_stack_destroy($4);
    $$0188 = 12;
    break;
   }
   (_memset(($3|0),0,36)|0);
   HEAP32[$3>>2] = $6;
   $8 = ((($3)) + 4|0);
   HEAP32[$8>>2] = $4;
   $9 = ((($3)) + 16|0);
   HEAP32[$9>>2] = $1;
   $10 = ((($3)) + 32|0);
   HEAP32[$10>>2] = $2;
   $11 = ((($3)) + 28|0);
   HEAP32[$11>>2] = -1;
   $12 = (_tre_parse($3)|0);
   $13 = ($12|0)==(0);
   L6: do {
    if ($13) {
     $14 = ((($3)) + 20|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + -1)|0;
     HEAP32[$0>>2] = $16;
     $17 = ((($3)) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = HEAP32[$11>>2]|0;
     $20 = ($19|0)<($15|0);
     if ($20) {
      $21 = (_calloc(1,68)|0);
      $22 = ($21|0)==(0|0);
      if ($22) {
       $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
      } else {
       $23 = HEAP32[$11>>2]|0;
       $$lobit = $23 >>> 31;
       $$lobit$not = $$lobit ^ 1;
       $24 = ((($21)) + 60|0);
       HEAP32[$24>>2] = $$lobit$not;
       $25 = ((($21)) + 64|0);
       HEAP32[$25>>2] = 0;
       $26 = HEAP32[$14>>2]|0;
       $27 = ((($21)) + 28|0);
       HEAP32[$27>>2] = $26;
       $28 = ($$lobit$not|0)!=(0);
       $29 = $2 & 8;
       $30 = ($29|0)==(0);
       $or$cond = $30 | $28;
       if ($or$cond) {
        $31 = (_tre_add_tags(0,$4,$18,$21)|0);
        $32 = ($31|0)==(0);
        if (!($32)) {
         $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = $31;$144 = 0;$146 = 0;
         break;
        }
        $33 = ((($21)) + 40|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($34|0)>(0);
        if ($35) {
         $36 = $34 << 2;
         $37 = (($36) + 4)|0;
         $38 = (_malloc($37)|0);
         $39 = ($38|0)==(0|0);
         if ($39) {
          $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
          break;
         }
         $40 = ((($21)) + 32|0);
         HEAP32[$40>>2] = $38;
         $41 = HEAP32[$33>>2]|0;
         $42 = $41 << 2;
         $43 = (($42) + 4)|0;
         (_memset(($38|0),-1,($43|0))|0);
         $$pre = HEAP32[$33>>2]|0;
         $$0190 = $38;$45 = $$pre;
        } else {
         $$0190 = 0;$45 = $34;
        }
        $44 = $45 << 1;
        $46 = $44 | 1;
        $47 = (_calloc($46,4)|0);
        $48 = ((($21)) + 36|0);
        HEAP32[$48>>2] = $47;
        $49 = ($47|0)==(0|0);
        if ($49) {
         $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
         break;
        }
        $50 = HEAP32[$14>>2]|0;
        $51 = (_calloc($50,12)|0);
        $52 = ($51|0)==(0|0);
        if ($52) {
         $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
         break;
        }
        $53 = ((($21)) + 16|0);
        HEAP32[$53>>2] = $51;
        $54 = (_tre_add_tags($6,$4,$18,$21)|0);
        $55 = ($54|0)==(0);
        if ($55) {
         $$1191 = $$0190;
        } else {
         $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = $54;$144 = 0;$146 = 0;
         break;
        }
       } else {
        $$1191 = 0;
       }
       $56 = ((($3)) + 24|0);
       $57 = (_tre_expand_ast($6,$4,$18,$56,$$1191)|0);
       $58 = ($57|0)==(0);
       if ($58) {
        $59 = HEAP32[$56>>2]|0;
        $60 = (($59) + 1)|0;
        HEAP32[$56>>2] = $60;
        $61 = (_tre_ast_new_literal($6,0,0,$59)|0);
        $62 = ($61|0)==(0|0);
        if ($62) {
         $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
        } else {
         $63 = (_tre_ast_new_catenation($6,$18,$61)|0);
         $64 = ($63|0)==(0|0);
         if ($64) {
          $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
         } else {
          $65 = (_tre_compute_nfl($6,$4,$63)|0);
          $66 = ($65|0)==(0);
          if ($66) {
           $67 = HEAP32[$56>>2]|0;
           $68 = $67 << 2;
           $69 = (_malloc($68)|0);
           $70 = ($69|0)==(0|0);
           if ($70) {
            $$0192 = $21;$$0195 = $69;$$0201 = 0;$$3 = 12;$144 = 0;$146 = 0;
           } else {
            $71 = HEAP32[$56>>2]|0;
            $72 = $71 << 2;
            $73 = (_malloc($72)|0);
            $74 = ($73|0)==(0|0);
            if ($74) {
             $$0192 = $21;$$0195 = $69;$$0201 = $73;$$3 = 12;$144 = $69;$146 = 0;
            } else {
             $75 = HEAP32[$56>>2]|0;
             $76 = ($75|0)>(0);
             if ($76) {
              $77 = $75 << 2;
              _memset(($69|0),0,($77|0))|0;
             }
             (_tre_ast_to_tnfa($63,0,$69,0)|0);
             $78 = HEAP32[$56>>2]|0;
             $79 = ($78|0)>(0);
             if ($79) {
              $$0196209 = 0;$$1198208 = 0;
              while(1) {
               $80 = (($73) + ($$1198208<<2)|0);
               HEAP32[$80>>2] = $$0196209;
               $81 = (($69) + ($$1198208<<2)|0);
               $82 = HEAP32[$81>>2]|0;
               $83 = (($$0196209) + 1)|0;
               $84 = (($83) + ($82))|0;
               HEAP32[$81>>2] = 0;
               $85 = (($$1198208) + 1)|0;
               $86 = ($85|0)<($78|0);
               if ($86) {
                $$0196209 = $84;$$1198208 = $85;
               } else {
                $$0196$lcssa = $84;
                break;
               }
              }
             } else {
              $$0196$lcssa = 0;
             }
             $87 = (($$0196$lcssa) + 1)|0;
             $88 = (_calloc($87,32)|0);
             $89 = ($88|0)==(0|0);
             if ($89) {
              $$0192 = $21;$$0195 = $69;$$0201 = $73;$$3 = 12;$144 = $69;$146 = $73;
             } else {
              HEAP32[$21>>2] = $88;
              $90 = ((($21)) + 4|0);
              HEAP32[$90>>2] = $$0196$lcssa;
              $91 = (_tre_ast_to_tnfa($63,$88,$69,$73)|0);
              $92 = ($91|0)==(0);
              if ($92) {
               $93 = ((($21)) + 20|0);
               HEAP32[$93>>2] = 0;
               $94 = ((($63)) + 24|0);
               $95 = HEAP32[$94>>2]|0;
               $$0193 = $95;$$2199 = 0;
               while(1) {
                $96 = HEAP32[$$0193>>2]|0;
                $97 = ($96|0)>(-1);
                $98 = (($$2199) + 1)|0;
                $99 = ((($$0193)) + 32|0);
                if ($97) {
                 $$0193 = $99;$$2199 = $98;
                } else {
                 break;
                }
               }
               $100 = (_calloc($98,32)|0);
               $101 = ($100|0)==(0|0);
               if ($101) {
                $$0192 = $21;$$0195 = $69;$$0201 = $73;$$3 = 12;$144 = $69;$146 = $73;
               } else {
                $102 = ((($21)) + 8|0);
                HEAP32[$102>>2] = $100;
                $103 = HEAP32[$94>>2]|0;
                $104 = HEAP32[$103>>2]|0;
                $105 = ($104|0)>(-1);
                if ($105) {
                 $$1194207 = $103;$$3200206 = 0;$107 = $104;
                 while(1) {
                  $106 = (($73) + ($107<<2)|0);
                  $108 = HEAP32[$106>>2]|0;
                  $109 = (($88) + ($108<<5)|0);
                  $110 = (((($100) + ($$3200206<<5)|0)) + 8|0);
                  HEAP32[$110>>2] = $109;
                  $111 = (((($100) + ($$3200206<<5)|0)) + 12|0);
                  HEAP32[$111>>2] = $107;
                  $112 = (((($100) + ($$3200206<<5)|0)) + 16|0);
                  HEAP32[$112>>2] = 0;
                  $113 = ((($$1194207)) + 12|0);
                  $114 = HEAP32[$113>>2]|0;
                  $115 = ($114|0)==(0|0);
                  if (!($115)) {
                   $$0 = 0;
                   while(1) {
                    $116 = (($114) + ($$0<<2)|0);
                    $117 = HEAP32[$116>>2]|0;
                    $118 = ($117|0)>(-1);
                    $119 = (($$0) + 1)|0;
                    if ($118) {
                     $$0 = $119;
                    } else {
                     break;
                    }
                   }
                   $120 = $119 << 2;
                   $121 = (_malloc($120)|0);
                   HEAP32[$112>>2] = $121;
                   $122 = ($121|0)==(0|0);
                   if ($122) {
                    $$0192 = $21;$$0195 = $69;$$0201 = $73;$$3 = 12;$144 = $69;$146 = $73;
                    break L6;
                   }
                   $123 = HEAP32[$113>>2]|0;
                   (_memcpy(($121|0),($123|0),($120|0))|0);
                  }
                  $124 = ((($$1194207)) + 16|0);
                  $125 = HEAP32[$124>>2]|0;
                  $126 = (((($100) + ($$3200206<<5)|0)) + 20|0);
                  HEAP32[$126>>2] = $125;
                  $127 = (($$3200206) + 1)|0;
                  $128 = ((($$1194207)) + 32|0);
                  $129 = HEAP32[$128>>2]|0;
                  $130 = ($129|0)>(-1);
                  if ($130) {
                   $$1194207 = $128;$$3200206 = $127;$107 = $129;
                  } else {
                   $$3200$lcssa = $127;
                   break;
                  }
                 }
                } else {
                 $$3200$lcssa = 0;
                }
                $131 = (((($100) + ($$3200$lcssa<<5)|0)) + 8|0);
                HEAP32[$131>>2] = 0;
                HEAP32[$90>>2] = $$0196$lcssa;
                $132 = ((($63)) + 28|0);
                $133 = HEAP32[$132>>2]|0;
                $134 = HEAP32[$133>>2]|0;
                $135 = (($73) + ($134<<2)|0);
                $136 = HEAP32[$135>>2]|0;
                $137 = (($88) + ($136<<5)|0);
                $138 = ((($21)) + 12|0);
                HEAP32[$138>>2] = $137;
                $139 = HEAP32[$56>>2]|0;
                $140 = ((($21)) + 52|0);
                HEAP32[$140>>2] = $139;
                $141 = ((($21)) + 56|0);
                HEAP32[$141>>2] = $2;
                ___tre_mem_destroy($6);
                _tre_stack_destroy($4);
                _free($69);
                _free($73);
                $142 = ((($0)) + 4|0);
                HEAP32[$142>>2] = $21;
                $$0188 = 0;
                break L1;
               }
              } else {
               $$0192 = $21;$$0195 = $69;$$0201 = $73;$$3 = $91;$144 = $69;$146 = $73;
              }
             }
            }
           }
          } else {
           $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = $65;$144 = 0;$146 = 0;
          }
         }
        }
       } else {
        $$0192 = $21;$$0195 = 0;$$0201 = 0;$$3 = $57;$144 = 0;$146 = 0;
       }
      }
     } else {
      $$0192 = 0;$$0195 = 0;$$0201 = 0;$$3 = 6;$144 = 0;$146 = 0;
     }
    } else {
     $$0192 = 0;$$0195 = 0;$$0201 = 0;$$3 = $12;$144 = 0;$146 = 0;
    }
   } while(0);
   ___tre_mem_destroy($6);
   _tre_stack_destroy($4);
   $143 = ($$0195|0)==(0|0);
   if (!($143)) {
    _free($144);
   }
   $145 = ($$0201|0)==(0|0);
   if (!($145)) {
    _free($146);
   }
   $147 = ((($0)) + 4|0);
   HEAP32[$147>>2] = $$0192;
   _regfree($0);
   $$0188 = $$3;
  }
 } while(0);
 STACKTOP = sp;return ($$0188|0);
}
function _tre_stack_new() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc(20)|0);
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $$0 = $0;
  } else {
   $2 = (_malloc(2048)|0);
   $3 = ((($0)) + 16|0);
   HEAP32[$3>>2] = $2;
   $4 = ($2|0)==(0|0);
   if ($4) {
    _free($0);
    $$0 = 0;
    break;
   } else {
    HEAP32[$0>>2] = 512;
    $5 = ((($0)) + 4|0);
    HEAP32[$5>>2] = 1024000;
    $6 = ((($0)) + 8|0);
    HEAP32[$6>>2] = 128;
    $7 = ((($0)) + 12|0);
    HEAP32[$7>>2] = 0;
    $$0 = $0;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _tre_stack_destroy($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 _free($2);
 _free($0);
 return;
}
function _tre_parse($0) {
 $0 = $0|0;
 var $$0141 = 0, $$0141$be = 0, $$0145 = 0, $$0145$ph = 0, $$0149$ph = 0, $$0150 = 0, $$0150$be = 0, $$0150$ph = 0, $$0157 = 0, $$0157$be = 0, $$1142 = 0, $$1146 = 0, $$1158 = 0, $$3153 = 0, $$3153$ph = 0, $$4154 = 0, $$6 = 0, $$6156364 = 0, $$6156365 = 0, $$7$ph = 0;
 var $$8 = 0, $$pr169 = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond419 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $spec$select = 0, $spec$select163 = 0, $spec$select168 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $1 = sp + 4|0;
 $2 = sp;
 $3 = ((($0)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ((($0)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_tre_stack_push_int($9,0)|0);
 $11 = ($10|0)==(0);
 L1: do {
  if ($11) {
   $12 = ($5|0)!=(0);
   $13 = ((($0)) + 8|0);
   $14 = ((($0)) + 12|0);
   $$0145$ph = 0;$$0149$ph = 1;$$0150$ph = $7;
   L3: while(1) {
    $$0141 = 0;$$0145 = $$0145$ph;$$0150 = $$0150$ph;$$0157 = 0;
    L5: while(1) {
     $15 = HEAP8[$$0150>>0]|0;
     if ($12) {
      $19 = ($15<<24>>24)==(40);
      if ($19) {
       break;
      }
      $30 = ($15<<24>>24)==(41);
      $31 = ($$0145|0)!=(0);
      $or$cond = $31 & $30;
      if ($or$cond) {
       label = 13;
      } else {
       label = 14;
      }
     } else {
      $16 = ($15<<24>>24)==(92);
      if ($16) {
       $17 = ((($$0150)) + 1|0);
       $18 = HEAP8[$17>>0]|0;
       switch ($18<<24>>24) {
       case 40:  {
        break L5;
        break;
       }
       case 41:  {
        label = 13;
        break;
       }
       default: {
        label = 14;
       }
       }
      } else {
       label = 14;
      }
     }
     if ((label|0) == 13) {
      label = 0;
      $32 = HEAP32[$0>>2]|0;
      $33 = (_tre_ast_new_literal($32,-1,-1,-1)|0);
      HEAP32[$13>>2] = $33;
      $34 = ($33|0)==(0|0);
      if ($34) {
       $$6 = 12;
       break L1;
      } else {
       $$3153$ph = $$0150;
      }
     }
     else if ((label|0) == 14) {
      label = 0;
      $35 = (_parse_atom($0,$$0150)|0);
      $36 = ($35|0)==(0);
      if (!($36)) {
       $$6 = $35;
       break L1;
      }
      $37 = HEAP32[$14>>2]|0;
      $$3153$ph = $37;
     }
     $$1142 = $$0141;$$1146 = $$0145;$$1158 = $$0157;$$3153 = $$3153$ph;
     L17: while(1) {
      $$4154 = $$3153;
      L19: while(1) {
       $38 = HEAP8[$$4154>>0]|0;
       switch ($38<<24>>24) {
       case 42: case 92:  {
        break;
       }
       default: {
        if (!($12)) {
         $$7$ph = $$4154;
         break L19;
        }
        switch ($38<<24>>24) {
        case 123: case 63: case 43:  {
         break;
        }
        default: {
         $$7$ph = $$4154;
         break L19;
        }
        }
       }
       }
       $39 = ($38<<24>>24)==(92);
       $or$cond3 = $12 & $39;
       if ($or$cond3) {
        $$7$ph = $$4154;
        break;
       }
       $40 = ((($$4154)) + 1|0);
       if ($39) {
        $41 = HEAP8[$40>>0]|0;
        switch ($41<<24>>24) {
        case 123: case 63: case 43:  {
         break;
        }
        default: {
         $$7$ph = $$4154;
         break L19;
        }
        }
       }
       $spec$select163 = $39 ? $40 : $$4154;
       if (!($12)) {
        $42 = HEAP32[$6>>2]|0;
        $43 = ((($42)) + 1|0);
        $44 = ($spec$select163|0)==($43|0);
        if ($44) {
         $45 = ((($spec$select163)) + -1|0);
         $46 = HEAP8[$45>>0]|0;
         $47 = ($46<<24>>24)==(94);
         if ($47) {
          $$7$ph = $spec$select163;
          break;
         }
        }
       }
       $48 = HEAP8[$spec$select163>>0]|0;
       $49 = ($48<<24>>24)==(123);
       if ($49) {
        $50 = ((($spec$select163)) + 1|0);
        $51 = (_parse_dup($50,$5,$1,$2)|0);
        $52 = ($51|0)==(0|0);
        if ($52) {
         label = 29;
         break L3;
        }
        $$pre = HEAP32[$2>>2]|0;
        $59 = ($$pre|0)==(0);
        $60 = HEAP32[$0>>2]|0;
        if ($59) {
         $61 = (_tre_ast_new_literal($60,-1,-1,-1)|0);
         $$6156364 = $51;$storemerge = $61;
        } else {
         $$6156365 = $51;$64 = $60;$65 = $$pre;
         label = 37;
        }
       } else {
        HEAP32[$1>>2] = 0;
        HEAP32[$2>>2] = -1;
        $53 = HEAP8[$spec$select163>>0]|0;
        $54 = ($53<<24>>24)==(43);
        if ($54) {
         HEAP32[$1>>2] = 1;
         $$pr169 = HEAP8[$spec$select163>>0]|0;
         $56 = $$pr169;
        } else {
         $56 = $53;
        }
        $55 = ($56<<24>>24)==(63);
        if ($55) {
         HEAP32[$2>>2] = 1;
         $104 = 1;
        } else {
         $104 = -1;
        }
        $57 = ((($spec$select163)) + 1|0);
        $58 = HEAP32[$0>>2]|0;
        $$6156365 = $57;$64 = $58;$65 = $104;
        label = 37;
       }
       if ((label|0) == 37) {
        label = 0;
        $62 = HEAP32[$13>>2]|0;
        $63 = HEAP32[$1>>2]|0;
        $66 = (_tre_ast_new_iter($64,$62,$63,$65,0)|0);
        $$6156364 = $$6156365;$storemerge = $66;
       }
       HEAP32[$13>>2] = $storemerge;
       $71 = ($storemerge|0)==(0|0);
       if ($71) {
        $$6 = 12;
        break L1;
       } else {
        $$4154 = $$6156364;
       }
      }
      $67 = HEAP32[$0>>2]|0;
      $68 = HEAP32[$13>>2]|0;
      $69 = (_tre_ast_new_catenation($67,$$1142,$68)|0);
      $70 = HEAP8[$$7$ph>>0]|0;
      L48: do {
       if ($12) {
        $72 = ($70<<24>>24)==(124);
        if ($72) {
         label = 47;
         break L17;
        }
        $73 = ($70<<24>>24)==(41);
        $74 = ($$1146|0)!=(0);
        $or$cond5 = $74 & $73;
        $75 = ($70<<24>>24)==(0);
        $or$cond419 = $or$cond5 | $75;
        if ($or$cond419) {
         label = 50;
        } else {
         $$0141$be = $69;$$0150$be = $$7$ph;$$0157$be = $$1158;
         break L17;
        }
       } else {
        switch ($70<<24>>24) {
        case 0:  {
         label = 50;
         break L48;
         break;
        }
        case 92:  {
         break;
        }
        default: {
         $$0141$be = $69;$$0150$be = $$7$ph;$$0157$be = $$1158;
         break L17;
        }
        }
        $76 = ((($$7$ph)) + 1|0);
        $77 = HEAP8[$76>>0]|0;
        switch ($77<<24>>24) {
        case 124: case 41:  {
         break;
        }
        default: {
         $$0141$be = $69;$$0150$be = $$7$ph;$$0157$be = $$1158;
         break L17;
        }
        }
        $78 = HEAP32[$0>>2]|0;
        $79 = (_tre_ast_new_union($78,$$1158,$69)|0);
        $80 = ((($$7$ph)) + 1|0);
        $81 = HEAP8[$80>>0]|0;
        $82 = ($81<<24>>24)==(124);
        if ($82) {
         label = 45;
         break L17;
        }
        $87 = ($$1146|0)==(0);
        if ($87) {
         $$6 = 8;
         break L1;
        }
        $88 = ((($$7$ph)) + 2|0);
        $$8 = $88;$95 = $79;$99 = 92;
       }
      } while(0);
      if ((label|0) == 50) {
       label = 0;
       $89 = HEAP32[$0>>2]|0;
       $90 = (_tre_ast_new_union($89,$$1158,$69)|0);
       $91 = ($70<<24>>24)==(41);
       $92 = ((($$7$ph)) + 1|0);
       $spec$select168 = $91 ? $92 : $$7$ph;
       $$8 = $spec$select168;$95 = $90;$99 = $70;
      }
      $93 = (($$1146) + -1)|0;
      $94 = (_tre_stack_pop_int($9)|0);
      $96 = (_marksub($0,$95,$94)|0);
      $97 = ($96|0)==(0);
      if (!($97)) {
       $$6 = $96;
       break L1;
      }
      $98 = ($99<<24>>24)==(0);
      $100 = ($$1146|0)<(1);
      $or$cond7 = $100 & $98;
      if ($or$cond7) {
       label = 53;
       break L3;
      }
      $or$cond9 = $100 | $98;
      if ($or$cond9) {
       $$6 = 8;
       break L1;
      }
      $102 = (_tre_stack_pop_voidptr($9)|0);
      $103 = (_tre_stack_pop_voidptr($9)|0);
      $$1142 = $102;$$1146 = $93;$$1158 = $103;$$3153 = $$8;
     }
     if ((label|0) == 45) {
      label = 0;
      $83 = ((($$7$ph)) + 2|0);
      $$0141$be = 0;$$0150$be = $83;$$0157$be = $79;
     }
     else if ((label|0) == 47) {
      label = 0;
      $84 = HEAP32[$0>>2]|0;
      $85 = (_tre_ast_new_union($84,$$1158,$69)|0);
      $86 = ((($$7$ph)) + 1|0);
      $$0141$be = 0;$$0150$be = $86;$$0157$be = $85;
     }
     $$0141 = $$0141$be;$$0145 = $$1146;$$0150 = $$0150$be;$$0157 = $$0157$be;
    }
    $20 = (_tre_stack_push_voidptr($9,$$0157)|0);
    $21 = ($20|0)==(0);
    if (!($21)) {
     $$6 = $20;
     break L1;
    }
    $22 = (_tre_stack_push_voidptr($9,$$0141)|0);
    $23 = ($22|0)==(0);
    if (!($23)) {
     $$6 = $22;
     break L1;
    }
    $24 = (_tre_stack_push_int($9,$$0149$ph)|0);
    $25 = ($24|0)==(0);
    if (!($25)) {
     $$6 = $24;
     break L1;
    }
    $26 = (($$0149$ph) + 1)|0;
    $27 = ((($$0150)) + 1|0);
    $28 = ((($$0150)) + 2|0);
    $spec$select = $12 ? $27 : $28;
    $29 = (($$0145) + 1)|0;
    $$0145$ph = $29;$$0149$ph = $26;$$0150$ph = $spec$select;
   }
   if ((label|0) == 29) {
    $$6 = 10;
    break;
   }
   else if ((label|0) == 53) {
    $101 = ((($0)) + 20|0);
    HEAP32[$101>>2] = $$0149$ph;
    $$6 = 0;
    break;
   }
  } else {
   $$6 = $10;
  }
 } while(0);
 STACKTOP = sp;return ($$6|0);
}
function _tre_add_tags($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0457 = 0, $$0458$lcssa = 0, $$0459$lcssa = 0, $$0459592 = 0, $$0462$lcssa = 0, $$0462589 = 0, $$0472$lcssa = 0, $$0472586 = 0, $$0488$lcssa = 0, $$0488583 = 0, $$0500 = 0, $$0501 = 0, $$0502 = 0, $$0503 = 0, $$0504580 = 0, $$0516$lcssa = 0, $$0516577 = 0, $$0532$ = 0, $$0532574 = 0;
 var $$0537 = 0, $$0540 = 0, $$0541603 = 0, $$0542 = 0, $$0544 = 0, $$0547 = 0, $$10482 = 0, $$10498 = 0, $$10514 = 0, $$10526 = 0, $$11 = 0, $$11483 = 0, $$11515 = 0, $$11527 = 0, $$12 = 0, $$13485 = 0, $$13529 = 0, $$14 = 0, $$14486 = 0, $$14530557 = 0;
 var $$14530558 = 0, $$1460 = 0, $$1473 = 0, $$15 = 0, $$1517 = 0, $$1543 = 0, $$1545 = 0, $$15487 = 0, $$15531 = 0, $$16 = 0, $$18 = 0, $$2461 = 0, $$2474 = 0, $$2518 = 0, $$2534 = 0, $$2546572 = 0, $$3507 = 0, $$3535 = 0, $$4 = 0, $$4536 = 0;
 var $$5467 = 0, $$5477 = 0, $$5493 = 0, $$5521 = 0, $$6478 = 0, $$6494 = 0, $$6522 = 0, $$7469 = 0, $$7511 = 0, $$8 = 0, $$8496 = 0, $$8512 = 0, $$9471 = 0, $$9481 = 0, $$9525 = 0, $$lcssa563 = 0, $$lobit = 0, $$lobit$not = 0, $$pre = 0, $$pre$phi615Z2D = 0;
 var $$pre$phiZ2D = 0, $$pre612 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond5 = 0, $or$cond548 = 0, $or$cond5573 = 0, $spec$select = 0, $spec$select549 = 0, $spec$select552 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_tre_stack_num_objects($1)|0);
 $5 = ($0|0)==(0|0);
 $6 = ($3|0)==(0|0);
 $7 = $5 | $6;
 if (!($7)) {
  $8 = ((($3)) + 48|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($3)) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$10>>2] = -1;
 }
 $11 = ((($3)) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 << 3;
 $14 = (($13) + 8)|0;
 $15 = (_malloc($14)|0);
 $16 = ($15|0)==(0|0);
 do {
  if ($16) {
   $$0457 = 12;
  } else {
   HEAP32[$15>>2] = -1;
   $17 = HEAP32[$11>>2]|0;
   $18 = $17 << 2;
   $19 = (($18) + 4)|0;
   $20 = (_malloc($19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    _free($15);
    $$0457 = 12;
    break;
   }
   HEAP32[$20>>2] = -1;
   $22 = HEAP32[$11>>2]|0;
   $23 = $22 << 3;
   $24 = (($23) + 8)|0;
   $25 = (_malloc($24)|0);
   $26 = ($25|0)==(0|0);
   if ($26) {
    _free($15);
    _free($20);
    $$0457 = 12;
    break;
   }
   $27 = HEAP32[$11>>2]|0;
   $$0541603 = 0;
   while(1) {
    $28 = (($25) + ($$0541603<<3)|0);
    HEAP32[$28>>2] = -1;
    $29 = (($$0541603) + 1)|0;
    $30 = ($29>>>0)>($27>>>0);
    if ($30) {
     break;
    } else {
     $$0541603 = $29;
    }
   }
   (_tre_stack_push_voidptr($1,$2)|0);
   $31 = (_tre_stack_push_int($1,0)|0);
   $32 = (_tre_stack_num_objects($1)|0);
   $33 = ($32|0)<=($4|0);
   $34 = ($31|0)!=(0);
   $or$cond5573 = $34 | $33;
   L15: do {
    if ($or$cond5573) {
     $$0458$lcssa = $31;$$0459$lcssa = $15;$$0462$lcssa = 0;$$0472$lcssa = 0;$$0488$lcssa = 0;$$0516$lcssa = -1;
    } else {
     $35 = ((($3)) + 32|0);
     $36 = ((($3)) + 16|0);
     $37 = ((($3)) + 36|0);
     $$0459592 = $15;$$0462589 = 0;$$0472586 = 0;$$0488583 = 0;$$0504580 = 1;$$0516577 = -1;$$0532574 = 0;
     while(1) {
      $38 = (_tre_stack_pop_int($1)|0);
      L19: do {
       switch ($38|0) {
       case 6:  {
        $39 = (_tre_stack_pop_int($1)|0);
        $$0542 = 0;
        while(1) {
         $40 = (($$0459592) + ($$0542<<2)|0);
         $41 = HEAP32[$40>>2]|0;
         $42 = ($41|0)>(-1);
         $43 = (($$0542) + 1)|0;
         if ($42) {
          $$0542 = $43;
         } else {
          break;
         }
        }
        $44 = $39 << 1;
        $45 = $44 | 1;
        HEAP32[$40>>2] = $45;
        $46 = (($$0459592) + ($43<<2)|0);
        HEAP32[$46>>2] = -1;
        $$1543 = 0;
        while(1) {
         $47 = (($20) + ($$1543<<2)|0);
         $48 = HEAP32[$47>>2]|0;
         $49 = ($48|0)>(-1);
         $50 = (($$1543) + 1)|0;
         if ($49) {
          $$1543 = $50;
         } else {
          break;
         }
        }
        $51 = (($$1543) + -1)|0;
        $52 = (($20) + ($51<<2)|0);
        HEAP32[$52>>2] = -1;
        $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
        break;
       }
       case 0:  {
        $53 = (_tre_stack_pop_voidptr($1)|0);
        $54 = ((($53)) + 12|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = ($55|0)>(-1);
        if ($56) {
         $$0544 = 0;
         while(1) {
          $57 = (($$0459592) + ($$0544<<2)|0);
          $58 = HEAP32[$57>>2]|0;
          $59 = ($58|0)>(-1);
          $60 = (($$0544) + 1)|0;
          if ($59) {
           $$0544 = $60;
          } else {
           break;
          }
         }
         $61 = $55 << 1;
         HEAP32[$57>>2] = $61;
         $62 = (($$0459592) + ($60<<2)|0);
         HEAP32[$62>>2] = -1;
         if (!($7)) {
          $$1545 = 0;
          while(1) {
           $63 = (($20) + ($$1545<<2)|0);
           $64 = HEAP32[$63>>2]|0;
           $65 = ($64|0)>(-1);
           $66 = (($$1545) + 1)|0;
           if ($65) {
            $$1545 = $66;
           } else {
            break;
           }
          }
          $67 = HEAP32[$36>>2]|0;
          $68 = (((($67) + (($55*12)|0)|0)) + 8|0);
          HEAP32[$68>>2] = 0;
          $69 = ($$1545|0)==(0);
          if (!($69)) {
           $70 = $$1545 << 2;
           $71 = (($70) + 4)|0;
           $72 = (_malloc($71)|0);
           $73 = ($72|0)==(0|0);
           if ($73) {
            $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 12;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
            break L19;
           }
           $74 = HEAP32[$36>>2]|0;
           $75 = (((($74) + (($55*12)|0)|0)) + 8|0);
           HEAP32[$75>>2] = $72;
           $76 = HEAP32[$20>>2]|0;
           $77 = ($76|0)>(-1);
           if ($77) {
            $$2546572 = 0;$78 = $76;$79 = $72;
            while(1) {
             HEAP32[$79>>2] = $78;
             $80 = (($$2546572) + 1)|0;
             $81 = (($20) + ($80<<2)|0);
             $82 = HEAP32[$81>>2]|0;
             $83 = ($82|0)>(-1);
             $84 = (($72) + ($80<<2)|0);
             if ($83) {
              $$2546572 = $80;$78 = $82;$79 = $84;
             } else {
              $$lcssa563 = $84;
              break;
             }
            }
           } else {
            $$lcssa563 = $72;
           }
           HEAP32[$$lcssa563>>2] = -1;
          }
         }
         $85 = HEAP32[$54>>2]|0;
         $86 = (_tre_stack_push_int($1,$85)|0);
         $87 = ($86|0)==(0);
         if (!($87)) {
          $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = $86;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
          break L19;
         }
         $88 = (_tre_stack_push_int($1,6)|0);
         $89 = ($88|0)==(0);
         if (!($89)) {
          $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = $88;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
          break L19;
         }
        }
        $90 = HEAP32[$53>>2]|0;
        L48: do {
         switch ($90|0) {
         case 0:  {
          $91 = ((($53)) + 4|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = HEAP32[$92>>2]|0;
          $94 = ($93|0)>(-1);
          $95 = ($93|0)==(-4);
          $or$cond548 = $94 | $95;
          if ($or$cond548) {
           $96 = HEAP32[$$0459592>>2]|0;
           $97 = ($96|0)>(-1);
           if ($97) {
            if ($7) {
             $111 = ((($53)) + 20|0);
             HEAP32[$111>>2] = 1;
             $$2474 = $$0472586;$$2518 = $$0516577;$$4 = 0;
            } else {
             $98 = (_tre_add_tag_left($0,$53,$$0488583)|0);
             $99 = HEAP32[$35>>2]|0;
             $100 = (($99) + ($$0488583<<2)|0);
             HEAP32[$100>>2] = $$0532574;
             $101 = ($$0516577|0)>(-1);
             if ($101) {
              $102 = HEAP32[$37>>2]|0;
              $$0547 = 0;
              while(1) {
               $103 = (($102) + ($$0547<<2)|0);
               $104 = HEAP32[$103>>2]|0;
               $105 = ($104|0)>(-1);
               $106 = (($$0547) + 1)|0;
               if ($105) {
                $$0547 = $106;
               } else {
                break;
               }
              }
              HEAP32[$103>>2] = $$0488583;
              $107 = (($102) + ($106<<2)|0);
              HEAP32[$107>>2] = $$0516577;
              $108 = (($$0547) + 2)|0;
              $109 = (($102) + ($108<<2)|0);
              HEAP32[$109>>2] = -1;
              $110 = (($$0472586) + 1)|0;
              $$1473 = $110;$$1517 = -1;
             } else {
              $$1473 = $$0472586;$$1517 = $$0516577;
             }
             _tre_purge_regset($$0459592,$3,$$0488583);
             $$2474 = $$1473;$$2518 = $$1517;$$4 = $98;
            }
            HEAP32[$$0459592>>2] = -1;
            $112 = (($$0462589) + 1)|0;
            $113 = (($$0504580) + 1)|0;
            $$10514 = $113;$$13485 = $$2474;$$13529 = $$2518;$$14 = $$4;$$2534 = $$0532574;$$7469 = $112;$$8496 = $$0504580;
           } else {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = 0;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
           }
          } else {
           $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = 0;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
          }
          break;
         }
         case 1:  {
          $114 = ((($53)) + 4|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = HEAP32[$115>>2]|0;
          $117 = ((($115)) + 4|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (_tre_stack_push_voidptr($1,$53)|0);
          $120 = ($119|0)==(0);
          if ($120) {
           $121 = (_tre_stack_push_int($1,5)|0);
           $122 = ($121|0)==(0);
           if ($122) {
            $123 = (_tre_stack_push_voidptr($1,$118)|0);
            $124 = ($123|0)==(0);
            if ($124) {
             $125 = (_tre_stack_push_int($1,0)|0);
             $126 = ($125|0)==(0);
             if ($126) {
              $127 = ((($116)) + 20|0);
              $128 = HEAP32[$127>>2]|0;
              $129 = (($128) + ($$0504580))|0;
              $130 = (_tre_stack_push_int($1,$129)|0);
              $131 = ($130|0)==(0);
              if ($131) {
               $132 = HEAP32[$127>>2]|0;
               $133 = ($132|0)>(0);
               if ($133) {
                $134 = ((($118)) + 20|0);
                $135 = HEAP32[$134>>2]|0;
                $136 = ($135|0)>(0);
                $spec$select = $136 ? $$0504580 : -1;
                $137 = $136&1;
                $spec$select549 = (($$0504580) + ($137))|0;
                $$0540 = $spec$select;$$3507 = $spec$select549;
               } else {
                $$0540 = -1;$$3507 = $$0504580;
               }
               $138 = (_tre_stack_push_int($1,$$0540)|0);
               $139 = ($138|0)==(0);
               if ($139) {
                $140 = (_tre_stack_push_int($1,4)|0);
                $141 = ($140|0)==(0);
                if ($141) {
                 $142 = (_tre_stack_push_voidptr($1,$116)|0);
                 $143 = ($142|0)==(0);
                 if ($143) {
                  $144 = (_tre_stack_push_int($1,0)|0);
                  $$10514 = $$3507;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $144;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                 } else {
                  $$10514 = $$3507;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $142;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                 }
                } else {
                 $$10514 = $$3507;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $140;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                }
               } else {
                $$10514 = $$3507;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $138;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
               }
              } else {
               $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $130;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
              }
             } else {
              $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $125;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
             }
            } else {
             $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $123;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            }
           } else {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $121;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
           }
          } else {
           $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $119;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
          }
          break;
         }
         case 2:  {
          $145 = ((($53)) + 4|0);
          $146 = HEAP32[$145>>2]|0;
          if ($7) {
           $147 = HEAP32[$$0459592>>2]|0;
           $148 = ($147|0)>(-1);
           if ($148) {
            $154 = 1;
           } else {
            $149 = ((($146)) + 12|0);
            $150 = HEAP8[$149>>0]|0;
            $151 = $150 & 1;
            $152 = ($151<<24>>24)!=(0);
            $154 = $152;
           }
           $153 = $154&1;
           $155 = (_tre_stack_push_int($1,$153)|0);
           $156 = ($155|0)==(0);
           if (!($156)) {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $155;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            break L48;
           }
          } else {
           $157 = (_tre_stack_push_int($1,$$0488583)|0);
           $158 = ($157|0)==(0);
           if (!($158)) {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $157;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            break L48;
           }
           $159 = ((($146)) + 12|0);
           $160 = HEAP8[$159>>0]|0;
           $161 = $160 & 1;
           $162 = $161&255;
           $163 = (_tre_stack_push_int($1,$162)|0);
           $164 = ($163|0)==(0);
           if (!($164)) {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $163;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            break L48;
           }
          }
          $165 = (_tre_stack_push_voidptr($1,$53)|0);
          $166 = ($165|0)==(0);
          if ($166) {
           $167 = (_tre_stack_push_int($1,1)|0);
           $168 = ($167|0)==(0);
           if ($168) {
            $169 = HEAP32[$146>>2]|0;
            $170 = (_tre_stack_push_voidptr($1,$169)|0);
            $171 = ($170|0)==(0);
            if ($171) {
             $172 = (_tre_stack_push_int($1,0)|0);
             $173 = ($172|0)==(0);
             if ($173) {
              $174 = HEAP32[$$0459592>>2]|0;
              $175 = ($174|0)>(-1);
              if (!($175)) {
               $176 = ((($146)) + 12|0);
               $177 = HEAP8[$176>>0]|0;
               $178 = $177 & 1;
               $179 = ($178<<24>>24)==(0);
               if ($179) {
                $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = 0;$$2534 = 0;$$7469 = $$0462589;$$8496 = $$0488583;
                break L48;
               }
              }
              if ($7) {
               $$6478 = $$0472586;$$6522 = $$0516577;$$8 = 0;
              } else {
               $180 = (_tre_add_tag_left($0,$53,$$0488583)|0);
               $181 = ((($146)) + 12|0);
               $182 = HEAP8[$181>>0]|0;
               $183 = $182 & 1;
               $184 = ($183<<24>>24)==(0);
               $185 = HEAP32[$35>>2]|0;
               $186 = (($185) + ($$0488583<<2)|0);
               $$0532$ = $184 ? $$0532574 : 1;
               HEAP32[$186>>2] = $$0532$;
               $187 = ($$0516577|0)>(-1);
               if ($187) {
                $188 = HEAP32[$37>>2]|0;
                $$0537 = 0;
                while(1) {
                 $189 = (($188) + ($$0537<<2)|0);
                 $190 = HEAP32[$189>>2]|0;
                 $191 = ($190|0)>(-1);
                 $192 = (($$0537) + 1)|0;
                 if ($191) {
                  $$0537 = $192;
                 } else {
                  break;
                 }
                }
                HEAP32[$189>>2] = $$0488583;
                $193 = (($188) + ($192<<2)|0);
                HEAP32[$193>>2] = $$0516577;
                $194 = (($$0537) + 2)|0;
                $195 = (($188) + ($194<<2)|0);
                HEAP32[$195>>2] = -1;
                $196 = (($$0472586) + 1)|0;
                $$5477 = $196;$$5521 = -1;
               } else {
                $$5477 = $$0472586;$$5521 = $$0516577;
               }
               _tre_purge_regset($$0459592,$3,$$0488583);
               $$6478 = $$5477;$$6522 = $$5521;$$8 = $180;
              }
              HEAP32[$$0459592>>2] = -1;
              $197 = (($$0462589) + 1)|0;
              $198 = (($$0504580) + 1)|0;
              $$10514 = $198;$$13485 = $$6478;$$13529 = $$6522;$$14 = $$8;$$2534 = 0;$$7469 = $197;$$8496 = $$0504580;
             } else {
              $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $172;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
             }
            } else {
             $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $170;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            }
           } else {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $167;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
           }
          } else {
           $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $165;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
          }
          break;
         }
         case 3:  {
          $199 = ((($53)) + 4|0);
          $200 = HEAP32[$199>>2]|0;
          $201 = HEAP32[$200>>2]|0;
          $202 = ((($200)) + 4|0);
          $203 = HEAP32[$202>>2]|0;
          $204 = HEAP32[$$0459592>>2]|0;
          $205 = ($204|0)>(-1);
          $206 = (($$0504580) + 1)|0;
          $$0502 = $205 ? $206 : $$0504580;
          $207 = (_tre_stack_push_int($1,$$0502)|0);
          $208 = ($207|0)==(0);
          if ($208) {
           $$0503 = $205 ? $$0504580 : $$0488583;
           $209 = (_tre_stack_push_int($1,$$0503)|0);
           $210 = ($209|0)==(0);
           if ($210) {
            $211 = (_tre_stack_push_voidptr($1,$$0459592)|0);
            $212 = ($211|0)==(0);
            if ($212) {
             $213 = HEAP32[$$0459592>>2]|0;
             $$lobit = $213 >>> 31;
             $$lobit$not = $$lobit ^ 1;
             $214 = (_tre_stack_push_int($1,$$lobit$not)|0);
             $215 = ($214|0)==(0);
             if ($215) {
              $216 = (_tre_stack_push_voidptr($1,$53)|0);
              $217 = ($216|0)==(0);
              if ($217) {
               $218 = (_tre_stack_push_voidptr($1,$203)|0);
               $219 = ($218|0)==(0);
               if ($219) {
                $220 = (_tre_stack_push_voidptr($1,$201)|0);
                $221 = ($220|0)==(0);
                if ($221) {
                 $222 = (_tre_stack_push_int($1,3)|0);
                 $223 = ($222|0)==(0);
                 if ($223) {
                  $224 = (_tre_stack_push_voidptr($1,$203)|0);
                  $225 = ($224|0)==(0);
                  if ($225) {
                   $226 = (_tre_stack_push_int($1,0)|0);
                   $227 = ($226|0)==(0);
                   if (!($227)) {
                    $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $226;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                    break L48;
                   }
                   $228 = (_tre_stack_push_int($1,2)|0);
                   $229 = ($228|0)==(0);
                   if (!($229)) {
                    $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $228;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                    break L48;
                   }
                   $230 = (_tre_stack_push_voidptr($1,$201)|0);
                   $231 = ($230|0)==(0);
                   if (!($231)) {
                    $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $230;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                    break L48;
                   }
                   $232 = (_tre_stack_push_int($1,0)|0);
                   $233 = ($232|0)==(0);
                   if (!($233)) {
                    $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $232;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                    break L48;
                   }
                   $234 = HEAP32[$$0459592>>2]|0;
                   $235 = ($234|0)>(-1);
                   if ($235) {
                    if ($7) {
                     $$10482 = $$0472586;$$10526 = $$0516577;$$11 = 0;
                    } else {
                     $236 = (_tre_add_tag_left($0,$53,$$0488583)|0);
                     $237 = HEAP32[$35>>2]|0;
                     $238 = (($237) + ($$0488583<<2)|0);
                     HEAP32[$238>>2] = $$0532574;
                     $239 = ($$0516577|0)>(-1);
                     if ($239) {
                      $240 = HEAP32[$37>>2]|0;
                      $$0501 = 0;
                      while(1) {
                       $241 = (($240) + ($$0501<<2)|0);
                       $242 = HEAP32[$241>>2]|0;
                       $243 = ($242|0)>(-1);
                       $244 = (($$0501) + 1)|0;
                       if ($243) {
                        $$0501 = $244;
                       } else {
                        break;
                       }
                      }
                      HEAP32[$241>>2] = $$0488583;
                      $245 = (($240) + ($244<<2)|0);
                      HEAP32[$245>>2] = $$0516577;
                      $246 = (($$0501) + 2)|0;
                      $247 = (($240) + ($246<<2)|0);
                      HEAP32[$247>>2] = -1;
                      $248 = (($$0472586) + 1)|0;
                      $$9481 = $248;$$9525 = -1;
                     } else {
                      $$9481 = $$0472586;$$9525 = $$0516577;
                     }
                     _tre_purge_regset($$0459592,$3,$$0488583);
                     $$10482 = $$9481;$$10526 = $$9525;$$11 = $236;
                    }
                    HEAP32[$$0459592>>2] = -1;
                    $249 = (($$0462589) + 1)|0;
                    $$pre = (($$0504580) + 2)|0;
                    $$11483 = $$10482;$$11527 = $$10526;$$12 = $$11;$$5467 = $249;$$5493 = $$0504580;$$7511 = $206;$$pre$phiZ2D = $$pre;
                   } else {
                    $$11483 = $$0472586;$$11527 = $$0516577;$$12 = 0;$$5467 = $$0462589;$$5493 = $$0488583;$$7511 = $$0504580;$$pre$phiZ2D = $206;
                   }
                   $250 = ((($53)) + 16|0);
                   $251 = HEAP32[$250>>2]|0;
                   $252 = ($251|0)>(0);
                   $253 = (($$7511) + 2)|0;
                   $$8512 = $252 ? $253 : $$7511;
                   $$6494 = $252 ? $$pre$phiZ2D : $$5493;
                   $$10514 = $$8512;$$13485 = $$11483;$$13529 = $$11527;$$14 = $$12;$$2534 = $$0532574;$$7469 = $$5467;$$8496 = $$6494;
                  } else {
                   $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $224;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                  }
                 } else {
                  $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $222;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                 }
                } else {
                 $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $220;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
                }
               } else {
                $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $218;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
               }
              } else {
               $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $216;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
              }
             } else {
              $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $214;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
             }
            } else {
             $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $211;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
            }
           } else {
            $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $209;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
           }
          } else {
           $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = $207;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
          }
          break;
         }
         default: {
          $$10514 = $$0504580;$$13485 = $$0472586;$$13529 = $$0516577;$$14 = 0;$$2534 = $$0532574;$$7469 = $$0462589;$$8496 = $$0488583;
         }
         }
        } while(0);
        $254 = HEAP32[$54>>2]|0;
        $255 = ($254|0)>(-1);
        if ($255) {
         $$0500 = 0;
         while(1) {
          $256 = (($20) + ($$0500<<2)|0);
          $257 = HEAP32[$256>>2]|0;
          $258 = ($257|0)>(-1);
          $259 = (($$0500) + 1)|0;
          if ($258) {
           $$0500 = $259;
          } else {
           break;
          }
         }
         HEAP32[$256>>2] = $254;
         $260 = (($20) + ($259<<2)|0);
         HEAP32[$260>>2] = -1;
         $$10498 = $$8496;$$11515 = $$10514;$$14486 = $$13485;$$15531 = $$13529;$$18 = $$14;$$2461 = $$0459592;$$4536 = $$2534;$$9471 = $$7469;
        } else {
         $$10498 = $$8496;$$11515 = $$10514;$$14486 = $$13485;$$15531 = $$13529;$$18 = $$14;$$2461 = $$0459592;$$4536 = $$2534;$$9471 = $$7469;
        }
        break;
       }
       case 1:  {
        $261 = (_tre_stack_pop_voidptr($1)|0);
        if ($7) {
         $262 = ((($261)) + 4|0);
         $263 = HEAP32[$262>>2]|0;
         $264 = HEAP32[$263>>2]|0;
         $265 = ((($264)) + 20|0);
         $266 = HEAP32[$265>>2]|0;
         $267 = (_tre_stack_pop_int($1)|0);
         $268 = (($267) + ($266))|0;
         $269 = ((($261)) + 20|0);
         HEAP32[$269>>2] = $268;
         $$14530558 = -1;
         label = 103;
        } else {
         $270 = (_tre_stack_pop_int($1)|0);
         $271 = (_tre_stack_pop_int($1)|0);
         $272 = ($270|0)==(0);
         if ($272) {
          $$14530558 = $$0516577;
          label = 103;
         } else {
          $$14530557 = $271;$273 = 0;
         }
        }
        if ((label|0) == 103) {
         label = 0;
         $$14530557 = $$14530558;$273 = 1;
        }
        $$3535 = $7 ? $$0532574 : $273;
        $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$14530557;$$18 = 0;$$2461 = $$0459592;$$4536 = $$3535;$$9471 = $$0462589;
        break;
       }
       case 4:  {
        $274 = (_tre_stack_pop_int($1)|0);
        $275 = (_tre_stack_pop_int($1)|0);
        $276 = ($274|0)>(-1);
        $spec$select552 = $276 ? $274 : $$0488583;
        $$10498 = $spec$select552;$$11515 = $275;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
        break;
       }
       case 5:  {
        $277 = (_tre_stack_pop_voidptr($1)|0);
        if ($7) {
         $278 = ((($277)) + 4|0);
         $279 = HEAP32[$278>>2]|0;
         $280 = HEAP32[$279>>2]|0;
         $281 = ((($280)) + 20|0);
         $282 = HEAP32[$281>>2]|0;
         $283 = ((($279)) + 4|0);
         $284 = HEAP32[$283>>2]|0;
         $285 = ((($284)) + 20|0);
         $286 = HEAP32[$285>>2]|0;
         $287 = (($286) + ($282))|0;
         $288 = ((($277)) + 20|0);
         HEAP32[$288>>2] = $287;
         $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
        } else {
         $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
        }
        break;
       }
       case 2:  {
        $$1460 = $$0459592;
        while(1) {
         $289 = HEAP32[$$1460>>2]|0;
         $290 = ($289|0)>(-1);
         $291 = ((($$1460)) + 4|0);
         if ($290) {
          $$1460 = $291;
         } else {
          $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$1460;$$4536 = $$0532574;$$9471 = $$0462589;
          break;
         }
        }
        break;
       }
       case 3:  {
        $292 = (_tre_stack_pop_voidptr($1)|0);
        $293 = (_tre_stack_pop_voidptr($1)|0);
        $294 = (_tre_stack_pop_voidptr($1)|0);
        $295 = (_tre_stack_pop_int($1)|0);
        if ($7) {
         $296 = ((($294)) + 4|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = HEAP32[$297>>2]|0;
         $299 = ((($298)) + 20|0);
         $300 = HEAP32[$299>>2]|0;
         $301 = ((($297)) + 4|0);
         $302 = HEAP32[$301>>2]|0;
         $303 = ((($302)) + 20|0);
         $304 = HEAP32[$303>>2]|0;
         $305 = ((($294)) + 16|0);
         $306 = HEAP32[$305>>2]|0;
         $307 = ($306|0)>(0);
         $308 = $307 ? 2 : 0;
         $309 = (($300) + ($295))|0;
         $310 = (($309) + ($304))|0;
         $311 = (($310) + ($308))|0;
         $312 = ((($294)) + 20|0);
         HEAP32[$312>>2] = $311;
         $$pre$phi615Z2D = $305;
        } else {
         $$pre612 = ((($294)) + 16|0);
         $$pre$phi615Z2D = $$pre612;
        }
        $313 = (_tre_stack_pop_voidptr($1)|0);
        $314 = (_tre_stack_pop_int($1)|0);
        $315 = (_tre_stack_pop_int($1)|0);
        $316 = HEAP32[$$pre$phi615Z2D>>2]|0;
        $317 = ($316|0)>(0);
        if ($317) {
         if ($7) {
          $$16 = 0;
         } else {
          $318 = (_tre_add_tag_right($0,$292,$314)|0);
          $319 = HEAP32[$35>>2]|0;
          $320 = (($319) + ($314<<2)|0);
          HEAP32[$320>>2] = 1;
          $321 = ($318|0)==(0);
          if ($321) {
           $322 = (_tre_add_tag_right($0,$293,$315)|0);
           $$15 = $322;
          } else {
           $$15 = $318;
          }
          $323 = HEAP32[$35>>2]|0;
          $324 = (($323) + ($315<<2)|0);
          HEAP32[$324>>2] = 1;
          $$16 = $$15;
         }
         $325 = (($$0462589) + 2)|0;
         $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = $$16;$$2461 = $313;$$4536 = 1;$$9471 = $325;
        } else {
         $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $313;$$4536 = 1;$$9471 = $$0462589;
        }
        break;
       }
       default: {
        $$10498 = $$0488583;$$11515 = $$0504580;$$14486 = $$0472586;$$15531 = $$0516577;$$18 = 0;$$2461 = $$0459592;$$4536 = $$0532574;$$9471 = $$0462589;
       }
       }
      } while(0);
      $326 = (_tre_stack_num_objects($1)|0);
      $327 = ($326|0)<=($4|0);
      $328 = ($$18|0)!=(0);
      $or$cond5 = $328 | $327;
      if ($or$cond5) {
       $$0458$lcssa = $$18;$$0459$lcssa = $$2461;$$0462$lcssa = $$9471;$$0472$lcssa = $$14486;$$0488$lcssa = $$10498;$$0516$lcssa = $$15531;
       break L15;
      } else {
       $$0459592 = $$2461;$$0462589 = $$9471;$$0472586 = $$14486;$$0488583 = $$10498;$$0504580 = $$11515;$$0516577 = $$15531;$$0532574 = $$4536;
      }
     }
    }
   } while(0);
   if ($7) {
    $$15487 = $$0472$lcssa;
   } else {
    _tre_purge_regset($$0459$lcssa,$3,$$0488$lcssa);
    $329 = ($$0516$lcssa|0)>(-1);
    if ($329) {
     $330 = ((($3)) + 36|0);
     $331 = HEAP32[$330>>2]|0;
     $$0 = 0;
     while(1) {
      $332 = (($331) + ($$0<<2)|0);
      $333 = HEAP32[$332>>2]|0;
      $334 = ($333|0)>(-1);
      $335 = (($$0) + 1)|0;
      if ($334) {
       $$0 = $335;
      } else {
       break;
      }
     }
     HEAP32[$332>>2] = $$0488$lcssa;
     $336 = (($331) + ($335<<2)|0);
     HEAP32[$336>>2] = $$0516$lcssa;
     $337 = (($$0) + 2)|0;
     $338 = (($331) + ($337<<2)|0);
     HEAP32[$338>>2] = -1;
     $339 = (($$0472$lcssa) + 1)|0;
     $$15487 = $339;
    } else {
     $$15487 = $$0472$lcssa;
    }
   }
   $340 = ((($3)) + 48|0);
   HEAP32[$340>>2] = $$0462$lcssa;
   $341 = ((($3)) + 40|0);
   HEAP32[$341>>2] = $$0462$lcssa;
   $342 = ((($3)) + 44|0);
   HEAP32[$342>>2] = $$15487;
   _free($15);
   _free($20);
   _free($25);
   $$0457 = $$0458$lcssa;
  }
 } while(0);
 return ($$0457|0);
}
function _tre_expand_ast($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0167$lcssa = 0, $$0180$lcssa = 0, $$0185$lcssa = 0, $$0185244275 = 0, $$0189$lcssa = 0, $$0189253 = 0, $$0194252 = 0, $$11178$ph = 0, $$1184248 = 0, $$1186 = 0, $$13 = 0, $$2182 = 0, $$3188 = 0, $$3188216 = 0, $$3192$ph = 0, $$4$ph = 0, $$4198$ph = 0, $$6$ph = 0, $$8$ph = 0, $$lcssa = 0;
 var $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $spec$store$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = (_tre_stack_num_objects($1)|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$6>>2] = 0;
 $11 = (_tre_stack_push_voidptr($1,$2)|0);
 $12 = ($11|0)==(0);
 do {
  if ($12) {
   $13 = (_tre_stack_push_int($1,0)|0);
   $14 = ($13|0)==(0);
   if ($14) {
    $$0189253 = 0;$$0194252 = 0;$28 = 0;
    L4: while(1) {
     $15 = (_tre_stack_num_objects($1)|0);
     $16 = ($15|0)>($10|0);
     if (!($16)) {
      $$0167$lcssa = 0;$$0189$lcssa = $$0189253;
      label = 62;
      break;
     }
     $17 = (_tre_stack_pop_int($1)|0);
     $18 = (_tre_stack_pop_voidptr($1)|0);
     L7: do {
      switch ($17|0) {
      case 0:  {
       $19 = HEAP32[$18>>2]|0;
       switch ($19|0) {
       case 0:  {
        $20 = ((($18)) + 4|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = HEAP32[$21>>2]|0;
        $23 = ($22|0)>(-1);
        $24 = ($22|0)==(-4);
        $or$cond = $23 | $24;
        if (!($or$cond)) {
         $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
         break L7;
        }
        $25 = ((($21)) + 8|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($26) + ($28))|0;
        HEAP32[$25>>2] = $27;
        $29 = HEAP32[$6>>2]|0;
        $30 = ($27|0)>($29|0);
        if (!($30)) {
         $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
         break L7;
        }
        HEAP32[$6>>2] = $27;
        $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
        break L7;
        break;
       }
       case 3:  {
        $31 = ((($18)) + 4|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = ((($32)) + 4|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = (_tre_stack_push_voidptr($1,$34)|0);
        $36 = ($35|0)==(0);
        if (!($36)) {
         $$0167$lcssa = $35;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $37 = (_tre_stack_push_int($1,0)|0);
        $38 = ($37|0)==(0);
        if (!($38)) {
         $$0167$lcssa = $37;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $39 = HEAP32[$32>>2]|0;
        $40 = (_tre_stack_push_voidptr($1,$39)|0);
        $41 = ($40|0)==(0);
        if (!($41)) {
         $$0167$lcssa = $40;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $42 = (_tre_stack_push_int($1,0)|0);
        $$11178$ph = $42;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
        break L7;
        break;
       }
       case 1:  {
        $43 = ((($18)) + 4|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ((($44)) + 4|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = (_tre_stack_push_voidptr($1,$46)|0);
        $48 = ($47|0)==(0);
        if (!($48)) {
         $$0167$lcssa = $47;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $49 = (_tre_stack_push_int($1,0)|0);
        $50 = ($49|0)==(0);
        if (!($50)) {
         $$0167$lcssa = $49;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $51 = HEAP32[$44>>2]|0;
        $52 = (_tre_stack_push_voidptr($1,$51)|0);
        $53 = ($52|0)==(0);
        if (!($53)) {
         $$0167$lcssa = $52;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $54 = (_tre_stack_push_int($1,0)|0);
        $$11178$ph = $54;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
        break L7;
        break;
       }
       case 2:  {
        $55 = ((($18)) + 4|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (_tre_stack_push_int($1,$28)|0);
        $58 = ($57|0)==(0);
        if (!($58)) {
         $$0167$lcssa = $57;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $59 = (_tre_stack_push_voidptr($1,$18)|0);
        $60 = ($59|0)==(0);
        if (!($60)) {
         $$0167$lcssa = $59;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $61 = (_tre_stack_push_int($1,1)|0);
        $62 = ($61|0)==(0);
        if (!($62)) {
         $$0167$lcssa = $61;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $63 = HEAP32[$56>>2]|0;
        $64 = (_tre_stack_push_voidptr($1,$63)|0);
        $65 = ($64|0)==(0);
        if (!($65)) {
         $$0167$lcssa = $64;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $66 = (_tre_stack_push_int($1,0)|0);
        $67 = ($66|0)==(0);
        if (!($67)) {
         $$0167$lcssa = $66;$$0189$lcssa = $$0189253;
         label = 62;
         break L4;
        }
        $68 = ((($56)) + 4|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)>(1);
        if ($70) {
         label = 25;
        } else {
         $71 = ((($56)) + 8|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ($72|0)>(1);
         if ($73) {
          label = 25;
         } else {
          $152 = $28;
         }
        }
        if ((label|0) == 25) {
         label = 0;
         HEAP32[$5>>2] = 0;
         $152 = 0;
        }
        $74 = (($$0194252) + 1)|0;
        $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $74;$151 = $152;
        break L7;
        break;
       }
       default: {
        $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
        break L7;
       }
       }
       break;
      }
      case 1:  {
       $75 = ((($18)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = (_tre_stack_pop_int($1)|0);
       HEAP32[$5>>2] = $77;
       $78 = ((($76)) + 4|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)>(1);
       if ($80) {
        HEAP32[$7>>2] = 0;
        label = 31;
       } else {
        $81 = ((($76)) + 8|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = ($82|0)>(1);
        if ($83) {
         HEAP32[$7>>2] = 0;
         $84 = ($79|0)>(0);
         if ($84) {
          label = 31;
         } else {
          $$0180$lcssa = $77;$$0185$lcssa = 0;$$lcssa = $79;
          label = 39;
         }
        } else {
         $143 = $77;
        }
       }
       L37: do {
        if ((label|0) == 31) {
         label = 0;
         $85 = ($79|0)>(1);
         $86 = $85 ? 1 : 2;
         $87 = HEAP32[$76>>2]|0;
         $88 = (_tre_copy_ast($0,$1,$87,$86,$5,$4,$8,$6)|0);
         $89 = ($88|0)==(0);
         if (!($89)) {
          $$4$ph = $88;
          label = 36;
          break L4;
         }
         $$0185244275 = 0;$153 = $77;$96 = 1;
         while(1) {
          $90 = ($$0185244275|0)==(0|0);
          $91 = HEAP32[$8>>2]|0;
          if ($90) {
           $$1186 = $91;
          } else {
           $92 = (_tre_ast_new_catenation($0,$$0185244275,$91)|0);
           $$1186 = $92;
          }
          $93 = ($$1186|0)==(0|0);
          if ($93) {
           $$4$ph = 12;
           label = 36;
           break L4;
          }
          $94 = HEAP32[$78>>2]|0;
          $95 = ($96|0)<($94|0);
          if (!($95)) {
           $$0180$lcssa = $153;$$0185$lcssa = $$1186;$$lcssa = $94;
           label = 39;
           break L37;
          }
          $$pre = HEAP32[$5>>2]|0;
          $97 = (($96) + 1)|0;
          $98 = ($97|0)<($94|0);
          $99 = $98 ? 1 : 2;
          $100 = HEAP32[$76>>2]|0;
          $101 = (_tre_copy_ast($0,$1,$100,$99,$5,$4,$8,$6)|0);
          $102 = ($101|0)==(0);
          if ($102) {
           $$0185244275 = $$1186;$153 = $$pre;$96 = $97;
          } else {
           $$4$ph = $101;
           label = 36;
           break L4;
          }
         }
        }
       } while(0);
       if ((label|0) == 39) {
        label = 0;
        $103 = ((($76)) + 8|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = ($104|0)==(-1);
        if ($105) {
         $106 = HEAP32[$5>>2]|0;
         $107 = HEAP32[$76>>2]|0;
         $108 = (_tre_copy_ast($0,$1,$107,0,$5,0,$7,$6)|0);
         $109 = ($108|0)==(0);
         if (!($109)) {
          $$8$ph = $108;
          break L4;
         }
         $110 = HEAP32[$7>>2]|0;
         $111 = (_tre_ast_new_iter($0,$110,0,-1,0)|0);
         HEAP32[$7>>2] = $111;
         $112 = ($111|0)==(0|0);
         if ($112) {
          $$8$ph = 12;
          break L4;
         } else {
          $$2182 = $106;$135 = $111;
         }
        } else {
         $113 = ($$lcssa|0)<($104|0);
         if ($113) {
          $$1184248 = $$lcssa;$119 = 0;
          while(1) {
           $114 = HEAP32[$5>>2]|0;
           $115 = HEAP32[$76>>2]|0;
           $116 = (_tre_copy_ast($0,$1,$115,0,$5,0,$9,$6)|0);
           $117 = ($116|0)==(0);
           if (!($117)) {
            $$6$ph = $116;
            label = 51;
            break L4;
           }
           $118 = ($119|0)==(0|0);
           if ($118) {
            $122 = HEAP32[$9>>2]|0;
            HEAP32[$7>>2] = $122;
            $123 = $122;
            $125 = $123;
           } else {
            $120 = HEAP32[$9>>2]|0;
            $121 = (_tre_ast_new_catenation($0,$120,$119)|0);
            HEAP32[$7>>2] = $121;
            $125 = $121;
           }
           $124 = ($125|0)==(0|0);
           if ($124) {
            $$6$ph = 12;
            label = 51;
            break L4;
           }
           $126 = (_tre_ast_new_literal($0,-1,-1,-1)|0);
           $127 = ($126|0)==(0|0);
           if ($127) {
            $$6$ph = 12;
            label = 51;
            break L4;
           }
           $128 = (_tre_ast_new_union($0,$126,$125)|0);
           HEAP32[$7>>2] = $128;
           $129 = ($128|0)==(0|0);
           if ($129) {
            $$6$ph = 12;
            label = 51;
            break L4;
           }
           $130 = (($$1184248) + 1)|0;
           $131 = HEAP32[$103>>2]|0;
           $132 = ($130|0)<($131|0);
           if ($132) {
            $$1184248 = $130;$119 = $128;
           } else {
            $$2182 = $114;$135 = $128;
            break;
           }
          }
         } else {
          $$2182 = $$0180$lcssa;$135 = 0;
         }
        }
        HEAP32[$5>>2] = $$2182;
        $133 = ($$0185$lcssa|0)==(0|0);
        if ($133) {
         $$3188 = $135;
         label = 56;
        } else {
         $134 = ($135|0)==(0|0);
         if ($134) {
          $$3188216 = $$0185$lcssa;
         } else {
          $136 = (_tre_ast_new_catenation($0,$$0185$lcssa,$135)|0);
          $$3188 = $136;
          label = 56;
         }
        }
        if ((label|0) == 56) {
         label = 0;
         $137 = ($$3188|0)==(0|0);
         if ($137) {
          $$8$ph = 12;
          break L4;
         } else {
          $$3188216 = $$3188;
         }
        }
        $138 = ((($$3188216)) + 4|0);
        $139 = HEAP32[$138>>2]|0;
        HEAP32[$75>>2] = $139;
        $140 = HEAP32[$$3188216>>2]|0;
        HEAP32[$18>>2] = $140;
        $143 = $$2182;
       }
       $141 = (($$0194252) + -1)|0;
       $142 = (($143) - ($77))|0;
       $144 = (($142) + ($$0189253))|0;
       $145 = ($141|0)==(0);
       if ($145) {
        HEAP32[$5>>2] = $144;
        $$11178$ph = 0;$$3192$ph = $144;$$4198$ph = 0;$151 = $144;
       } else {
        $$11178$ph = 0;$$3192$ph = $144;$$4198$ph = $141;$151 = $143;
       }
       break;
      }
      default: {
       $$11178$ph = 0;$$3192$ph = $$0189253;$$4198$ph = $$0194252;$151 = $28;
      }
      }
     } while(0);
     $146 = ($$11178$ph|0)==(0);
     if ($146) {
      $$0189253 = $$3192$ph;$$0194252 = $$4198$ph;$28 = $151;
     } else {
      $$0167$lcssa = $$11178$ph;$$0189$lcssa = $$3192$ph;
      label = 62;
      break;
     }
    }
    if ((label|0) == 36) {
     $$8$ph = $$4$ph;
    }
    else if ((label|0) == 51) {
     $$8$ph = $$6$ph;
    }
    else if ((label|0) == 62) {
     $147 = HEAP32[$3>>2]|0;
     $148 = (($147) + ($$0189$lcssa))|0;
     $149 = HEAP32[$6>>2]|0;
     $150 = ($149|0)>($148|0);
     $spec$store$select = $150 ? $149 : $148;
     HEAP32[$3>>2] = $spec$store$select;
     $$13 = $$0167$lcssa;
     break;
    }
    $$13 = $$8$ph;
   } else {
    $$13 = $13;
   }
  } else {
   $$13 = $11;
  }
 } while(0);
 STACKTOP = sp;return ($$13|0);
}
function _tre_ast_new_literal($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (___tre_mem_alloc_impl($0,0,0,1,20)|0);
 $5 = (_tre_ast_new_node($0,0,$4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
 } else {
  HEAP32[$4>>2] = $1;
  $7 = ((($4)) + 4|0);
  HEAP32[$7>>2] = $2;
  $8 = ((($4)) + 8|0);
  HEAP32[$8>>2] = $3;
  $$0 = $5;
 }
 return ($$0|0);
}
function _tre_ast_new_catenation($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$0 = $2;
 } else {
  $4 = (___tre_mem_alloc_impl($0,0,0,1,8)|0);
  $5 = (_tre_ast_new_node($0,1,$4)|0);
  $6 = ($5|0)==(0|0);
  if ($6) {
   $$0 = 0;
  } else {
   HEAP32[$4>>2] = $1;
   $7 = ((($4)) + 4|0);
   HEAP32[$7>>2] = $2;
   $8 = ((($1)) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($2)) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($9))|0;
   $13 = ((($5)) + 16|0);
   HEAP32[$13>>2] = $12;
   $$0 = $5;
  }
 }
 return ($$0|0);
}
function _tre_compute_nfl($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$21$ph = 0, $$24 = 0, $$pre$phi390Z2D = 0, $$pre$pre = 0, $$pre389 = 0, $$sink = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = (_tre_stack_num_objects($1)|0);
 $6 = (_tre_stack_push_voidptr($1,$2)|0);
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $8 = (_tre_stack_push_int($1,0)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = (_tre_stack_num_objects($1)|0);
    $11 = ($10|0)>($5|0);
    if ($11) {
     L5: while(1) {
      $12 = (_tre_stack_pop_int($1)|0);
      $13 = (_tre_stack_pop_voidptr($1)|0);
      L7: do {
       switch ($12|0) {
       case 0:  {
        $14 = HEAP32[$13>>2]|0;
        switch ($14|0) {
        case 0:  {
         $15 = ((($13)) + 4|0);
         $16 = HEAP32[$15>>2]|0;
         $17 = HEAP32[$16>>2]|0;
         $18 = ($17|0)==(-4);
         if ($18) {
          $19 = ((($13)) + 8|0);
          HEAP32[$19>>2] = 0;
          $20 = ((($16)) + 8|0);
          $21 = HEAP32[$20>>2]|0;
          $22 = (_tre_set_one($0,$21,0,1114111,0,0,-1)|0);
          $23 = ((($13)) + 24|0);
          HEAP32[$23>>2] = $22;
          $24 = ($22|0)==(0|0);
          if ($24) {
           $$24 = 12;
           break L1;
          }
          $25 = HEAP32[$20>>2]|0;
          $26 = ((($16)) + 4|0);
          $27 = HEAP32[$26>>2]|0;
          $28 = (_tre_set_one($0,$25,0,1114111,0,0,$27)|0);
          $29 = ((($13)) + 28|0);
          HEAP32[$29>>2] = $28;
          $30 = ($28|0)==(0|0);
          if ($30) {
           $$24 = 12;
           break L1;
          } else {
           break L7;
          }
         }
         $31 = ($17|0)<(0);
         $32 = ((($13)) + 8|0);
         if ($31) {
          HEAP32[$32>>2] = 1;
          $33 = (_tre_set_empty($0)|0);
          $34 = ((($13)) + 24|0);
          HEAP32[$34>>2] = $33;
          $35 = ($33|0)==(0|0);
          if ($35) {
           $$24 = 12;
           break L1;
          }
          $36 = (_tre_set_empty($0)|0);
          $37 = ((($13)) + 28|0);
          HEAP32[$37>>2] = $36;
          $38 = ($36|0)==(0|0);
          if ($38) {
           $$24 = 12;
           break L1;
          } else {
           break L7;
          }
         } else {
          HEAP32[$32>>2] = 0;
          $39 = ((($16)) + 8|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ((($16)) + 4|0);
          $42 = HEAP32[$41>>2]|0;
          $43 = (_tre_set_one($0,$40,$17,$42,0,0,-1)|0);
          $44 = ((($13)) + 24|0);
          HEAP32[$44>>2] = $43;
          $45 = ($43|0)==(0|0);
          if ($45) {
           $$24 = 12;
           break L1;
          }
          $46 = HEAP32[$39>>2]|0;
          $47 = HEAP32[$16>>2]|0;
          $48 = HEAP32[$41>>2]|0;
          $49 = ((($16)) + 12|0);
          $50 = HEAP32[$49>>2]|0;
          $51 = ((($16)) + 16|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (_tre_set_one($0,$46,$47,$48,$50,$52,-1)|0);
          $54 = ((($13)) + 28|0);
          HEAP32[$54>>2] = $53;
          $55 = ($53|0)==(0|0);
          if ($55) {
           $$24 = 12;
           break L1;
          } else {
           break L7;
          }
         }
         break;
        }
        case 3:  {
         $56 = (_tre_stack_push_voidptr($1,$13)|0);
         $57 = ($56|0)==(0);
         if (!($57)) {
          $$24 = $56;
          break L1;
         }
         $58 = (_tre_stack_push_int($1,1)|0);
         $59 = ($58|0)==(0);
         if (!($59)) {
          $$24 = $58;
          break L1;
         }
         $60 = ((($13)) + 4|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = ((($61)) + 4|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (_tre_stack_push_voidptr($1,$63)|0);
         $65 = ($64|0)==(0);
         if (!($65)) {
          $$24 = $64;
          break L1;
         }
         $66 = (_tre_stack_push_int($1,0)|0);
         $67 = ($66|0)==(0);
         if (!($67)) {
          $$24 = $66;
          break L1;
         }
         $68 = HEAP32[$60>>2]|0;
         $69 = HEAP32[$68>>2]|0;
         $70 = (_tre_stack_push_voidptr($1,$69)|0);
         $71 = ($70|0)==(0);
         if (!($71)) {
          $$24 = $70;
          break L1;
         }
         $72 = (_tre_stack_push_int($1,0)|0);
         $73 = ($72|0)==(0);
         if ($73) {
          break L7;
         } else {
          $$24 = $72;
          break L1;
         }
         break;
        }
        case 1:  {
         $74 = (_tre_stack_push_voidptr($1,$13)|0);
         $75 = ($74|0)==(0);
         if (!($75)) {
          $$24 = $74;
          break L1;
         }
         $76 = (_tre_stack_push_int($1,2)|0);
         $77 = ($76|0)==(0);
         if (!($77)) {
          $$24 = $76;
          break L1;
         }
         $78 = ((($13)) + 4|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = ((($79)) + 4|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = (_tre_stack_push_voidptr($1,$81)|0);
         $83 = ($82|0)==(0);
         if (!($83)) {
          $$24 = $82;
          break L1;
         }
         $84 = (_tre_stack_push_int($1,0)|0);
         $85 = ($84|0)==(0);
         if (!($85)) {
          $$24 = $84;
          break L1;
         }
         $86 = HEAP32[$78>>2]|0;
         $87 = HEAP32[$86>>2]|0;
         $88 = (_tre_stack_push_voidptr($1,$87)|0);
         $89 = ($88|0)==(0);
         if (!($89)) {
          $$24 = $88;
          break L1;
         }
         $90 = (_tre_stack_push_int($1,0)|0);
         $91 = ($90|0)==(0);
         if ($91) {
          break L7;
         } else {
          $$24 = $90;
          break L1;
         }
         break;
        }
        case 2:  {
         $92 = (_tre_stack_push_voidptr($1,$13)|0);
         $93 = ($92|0)==(0);
         if (!($93)) {
          $$24 = $92;
          break L1;
         }
         $94 = (_tre_stack_push_int($1,3)|0);
         $95 = ($94|0)==(0);
         if (!($95)) {
          $$24 = $94;
          break L1;
         }
         $96 = ((($13)) + 4|0);
         $97 = HEAP32[$96>>2]|0;
         $98 = HEAP32[$97>>2]|0;
         $99 = (_tre_stack_push_voidptr($1,$98)|0);
         $100 = ($99|0)==(0);
         if (!($100)) {
          $$24 = $99;
          break L1;
         }
         $101 = (_tre_stack_push_int($1,0)|0);
         $102 = ($101|0)==(0);
         if ($102) {
          break L7;
         } else {
          $$24 = $101;
          break L1;
         }
         break;
        }
        default: {
         break L7;
        }
        }
        break;
       }
       case 1:  {
        $103 = ((($13)) + 4|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = HEAP32[$104>>2]|0;
        $106 = ((($105)) + 8|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = ($107|0)==(0);
        $109 = ((($104)) + 4|0);
        $110 = HEAP32[$109>>2]|0;
        if ($108) {
         $111 = ((($110)) + 8|0);
         $112 = HEAP32[$111>>2]|0;
         $113 = ($112|0)!=(0);
         $115 = $113;
        } else {
         $115 = 1;
        }
        $114 = $115&1;
        $116 = ((($13)) + 8|0);
        HEAP32[$116>>2] = $114;
        $117 = ((($105)) + 24|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = ((($110)) + 24|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = (_tre_set_union($0,$118,$120,0,0)|0);
        $122 = ((($13)) + 24|0);
        HEAP32[$122>>2] = $121;
        $123 = ($121|0)==(0|0);
        if ($123) {
         $$24 = 12;
         break L1;
        }
        $124 = HEAP32[$104>>2]|0;
        $125 = ((($124)) + 28|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = HEAP32[$109>>2]|0;
        $128 = ((($127)) + 28|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = (_tre_set_union($0,$126,$129,0,0)|0);
        $131 = ((($13)) + 28|0);
        HEAP32[$131>>2] = $130;
        $132 = ($130|0)==(0|0);
        if ($132) {
         $$24 = 12;
         break L1;
        }
        break;
       }
       case 3:  {
        $133 = ((($13)) + 4|0);
        $134 = HEAP32[$133>>2]|0;
        $135 = ((($134)) + 4|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = ($136|0)==(0);
        $$pre$pre = HEAP32[$134>>2]|0;
        if ($137) {
         $$sink = 1;
        } else {
         $138 = ((($$pre$pre)) + 8|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ($139|0)!=(0);
         $spec$select = $140&1;
         $$sink = $spec$select;
        }
        $141 = ((($13)) + 8|0);
        HEAP32[$141>>2] = $$sink;
        $142 = ((($$pre$pre)) + 24|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = ((($13)) + 24|0);
        HEAP32[$144>>2] = $143;
        $145 = ((($$pre$pre)) + 28|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = ((($13)) + 28|0);
        HEAP32[$147>>2] = $146;
        break;
       }
       case 2:  {
        $148 = ((($13)) + 4|0);
        $149 = HEAP32[$148>>2]|0;
        $150 = HEAP32[$149>>2]|0;
        $151 = ((($150)) + 8|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = ($152|0)==(0);
        if ($153) {
         $160 = 0;
        } else {
         $154 = ((($149)) + 4|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = ((($155)) + 8|0);
         $157 = HEAP32[$156>>2]|0;
         $158 = ($157|0)!=(0);
         $160 = $158;
        }
        $159 = $160&1;
        $161 = ((($13)) + 8|0);
        HEAP32[$161>>2] = $159;
        $162 = HEAP32[$151>>2]|0;
        $163 = ($162|0)==(0);
        if ($163) {
         $186 = ((($150)) + 24|0);
         $187 = HEAP32[$186>>2]|0;
         $188 = ((($13)) + 24|0);
         HEAP32[$188>>2] = $187;
         $$pre389 = ((($149)) + 4|0);
         $$pre$phi390Z2D = $$pre389;
        } else {
         $164 = (_tre_match_empty($1,$150,0,0,$3)|0);
         $165 = ($164|0)==(0);
         if (!($165)) {
          $$21$ph = $164;
          break L5;
         }
         $166 = HEAP32[$3>>2]|0;
         $167 = $166 << 2;
         $168 = (($167) + 4)|0;
         $169 = (_malloc($168)|0);
         $170 = ($169|0)==(0|0);
         if ($170) {
          $$21$ph = 12;
          break L5;
         }
         HEAP32[$169>>2] = -1;
         HEAP32[$4>>2] = 0;
         $171 = HEAP32[$149>>2]|0;
         $172 = (_tre_match_empty($1,$171,$169,$4,0)|0);
         $173 = ($172|0)==(0);
         if (!($173)) {
          label = 44;
          break L5;
         }
         $174 = ((($149)) + 4|0);
         $175 = HEAP32[$174>>2]|0;
         $176 = ((($175)) + 24|0);
         $177 = HEAP32[$176>>2]|0;
         $178 = HEAP32[$149>>2]|0;
         $179 = ((($178)) + 24|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = HEAP32[$4>>2]|0;
         $182 = (_tre_set_union($0,$177,$180,$169,$181)|0);
         $183 = ((($13)) + 24|0);
         HEAP32[$183>>2] = $182;
         _free($169);
         $184 = HEAP32[$183>>2]|0;
         $185 = ($184|0)==(0|0);
         if ($185) {
          $$21$ph = 12;
          break L5;
         } else {
          $$pre$phi390Z2D = $174;
         }
        }
        $189 = HEAP32[$$pre$phi390Z2D>>2]|0;
        $190 = ((($189)) + 8|0);
        $191 = HEAP32[$190>>2]|0;
        $192 = ($191|0)==(0);
        if ($192) {
         $214 = ((($189)) + 28|0);
         $215 = HEAP32[$214>>2]|0;
         $216 = ((($13)) + 28|0);
         HEAP32[$216>>2] = $215;
        } else {
         $193 = (_tre_match_empty($1,$189,0,0,$3)|0);
         $194 = ($193|0)==(0);
         if (!($194)) {
          $$21$ph = $193;
          break L5;
         }
         $195 = HEAP32[$3>>2]|0;
         $196 = $195 << 2;
         $197 = (($196) + 4)|0;
         $198 = (_malloc($197)|0);
         $199 = ($198|0)==(0|0);
         if ($199) {
          $$21$ph = 12;
          break L5;
         }
         HEAP32[$198>>2] = -1;
         HEAP32[$4>>2] = 0;
         $200 = HEAP32[$$pre$phi390Z2D>>2]|0;
         $201 = (_tre_match_empty($1,$200,$198,$4,0)|0);
         $202 = ($201|0)==(0);
         if (!($202)) {
          label = 51;
          break L5;
         }
         $203 = HEAP32[$149>>2]|0;
         $204 = ((($203)) + 28|0);
         $205 = HEAP32[$204>>2]|0;
         $206 = HEAP32[$$pre$phi390Z2D>>2]|0;
         $207 = ((($206)) + 28|0);
         $208 = HEAP32[$207>>2]|0;
         $209 = HEAP32[$4>>2]|0;
         $210 = (_tre_set_union($0,$205,$208,$198,$209)|0);
         $211 = ((($13)) + 28|0);
         HEAP32[$211>>2] = $210;
         _free($198);
         $212 = HEAP32[$211>>2]|0;
         $213 = ($212|0)==(0|0);
         if ($213) {
          $$21$ph = 12;
          break L5;
         }
        }
        break;
       }
       default: {
       }
       }
      } while(0);
      $217 = (_tre_stack_num_objects($1)|0);
      $218 = ($217|0)>($5|0);
      if (!($218)) {
       $$24 = 0;
       break L1;
      }
     }
     if ((label|0) == 44) {
      _free($169);
      $$21$ph = $172;
     }
     else if ((label|0) == 51) {
      _free($198);
      $$21$ph = $201;
     }
     $$24 = $$21$ph;
    } else {
     $$24 = 0;
    }
   } else {
    $$24 = $8;
   }
  } else {
   $$24 = $6;
  }
 } while(0);
 STACKTOP = sp;return ($$24|0);
}
function _tre_ast_to_tnfa($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$051 = 0, $$tr = 0, $$tr$be = 0, $$tr$be$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$tr = $0;
 L1: while(1) {
  $4 = HEAP32[$$tr>>2]|0;
  switch ($4|0) {
  case 2:  {
   $25 = ((($$tr)) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26)) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(-1);
   if ($29) {
    $30 = HEAP32[$26>>2]|0;
    $31 = ((($30)) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ((($30)) + 24|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (_tre_make_trans($32,$34,$1,$2,$3)|0);
    $36 = ($35|0)==(0);
    if ($36) {
     $$tr$be$in = $26;
    } else {
     $$051 = $35;
     break L1;
    }
   } else {
    $$tr$be$in = $26;
   }
   break;
  }
  case 3:  {
   $5 = ((($$tr)) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = (_tre_ast_to_tnfa($7,$1,$2,$3)|0);
   $9 = ($8|0)==(0);
   if (!($9)) {
    $$051 = $8;
    break L1;
   }
   $10 = ((($6)) + 4|0);
   $$tr$be$in = $10;
   break;
  }
  case 1:  {
   $11 = ((($$tr)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($13)) + 28|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($12)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($17)) + 24|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (_tre_make_trans($15,$19,$1,$2,$3)|0);
   $21 = ($20|0)==(0);
   if (!($21)) {
    $$051 = $20;
    break L1;
   }
   $22 = HEAP32[$12>>2]|0;
   $23 = (_tre_ast_to_tnfa($22,$1,$2,$3)|0);
   $24 = ($23|0)==(0);
   if ($24) {
    $$tr$be$in = $16;
   } else {
    $$051 = $23;
    break L1;
   }
   break;
  }
  default: {
   $$051 = 0;
   break L1;
  }
  }
  $$tr$be = HEAP32[$$tr$be$in>>2]|0;
  $$tr = $$tr$be;
 }
 return ($$051|0);
}
function _regfree($0) {
 $0 = $0|0;
 var $$04249 = 0, $$045 = 0, $$144 = 0, $$lcssa = 0, $$lcssa43 = 0, $$pre = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  $7 = HEAP32[$2>>2]|0;
  if ($6) {
   $$lcssa43 = $7;
  } else {
   $$04249 = 0;$9 = $7;
   while(1) {
    $8 = (((($9) + ($$04249<<5)|0)) + 8|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $59 = $9;
    } else {
     $12 = (((($9) + ($$04249<<5)|0)) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      $16 = $9;
     } else {
      _free($13);
      $$pre = HEAP32[$2>>2]|0;
      $16 = $$pre;
     }
     $15 = (((($16) + ($$04249<<5)|0)) + 28|0);
     $17 = HEAP32[$15>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $59 = $16;
     } else {
      _free($17);
      $$pre57 = HEAP32[$2>>2]|0;
      $59 = $$pre57;
     }
    }
    $19 = (($$04249) + 1)|0;
    $20 = HEAP32[$4>>2]|0;
    $21 = ($19>>>0)<($20>>>0);
    if ($21) {
     $$04249 = $19;$9 = $59;
    } else {
     $$lcssa43 = $59;
     break;
    }
   }
  }
  $22 = ($$lcssa43|0)==(0|0);
  if (!($22)) {
   _free($$lcssa43);
  }
  $23 = ((($2)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = ((($24)) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $36 = $24;
   } else {
    $$045 = $24;
    while(1) {
     $29 = ((($$045)) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if (!($31)) {
      _free($30);
     }
     $32 = ((($$045)) + 32|0);
     $33 = ((($$045)) + 40|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      break;
     } else {
      $$045 = $32;
     }
    }
    $$pre58 = HEAP32[$23>>2]|0;
    $36 = $$pre58;
   }
   _free($36);
  }
  $37 = ((($2)) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = ((($2)) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0);
   if ($42) {
    $$lcssa = $38;
   } else {
    $$144 = 0;$44 = $38;$60 = $41;
    while(1) {
     $43 = (((($44) + (($$144*12)|0)|0)) + 8|0);
     $45 = HEAP32[$43>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $49 = $60;$61 = $44;
     } else {
      _free($45);
      $$pre59 = HEAP32[$40>>2]|0;
      $$pre60 = HEAP32[$37>>2]|0;
      $49 = $$pre59;$61 = $$pre60;
     }
     $47 = (($$144) + 1)|0;
     $48 = ($47>>>0)<($49>>>0);
     if ($48) {
      $$144 = $47;$44 = $61;$60 = $49;
     } else {
      $$lcssa = $61;
      break;
     }
    }
   }
   _free($$lcssa);
  }
  $50 = ((($2)) + 32|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if (!($52)) {
   _free($51);
  }
  $53 = ((($2)) + 20|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   _free($54);
  }
  $56 = ((($2)) + 36|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   _free($57);
  }
  _free($2);
 }
 return;
}
function _tre_make_trans($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$ph173 = 0, $$0119167 = 0, $$0120162 = 0, $$0121 = 0, $$0124 = 0, $$0127 = 0, $$0128 = 0, $$0131$ph172 = 0, $$0131150 = 0, $$1 = 0, $$1122 = 0, $$1125154 = 0, $$2 = 0, $$2123166 = 0, $$2126 = 0, $$3 = 0, $$4158 = 0, $$5 = 0, $$lcssa143 = 0, $$pre = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($2|0)==(0|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = ($6|0)>(-1);
 L1: do {
  if ($5) {
   if ($7) {
    $134 = ((($1)) + 32|0);
    $138 = $6;$143 = $0;
    while(1) {
     $135 = HEAP32[$1>>2]|0;
     $136 = ($135|0)>(-1);
     if ($136) {
      $137 = (($3) + ($138<<2)|0);
      $139 = HEAP32[$137>>2]|0;
      $140 = (($139) + 1)|0;
      HEAP32[$137>>2] = $140;
      $141 = HEAP32[$134>>2]|0;
      $142 = ($141|0)>(-1);
      if ($142) {
       $148 = $134;
       while(1) {
        $$pre = HEAP32[$143>>2]|0;
        $144 = (($3) + ($$pre<<2)|0);
        $145 = HEAP32[$144>>2]|0;
        $146 = (($145) + 1)|0;
        HEAP32[$144>>2] = $146;
        $147 = ((($148)) + 32|0);
        $149 = HEAP32[$147>>2]|0;
        $150 = ($149|0)>(-1);
        if ($150) {
         $148 = $147;
        } else {
         break;
        }
       }
      }
     }
     $151 = ((($143)) + 32|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)>(-1);
     if ($153) {
      $138 = $152;$143 = $151;
     } else {
      $$0128 = 0;
      break;
     }
    }
   } else {
    $$0128 = 0;
   }
  } else {
   if ($7) {
    $11 = $0;
    while(1) {
     $8 = HEAP32[$1>>2]|0;
     $9 = ($8|0)>(-1);
     L16: do {
      if ($9) {
       $10 = ((($11)) + 4|0);
       $12 = ((($11)) + 8|0);
       $13 = ((($11)) + 16|0);
       $14 = ((($11)) + 20|0);
       $15 = ((($11)) + 24|0);
       $16 = ((($11)) + 28|0);
       $17 = ((($11)) + 12|0);
       $$0$ph173 = -1;$$0131$ph172 = $1;$154 = $8;
       while(1) {
        $$0131150 = $$0131$ph172;$19 = $154;
        while(1) {
         $18 = ($19|0)==($$0$ph173|0);
         if (!($18)) {
          break;
         }
         $20 = ((($$0131150)) + 32|0);
         $21 = HEAP32[$20>>2]|0;
         $22 = ($21|0)>(-1);
         if ($22) {
          $$0131150 = $20;$19 = $21;
         } else {
          break L16;
         }
        }
        $23 = HEAP32[$11>>2]|0;
        $24 = (($4) + ($23<<2)|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = (($2) + ($25<<5)|0);
        $$0127 = $26;
        while(1) {
         $27 = ((($$0127)) + 8|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = ($28|0)==(0|0);
         $30 = ((($$0127)) + 32|0);
         if ($29) {
          break;
         } else {
          $$0127 = $30;
         }
        }
        $31 = ((($$0127)) + 8|0);
        $32 = ((($$0127)) + 40|0);
        HEAP32[$32>>2] = 0;
        $33 = HEAP32[$10>>2]|0;
        HEAP32[$$0127>>2] = $33;
        $34 = HEAP32[$12>>2]|0;
        $35 = ((($$0127)) + 4|0);
        HEAP32[$35>>2] = $34;
        $36 = (($4) + ($19<<2)|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($2) + ($37<<5)|0);
        HEAP32[$31>>2] = $38;
        $39 = ((($$0127)) + 12|0);
        HEAP32[$39>>2] = $19;
        $40 = HEAP32[$13>>2]|0;
        $41 = ((($$0131150)) + 16|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = $42 | $40;
        $44 = HEAP32[$14>>2]|0;
        $45 = ($44|0)==(0);
        $46 = $45 ? 0 : 4;
        $47 = $43 | $46;
        $48 = HEAP32[$15>>2]|0;
        $49 = ($48|0)==(0|0);
        $50 = $49 ? 0 : 8;
        $51 = $47 | $50;
        $52 = ((($$0127)) + 20|0);
        HEAP32[$52>>2] = $51;
        $53 = HEAP32[$16>>2]|0;
        $54 = ($53|0)>(-1);
        $55 = ((($$0127)) + 24|0);
        if ($54) {
         HEAP32[$55>>2] = $53;
         $56 = $51 | 256;
         HEAP32[$52>>2] = $56;
        } else {
         HEAP32[$55>>2] = $44;
        }
        $57 = HEAP32[$15>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         $77 = ((($$0127)) + 28|0);
         HEAP32[$77>>2] = 0;
        } else {
         $$0124 = 0;
         while(1) {
          $59 = (($57) + ($$0124<<2)|0);
          $60 = HEAP32[$59>>2]|0;
          $61 = ($60|0)==(0);
          $62 = (($$0124) + 1)|0;
          if ($61) {
           break;
          } else {
           $$0124 = $62;
          }
         }
         $63 = $62 << 2;
         $64 = (_malloc($63)|0);
         $65 = ((($$0127)) + 28|0);
         HEAP32[$65>>2] = $64;
         $66 = ($64|0)==(0|0);
         if ($66) {
          $$0128 = 12;
          break L1;
         }
         $67 = HEAP32[$15>>2]|0;
         $68 = HEAP32[$67>>2]|0;
         $69 = ($68|0)==(0);
         if ($69) {
          $$lcssa143 = $64;
         } else {
          $$1125154 = 0;$70 = $68;$71 = $64;
          while(1) {
           HEAP32[$71>>2] = $70;
           $72 = (($$1125154) + 1)|0;
           $73 = (($67) + ($72<<2)|0);
           $74 = HEAP32[$73>>2]|0;
           $75 = ($74|0)==(0);
           $76 = (($64) + ($72<<2)|0);
           if ($75) {
            $$lcssa143 = $76;
            break;
           } else {
            $$1125154 = $72;$70 = $74;$71 = $76;
           }
          }
         }
         HEAP32[$$lcssa143>>2] = 0;
        }
        $78 = HEAP32[$17>>2]|0;
        $79 = ($78|0)==(0|0);
        if ($79) {
         $$3 = 0;
        } else {
         $$2126 = 0;
         while(1) {
          $80 = (($78) + ($$2126<<2)|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = ($81|0)>(-1);
          $83 = (($$2126) + 1)|0;
          if ($82) {
           $$2126 = $83;
          } else {
           $$3 = $$2126;
           break;
          }
         }
        }
        $84 = ((($$0131150)) + 12|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($85|0)==(0|0);
        if ($86) {
         $$1122 = 0;
        } else {
         $$0121 = 0;
         while(1) {
          $87 = (($85) + ($$0121<<2)|0);
          $88 = HEAP32[$87>>2]|0;
          $89 = ($88|0)>(-1);
          $90 = (($$0121) + 1)|0;
          if ($89) {
           $$0121 = $90;
          } else {
           $$1122 = $$0121;
           break;
          }
         }
        }
        $91 = ((($$0127)) + 16|0);
        $92 = HEAP32[$91>>2]|0;
        $93 = ($92|0)==(0|0);
        if (!($93)) {
         _free($92);
        }
        HEAP32[$91>>2] = 0;
        $94 = (($$1122) + ($$3))|0;
        $95 = ($94|0)==(0);
        if (!($95)) {
         $96 = $94 << 2;
         $97 = (($96) + 4)|0;
         $98 = (_malloc($97)|0);
         HEAP32[$91>>2] = $98;
         $99 = ($98|0)==(0|0);
         if ($99) {
          $$0128 = 12;
          break L1;
         }
         $100 = HEAP32[$17>>2]|0;
         $101 = ($100|0)==(0|0);
         if ($101) {
          $$5 = 0;
         } else {
          $102 = HEAP32[$100>>2]|0;
          $103 = ($102|0)>(-1);
          if ($103) {
           $$4158 = 0;$105 = $102;
           while(1) {
            $104 = (($98) + ($$4158<<2)|0);
            HEAP32[$104>>2] = $105;
            $106 = (($$4158) + 1)|0;
            $107 = (($100) + ($106<<2)|0);
            $108 = HEAP32[$107>>2]|0;
            $109 = ($108|0)>(-1);
            if ($109) {
             $$4158 = $106;$105 = $108;
            } else {
             $$5 = $106;
             break;
            }
           }
          } else {
           $$5 = 0;
          }
         }
         $110 = HEAP32[$84>>2]|0;
         $111 = ($110|0)==(0|0);
         if ($111) {
          $$2 = $$5;
         } else {
          $112 = HEAP32[$110>>2]|0;
          $113 = ($112|0)>(-1);
          if ($113) {
           $114 = ($$5|0)==(0);
           $$0119167 = $$5;$$2123166 = 0;$120 = $112;
           while(1) {
            L71: do {
             if ($114) {
              label = 44;
             } else {
              $$0120162 = 0;
              while(1) {
               $117 = (($98) + ($$0120162<<2)|0);
               $118 = HEAP32[$117>>2]|0;
               $119 = ($118|0)==($120|0);
               $116 = (($$0120162) + 1)|0;
               if ($119) {
                $$1 = $$0119167;
                break L71;
               }
               $115 = ($116>>>0)<($$5>>>0);
               if ($115) {
                $$0120162 = $116;
               } else {
                label = 44;
                break;
               }
              }
             }
            } while(0);
            if ((label|0) == 44) {
             label = 0;
             $121 = (($$0119167) + 1)|0;
             $122 = (($98) + ($$0119167<<2)|0);
             HEAP32[$122>>2] = $120;
             $$1 = $121;
            }
            $123 = (($$2123166) + 1)|0;
            $124 = (($110) + ($123<<2)|0);
            $125 = HEAP32[$124>>2]|0;
            $126 = ($125|0)>(-1);
            if ($126) {
             $$0119167 = $$1;$$2123166 = $123;$120 = $125;
            } else {
             $$2 = $$1;
             break;
            }
           }
          } else {
           $$2 = $$5;
          }
         }
         $127 = (($98) + ($$2<<2)|0);
         HEAP32[$127>>2] = -1;
        }
        $128 = ((($$0131150)) + 32|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ($129|0)>(-1);
        if ($130) {
         $$0$ph173 = $19;$$0131$ph172 = $128;$154 = $129;
        } else {
         break;
        }
       }
      }
     } while(0);
     $131 = ((($11)) + 32|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($132|0)>(-1);
     if ($133) {
      $11 = $131;
     } else {
      $$0128 = 0;
      break;
     }
    }
   } else {
    $$0128 = 0;
   }
  }
 } while(0);
 return ($$0128|0);
}
function _tre_stack_num_objects($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function _tre_stack_push_voidptr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $2 = sp;
 HEAP32[$2>>2] = $1;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
 $3 = (_tre_stack_push($0,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function _tre_stack_push_int($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp + 4|0;
 $2 = sp;
 HEAP32[$2>>2] = $1;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;
 $3 = (_tre_stack_push($0,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function _tre_stack_pop_int($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($2) + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 return ($7|0);
}
function _tre_stack_pop_voidptr($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($2) + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 return ($7|0);
}
function _tre_set_one($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $7 = (___tre_mem_alloc_impl($0,0,0,1,64)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $$0 = 0;
 } else {
  HEAP32[$7>>2] = $1;
  $9 = ((($7)) + 4|0);
  HEAP32[$9>>2] = $2;
  $10 = ((($7)) + 8|0);
  HEAP32[$10>>2] = $3;
  $11 = ((($7)) + 20|0);
  HEAP32[$11>>2] = $4;
  $12 = ((($7)) + 24|0);
  HEAP32[$12>>2] = $5;
  $13 = ((($7)) + 28|0);
  HEAP32[$13>>2] = $6;
  $14 = ((($7)) + 32|0);
  HEAP32[$14>>2] = -1;
  $15 = ((($7)) + 36|0);
  HEAP32[$15>>2] = -1;
  $16 = ((($7)) + 40|0);
  HEAP32[$16>>2] = -1;
  $$0 = $7;
 }
 return ($$0|0);
}
function _tre_set_empty($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___tre_mem_alloc_impl($0,0,0,1,32)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  HEAP32[$1>>2] = -1;
  $3 = ((($1)) + 4|0);
  HEAP32[$3>>2] = -1;
  $4 = ((($1)) + 8|0);
  HEAP32[$4>>2] = -1;
  $$0 = $1;
 }
 return ($$0|0);
}
function _tre_set_union($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$0166 = 0, $$0167$lcssa = 0, $$0167190 = 0, $$0168$lcssa = 0, $$0168184 = 0, $$0170 = 0, $$0172 = 0, $$0206 = 0, $$1$lcssa = 0, $$1169$lcssa = 0, $$1169195 = 0, $$1171179 = 0, $$1173$lcssa = 0, $$1173200 = 0, $$1178 = 0, $$2 = 0, $$lcssa = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond220 = 0, $exitcond221 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = ($3|0)==(0|0);
 if ($5) {
  $$0$lcssa = 0;
 } else {
  $$0206 = 0;
  while(1) {
   $6 = (($3) + ($$0206<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)>(-1);
   $9 = (($$0206) + 1)|0;
   if ($8) {
    $$0206 = $9;
   } else {
    $$0$lcssa = $$0206;
    break;
   }
  }
 }
 $$0172 = 0;
 while(1) {
  $10 = (($1) + ($$0172<<5)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(-1);
  $13 = (($$0172) + 1)|0;
  if ($12) {
   $$0172 = $13;
  } else {
   break;
  }
 }
 $$0170 = 0;
 while(1) {
  $14 = (($2) + ($$0170<<5)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)>(-1);
  $17 = (($$0170) + 1)|0;
  if ($16) {
   $$0170 = $17;
  } else {
   break;
  }
 }
 $18 = (($$0170) + ($$0172))|0;
 $19 = $18 << 5;
 $20 = (($19) + 32)|0;
 $21 = (___tre_mem_alloc_impl($0,0,0,1,$20)|0);
 $22 = ($21|0)==(0|0);
 L12: do {
  if ($22) {
   $$0166 = 0;
  } else {
   $23 = HEAP32[$1>>2]|0;
   $24 = ($23|0)>(-1);
   if ($24) {
    $25 = ($$0$lcssa|0)==(0);
    $$1173200 = 0;$27 = $23;
    while(1) {
     $26 = (($21) + ($$1173200<<5)|0);
     HEAP32[$26>>2] = $27;
     $28 = (((($1) + ($$1173200<<5)|0)) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (((($21) + ($$1173200<<5)|0)) + 4|0);
     HEAP32[$30>>2] = $29;
     $31 = (((($1) + ($$1173200<<5)|0)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (((($21) + ($$1173200<<5)|0)) + 8|0);
     HEAP32[$33>>2] = $32;
     $34 = (((($1) + ($$1173200<<5)|0)) + 16|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = $35 | $4;
     $37 = (((($21) + ($$1173200<<5)|0)) + 16|0);
     HEAP32[$37>>2] = $36;
     $38 = (((($1) + ($$1173200<<5)|0)) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (((($21) + ($$1173200<<5)|0)) + 20|0);
     HEAP32[$40>>2] = $39;
     $41 = (((($1) + ($$1173200<<5)|0)) + 24|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (((($21) + ($$1173200<<5)|0)) + 24|0);
     HEAP32[$43>>2] = $42;
     $44 = (((($1) + ($$1173200<<5)|0)) + 28|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (((($21) + ($$1173200<<5)|0)) + 28|0);
     HEAP32[$46>>2] = $45;
     $47 = (((($1) + ($$1173200<<5)|0)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0|0);
     $or$cond = $5 & $49;
     if ($or$cond) {
      $50 = (((($21) + ($$1173200<<5)|0)) + 12|0);
      HEAP32[$50>>2] = 0;
     } else {
      if ($49) {
       $$0168$lcssa = 0;
      } else {
       $$0168184 = 0;
       while(1) {
        $51 = (($48) + ($$0168184<<2)|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = ($52|0)>(-1);
        $54 = (($$0168184) + 1)|0;
        if ($53) {
         $$0168184 = $54;
        } else {
         $$0168$lcssa = $$0168184;
         break;
        }
       }
      }
      $55 = (($$0168$lcssa) + ($$0$lcssa))|0;
      $56 = $55 << 2;
      $57 = (($56) + 4)|0;
      $58 = (___tre_mem_alloc_impl($0,0,0,0,$57)|0);
      $59 = ($58|0)==(0|0);
      if ($59) {
       $$0166 = 0;
       break L12;
      }
      $60 = ($$0168$lcssa|0)==(0);
      if ($60) {
       $$0167$lcssa = 0;
      } else {
       $61 = HEAP32[$47>>2]|0;
       $$0167190 = 0;
       while(1) {
        $62 = (($61) + ($$0167190<<2)|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = (($58) + ($$0167190<<2)|0);
        HEAP32[$64>>2] = $63;
        $65 = (($$0167190) + 1)|0;
        $exitcond220 = ($65|0)==($$0168$lcssa|0);
        if ($exitcond220) {
         $$0167$lcssa = $$0168$lcssa;
         break;
        } else {
         $$0167190 = $65;
        }
       }
      }
      if ($25) {
       $$1169$lcssa = 0;
      } else {
       $$1169195 = 0;
       while(1) {
        $66 = (($3) + ($$1169195<<2)|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = (($$1169195) + ($$0167$lcssa))|0;
        $69 = (($58) + ($68<<2)|0);
        HEAP32[$69>>2] = $67;
        $70 = (($$1169195) + 1)|0;
        $exitcond221 = ($70|0)==($$0$lcssa|0);
        if ($exitcond221) {
         $$1169$lcssa = $$0$lcssa;
         break;
        } else {
         $$1169195 = $70;
        }
       }
      }
      $71 = (($$1169$lcssa) + ($$0167$lcssa))|0;
      $72 = (($58) + ($71<<2)|0);
      HEAP32[$72>>2] = -1;
      $73 = (((($21) + ($$1173200<<5)|0)) + 12|0);
      HEAP32[$73>>2] = $58;
     }
     $74 = (($$1173200) + 1)|0;
     $75 = (($1) + ($74<<5)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)>(-1);
     if ($77) {
      $$1173200 = $74;$27 = $76;
     } else {
      $$1173$lcssa = $74;
      break;
     }
    }
   } else {
    $$1173$lcssa = 0;
   }
   $78 = HEAP32[$2>>2]|0;
   $79 = ($78|0)>(-1);
   $80 = (($21) + ($$1173$lcssa<<5)|0);
   if ($79) {
    $$1171179 = 0;$81 = $78;$82 = $80;$86 = $$1173$lcssa;
    while(1) {
     HEAP32[$82>>2] = $81;
     $83 = (((($2) + ($$1171179<<5)|0)) + 4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (((($21) + ($86<<5)|0)) + 4|0);
     HEAP32[$85>>2] = $84;
     $87 = (((($2) + ($$1171179<<5)|0)) + 8|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (((($21) + ($86<<5)|0)) + 8|0);
     HEAP32[$89>>2] = $88;
     $90 = (((($2) + ($$1171179<<5)|0)) + 16|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (((($21) + ($86<<5)|0)) + 16|0);
     HEAP32[$92>>2] = $91;
     $93 = (((($2) + ($$1171179<<5)|0)) + 20|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (((($21) + ($86<<5)|0)) + 20|0);
     HEAP32[$95>>2] = $94;
     $96 = (((($2) + ($$1171179<<5)|0)) + 24|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (((($21) + ($86<<5)|0)) + 24|0);
     HEAP32[$98>>2] = $97;
     $99 = (((($2) + ($$1171179<<5)|0)) + 28|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = (((($21) + ($86<<5)|0)) + 28|0);
     HEAP32[$101>>2] = $100;
     $102 = (((($2) + ($$1171179<<5)|0)) + 12|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103|0)==(0|0);
     if ($104) {
      $105 = (((($21) + ($86<<5)|0)) + 12|0);
      HEAP32[$105>>2] = 0;
     } else {
      $$2 = 0;
      while(1) {
       $106 = (($103) + ($$2<<2)|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = ($107|0)>(-1);
       $109 = (($$2) + 1)|0;
       if ($108) {
        $$2 = $109;
       } else {
        break;
       }
      }
      $110 = $$2 << 2;
      $111 = (($110) + 4)|0;
      $112 = (___tre_mem_alloc_impl($0,0,0,0,$111)|0);
      $113 = ($112|0)==(0|0);
      if ($113) {
       $$0166 = 0;
       break L12;
      }
      $114 = ($$2|0)==(0);
      if ($114) {
       $$1$lcssa = 0;
      } else {
       $115 = HEAP32[$102>>2]|0;
       $$1178 = 0;
       while(1) {
        $116 = (($115) + ($$1178<<2)|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = (($112) + ($$1178<<2)|0);
        HEAP32[$118>>2] = $117;
        $119 = (($$1178) + 1)|0;
        $exitcond = ($119|0)==($$2|0);
        if ($exitcond) {
         $$1$lcssa = $$2;
         break;
        } else {
         $$1178 = $119;
        }
       }
      }
      $120 = (($112) + ($$1$lcssa<<2)|0);
      HEAP32[$120>>2] = -1;
      $121 = (((($21) + ($86<<5)|0)) + 12|0);
      HEAP32[$121>>2] = $112;
     }
     $122 = (($$1171179) + 1)|0;
     $123 = (($2) + ($122<<5)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($124|0)>(-1);
     $126 = (($122) + ($$1173$lcssa))|0;
     $127 = (($21) + ($126<<5)|0);
     if ($125) {
      $$1171179 = $122;$81 = $124;$82 = $127;$86 = $126;
     } else {
      $$lcssa = $127;
      break;
     }
    }
   } else {
    $$lcssa = $80;
   }
   HEAP32[$$lcssa>>2] = -1;
   $$0166 = $21;
  }
 } while(0);
 return ($$0166|0);
}
function _tre_match_empty($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0$lcssa = 0, $$062$lcssa = 0, $$06265 = 0, $$1 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (_tre_stack_num_objects($0)|0);
 $6 = ($4|0)!=(0|0);
 if ($6) {
  HEAP32[$4>>2] = 0;
 }
 $7 = (_tre_stack_push_voidptr($0,$1)|0);
 $8 = ($7|0)==(0);
 L4: do {
  if ($8) {
   $9 = ($3|0)==(0|0);
   $10 = ($2|0)==(0|0);
   while(1) {
    $11 = (_tre_stack_num_objects($0)|0);
    $12 = ($11|0)>($5|0);
    if (!($12)) {
     $$0$lcssa = 0;
     break L4;
    }
    $13 = (_tre_stack_pop_voidptr($0)|0);
    $14 = HEAP32[$13>>2]|0;
    L9: do {
     switch ($14|0) {
     case 0:  {
      $15 = ((($13)) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = HEAP32[$16>>2]|0;
      switch ($17|0) {
      case -3:  {
       break;
      }
      case -2:  {
       if ($9) {
        $$1 = 0;
        break L9;
       }
       $33 = ((($16)) + 4|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = HEAP32[$3>>2]|0;
       $36 = $35 | $34;
       HEAP32[$3>>2] = $36;
       $$1 = 0;
       break L9;
       break;
      }
      default: {
       $$1 = 0;
       break L9;
      }
      }
      $18 = ((($16)) + 4|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19|0)>(-1);
      if ($20) {
       L16: do {
        if (!($10)) {
         $21 = HEAP32[$2>>2]|0;
         $22 = ($21|0)>(-1);
         if ($22) {
          $$06265 = 0;$24 = $21;
          while(1) {
           $23 = ($24|0)==($19|0);
           if ($23) {
            break L16;
           }
           $25 = (($$06265) + 1)|0;
           $26 = (($2) + ($25<<2)|0);
           $27 = HEAP32[$26>>2]|0;
           $28 = ($27|0)>(-1);
           if ($28) {
            $$06265 = $25;$24 = $27;
           } else {
            $$062$lcssa = $25;$$lcssa = $26;
            break;
           }
          }
         } else {
          $$062$lcssa = 0;$$lcssa = $2;
         }
         $29 = (($$062$lcssa) + 1)|0;
         $30 = (($2) + ($29<<2)|0);
         HEAP32[$$lcssa>>2] = $19;
         HEAP32[$30>>2] = -1;
        }
       } while(0);
       if ($6) {
        $31 = HEAP32[$4>>2]|0;
        $32 = (($31) + 1)|0;
        HEAP32[$4>>2] = $32;
        $$1 = 0;
       } else {
        $$1 = 0;
       }
      } else {
       $$1 = 0;
      }
      break;
     }
     case 3:  {
      $37 = ((($13)) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = HEAP32[$38>>2]|0;
      $40 = ((($39)) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0);
      if (!($42)) {
       $43 = (_tre_stack_push_voidptr($0,$39)|0);
       $$1 = $43;
       break L9;
      }
      $44 = ((($38)) + 4|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ((($45)) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==(0);
      if ($48) {
       $$1 = 0;
      } else {
       $49 = (_tre_stack_push_voidptr($0,$45)|0);
       $$1 = $49;
      }
      break;
     }
     case 1:  {
      $50 = ((($13)) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (_tre_stack_push_voidptr($0,$52)|0);
      $54 = ($53|0)==(0);
      if ($54) {
       $55 = ((($51)) + 4|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = (_tre_stack_push_voidptr($0,$56)|0);
       $$1 = $57;
      } else {
       $$1 = $53;
      }
      break;
     }
     case 2:  {
      $58 = ((($13)) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = HEAP32[$59>>2]|0;
      $61 = ((($60)) + 8|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(0);
      if ($63) {
       $$1 = 0;
      } else {
       $64 = (_tre_stack_push_voidptr($0,$60)|0);
       $$1 = $64;
      }
      break;
     }
     default: {
      $$1 = 0;
     }
     }
    } while(0);
    $65 = ($$1|0)==(0);
    if (!($65)) {
     $$0$lcssa = $$1;
     break L4;
    }
   }
  } else {
   $$0$lcssa = $7;
  }
 } while(0);
 return ($$0$lcssa|0);
}
function _tre_stack_push($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $$byval_copy = sp;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = ($3|0)<($4|0);
 if ($5) {
  $6 = ((($0)) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($3<<2)|0);
  $9 = HEAP32[$1>>2]|0;
  HEAP32[$8>>2] = $9;
  $10 = HEAP32[$2>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$2>>2] = $11;
  $$1 = 0;
 } else {
  $12 = ((($0)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($4|0)<($13|0);
  if ($14) {
   $15 = ((($0)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($4))|0;
   $18 = ($17|0)>($13|0);
   $spec$select = $18 ? $13 : $17;
   $19 = ((($0)) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $spec$select << 2;
   $22 = (_realloc($20,$21)|0);
   $23 = ($22|0)==(0|0);
   if ($23) {
    $$1 = 12;
   } else {
    HEAP32[$0>>2] = $spec$select;
    HEAP32[$19>>2] = $22;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;
    (_tre_stack_push($0,$$byval_copy)|0);
    $$1 = 0;
   }
  } else {
   $$1 = 12;
  }
 }
 STACKTOP = sp;return ($$1|0);
}
function _tre_ast_new_node($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___tre_mem_alloc_impl($0,0,0,1,32)|0);
 $4 = ($3|0)!=(0|0);
 $5 = ($2|0)!=(0|0);
 $or$cond = $5 & $4;
 if ($or$cond) {
  $6 = ((($3)) + 4|0);
  HEAP32[$6>>2] = $2;
  HEAP32[$3>>2] = $1;
  $7 = ((($3)) + 8|0);
  HEAP32[$7>>2] = -1;
  $8 = ((($3)) + 12|0);
  HEAP32[$8>>2] = -1;
  $$0 = $3;
 } else {
  $$0 = 0;
 }
 return ($$0|0);
}
function _tre_copy_ast($0,$1,$2,$3,$4,$5,$6,$7) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var $$0$lcssa = 0, $$0143$lcssa = 0, $$0143167 = 0, $$0148166 = 0, $$0152165 = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$1 = 0, $$1144 = 0, $$1149 = 0, $$3146 = 0, $$3151 = 0, $$5157 = 0, $$6 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond162 = 0, $or$cond164 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $8 = (_tre_stack_num_objects($1)|0);
 (_tre_stack_push_voidptr($1,$2)|0);
 $9 = (_tre_stack_push_int($1,0)|0);
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   $11 = $3 & 1;
   $12 = ($11|0)==(0);
   $13 = $3 & 2;
   $14 = ($13|0)!=(0);
   $$0143167 = 0;$$0148166 = 1;$$0152165 = $6;
   while(1) {
    $15 = (_tre_stack_num_objects($1)|0);
    $16 = ($15|0)>($8|0);
    if (!($16)) {
     $$0$lcssa = 0;$$0143$lcssa = $$0143167;
     break L1;
    }
    $17 = (_tre_stack_pop_int($1)|0);
    L6: do {
     switch ($17|0) {
     case 1:  {
      $18 = (_tre_stack_pop_voidptr($1)|0);
      $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $18;$$6 = 0;
      break;
     }
     case 0:  {
      $19 = (_tre_stack_pop_voidptr($1)|0);
      $20 = HEAP32[$19>>2]|0;
      switch ($20|0) {
      case 0:  {
       $21 = ((($19)) + 4|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ((($22)) + 8|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = HEAP32[$22>>2]|0;
       $26 = ((($22)) + 4|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($25|0)>(-1);
       $29 = ($25|0)==(-4);
       $or$cond162 = $28 | $29;
       if ($or$cond162) {
        $30 = HEAP32[$4>>2]|0;
        $31 = (($30) + ($24))|0;
        $32 = (($$0143167) + 1)|0;
        $$0159 = $27;$$0160 = $25;$$0161 = $31;$$1144 = $32;$$1149 = $$0148166;
       } else {
        $33 = ($25|0)!=(-3);
        $or$cond164 = $12 | $33;
        if ($or$cond164) {
         $34 = ($25|0)==(-3);
         if ($34) {
          $35 = ($$0148166|0)!=(0);
          $or$cond = $14 & $35;
          if ($or$cond) {
           $36 = (($5) + ($27<<2)|0);
           HEAP32[$36>>2] = 1;
           $$0159 = $27;$$0160 = -3;$$0161 = $24;$$1144 = $$0143167;$$1149 = 0;
          } else {
           $$0159 = $27;$$0160 = -3;$$0161 = $24;$$1144 = $$0143167;$$1149 = $$0148166;
          }
         } else {
          $$0159 = $27;$$0160 = $25;$$0161 = $24;$$1144 = $$0143167;$$1149 = $$0148166;
         }
        } else {
         $$0159 = -1;$$0160 = -1;$$0161 = -1;$$1144 = $$0143167;$$1149 = $$0148166;
        }
       }
       $37 = (_tre_ast_new_literal($0,$$0160,$$0159,$$0161)|0);
       HEAP32[$$0152165>>2] = $37;
       $38 = ($37|0)==(0|0);
       if ($38) {
        $$1 = 12;
       } else {
        $39 = ((($37)) + 4|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = ((($22)) + 12|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ((($40)) + 12|0);
        HEAP32[$43>>2] = $42;
        $44 = ((($22)) + 16|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ((($40)) + 16|0);
        HEAP32[$46>>2] = $45;
        $$1 = 0;
       }
       $47 = HEAP32[$7>>2]|0;
       $48 = ($$0161|0)>($47|0);
       if (!($48)) {
        $$3146 = $$1144;$$3151 = $$1149;$$5157 = $$0152165;$$6 = $$1;
        break L6;
       }
       HEAP32[$7>>2] = $$0161;
       $$3146 = $$1144;$$3151 = $$1149;$$5157 = $$0152165;$$6 = $$1;
       break L6;
       break;
      }
      case 3:  {
       $49 = ((($19)) + 4|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = HEAP32[$50>>2]|0;
       $52 = ((($50)) + 4|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (_tre_ast_new_union($0,$51,$53)|0);
       HEAP32[$$0152165>>2] = $54;
       $55 = ($54|0)==(0|0);
       if ($55) {
        $$0$lcssa = 12;$$0143$lcssa = $$0143167;
        break L1;
       }
       $56 = ((($54)) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = HEAP32[$52>>2]|0;
       $59 = (_tre_stack_push_voidptr($1,$58)|0);
       $60 = ($59|0)==(0);
       if (!($60)) {
        $$0$lcssa = $59;$$0143$lcssa = $$0143167;
        break L1;
       }
       $61 = (_tre_stack_push_int($1,0)|0);
       $62 = ($61|0)==(0);
       if (!($62)) {
        $$0$lcssa = $61;$$0143$lcssa = $$0143167;
        break L1;
       }
       $63 = ((($57)) + 4|0);
       $64 = (_tre_stack_push_voidptr($1,$63)|0);
       $65 = ($64|0)==(0);
       if (!($65)) {
        $$0$lcssa = $64;$$0143$lcssa = $$0143167;
        break L1;
       }
       $66 = (_tre_stack_push_int($1,1)|0);
       $67 = ($66|0)==(0);
       if (!($67)) {
        $$0$lcssa = $66;$$0143$lcssa = $$0143167;
        break L1;
       }
       $68 = HEAP32[$50>>2]|0;
       $69 = (_tre_stack_push_voidptr($1,$68)|0);
       $70 = ($69|0)==(0);
       if (!($70)) {
        $$0$lcssa = $69;$$0143$lcssa = $$0143167;
        break L1;
       }
       $71 = (_tre_stack_push_int($1,0)|0);
       $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $57;$$6 = $71;
       break L6;
       break;
      }
      case 1:  {
       $72 = ((($19)) + 4|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = HEAP32[$73>>2]|0;
       $75 = ((($73)) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = (_tre_ast_new_catenation($0,$74,$76)|0);
       HEAP32[$$0152165>>2] = $77;
       $78 = ($77|0)==(0|0);
       if ($78) {
        $$0$lcssa = 12;$$0143$lcssa = $$0143167;
        break L1;
       }
       $79 = ((($77)) + 4|0);
       $80 = HEAP32[$79>>2]|0;
       HEAP32[$80>>2] = 0;
       $81 = ((($80)) + 4|0);
       HEAP32[$81>>2] = 0;
       $82 = HEAP32[$75>>2]|0;
       $83 = (_tre_stack_push_voidptr($1,$82)|0);
       $84 = ($83|0)==(0);
       if (!($84)) {
        $$0$lcssa = $83;$$0143$lcssa = $$0143167;
        break L1;
       }
       $85 = (_tre_stack_push_int($1,0)|0);
       $86 = ($85|0)==(0);
       if (!($86)) {
        $$0$lcssa = $85;$$0143$lcssa = $$0143167;
        break L1;
       }
       $87 = (_tre_stack_push_voidptr($1,$81)|0);
       $88 = ($87|0)==(0);
       if (!($88)) {
        $$0$lcssa = $87;$$0143$lcssa = $$0143167;
        break L1;
       }
       $89 = (_tre_stack_push_int($1,1)|0);
       $90 = ($89|0)==(0);
       if (!($90)) {
        $$0$lcssa = $89;$$0143$lcssa = $$0143167;
        break L1;
       }
       $91 = HEAP32[$73>>2]|0;
       $92 = (_tre_stack_push_voidptr($1,$91)|0);
       $93 = ($92|0)==(0);
       if (!($93)) {
        $$0$lcssa = $92;$$0143$lcssa = $$0143167;
        break L1;
       }
       $94 = (_tre_stack_push_int($1,0)|0);
       $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $80;$$6 = $94;
       break L6;
       break;
      }
      case 2:  {
       $95 = ((($19)) + 4|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = HEAP32[$96>>2]|0;
       $98 = (_tre_stack_push_voidptr($1,$97)|0);
       $99 = ($98|0)==(0);
       if (!($99)) {
        $$0$lcssa = $98;$$0143$lcssa = $$0143167;
        break L1;
       }
       $100 = (_tre_stack_push_int($1,0)|0);
       $101 = ($100|0)==(0);
       if (!($101)) {
        $$0$lcssa = $100;$$0143$lcssa = $$0143167;
        break L1;
       }
       $102 = HEAP32[$96>>2]|0;
       $103 = ((($96)) + 4|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ((($96)) + 8|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ((($96)) + 12|0);
       $108 = HEAP8[$107>>0]|0;
       $109 = $108 & 1;
       $110 = $109&255;
       $111 = (_tre_ast_new_iter($0,$102,$104,$106,$110)|0);
       HEAP32[$$0152165>>2] = $111;
       $112 = ($111|0)==(0|0);
       if ($112) {
        $$0$lcssa = 12;$$0143$lcssa = $$0143167;
        break L1;
       }
       $113 = ((($111)) + 4|0);
       $114 = HEAP32[$113>>2]|0;
       $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $114;$$6 = 0;
       break L6;
       break;
      }
      default: {
       $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $$0152165;$$6 = 0;
       break L6;
      }
      }
      break;
     }
     default: {
      $$3146 = $$0143167;$$3151 = $$0148166;$$5157 = $$0152165;$$6 = 0;
     }
     }
    } while(0);
    $115 = ($$6|0)==(0);
    if ($115) {
     $$0143167 = $$3146;$$0148166 = $$3151;$$0152165 = $$5157;
    } else {
     $$0$lcssa = $$6;$$0143$lcssa = $$3146;
     break L1;
    }
   }
  } else {
   $$0$lcssa = $9;$$0143$lcssa = 0;
  }
 } while(0);
 $116 = HEAP32[$4>>2]|0;
 $117 = (($116) + ($$0143$lcssa))|0;
 HEAP32[$4>>2] = $117;
 return ($$0$lcssa|0);
}
function _tre_ast_new_iter($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (___tre_mem_alloc_impl($0,0,0,1,16)|0);
 $6 = (_tre_ast_new_node($0,2,$5)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
 } else {
  HEAP32[$5>>2] = $1;
  $8 = ((($5)) + 4|0);
  HEAP32[$8>>2] = $2;
  $9 = ((($5)) + 8|0);
  HEAP32[$9>>2] = $3;
  $10 = ((($5)) + 12|0);
  $11 = $4&255;
  $12 = HEAP8[$10>>0]|0;
  $13 = $11 & 1;
  $14 = $12 & -2;
  $15 = $14 | $13;
  HEAP8[$10>>0] = $15;
  $16 = ((($1)) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($6)) + 16|0);
  HEAP32[$18>>2] = $17;
  $$0 = $6;
 }
 return ($$0|0);
}
function _tre_ast_new_union($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$0 = $2;
 } else {
  $4 = (___tre_mem_alloc_impl($0,0,0,1,8)|0);
  $5 = (_tre_ast_new_node($0,3,$4)|0);
  $6 = ($5|0)!=(0|0);
  $7 = ($2|0)!=(0|0);
  $or$cond = $7 & $6;
  if ($or$cond) {
   HEAP32[$4>>2] = $1;
   $8 = ((($4)) + 4|0);
   HEAP32[$8>>2] = $2;
   $9 = ((($1)) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($2)) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($10))|0;
   $14 = ((($5)) + 16|0);
   HEAP32[$14>>2] = $13;
   $$0 = $5;
  } else {
   $$0 = 0;
  }
 }
 return ($$0|0);
}
function _tre_add_tag_left($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___tre_mem_alloc_impl($0,0,0,0,8)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 12;
 } else {
  $5 = (_tre_ast_new_literal($0,-3,$2,-1)|0);
  HEAP32[$3>>2] = $5;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $$0 = 12;
  } else {
   $7 = (___tre_mem_alloc_impl($0,0,0,0,32)|0);
   $8 = ((($3)) + 4|0);
   HEAP32[$8>>2] = $7;
   $9 = ($7|0)==(0|0);
   if ($9) {
    $$0 = 12;
   } else {
    $10 = ((($1)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($7)) + 4|0);
    HEAP32[$12>>2] = $11;
    $13 = HEAP32[$1>>2]|0;
    HEAP32[$7>>2] = $13;
    $14 = ((($7)) + 8|0);
    HEAP32[$14>>2] = -1;
    $15 = ((($7)) + 12|0);
    HEAP32[$15>>2] = -1;
    $16 = ((($7)) + 16|0);
    ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
    HEAP32[$10>>2] = $3;
    HEAP32[$1>>2] = 1;
    $$0 = 0;
   }
  }
 }
 return ($$0|0);
}
function _tre_purge_regset($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$016 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)>(-1);
 if ($4) {
  $5 = ((($1)) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $$016 = 0;$8 = $3;
  while(1) {
   $7 = $8 >>> 1;
   $9 = $8 & 1;
   $10 = ($9|0)==(0);
   $11 = (((($6) + (($7*12)|0)|0)) + 4|0);
   $12 = (($6) + (($7*12)|0)|0);
   $$sink = $10 ? $12 : $11;
   HEAP32[$$sink>>2] = $2;
   $13 = (($$016) + 1)|0;
   $14 = (($0) + ($13<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   if ($16) {
    $$016 = $13;$8 = $15;
   } else {
    break;
   }
  }
 }
 HEAP32[$0>>2] = -1;
 return;
}
function _tre_add_tag_right($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (___tre_mem_alloc_impl($0,0,0,0,8)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 12;
 } else {
  $5 = (_tre_ast_new_literal($0,-3,$2,-1)|0);
  $6 = ((($3)) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = ($5|0)==(0|0);
  if ($7) {
   $$0 = 12;
  } else {
   $8 = (___tre_mem_alloc_impl($0,0,0,0,32)|0);
   HEAP32[$3>>2] = $8;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0 = 12;
   } else {
    $10 = ((($1)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($8)) + 4|0);
    HEAP32[$12>>2] = $11;
    $13 = HEAP32[$1>>2]|0;
    HEAP32[$8>>2] = $13;
    $14 = ((($8)) + 8|0);
    HEAP32[$14>>2] = -1;
    $15 = ((($8)) + 12|0);
    HEAP32[$15>>2] = -1;
    $16 = ((($8)) + 16|0);
    ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
    HEAP32[$10>>2] = $3;
    HEAP32[$1>>2] = 1;
    $$0 = 0;
   }
  }
 }
 return ($$0|0);
}
function _parse_atom($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $$0125 = 0, $$0130138 = 0, $$0131$lcssa = 0, $$0131137 = 0, $$1 = 0, $$2 = 0, $$2127 = 0, $$3 = 0, $$4 = 0, $$4129 = 0, $$5 = 0, $$pn = 0, $$pre$phi140Z2D = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $cond133 = 0, $cond134 = 0, $or$cond = 0, $or$cond136 = 0, $or$cond3 = 0, $spec$select = 0;
 var $spec$select132 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = ((($0)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = HEAP8[$1>>0]|0;
 $7 = $6 << 24 >> 24;
 L1: do {
  switch ($7|0) {
  case 91:  {
   $8 = ((($1)) + 1|0);
   $9 = (_parse_bracket($0,$8)|0);
   $$0 = $9;
   break;
  }
  case 92:  {
   $10 = ((($1)) + 1|0);
   $11 = (_tre_expand_macro($10)|0);
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = (_parse_atom($0,$11)|0);
    $14 = ((($1)) + 2|0);
    $15 = ((($0)) + 12|0);
    HEAP32[$15>>2] = $14;
    $$0 = $13;
    break L1;
   }
   $16 = HEAP8[$10>>0]|0;
   $17 = $16 << 24 >> 24;
   switch ($17|0) {
   case 0:  {
    $$0 = 5;
    break L1;
    break;
   }
   case 98:  {
    $18 = HEAP32[$0>>2]|0;
    $19 = (_tre_ast_new_literal($18,-2,64,-1)|0);
    $$0125 = $19;$$2 = $10;
    break;
   }
   case 66:  {
    $20 = HEAP32[$0>>2]|0;
    $21 = (_tre_ast_new_literal($20,-2,128,-1)|0);
    $$0125 = $21;$$2 = $10;
    break;
   }
   case 60:  {
    $22 = HEAP32[$0>>2]|0;
    $23 = (_tre_ast_new_literal($22,-2,16,-1)|0);
    $$0125 = $23;$$2 = $10;
    break;
   }
   case 62:  {
    $24 = HEAP32[$0>>2]|0;
    $25 = (_tre_ast_new_literal($24,-2,32,-1)|0);
    $$0125 = $25;$$2 = $10;
    break;
   }
   case 120:  {
    $26 = ((($1)) + 2|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(123);
    $29 = ((($1)) + 3|0);
    $spec$select = $28 ? 8 : 2;
    $spec$select132 = $28 ? $29 : $26;
    $$0130138 = 0;$$0131137 = 0;
    while(1) {
     $30 = (($spec$select132) + ($$0130138)|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = $31 << 24 >> 24;
     $33 = (_hexval_540($32)|0);
     $34 = ($33|0)<(0);
     if ($34) {
      $$0131$lcssa = $$0131137;$$pn = $$0130138;
      break;
     }
     $35 = $$0131137 << 4;
     $36 = (($33) + ($35))|0;
     $37 = (($$0130138) + 1)|0;
     $38 = ($37>>>0)<($spec$select>>>0);
     $39 = ($36|0)<(1114112);
     $40 = $39 & $38;
     if ($40) {
      $$0130138 = $37;$$0131137 = $36;
     } else {
      $$0131$lcssa = $36;$$pn = $37;
      break;
     }
    }
    $$pre$phi140Z2D = (($spec$select132) + ($$pn)|0);
    if ($28) {
     $41 = HEAP8[$$pre$phi140Z2D>>0]|0;
     $42 = ($41<<24>>24)==(125);
     if (!($42)) {
      $$0 = 9;
      break L1;
     }
     $43 = ((($$pre$phi140Z2D)) + 1|0);
     $$1 = $43;
    } else {
     $$1 = $$pre$phi140Z2D;
    }
    $44 = HEAP32[$0>>2]|0;
    $45 = ((($0)) + 24|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 1)|0;
    HEAP32[$45>>2] = $47;
    $48 = (_tre_ast_new_literal($44,$$0131$lcssa,$$0131$lcssa,$46)|0);
    $49 = ((($$1)) + -1|0);
    $$0125 = $48;$$2 = $49;
    break;
   }
   case 63: case 43: case 123:  {
    $cond = ($5|0)==(0);
    if ($cond) {
     $$0 = 13;
     break L1;
    } else {
     $$3 = $10;
     label = 37;
     break L1;
    }
    break;
   }
   case 124:  {
    $cond133 = ($5|0)==(0);
    if (!($cond133)) {
     $$3 = $10;
     label = 37;
     break L1;
    }
    $50 = HEAP32[$0>>2]|0;
    $51 = (_tre_ast_new_literal($50,-1,-1,-1)|0);
    $$4 = $1;$$5 = $51;
    label = 45;
    break L1;
    break;
   }
   default: {
    $52 = ($5|0)==(0);
    $53 = (($17) + -49)|0;
    $54 = ($53>>>0)<(9);
    $or$cond136 = $52 & $54;
    if (!($or$cond136)) {
     $$3 = $10;
     label = 37;
     break L1;
    }
    $55 = (($17) + -48)|0;
    $56 = HEAP32[$0>>2]|0;
    $57 = ((($0)) + 24|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($58) + 1)|0;
    HEAP32[$57>>2] = $59;
    $60 = (_tre_ast_new_literal($56,-4,$55,$58)|0);
    $61 = ((($0)) + 28|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($55|0)<($62|0);
    $$ = $63 ? $62 : $55;
    HEAP32[$61>>2] = $$;
    $$0125 = $60;$$2 = $10;
   }
   }
   $64 = ((($$2)) + 1|0);
   $$4 = $64;$$5 = $$0125;
   label = 45;
   break;
  }
  case 46:  {
   $65 = $4 & 4;
   $66 = ($65|0)==(0);
   $67 = HEAP32[$0>>2]|0;
   $68 = ((($0)) + 24|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($69) + 1)|0;
   HEAP32[$68>>2] = $70;
   if ($66) {
    $80 = (_tre_ast_new_literal($67,0,1114111,$69)|0);
    $$2127 = $80;
   } else {
    $71 = (_tre_ast_new_literal($67,0,9,$69)|0);
    $72 = HEAP32[$0>>2]|0;
    $73 = HEAP32[$68>>2]|0;
    $74 = (($73) + 1)|0;
    HEAP32[$68>>2] = $74;
    $75 = (_tre_ast_new_literal($72,11,1114111,$73)|0);
    $76 = ($71|0)!=(0|0);
    $77 = ($75|0)!=(0|0);
    $or$cond = $76 & $77;
    if ($or$cond) {
     $78 = HEAP32[$0>>2]|0;
     $79 = (_tre_ast_new_union($78,$71,$75)|0);
     $$2127 = $79;
    } else {
     $$2127 = 0;
    }
   }
   $81 = ((($1)) + 1|0);
   $$4 = $81;$$5 = $$2127;
   label = 45;
   break;
  }
  case 94:  {
   $82 = ($5|0)==(0);
   if ($82) {
    $83 = ((($0)) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($1|0);
    if (!($85)) {
     $$3 = $1;
     label = 37;
     break L1;
    }
   }
   $86 = HEAP32[$0>>2]|0;
   $87 = (_tre_ast_new_literal($86,-2,1,-1)|0);
   $88 = ((($1)) + 1|0);
   $$4 = $88;$$5 = $87;
   label = 45;
   break;
  }
  case 36:  {
   $89 = ($5|0)==(0);
   $90 = ((($1)) + 1|0);
   if ($89) {
    $91 = HEAP8[$90>>0]|0;
    $92 = ($91<<24>>24)==(0);
    if (!($92)) {
     $$3 = $1;
     label = 37;
     break L1;
    }
   }
   $93 = HEAP32[$0>>2]|0;
   $94 = (_tre_ast_new_literal($93,-2,2,-1)|0);
   $$4 = $90;$$5 = $94;
   label = 45;
   break;
  }
  case 63: case 43: case 123: case 42:  {
   $cond134 = ($5|0)==(0);
   if ($cond134) {
    $$3 = $1;
    label = 37;
   } else {
    $$0 = 13;
   }
   break;
  }
  case 124:  {
   $95 = ($5|0)==(0);
   if ($95) {
    $$3 = $1;
    label = 37;
   } else {
    label = 36;
   }
   break;
  }
  case 0:  {
   label = 36;
   break;
  }
  default: {
   $$3 = $1;
   label = 37;
  }
  }
 } while(0);
 if ((label|0) == 36) {
  $96 = HEAP32[$0>>2]|0;
  $97 = (_tre_ast_new_literal($96,-1,-1,-1)|0);
  $$4 = $1;$$5 = $97;
  label = 45;
 }
 else if ((label|0) == 37) {
  $98 = (_mbtowc($2,$$3,-1)|0);
  $99 = ($98|0)<(0);
  if ($99) {
   $$0 = 2;
  } else {
   $100 = HEAP32[$3>>2]|0;
   $101 = $100 & 2;
   $102 = ($101|0)==(0);
   do {
    if ($102) {
     label = 43;
    } else {
     $103 = HEAP32[$2>>2]|0;
     $104 = (_iswupper($103)|0);
     $105 = ($104|0)==(0);
     if ($105) {
      $106 = HEAP32[$2>>2]|0;
      $107 = (_iswlower($106)|0);
      $108 = ($107|0)==(0);
      if ($108) {
       label = 43;
       break;
      }
     }
     $109 = HEAP32[$0>>2]|0;
     $110 = HEAP32[$2>>2]|0;
     $111 = (_towupper($110)|0);
     $112 = HEAP32[$2>>2]|0;
     $113 = (_towupper($112)|0);
     $114 = ((($0)) + 24|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = (_tre_ast_new_literal($109,$111,$113,$115)|0);
     $117 = HEAP32[$0>>2]|0;
     $118 = HEAP32[$2>>2]|0;
     $119 = (_towlower($118)|0);
     $120 = HEAP32[$2>>2]|0;
     $121 = (_towlower($120)|0);
     $122 = HEAP32[$114>>2]|0;
     $123 = (_tre_ast_new_literal($117,$119,$121,$122)|0);
     $124 = ($116|0)!=(0|0);
     $125 = ($123|0)!=(0|0);
     $or$cond3 = $124 & $125;
     if ($or$cond3) {
      $126 = HEAP32[$0>>2]|0;
      $127 = (_tre_ast_new_union($126,$116,$123)|0);
      $$4129 = $127;$$pre$phiZ2D = $114;
     } else {
      $$4129 = 0;$$pre$phiZ2D = $114;
     }
    }
   } while(0);
   if ((label|0) == 43) {
    $128 = HEAP32[$0>>2]|0;
    $129 = HEAP32[$2>>2]|0;
    $130 = ((($0)) + 24|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (_tre_ast_new_literal($128,$129,$129,$131)|0);
    $$4129 = $132;$$pre$phiZ2D = $130;
   }
   $133 = HEAP32[$$pre$phiZ2D>>2]|0;
   $134 = (($133) + 1)|0;
   HEAP32[$$pre$phiZ2D>>2] = $134;
   $135 = (($$3) + ($98)|0);
   $$4 = $135;$$5 = $$4129;
   label = 45;
  }
 }
 if ((label|0) == 45) {
  $136 = ($$5|0)==(0|0);
  if ($136) {
   $$0 = 12;
  } else {
   $137 = ((($0)) + 8|0);
   HEAP32[$137>>2] = $$5;
   $138 = ((($0)) + 12|0);
   HEAP32[$138>>2] = $$4;
   $$0 = 0;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _parse_dup($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$016 = 0, $$1 = 0, $$pre = 0, $$pre17 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $4 = sp + 4|0;
 $5 = sp;
 $6 = (_parse_dup_count($0,$4)|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(44);
 if ($8) {
  $9 = ((($6)) + 1|0);
  $10 = (_parse_dup_count($9,$5)|0);
  $$pre = HEAP32[$5>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $$016 = $10;$13 = $$pre;$14 = $$pre17;
 } else {
  $11 = HEAP32[$4>>2]|0;
  HEAP32[$5>>2] = $11;
  $$016 = $6;$13 = $11;$14 = $11;
 }
 $12 = ($13|0)<($14|0);
 $15 = ($13|0)>(-1);
 $or$cond = $15 & $12;
 $16 = ($13|0)>(255);
 $or$cond3 = $16 | $or$cond;
 $17 = ($14>>>0)>(255);
 $18 = $17 | $or$cond3;
 do {
  if ($18) {
   $$0 = 0;
  } else {
   $19 = ($1|0)==(0);
   if ($19) {
    $20 = ((($$016)) + 1|0);
    $21 = HEAP8[$$016>>0]|0;
    $22 = ($21<<24>>24)==(92);
    if ($22) {
     $$1 = $20;
    } else {
     $$0 = 0;
     break;
    }
   } else {
    $$1 = $$016;
   }
   $23 = HEAP8[$$1>>0]|0;
   $24 = ($23<<24>>24)==(125);
   if ($24) {
    $25 = ((($$1)) + 1|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$3>>2] = $13;
    $$0 = $25;
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _marksub($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$1 = 0, $$119 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi21Z2D = 0, $$pre$phiZ2D = 0, $$pre20 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ((($1)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  $6 = HEAP32[$0>>2]|0;
  $7 = (_tre_ast_new_literal($6,-1,-1,-1)|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$1 = 12;
  } else {
   $9 = HEAP32[$0>>2]|0;
   $10 = (_tre_ast_new_catenation($9,$7,$1)|0);
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$1 = 12;
   } else {
    $12 = ((($1)) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($10)) + 16|0);
    HEAP32[$14>>2] = $13;
    $$pre20 = ((($10)) + 12|0);
    $$119 = $10;$$pre$phi21Z2D = $14;$$pre$phiZ2D = $$pre20;$16 = $13;
    label = 6;
   }
  }
 } else {
  $$phi$trans$insert = ((($1)) + 16|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$119 = $1;$$pre$phi21Z2D = $$phi$trans$insert;$$pre$phiZ2D = $3;$16 = $$pre;
  label = 6;
 }
 if ((label|0) == 6) {
  HEAP32[$$pre$phiZ2D>>2] = $2;
  $15 = (($16) + 1)|0;
  HEAP32[$$pre$phi21Z2D>>2] = $15;
  $17 = ((($0)) + 8|0);
  HEAP32[$17>>2] = $$119;
  $$1 = 0;
 }
 return ($$1|0);
}
function _parse_dup_count($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$1>>2] = -1;
 $2 = HEAP8[$0>>0]|0;
 $3 = $2 << 24 >> 24;
 $4 = (_isdigit($3)|0);
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $$0 = $0;
  } else {
   HEAP32[$1>>2] = 0;
   $6 = HEAP8[$0>>0]|0;
   $7 = $6 << 24 >> 24;
   $8 = (($7) + -48)|0;
   HEAP32[$1>>2] = $8;
   $9 = ((($0)) + 1|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 << 24 >> 24;
   $12 = (_isdigit($11)|0);
   $13 = ($12|0)==(0);
   if ($13) {
    $$0 = $9;
   } else {
    $17 = $9;
    while(1) {
     $15 = HEAP32[$1>>2]|0;
     $26 = ($15|0)>(255);
     if ($26) {
      $$0 = $17;
      break L1;
     }
     $14 = ($15*10)|0;
     $16 = HEAP8[$17>>0]|0;
     $18 = $16 << 24 >> 24;
     $19 = (($14) + -48)|0;
     $20 = (($19) + ($18))|0;
     HEAP32[$1>>2] = $20;
     $21 = ((($17)) + 1|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = $22 << 24 >> 24;
     $24 = (_isdigit($23)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $$0 = $21;
      break;
     } else {
      $17 = $21;
     }
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _parse_bracket($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$064 = 0, $$065 = 0, $$06674 = 0, $$06773 = 0, $$07172 = 0, $$1 = 0, $$168 = 0, $$2 = 0, $$269 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(288|0);
 $2 = sp + 264|0;
 $3 = sp;
 $4 = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($2)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 12|0);
 HEAP32[$6>>2] = 32;
 $7 = (_malloc(128)|0);
 $8 = ((($2)) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if ($9) {
  $$065 = 12;
 } else {
  $10 = ((($3)) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = HEAP8[$1>>0]|0;
  $12 = ($11<<24>>24)==(94);
  $13 = $12&1;
  HEAP32[$3>>2] = $13;
  $14 = ((($1)) + 1|0);
  $spec$select = $12 ? $14 : $1;
  $15 = (_parse_bracket_terms($0,$spec$select,$2,$3)|0);
  $16 = ($15|0)==(0);
  L3: do {
   if ($16) {
    $17 = HEAP32[$3>>2]|0;
    $18 = ($17|0)==(0);
    if ($18) {
     $$064 = 0;
    } else {
     $19 = HEAP32[$8>>2]|0;
     $20 = HEAP32[$5>>2]|0;
     _qsort($19,$20,4,(fb + (37) | 0));
     $21 = (_tre_new_lit($2)|0);
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$0 = 12;$$2 = 0;
      break;
     }
     HEAP32[$21>>2] = 1114112;
     $23 = ((($21)) + 4|0);
     HEAP32[$23>>2] = 1114112;
     $24 = ((($21)) + 8|0);
     HEAP32[$24>>2] = -1;
     $25 = HEAP32[$10>>2]|0;
     $26 = ($25|0)==(0);
     if ($26) {
      $$064 = 0;
     } else {
      $27 = HEAP32[$0>>2]|0;
      $28 = $25 << 2;
      $29 = (($28) + 4)|0;
      $30 = (___tre_mem_alloc_impl($27,0,0,0,$29)|0);
      $31 = ($30|0)==(0|0);
      if ($31) {
       $$0 = 12;$$2 = 0;
       break;
      }
      $32 = ((($3)) + 8|0);
      (_memcpy(($30|0),($32|0),($28|0))|0);
      $33 = (($30) + ($25<<2)|0);
      HEAP32[$33>>2] = 0;
      $$064 = $30;
     }
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ($34|0)>(0);
    if ($35) {
     $36 = HEAP32[$8>>2]|0;
     $37 = ((($0)) + 24|0);
     $$06674 = 0;$$06773 = 0;$$07172 = 0;
     while(1) {
      $38 = (($36) + ($$07172<<2)|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      $41 = ((($39)) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      do {
       if ($18) {
        $$168 = $$06773;
        label = 14;
       } else {
        $43 = ($40|0)>($$06773|0);
        if ($43) {
         $47 = (($40) + -1)|0;
         HEAP32[$39>>2] = $$06773;
         HEAP32[$41>>2] = $47;
         $48 = (($42) + 1)|0;
         $$168 = $48;
         label = 14;
         break;
        } else {
         $44 = (($42) + 1)|0;
         $45 = ($44|0)<($$06773|0);
         $46 = $45 ? $$06773 : $44;
         $$1 = $$06674;$$269 = $46;
         break;
        }
       }
      } while(0);
      if ((label|0) == 14) {
       label = 0;
       $49 = HEAP32[$37>>2]|0;
       $50 = ((($39)) + 8|0);
       HEAP32[$50>>2] = $49;
       $51 = ((($39)) + 16|0);
       HEAP32[$51>>2] = $$064;
       $52 = HEAP32[$0>>2]|0;
       $53 = (_tre_ast_new_node($52,0,$39)|0);
       $54 = HEAP32[$0>>2]|0;
       $55 = (_tre_ast_new_union($54,$$06674,$53)|0);
       $56 = ($55|0)==(0|0);
       if ($56) {
        $$0 = 12;$$2 = 0;
        break L3;
       } else {
        $$1 = $55;$$269 = $$168;
       }
      }
      $57 = (($$07172) + 1)|0;
      $58 = ($57|0)<($34|0);
      if ($58) {
       $$06674 = $$1;$$06773 = $$269;$$07172 = $57;
      } else {
       $$0 = 0;$$2 = $$1;
       break;
      }
     }
    } else {
     $$0 = 0;$$2 = 0;
    }
   } else {
    $$0 = $15;$$2 = 0;
   }
  } while(0);
  $59 = HEAP32[$8>>2]|0;
  _free($59);
  $60 = ((($0)) + 24|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 1)|0;
  HEAP32[$60>>2] = $62;
  $63 = ((($0)) + 8|0);
  HEAP32[$63>>2] = $$2;
  $$065 = $$0;
 }
 STACKTOP = sp;return ($$065|0);
}
function _tre_expand_macro($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$05 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $$05 = 0;
 while(1) {
  $2 = ((gb + (153600) | 0) + ($$05<<3)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==($1<<24>>24);
  if ($4) {
   $$0$lcssa = $$05;
   break;
  }
  $5 = (($$05) + 1)|0;
  $6 = ($5|0)==(12);
  if ($6) {
   $$0$lcssa = 12;
   break;
  } else {
   $$05 = $5;
  }
 }
 $7 = ((((gb + (153600) | 0) + ($$0$lcssa<<3)|0)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 return ($8|0);
}
function _hexval_540($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -48)|0;
 $2 = ($1>>>0)<(10);
 if ($2) {
  return ($1|0);
 } else {
  $3 = $0 | 32;
  $4 = (($3) + -97)|0;
  $5 = ($4>>>0)<(6);
  $6 = (($3) + -87)|0;
  $spec$select = $5 ? $6 : -1;
  return ($spec$select|0);
 }
 return (0)|0;
}
function _parse_bracket_terms($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$082124 = 0, $$091125 = 0, $$190104 = 0, $$285108 = 0, $$288106 = 0, $$293102 = 0, $$293103 = 0, $$5 = 0, $$lcssa115 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond94 = 0, $or$cond95 = 0, $or$cond96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $4 = sp;
 $5 = sp + 4|0;
 $6 = (_mbtowc($4,$1,-1)|0);
 $7 = ($6|0)<(1);
 $8 = HEAP8[$1>>0]|0;
 L1: do {
  if ($7) {
   $$lcssa115 = $8;
   label = 3;
  } else {
   $9 = ((($0)) + 32|0);
   $10 = ((($3)) + 4|0);
   $$091125 = $1;$14 = $8;$43 = $6;
   L3: while(1) {
    $13 = ($14<<24>>24)!=(93);
    $15 = ($$091125|0)==($1|0);
    $or$cond94 = $15 | $13;
    if (!($or$cond94)) {
     label = 5;
     break;
    }
    $18 = ($14<<24>>24)!=(45);
    $or$cond95 = $15 | $18;
    L6: do {
     if ($or$cond95) {
      $24 = ($14<<24>>24)==(91);
      if ($24) {
       $25 = ((($$091125)) + 1|0);
       $26 = HEAP8[$25>>0]|0;
       switch ($26<<24>>24) {
       case 61: case 46:  {
        $$5 = 3;
        break L1;
        break;
       }
       case 58:  {
        break;
       }
       default: {
        label = 17;
        break L6;
       }
       }
       $27 = ((($$091125)) + 2|0);
       $$082124 = 0;
       L10: while(1) {
        $28 = (($27) + ($$082124)|0);
        $29 = HEAP8[$28>>0]|0;
        switch ($29<<24>>24) {
        case 0:  {
         label = 16;
         break L3;
         break;
        }
        case 58:  {
         break L10;
         break;
        }
        default: {
        }
        }
        $30 = (($$082124) + 1)|0;
        $31 = ($30>>>0)<(14);
        if ($31) {
         $$082124 = $30;
        } else {
         label = 16;
         break L3;
        }
       }
       (_memcpy(($5|0),($27|0),($$082124|0))|0);
       $32 = (($5) + ($$082124)|0);
       HEAP8[$32>>0] = 0;
       $33 = (_wctype($5)|0);
       $34 = ($33|0)==(0);
       if ($34) {
        label = 16;
        break L3;
       }
       $35 = (($$082124) + 1)|0;
       $36 = (($27) + ($35)|0);
       $37 = HEAP8[$36>>0]|0;
       $38 = ($37<<24>>24)==(93);
       $39 = (($$082124) + 2)|0;
       $40 = (($27) + ($39)|0);
       if (!($38)) {
        label = 16;
        break L3;
       }
       $54 = HEAP32[$3>>2]|0;
       $55 = ($54|0)==(0);
       if ($55) {
        $$190104 = $33;$$285108 = 1114111;$$288106 = 0;$$293103 = $40;$68 = 1;
        label = 24;
       } else {
        $56 = HEAP32[$10>>2]|0;
        $57 = ($56|0)>(63);
        if ($57) {
         $$5 = 12;
         break L1;
        }
        $58 = (($56) + 1)|0;
        HEAP32[$10>>2] = $58;
        $59 = (((($3)) + 8|0) + ($56<<2)|0);
        HEAP32[$59>>2] = $33;
        $$293102 = $40;
       }
      } else {
       label = 17;
      }
     } else {
      $19 = ((($$091125)) + 1|0);
      $20 = HEAP8[$19>>0]|0;
      switch ($20<<24>>24) {
      case 93:  {
       label = 17;
       break L6;
       break;
      }
      case 45:  {
       break;
      }
      default: {
       $$5 = 11;
       break L1;
      }
      }
      $21 = ((($$091125)) + 2|0);
      $22 = HEAP8[$21>>0]|0;
      $23 = ($22<<24>>24)==(93);
      if ($23) {
       $$5 = 11;
       break L1;
      } else {
       label = 17;
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     $41 = HEAP32[$4>>2]|0;
     $42 = (($$091125) + ($43)|0);
     $44 = HEAP8[$42>>0]|0;
     $45 = ($44<<24>>24)==(45);
     if ($45) {
      $46 = ((($42)) + 1|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = ($47<<24>>24)==(93);
      if ($48) {
       $$190104 = 0;$$285108 = $41;$$288106 = $41;$$293103 = $42;$68 = 0;
       label = 24;
      } else {
       $49 = (_mbtowc($4,$46,-1)|0);
       $50 = HEAP32[$4>>2]|0;
       $51 = ($49|0)<(1);
       $52 = ($41|0)>($50|0);
       $or$cond96 = $51 | $52;
       if ($or$cond96) {
        $$5 = 11;
        break L1;
       }
       $53 = (($46) + ($49)|0);
       $$190104 = 0;$$285108 = $50;$$288106 = $41;$$293103 = $53;$68 = 0;
       label = 24;
      }
     } else {
      $$190104 = 0;$$285108 = $41;$$288106 = $41;$$293103 = $42;$68 = 0;
      label = 24;
     }
    }
    if ((label|0) == 24) {
     label = 0;
     $60 = (_tre_new_lit($2)|0);
     $61 = ($60|0)==(0|0);
     if ($61) {
      $$5 = 12;
      break L1;
     }
     HEAP32[$60>>2] = $$288106;
     $62 = ((($60)) + 4|0);
     HEAP32[$62>>2] = $$285108;
     $63 = ((($60)) + 12|0);
     HEAP32[$63>>2] = $$190104;
     $64 = ((($60)) + 8|0);
     HEAP32[$64>>2] = -1;
     $65 = HEAP32[$9>>2]|0;
     $66 = $65 & 2;
     $67 = ($66|0)==(0);
     $or$cond = $68 | $67;
     if ($or$cond) {
      $$293102 = $$293103;
     } else {
      $69 = (_add_icase_literals($2,$$288106,$$285108)|0);
      $70 = ($69|0)==(0);
      if ($70) {
       $$293102 = $$293103;
      } else {
       $$5 = 12;
       break L1;
      }
     }
    }
    $71 = (_mbtowc($4,$$293102,-1)|0);
    $72 = ($71|0)<(1);
    $73 = HEAP8[$$293102>>0]|0;
    if ($72) {
     $$lcssa115 = $73;
     label = 3;
     break L1;
    } else {
     $$091125 = $$293102;$14 = $73;$43 = $71;
    }
   }
   if ((label|0) == 5) {
    $16 = ((($$091125)) + 1|0);
    $17 = ((($0)) + 12|0);
    HEAP32[$17>>2] = $16;
    $$5 = 0;
    break;
   }
   else if ((label|0) == 16) {
    $$5 = 4;
    break;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ($$lcssa115<<24>>24)==(0);
  $12 = $11 ? 7 : 2;
  $$5 = $12;
 }
 STACKTOP = sp;return ($$5|0);
}
function _tre_compare_lit($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 return ($6|0);
}
function _tre_new_lit($0) {
 $0 = $0|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre16 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)<($4|0);
 if ($5) {
  $$phi$trans$insert = ((($0)) + 4|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $2;$16 = $$pre;
  label = 6;
 } else {
  $6 = ($4|0)>(32767);
  if ($6) {
   $$0 = 0;
  } else {
   $7 = $4 << 1;
   HEAP32[$3>>2] = $7;
   $8 = ((($0)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $4 << 3;
   $11 = (_realloc($9,$10)|0);
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0 = 0;
   } else {
    HEAP32[$8>>2] = $11;
    $$pre16 = HEAP32[$1>>2]|0;
    $14 = $$pre16;$16 = $11;
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $13 = (($14) + 1)|0;
  HEAP32[$1>>2] = $13;
  $15 = (($16) + ($14<<2)|0);
  $17 = HEAP32[$0>>2]|0;
  $18 = (___tre_mem_alloc_impl($17,0,0,1,20)|0);
  HEAP32[$15>>2] = $18;
  $$0 = $18;
 }
 return ($$0|0);
}
function _add_icase_literals($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$be = 0, $$036 = 0, $$03643 = 0, $$03645 = 0, $$039 = 0, $$040 = 0, $$060 = 0, $$1 = 0, $$137 = 0, $$13751 = 0, $$13753 = 0, $$142 = 0, $$144 = 0, $$2 = 0, $$238 = 0, $$250 = 0, $$252 = 0, $$3 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($1|0)>($2|0);
 L1: do {
  if ($3) {
   $$040 = 0;
  } else {
   $$060 = $1;
   while(1) {
    $4 = (_iswlower($$060)|0);
    $5 = ($4|0)==(0);
    L5: do {
     if ($5) {
      $11 = (_iswupper($$060)|0);
      $12 = ($11|0)==(0);
      if ($12) {
       $18 = (($$060) + 1)|0;
       $$0$be = $18;
       break;
      }
      $13 = (_towlower($$060)|0);
      $$250 = (($$060) + 1)|0;
      $$13751 = (($13) + 1)|0;
      $14 = ($$060|0)<($2|0);
      if ($14) {
       $$13753 = $$13751;$$252 = $$250;
       while(1) {
        $16 = (_towlower($$252)|0);
        $17 = ($16|0)==($$13753|0);
        if (!($17)) {
         $$039 = $13;$$238 = $$13753;$$3 = $$252;
         label = 15;
         break L5;
        }
        $$2 = (($$252) + 1)|0;
        $$137 = (($$13753) + 1)|0;
        $15 = ($$252|0)<($2|0);
        if ($15) {
         $$13753 = $$137;$$252 = $$2;
        } else {
         $$039 = $13;$$238 = $$137;$$3 = $$2;
         label = 15;
         break;
        }
       }
      } else {
       $$039 = $13;$$238 = $$13751;$$3 = $$250;
       label = 15;
      }
     } else {
      $6 = (_towupper($$060)|0);
      $$142 = (($$060) + 1)|0;
      $$03643 = (($6) + 1)|0;
      $7 = ($$060|0)<($2|0);
      if ($7) {
       $$03645 = $$03643;$$144 = $$142;
       while(1) {
        $9 = (_towupper($$144)|0);
        $10 = ($9|0)==($$03645|0);
        if (!($10)) {
         $$039 = $6;$$238 = $$03645;$$3 = $$144;
         label = 15;
         break L5;
        }
        $$1 = (($$144) + 1)|0;
        $$036 = (($$03645) + 1)|0;
        $8 = ($$144|0)<($2|0);
        if ($8) {
         $$03645 = $$036;$$144 = $$1;
        } else {
         $$039 = $6;$$238 = $$036;$$3 = $$1;
         label = 15;
         break;
        }
       }
      } else {
       $$039 = $6;$$238 = $$03643;$$3 = $$142;
       label = 15;
      }
     }
    } while(0);
    if ((label|0) == 15) {
     label = 0;
     $20 = (_tre_new_lit($0)|0);
     $21 = ($20|0)==(0|0);
     if ($21) {
      $$040 = -1;
      break L1;
     }
     HEAP32[$20>>2] = $$039;
     $22 = (($$238) + -1)|0;
     $23 = ((($20)) + 4|0);
     HEAP32[$23>>2] = $22;
     $24 = ((($20)) + 8|0);
     HEAP32[$24>>2] = -1;
     $$0$be = $$3;
    }
    $19 = ($$0$be|0)>($2|0);
    if ($19) {
     $$040 = 0;
     break;
    } else {
     $$060 = $$0$be;
    }
   }
  }
 } while(0);
 return ($$040|0);
}
function _regexec($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $$026 = 0, $$027 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 $6 = ((($0)) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 8;
 $11 = ($10|0)==(0);
 $spec$select = $11 ? $2 : 0;
 $12 = ((($7)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 $15 = ($spec$select|0)!=(0);
 $or$cond = $14 & $15;
 if ($or$cond) {
  $16 = $13 << 2;
  $17 = (_malloc($16)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$027 = 12;
  } else {
   $$0 = $17;$28 = $17;
   label = 3;
  }
 } else {
  $$0 = 0;$28 = 0;
  label = 3;
 }
 if ((label|0) == 3) {
  $19 = ((($7)) + 60|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $23 = (_tre_tnfa_run_parallel($7,$1,$$0,$4,$5)|0);
   $$026 = $23;
  } else {
   $22 = (_tre_tnfa_run_backtrack($7,$1,$$0,$4,$5)|0);
   $$026 = $22;
  }
  $24 = ($$026|0)==(0);
  if ($24) {
   $25 = HEAP32[$8>>2]|0;
   $26 = HEAP32[$5>>2]|0;
   _tre_fill_pmatch($spec$select,$3,$25,$7,$$0,$26);
  }
  $27 = ($$0|0)==(0|0);
  if ($27) {
   $$027 = $$026;
  } else {
   _free($28);
   $$027 = $$026;
  }
 }
 STACKTOP = sp;return ($$027|0);
}
function _tre_tnfa_run_backtrack($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0450616675 = 0, $$0452612 = 0, $$0453 = 0, $$0453$ph = 0, $$0458 = 0, $$0463 = 0, $$0463$ph = 0, $$0467 = 0, $$0476 = 0, $$0477638 = 0, $$0479627 = 0, $$0481590 = 0, $$0482 = 0, $$0487586 = 0, $$0488579 = 0, $$0502 = 0, $$0504597 = 0, $$0506 = 0, $$0520594 = 0, $$0531 = 0;
 var $$0533593 = 0, $$0537 = 0, $$0608 = 0, $$11517 = 0, $$12518 = 0, $$12518$ph = 0, $$14 = 0, $$1454 = 0, $$1459 = 0, $$1459$ph = 0, $$1464 = 0, $$1468 = 0, $$1480 = 0, $$1483$ph = 0, $$1503 = 0, $$1505624 = 0, $$1507595 = 0, $$1521 = 0, $$1532 = 0, $$1534 = 0;
 var $$1538 = 0, $$2455 = 0, $$2460 = 0, $$2465 = 0, $$2469 = 0, $$2469$ph = 0, $$2492 = 0, $$2492$clear = 0, $$2522604 = 0, $$2535 = 0, $$2535$ph = 0, $$3456 = 0, $$3456$ph = 0, $$3461 = 0, $$3470 = 0, $$3485 = 0, $$3509 = 0, $$3523 = 0, $$4471 = 0, $$4524 = 0;
 var $$4524$be = 0, $$4524$ph = 0, $$5472 = 0, $$5511 = 0, $$5525620 = 0, $$6473 = 0, $$6501 = 0, $$6512 = 0, $$6512$ph = 0, $$6526 = 0, $$7474 = 0, $$7474$ph = 0, $$7513621 = 0, $$7527634 = 0, $$9515 = 0, $$9529 = 0, $$9529$ph = 0, $$old = 0, $$old11 = 0, $$old37 = 0;
 var $$old38 = 0, $$pr = 0, $$pr539 = 0, $$pr545 = 0, $$pr547 = 0, $$pre = 0, $$pre651 = 0, $$pre655 = 0, $$pre657 = 0, $$pre658 = 0, $$pre659 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0;
 var $brmerge640 = 0, $brmerge643 = 0, $brmerge644 = 0, $not$ = 0, $or$cond$not = 0, $or$cond10 = 0, $or$cond12 = 0, $or$cond15 = 0, $or$cond18 = 0, $or$cond21 = 0, $or$cond24 = 0, $or$cond27$not = 0, $or$cond30 = 0, $or$cond36 = 0, $or$cond39 = 0, $or$cond42 = 0, $or$cond45 = 0, $or$cond48 = 0, $or$cond51 = 0, $or$cond6 = 0;
 var $or$cond642 = 0, $or$cond646 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 HEAP32[$5>>2] = 0;
 $6 = $3 & 1;
 $7 = $3 & 2;
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 4;
 $11 = (___tre_mem_new_impl(0,0)|0);
 $12 = ($11|0)==(0|0);
 L1: do {
  if ($12) {
   $$14 = 12;
  } else {
   $13 = (___tre_mem_alloc_impl($11,0,0,0,32)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    ___tre_mem_destroy($11);
    $$14 = 12;
    break;
   }
   $15 = ((($13)) + 24|0);
   HEAP32[$15>>2] = 0;
   $16 = ((($13)) + 28|0);
   HEAP32[$16>>2] = 0;
   $17 = ((($0)) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    $$0537 = 0;$135 = 0;
    label = 6;
   } else {
    $20 = $18 << 2;
    $21 = (_malloc($20)|0);
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$1503 = 0;$$1532 = 0;$$1538 = $21;$$6501 = 12;$447 = 0;$449 = 0;$451 = 0;
    } else {
     $$0537 = $21;$135 = $21;
     label = 6;
    }
   }
   L8: do {
    if ((label|0) == 6) {
     $23 = ((($0)) + 28|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0);
     if ($25) {
      $$0502 = 0;$137 = 0;
     } else {
      $26 = $24 << 3;
      $27 = (_malloc($26)|0);
      $28 = ($27|0)==(0|0);
      if ($28) {
       $$1503 = $27;$$1532 = 0;$$1538 = $$0537;$$6501 = 12;$447 = $135;$449 = 0;$451 = 0;
       break;
      } else {
       $$0502 = $27;$137 = $27;
      }
     }
     $29 = ((($0)) + 52|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0);
     if ($31) {
      $$0531 = 0;$52 = 0;
     } else {
      $32 = $30 << 2;
      $33 = (_malloc($32)|0);
      $34 = ($33|0)==(0|0);
      if ($34) {
       $$1503 = $$0502;$$1532 = $33;$$1538 = $$0537;$$6501 = 12;$447 = $135;$449 = $137;$451 = 0;
       break;
      } else {
       $$0531 = $33;$52 = $33;
      }
     }
     $35 = ($2|0)==(0|0);
     $36 = ((($0)) + 8|0);
     $37 = ($6|0)==(0);
     $38 = ($10|0)!=(0);
     $39 = ((($0)) + 12|0);
     $40 = ($2|0)!=(0|0);
     $41 = ((($0)) + 32|0);
     $$0458 = $1;$$0467 = 1;$$0476 = -1;$$0482 = -1;$$0506 = $13;$65 = 0;
     L16: while(1) {
      $42 = HEAP32[$17>>2]|0;
      $43 = ($42|0)>(0);
      if ($43) {
       $$0488579 = 0;$452 = $42;
       while(1) {
        $44 = (($$0537) + ($$0488579<<2)|0);
        HEAP32[$44>>2] = -1;
        if ($35) {
         $48 = $452;
        } else {
         $45 = (($2) + ($$0488579<<2)|0);
         HEAP32[$45>>2] = -1;
         $$pre = HEAP32[$17>>2]|0;
         $48 = $$pre;
        }
        $46 = (($$0488579) + 1)|0;
        $47 = ($46|0)<($48|0);
        if ($47) {
         $$0488579 = $46;$452 = $48;
        } else {
         break;
        }
       }
      }
      $49 = HEAP32[$29>>2]|0;
      $50 = ($49|0)>(0);
      if ($50) {
       $51 = $49 << 2;
       _memset(($52|0),0,($51|0))|0;
      }
      $53 = (($$0467) + ($$0476))|0;
      $54 = (_mbtowc($5,$$0458,4)|0);
      $55 = ($54|0)<(1);
      if ($55) {
       $56 = ($54|0)<(0);
       if ($56) {
        $$1503 = $$0502;$$1532 = $$0531;$$1538 = $$0537;$$6501 = 1;$447 = $135;$449 = $137;$451 = $52;
        break L8;
       } else {
        $$1468 = 1;
       }
      } else {
       $$1468 = $54;
      }
      $57 = (($$0458) + ($$1468)|0);
      $58 = HEAP32[$5>>2]|0;
      $59 = HEAP32[$36>>2]|0;
      $60 = ((($59)) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $$12518 = $$0506;$$3456 = $65;$$3485 = $$0482;$$7474 = $$1468;$$9529 = 0;
       label = 179;
      } else {
       $63 = ($53|0)<(1);
       $64 = ($65|0)==(10);
       $or$cond6 = $38 & $64;
       $66 = ($65|0)==(95);
       $67 = ($53|0)!=(0);
       $68 = ($53|0)==(0);
       $or$cond$not = $63 & $37;
       $$0504597 = $59;$$0520594 = 0;$$0533593 = 0;$$1507595 = $$0506;$126 = $60;
       while(1) {
        $69 = ((($$0504597)) + 20|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)==(0);
        L36: do {
         if ($71) {
          label = 50;
         } else {
          $72 = $70 & 1;
          $73 = ($72|0)==(0);
          $brmerge = $73 | $or$cond$not;
          $brmerge640 = $brmerge | $or$cond6;
          if ($brmerge640) {
           $74 = $70 & 2;
           $75 = ($74|0)==(0);
           if (!($75)) {
            $76 = HEAP32[$5>>2]|0;
            $77 = $76 | $7;
            $78 = ($77|0)==(0);
            $79 = ($76|0)==(10);
            $or$cond10 = $38 & $79;
            $or$cond642 = $78 | $or$cond10;
            if (!($or$cond642)) {
             $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
             break;
            }
           }
           $80 = $70 & 16;
           $81 = ($80|0)==(0);
           do {
            if (!($81)) {
             if ($66) {
              $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
              break L36;
             }
             $82 = (_iswalnum($65)|0);
             $83 = ($82|0)==(0);
             if (!($83)) {
              $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
              break L36;
             }
             $84 = HEAP32[$5>>2]|0;
             $85 = ($84|0)==(95);
             if ($85) {
              break;
             }
             $86 = (_iswalnum($84)|0);
             $87 = ($86|0)==(0);
             if ($87) {
              $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
              break L36;
             }
            }
           } while(0);
           $88 = HEAP32[$69>>2]|0;
           $89 = $88 & 32;
           $90 = ($89|0)==(0);
           if ($90) {
            $99 = $88;
           } else {
            if ($66) {
             $$old = HEAP32[$5>>2]|0;
             $$old11 = ($$old|0)==(95);
             if ($$old11) {
              $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
              break;
             } else {
              $95 = $$old;
             }
            } else {
             $91 = (_iswalnum($65)|0);
             $92 = ($91|0)==(0);
             $93 = HEAP32[$5>>2]|0;
             $94 = ($93|0)==(95);
             $or$cond12 = $92 | $94;
             if ($or$cond12) {
              $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
              break;
             } else {
              $95 = $93;
             }
            }
            $96 = (_iswalnum($95)|0);
            $97 = ($96|0)==(0);
            if (!($97)) {
             $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
             break;
            }
            $$pre651 = HEAP32[$69>>2]|0;
            $99 = $$pre651;
           }
           $98 = $99 & 64;
           $100 = ($98|0)!=(0);
           $or$cond15 = $67 & $100;
           $101 = HEAP32[$5>>2]|0;
           $102 = ($101|0)!=(0);
           $or$cond18 = $102 & $or$cond15;
           do {
            if ($or$cond18) {
             if ($66) {
              $106 = $101;$110 = 1;
             } else {
              $103 = (_iswalnum($65)|0);
              $104 = ($103|0)!=(0);
              $$pr = HEAP32[$5>>2]|0;
              $106 = $$pr;$110 = $104;
             }
             $105 = ($106|0)==(95);
             if ($105) {
              if ($110) {
               $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
               break L36;
              } else {
               break;
              }
             } else {
              $107 = (_iswalnum($106)|0);
              $108 = ($107|0)!=(0);
              $109 = $110 ^ $108;
              if ($109) {
               break;
              } else {
               $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
               break L36;
              }
             }
            }
           } while(0);
           $111 = HEAP32[$69>>2]|0;
           $112 = $111 & 128;
           $113 = ($112|0)==(0);
           if ($113) {
            label = 50;
            break;
           }
           $114 = HEAP32[$5>>2]|0;
           $115 = ($114|0)==(0);
           $or$cond21 = $68 | $115;
           if ($or$cond21) {
            $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
            break;
           }
           if ($66) {
            $119 = $114;$123 = 1;
           } else {
            $116 = (_iswalnum($65)|0);
            $117 = ($116|0)!=(0);
            $$pr539 = HEAP32[$5>>2]|0;
            $119 = $$pr539;$123 = $117;
           }
           $118 = ($119|0)==(95);
           if ($118) {
            if ($123) {
             label = 50;
             break;
            } else {
             $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
             break;
            }
           } else {
            $120 = (_iswalnum($119)|0);
            $121 = ($120|0)!=(0);
            $122 = $123 ^ $121;
            if ($122) {
             $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
             break;
            } else {
             label = 50;
             break;
            }
           }
          } else {
           $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$1507595;
          }
         }
        } while(0);
        do {
         if ((label|0) == 50) {
          label = 0;
          $124 = ($$0533593|0)==(0|0);
          if ($124) {
           $125 = HEAP32[$126>>2]|0;
           $127 = ((($$0504597)) + 16|0);
           $128 = HEAP32[$127>>2]|0;
           $$1521 = $128;$$1534 = $125;$$5511 = $$1507595;
           break;
          }
          $129 = ((($$1507595)) + 28|0);
          $130 = HEAP32[$129>>2]|0;
          $131 = ($130|0)==(0|0);
          if ($131) {
           $132 = (___tre_mem_alloc_impl($11,0,0,0,32)|0);
           $133 = ($132|0)==(0|0);
           if ($133) {
            label = 54;
            break L16;
           }
           $139 = ((($132)) + 24|0);
           HEAP32[$139>>2] = $$1507595;
           $140 = ((($132)) + 28|0);
           HEAP32[$140>>2] = 0;
           $141 = HEAP32[$17>>2]|0;
           $142 = $141 << 2;
           $143 = (___tre_mem_alloc_impl($11,0,0,0,$142)|0);
           $144 = ((($132)) + 20|0);
           HEAP32[$144>>2] = $143;
           $145 = ($143|0)==(0|0);
           if ($145) {
            label = 61;
            break L16;
           }
           HEAP32[$129>>2] = $132;
           $$3509 = $132;
          } else {
           $$3509 = $130;
          }
          HEAP32[$$3509>>2] = $53;
          $149 = ((($$3509)) + 4|0);
          HEAP32[$149>>2] = $57;
          $150 = HEAP32[$126>>2]|0;
          $151 = ((($$3509)) + 8|0);
          HEAP32[$151>>2] = $150;
          $152 = ((($$0504597)) + 12|0);
          $153 = HEAP32[$152>>2]|0;
          $154 = ((($$3509)) + 12|0);
          HEAP32[$154>>2] = $153;
          $155 = HEAP32[$5>>2]|0;
          $156 = ((($$3509)) + 16|0);
          HEAP32[$156>>2] = $155;
          $157 = HEAP32[$17>>2]|0;
          $158 = ($157|0)>(0);
          if ($158) {
           $159 = ((($$3509)) + 20|0);
           $160 = HEAP32[$159>>2]|0;
           $$0487586 = 0;
           while(1) {
            $161 = (($$0537) + ($$0487586<<2)|0);
            $162 = HEAP32[$161>>2]|0;
            $163 = (($160) + ($$0487586<<2)|0);
            HEAP32[$163>>2] = $162;
            $164 = (($$0487586) + 1)|0;
            $165 = HEAP32[$17>>2]|0;
            $166 = ($164|0)<($165|0);
            if ($166) {
             $$0487586 = $164;
            } else {
             break;
            }
           }
          }
          $167 = ((($$0504597)) + 16|0);
          $168 = HEAP32[$167>>2]|0;
          $169 = ($168|0)==(0|0);
          if ($169) {
           $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$3509;
          } else {
           $170 = HEAP32[$168>>2]|0;
           $171 = ($170|0)>(-1);
           if (!($171)) {
            $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$3509;
            break;
           }
           $172 = ((($$3509)) + 20|0);
           $173 = HEAP32[$172>>2]|0;
           $$0481590 = $168;$176 = $170;
           while(1) {
            $174 = ((($$0481590)) + 4|0);
            $175 = (($173) + ($176<<2)|0);
            HEAP32[$175>>2] = $53;
            $177 = HEAP32[$174>>2]|0;
            $178 = ($177|0)>(-1);
            if ($178) {
             $$0481590 = $174;$176 = $177;
            } else {
             $$1521 = $$0520594;$$1534 = $$0533593;$$5511 = $$3509;
             break;
            }
           }
          }
         }
        } while(0);
        $179 = ((($$0504597)) + 32|0);
        $180 = ((($$0504597)) + 40|0);
        $181 = HEAP32[$180>>2]|0;
        $182 = ($181|0)==(0|0);
        if ($182) {
         break;
        } else {
         $$0504597 = $179;$$0520594 = $$1521;$$0533593 = $$1534;$$1507595 = $$5511;$126 = $180;
        }
       }
       $183 = ($$1521|0)==(0|0);
       if ($183) {
        $$3523 = 0;
       } else {
        $184 = HEAP32[$$1521>>2]|0;
        $185 = ($184|0)>(-1);
        if ($185) {
         $$2522604 = $$1521;$187 = $184;
         while(1) {
          $186 = (($$0537) + ($187<<2)|0);
          HEAP32[$186>>2] = $53;
          $188 = ((($$2522604)) + 4|0);
          $189 = HEAP32[$188>>2]|0;
          $190 = ($189|0)>(-1);
          if ($190) {
           $$2522604 = $188;$187 = $189;
          } else {
           $$3523 = $188;
           break;
          }
         }
        } else {
         $$3523 = $$1521;
        }
       }
       $191 = ($$1534|0)==(0|0);
       if ($191) {
        $$12518 = $$5511;$$3456 = $65;$$3485 = $$0482;$$7474 = $$1468;$$9529 = $$3523;
        label = 179;
       } else {
        $$0453$ph = $65;$$0463$ph = $53;$$1459$ph = $57;$$1483$ph = $$0482;$$2469$ph = $$1468;$$2535$ph = $$1534;$$4524$ph = $$3523;$$6512$ph = $$5511;
       }
      }
      L100: while(1) {
       if ((label|0) == 179) {
        label = 0;
        $416 = ((($$12518)) + 24|0);
        $417 = HEAP32[$416>>2]|0;
        $418 = ($417|0)==(0|0);
        if ($418) {
         break;
        }
        $419 = ((($$12518)) + 8|0);
        $420 = HEAP32[$419>>2]|0;
        $421 = ((($420)) + 20|0);
        $422 = HEAP32[$421>>2]|0;
        $423 = $422 & 256;
        $424 = ($423|0)==(0);
        if (!($424)) {
         $425 = ((($$12518)) + 12|0);
         $426 = HEAP32[$425>>2]|0;
         $427 = (($$0531) + ($426<<2)|0);
         HEAP32[$427>>2] = 0;
        }
        $428 = HEAP32[$$12518>>2]|0;
        $429 = ((($$12518)) + 4|0);
        $430 = HEAP32[$429>>2]|0;
        $431 = ((($$12518)) + 16|0);
        $432 = HEAP32[$431>>2]|0;
        HEAP32[$5>>2] = $432;
        $433 = HEAP32[$17>>2]|0;
        $434 = ($433|0)>(0);
        if (!($434)) {
         $$0453$ph = $$3456;$$0463$ph = $428;$$1459$ph = $430;$$1483$ph = $$3485;$$2469$ph = $$7474;$$2535$ph = $420;$$4524$ph = $$9529;$$6512$ph = $417;
         continue;
        }
        $435 = ((($$12518)) + 20|0);
        $436 = HEAP32[$435>>2]|0;
        $$0608 = 0;
        while(1) {
         $437 = (($436) + ($$0608<<2)|0);
         $438 = HEAP32[$437>>2]|0;
         $439 = (($$0537) + ($$0608<<2)|0);
         HEAP32[$439>>2] = $438;
         $440 = (($$0608) + 1)|0;
         $441 = ($440|0)<($433|0);
         if ($441) {
          $$0608 = $440;
         } else {
          $$0453$ph = $$3456;$$0463$ph = $428;$$1459$ph = $430;$$1483$ph = $$3485;$$2469$ph = $$7474;$$2535$ph = $420;$$4524$ph = $$9529;$$6512$ph = $417;
          continue L100;
         }
        }
       }
       $$0453 = $$0453$ph;$$0463 = $$0463$ph;$$1459 = $$1459$ph;$$2469 = $$2469$ph;$$2535 = $$2535$ph;$$4524 = $$4524$ph;$$6512 = $$6512$ph;
       L111: while(1) {
        $192 = HEAP32[$39>>2]|0;
        $193 = ($$2535|0)==($192|0);
        if ($193) {
         break;
        }
        $208 = ((($$2535)) + 8|0);
        $209 = HEAP32[$208>>2]|0;
        $210 = ($209|0)==(0|0);
        if ($210) {
         label = 100;
        } else {
         $211 = ((($$2535)) + 20|0);
         $212 = HEAP32[$211>>2]|0;
         $213 = $212 & 256;
         $214 = ($213|0)==(0);
         if ($214) {
          label = 100;
         } else {
          $215 = ((($$2535)) + 24|0);
          $216 = HEAP32[$215>>2]|0;
          $217 = (($216) + 1)|0;
          $218 = HEAP32[$8>>2]|0;
          $219 = $218 & -9;
          _tre_fill_pmatch($217,$$0502,$219,$0,$$0537,$$0463);
          $220 = (($$0502) + ($216<<3)|0);
          $221 = HEAP32[$220>>2]|0;
          $222 = (((($$0502) + ($216<<3)|0)) + 4|0);
          $223 = HEAP32[$222>>2]|0;
          $224 = (($223) - ($221))|0;
          $225 = (($1) + ($221)|0);
          $226 = ((($$1459)) + -1|0);
          $227 = (_strncmp($225,$226,$224)|0);
          $228 = ($227|0)==(0);
          do {
           if ($228) {
            $229 = ($224|0)==(0);
            $spec$select = $229&1;
            $230 = ((($$2535)) + 12|0);
            $231 = HEAP32[$230>>2]|0;
            $232 = (($$0531) + ($231<<2)|0);
            if ($229) {
             $233 = HEAP32[$232>>2]|0;
             $234 = ($233|0)==(0);
             if (!($234)) {
              $$1454 = $$0453;$$1464 = $$0463;$$2460 = $$1459;$$2492 = 25;$$4471 = $$2469;
              break;
             }
            }
            HEAP32[$232>>2] = $spec$select;
            $235 = (($224) + -1)|0;
            $236 = (($$1459) + ($235)|0);
            $237 = HEAP32[$5>>2]|0;
            $238 = (($$0463) + ($$2469))|0;
            $239 = (($238) + ($235))|0;
            $240 = (_mbtowc($5,$236,4)|0);
            $241 = ($240|0)<(1);
            if ($241) {
             $242 = ($240|0)<(0);
             if ($242) {
              $$1454 = $237;$$1464 = $239;$$2460 = $236;$$2492 = 2;$$4471 = $240;
              break;
             } else {
              $$3470 = 1;
             }
            } else {
             $$3470 = $240;
            }
            $243 = (($236) + ($$3470)|0);
            $$1454 = $237;$$1464 = $239;$$2460 = $243;$$2492 = 0;$$4471 = $$3470;
           } else {
            $$1454 = $$0453;$$1464 = $$0463;$$2460 = $$1459;$$2492 = 25;$$4471 = $$2469;
           }
          } while(0);
          $$2492$clear = $$2492 & 31;
          switch ($$2492$clear<<24>>24) {
          case 2:  {
           $$1503 = $$0502;$$1532 = $$0531;$$1538 = $$0537;$$6501 = 1;$447 = $135;$449 = $137;$451 = $52;
           break L8;
           break;
          }
          case 25:  {
           $$12518$ph = $$6512;$$3456$ph = $$1454;$$7474$ph = $$4471;$$9529$ph = $$4524;
           label = 178;
           break L111;
           break;
          }
          case 0:  {
           $$2455 = $$1454;$$2465 = $$1464;$$3461 = $$2460;$$6473 = $$4471;
           break;
          }
          default: {
           $$14 = 12;
           break L1;
          }
          }
         }
        }
        if ((label|0) == 100) {
         label = 0;
         $244 = HEAP32[$5>>2]|0;
         $245 = ($244|0)==(0);
         if ($245) {
          $$12518$ph = $$6512;$$3456$ph = $$0453;$$7474$ph = $$2469;$$9529$ph = $$4524;
          label = 178;
          break;
         }
         $246 = (($$0463) + ($$2469))|0;
         $247 = (_mbtowc($5,$$1459,4)|0);
         $248 = ($247|0)<(1);
         if ($248) {
          $249 = ($247|0)<(0);
          if ($249) {
           $$1503 = $$0502;$$1532 = $$0531;$$1538 = $$0537;$$6501 = 1;$447 = $135;$449 = $137;$451 = $52;
           break L8;
          } else {
           $$5472 = 1;
          }
         } else {
          $$5472 = $247;
         }
         $250 = (($$1459) + ($$5472)|0);
         $$2455 = $244;$$2465 = $246;$$3461 = $250;$$6473 = $$5472;
        }
        $251 = HEAP32[$208>>2]|0;
        $252 = ($251|0)==(0|0);
        if ($252) {
         $$12518$ph = $$6512;$$3456$ph = $$2455;$$7474$ph = $$6473;$$9529$ph = $$4524;
         label = 178;
         break;
        }
        $253 = ($$2465|0)<(1);
        $254 = ($$2455|0)==(10);
        $or$cond30 = $38 & $254;
        $255 = ($$2455|0)==(95);
        $256 = ($$2465|0)!=(0);
        $257 = ($$2465|0)==(0);
        $or$cond27$not = $253 & $37;
        $$0479627 = 0;$$1505624 = $$2535;$$5525620 = $$4524;$$7513621 = $$6512;$352 = $208;
        while(1) {
         $258 = HEAP32[$$1505624>>2]|0;
         $259 = ($258>>>0)>($$2455>>>0);
         L136: do {
          if ($259) {
           $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
          } else {
           $260 = ((($$1505624)) + 4|0);
           $261 = HEAP32[$260>>2]|0;
           $262 = ($261>>>0)<($$2455>>>0);
           if ($262) {
            $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
            break;
           }
           $263 = ((($$1505624)) + 20|0);
           $264 = HEAP32[$263>>2]|0;
           $265 = ($264|0)==(0);
           do {
            if (!($265)) {
             $266 = $264 & 1;
             $267 = ($266|0)==(0);
             $brmerge643 = $267 | $or$cond27$not;
             $brmerge644 = $brmerge643 | $or$cond30;
             if (!($brmerge644)) {
              $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
              break L136;
             }
             $268 = $264 & 2;
             $269 = ($268|0)==(0);
             if (!($269)) {
              $270 = HEAP32[$5>>2]|0;
              $271 = $270 | $7;
              $272 = ($271|0)==(0);
              $273 = ($270|0)==(10);
              $or$cond36 = $38 & $273;
              $or$cond646 = $272 | $or$cond36;
              if (!($or$cond646)) {
               $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
               break L136;
              }
             }
             $274 = $264 & 16;
             $275 = ($274|0)==(0);
             do {
              if (!($275)) {
               if ($255) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               }
               $276 = (_iswalnum($$2455)|0);
               $277 = ($276|0)==(0);
               if (!($277)) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               }
               $278 = HEAP32[$5>>2]|0;
               $279 = ($278|0)==(95);
               if ($279) {
                break;
               }
               $280 = (_iswalnum($278)|0);
               $281 = ($280|0)==(0);
               if ($281) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               }
              }
             } while(0);
             $282 = HEAP32[$263>>2]|0;
             $283 = $282 & 32;
             $284 = ($283|0)==(0);
             if ($284) {
              $293 = $282;
             } else {
              if ($255) {
               $$old37 = HEAP32[$5>>2]|0;
               $$old38 = ($$old37|0)==(95);
               if ($$old38) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               } else {
                $289 = $$old37;
               }
              } else {
               $285 = (_iswalnum($$2455)|0);
               $286 = ($285|0)==(0);
               $287 = HEAP32[$5>>2]|0;
               $288 = ($287|0)==(95);
               $or$cond39 = $286 | $288;
               if ($or$cond39) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               } else {
                $289 = $287;
               }
              }
              $290 = (_iswalnum($289)|0);
              $291 = ($290|0)==(0);
              if (!($291)) {
               $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
               break L136;
              }
              $$pre655 = HEAP32[$263>>2]|0;
              $293 = $$pre655;
             }
             $292 = $293 & 64;
             $294 = ($292|0)!=(0);
             $or$cond42 = $256 & $294;
             $295 = HEAP32[$5>>2]|0;
             $296 = ($295|0)!=(0);
             $or$cond45 = $296 & $or$cond42;
             do {
              if ($or$cond45) {
               if ($255) {
                $300 = $295;$304 = 1;
               } else {
                $297 = (_iswalnum($$2455)|0);
                $298 = ($297|0)!=(0);
                $$pr545 = HEAP32[$5>>2]|0;
                $300 = $$pr545;$304 = $298;
               }
               $299 = ($300|0)==(95);
               if ($299) {
                if ($304) {
                 $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                 break L136;
                } else {
                 break;
                }
               } else {
                $301 = (_iswalnum($300)|0);
                $302 = ($301|0)!=(0);
                $303 = $304 ^ $302;
                if ($303) {
                 break;
                } else {
                 $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                 break L136;
                }
               }
              }
             } while(0);
             $305 = HEAP32[$263>>2]|0;
             $306 = $305 & 128;
             $307 = ($306|0)==(0);
             do {
              if (!($307)) {
               $308 = HEAP32[$5>>2]|0;
               $309 = ($308|0)==(0);
               $or$cond48 = $257 | $309;
               if ($or$cond48) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               }
               if ($255) {
                $313 = $308;$317 = 1;
               } else {
                $310 = (_iswalnum($$2455)|0);
                $311 = ($310|0)!=(0);
                $$pr547 = HEAP32[$5>>2]|0;
                $313 = $$pr547;$317 = $311;
               }
               $312 = ($313|0)==(95);
               if ($312) {
                if ($317) {
                 break;
                } else {
                 $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                 break L136;
                }
               } else {
                $314 = (_iswalnum($313)|0);
                $315 = ($314|0)!=(0);
                $316 = $317 ^ $315;
                if ($316) {
                 $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                 break L136;
                } else {
                 break;
                }
               }
              }
             } while(0);
             $318 = HEAP32[$263>>2]|0;
             $319 = $318 & 4;
             $320 = ($319|0)==(0);
             do {
              if (!($320)) {
               $321 = HEAP32[$8>>2]|0;
               $322 = $321 & 2;
               $323 = ($322|0)==(0);
               if ($323) {
                $324 = ((($$1505624)) + 24|0);
                $325 = HEAP32[$324>>2]|0;
                $326 = (_iswctype($$2455,$325)|0);
                $327 = ($326|0)==(0);
                if ($327) {
                 $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                 break L136;
                }
                $$pre657 = HEAP32[$263>>2]|0;
                $$pre659 = $$pre657 & 4;
                $328 = ($$pre659|0)==(0);
                if ($328) {
                 break;
                }
               }
               $329 = HEAP32[$8>>2]|0;
               $330 = $329 & 2;
               $331 = ($330|0)==(0);
               if ($331) {
                break;
               }
               $332 = (_towlower($$2455)|0);
               $333 = ((($$1505624)) + 24|0);
               $334 = HEAP32[$333>>2]|0;
               $335 = (_iswctype($332,$334)|0);
               $336 = ($335|0)==(0);
               if (!($336)) {
                break;
               }
               $337 = (_towupper($$2455)|0);
               $338 = HEAP32[$333>>2]|0;
               $339 = (_iswctype($337,$338)|0);
               $340 = ($339|0)==(0);
               if ($340) {
                $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
                break L136;
               }
              }
             } while(0);
             $341 = HEAP32[$263>>2]|0;
             $342 = $341 & 8;
             $343 = ($342|0)==(0);
             if ($343) {
              break;
             }
             $344 = ((($$1505624)) + 28|0);
             $345 = HEAP32[$344>>2]|0;
             $346 = HEAP32[$8>>2]|0;
             $347 = $346 & 2;
             $348 = (_tre_neg_char_classes_match($345,$$2455,$347)|0);
             $349 = ($348|0)==(0);
             if (!($349)) {
              $$11517 = $$7513621;$$1480 = $$0479627;$$6526 = $$5525620;
              break L136;
             }
            }
           } while(0);
           $350 = ($$0479627|0)==(0|0);
           if ($350) {
            $351 = HEAP32[$352>>2]|0;
            $353 = ((($$1505624)) + 16|0);
            $354 = HEAP32[$353>>2]|0;
            $$11517 = $$7513621;$$1480 = $351;$$6526 = $354;
            break;
           }
           $355 = ((($$7513621)) + 28|0);
           $356 = HEAP32[$355>>2]|0;
           $357 = ($356|0)==(0|0);
           if ($357) {
            $358 = (___tre_mem_alloc_impl($11,0,0,0,32)|0);
            $359 = ($358|0)==(0|0);
            if ($359) {
             label = 149;
             break L16;
            }
            $363 = ((($358)) + 24|0);
            HEAP32[$363>>2] = $$7513621;
            $364 = ((($358)) + 28|0);
            HEAP32[$364>>2] = 0;
            $365 = HEAP32[$17>>2]|0;
            $366 = $365 << 2;
            $367 = (___tre_mem_alloc_impl($11,0,0,0,$366)|0);
            $368 = ((($358)) + 20|0);
            HEAP32[$368>>2] = $367;
            $369 = ($367|0)==(0|0);
            if ($369) {
             label = 156;
             break L16;
            }
            HEAP32[$355>>2] = $358;
            $$9515 = $358;
           } else {
            $$9515 = $356;
           }
           HEAP32[$$9515>>2] = $$2465;
           $373 = ((($$9515)) + 4|0);
           HEAP32[$373>>2] = $$3461;
           $374 = HEAP32[$352>>2]|0;
           $375 = ((($$9515)) + 8|0);
           HEAP32[$375>>2] = $374;
           $376 = ((($$1505624)) + 12|0);
           $377 = HEAP32[$376>>2]|0;
           $378 = ((($$9515)) + 12|0);
           HEAP32[$378>>2] = $377;
           $379 = HEAP32[$5>>2]|0;
           $380 = ((($$9515)) + 16|0);
           HEAP32[$380>>2] = $379;
           $381 = HEAP32[$17>>2]|0;
           $382 = ($381|0)>(0);
           if ($382) {
            $383 = ((($$9515)) + 20|0);
            $384 = HEAP32[$383>>2]|0;
            $$0452612 = 0;
            while(1) {
             $385 = (($$0537) + ($$0452612<<2)|0);
             $386 = HEAP32[$385>>2]|0;
             $387 = (($384) + ($$0452612<<2)|0);
             HEAP32[$387>>2] = $386;
             $388 = (($$0452612) + 1)|0;
             $389 = HEAP32[$17>>2]|0;
             $390 = ($388|0)<($389|0);
             if ($390) {
              $$0452612 = $388;
             } else {
              break;
             }
            }
           }
           $391 = ((($$1505624)) + 16|0);
           $392 = HEAP32[$391>>2]|0;
           $393 = ($392|0)==(0|0);
           if ($393) {
            $$11517 = $$9515;$$1480 = $$0479627;$$6526 = $$5525620;
            break;
           }
           $394 = ((($$9515)) + 20|0);
           $395 = HEAP32[$392>>2]|0;
           $396 = ($395|0)>(-1);
           if (!($396)) {
            $$11517 = $$9515;$$1480 = $$0479627;$$6526 = $$5525620;
            break;
           }
           $397 = HEAP32[$394>>2]|0;
           $$0450616675 = $392;$399 = $395;
           while(1) {
            $398 = (($397) + ($399<<2)|0);
            HEAP32[$398>>2] = $$2465;
            $400 = ((($$0450616675)) + 4|0);
            $401 = HEAP32[$400>>2]|0;
            $402 = ($401|0)>(-1);
            if ($402) {
             $$0450616675 = $400;$399 = $401;
            } else {
             $$11517 = $$9515;$$1480 = $$0479627;$$6526 = $$5525620;
             break;
            }
           }
          }
         } while(0);
         $403 = ((($$1505624)) + 32|0);
         $404 = ((($$1505624)) + 40|0);
         $405 = HEAP32[$404>>2]|0;
         $406 = ($405|0)==(0|0);
         if ($406) {
          break;
         } else {
          $$0479627 = $$1480;$$1505624 = $403;$$5525620 = $$6526;$$7513621 = $$11517;$352 = $404;
         }
        }
        $407 = ($$1480|0)==(0|0);
        if ($407) {
         $$12518$ph = $$11517;$$3456$ph = $$2455;$$7474$ph = $$6473;$$9529$ph = $$6526;
         label = 178;
         break;
        }
        $408 = ($$6526|0)==(0|0);
        do {
         if ($408) {
          $$4524$be = 0;
         } else {
          $409 = HEAP32[$$6526>>2]|0;
          $410 = ($409|0)>(-1);
          if (!($410)) {
           $$4524$be = $$6526;
           break;
          }
          $$7527634 = $$6526;$413 = $409;
          while(1) {
           $411 = ((($$7527634)) + 4|0);
           $412 = (($$0537) + ($413<<2)|0);
           HEAP32[$412>>2] = $$2465;
           $414 = HEAP32[$411>>2]|0;
           $415 = ($414|0)>(-1);
           if ($415) {
            $$7527634 = $411;$413 = $414;
           } else {
            $$4524$be = $411;
            break;
           }
          }
         }
        } while(0);
        $$0453 = $$2455;$$0463 = $$2465;$$1459 = $$3461;$$2469 = $$6473;$$2535 = $$1480;$$4524 = $$4524$be;$$6512 = $$11517;
       }
       if ((label|0) == 178) {
        label = 0;
        $$12518 = $$12518$ph;$$3456 = $$3456$ph;$$3485 = $$1483$ph;$$7474 = $$7474$ph;$$9529 = $$9529$ph;
        label = 179;
        continue;
       }
       $194 = ($$1483$ph|0)<($$0463|0);
       if ($194) {
        if ($35) {
         $$12518 = $$6512;$$3456 = $$0453;$$3485 = $$0463;$$7474 = $$2469;$$9529 = $$4524;
         label = 179;
         continue;
        }
        $$pre658 = HEAP32[$17>>2]|0;
        $201 = $$pre658;
       } else {
        $195 = ($$1483$ph|0)==($$0463|0);
        $or$cond24 = $40 & $195;
        if (!($or$cond24)) {
         $$12518 = $$6512;$$3456 = $$0453;$$3485 = $$1483$ph;$$7474 = $$2469;$$9529 = $$4524;
         label = 179;
         continue;
        }
        $196 = HEAP32[$17>>2]|0;
        $197 = HEAP32[$41>>2]|0;
        $198 = (_tre_tag_order($196,$197,$$0537,$2)|0);
        $199 = ($198|0)==(0);
        if ($199) {
         $$12518 = $$6512;$$3456 = $$0453;$$3485 = $$1483$ph;$$7474 = $$2469;$$9529 = $$4524;
         label = 179;
         continue;
        } else {
         $201 = $196;
        }
       }
       $200 = ($201|0)>(0);
       if (!($200)) {
        $$12518 = $$6512;$$3456 = $$0453;$$3485 = $$0463;$$7474 = $$2469;$$9529 = $$4524;
        label = 179;
        continue;
       }
       $$0477638 = 0;
       while(1) {
        $202 = (($$0537) + ($$0477638<<2)|0);
        $203 = HEAP32[$202>>2]|0;
        $204 = (($2) + ($$0477638<<2)|0);
        HEAP32[$204>>2] = $203;
        $205 = (($$0477638) + 1)|0;
        $206 = HEAP32[$17>>2]|0;
        $207 = ($205|0)<($206|0);
        if ($207) {
         $$0477638 = $205;
        } else {
         break;
        }
       }
       $$12518 = $$6512;$$3456 = $$0453;$$3485 = $$0463;$$7474 = $$2469;$$9529 = $$4524;
       label = 179;
      }
      $442 = ($$3485|0)>(-1);
      $443 = HEAP32[$5>>2]|0;
      $444 = ($443|0)==(0);
      $or$cond51 = $442 | $444;
      if ($or$cond51) {
       label = 187;
       break;
      }
      HEAP32[$5>>2] = $58;
      $$0458 = $57;$$0467 = $$7474;$$0476 = $53;$$0482 = $$3485;$$0506 = $$12518;$65 = $58;
     }
     if ((label|0) == 54) {
      ___tre_mem_destroy($11);
      $134 = ($$0537|0)==(0|0);
      if (!($134)) {
       _free($135);
      }
      $136 = ($$0502|0)==(0|0);
      if (!($136)) {
       _free($137);
      }
      $138 = ($$0531|0)==(0|0);
      if ($138) {
       $$14 = 12;
       break L1;
      }
      _free($52);
      $$14 = 12;
      break L1;
     }
     else if ((label|0) == 61) {
      ___tre_mem_destroy($11);
      $146 = ($$0537|0)==(0|0);
      if (!($146)) {
       _free($135);
      }
      $147 = ($$0502|0)==(0|0);
      if (!($147)) {
       _free($137);
      }
      $148 = ($$0531|0)==(0|0);
      if ($148) {
       $$14 = 12;
       break L1;
      }
      _free($52);
      $$14 = 12;
      break L1;
     }
     else if ((label|0) == 149) {
      ___tre_mem_destroy($11);
      $360 = ($$0537|0)==(0|0);
      if (!($360)) {
       _free($135);
      }
      $361 = ($$0502|0)==(0|0);
      if (!($361)) {
       _free($137);
      }
      $362 = ($$0531|0)==(0|0);
      if ($362) {
       $$14 = 12;
       break L1;
      }
      _free($52);
      $$14 = 12;
      break L1;
     }
     else if ((label|0) == 156) {
      ___tre_mem_destroy($11);
      $370 = ($$0537|0)==(0|0);
      if (!($370)) {
       _free($135);
      }
      $371 = ($$0502|0)==(0|0);
      if (!($371)) {
       _free($137);
      }
      $372 = ($$0531|0)==(0|0);
      if ($372) {
       $$14 = 12;
       break L1;
      }
      _free($52);
      $$14 = 12;
      break L1;
     }
     else if ((label|0) == 187) {
      $not$ = $442 ^ 1;
      $445 = $not$&1;
      HEAP32[$4>>2] = $$3485;
      $$1503 = $$0502;$$1532 = $$0531;$$1538 = $$0537;$$6501 = $445;$447 = $135;$449 = $137;$451 = $52;
      break;
     }
    }
   } while(0);
   ___tre_mem_destroy($11);
   $446 = ($$1538|0)==(0|0);
   if (!($446)) {
    _free($447);
   }
   $448 = ($$1503|0)==(0|0);
   if (!($448)) {
    _free($449);
   }
   $450 = ($$1532|0)==(0|0);
   if ($450) {
    $$14 = $$6501;
   } else {
    _free($451);
    $$14 = $$6501;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$14|0);
}
function _tre_tnfa_run_parallel($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0415 = 0, $$0420592 = 0, $$0421 = 0, $$0422 = 0, $$0423 = 0, $$0426 = 0, $$0427$ph526 = 0, $$0427502 = 0, $$0432 = 0, $$0437 = 0, $$0448591 = 0, $$0456 = 0, $$0457514 = 0, $$0460 = 0, $$0468534 = 0, $$1 = 0, $$10 = 0, $$10447 = 0, $$10447$lobit = 0, $$1424 = 0;
 var $$1428565 = 0, $$1430 = 0, $$1433$ph$lcssa = 0, $$1433$ph524 = 0, $$1433$ph525$mux = 0, $$1438$ph$lcssa = 0, $$1438$ph522 = 0, $$1438$ph523$mux = 0, $$1449587 = 0, $$1458546 = 0, $$1461$ph$lcssa = 0, $$1461$ph520 = 0, $$1469575 = 0, $$1471 = 0, $$1474 = 0, $$2425 = 0, $$2431$lcssa = 0, $$2431579 = 0, $$2434 = 0, $$2439 = 0;
 var $$2462 = 0, $$2472 = 0, $$2475 = 0, $$3$lcssa = 0, $$3435 = 0, $$3440 = 0, $$3451517 = 0, $$3463$lcssa = 0, $$3463536 = 0, $$3562 = 0, $$4 = 0, $$4436 = 0, $$4441 = 0, $$4452530 = 0, $$4464 = 0, $$5 = 0, $$5442$lcssa = 0, $$5442577 = 0, $$5453542 = 0, $$5465$lcssa = 0;
 var $$5465576 = 0, $$6$lcssa = 0, $$6443$lcssa = 0, $$6443556 = 0, $$6454552 = 0, $$6466$lcssa = 0, $$6466555 = 0, $$6578 = 0, $$7$lcssa = 0, $$7444 = 0, $$7455549 = 0, $$7467 = 0, $$7559 = 0, $$8 = 0, $$9446 = 0, $$old = 0, $$old34 = 0, $$old35 = 0, $$old46 = 0, $$old47 = 0;
 var $$old8 = 0, $$pr = 0, $$pr481 = 0, $$pr484 = 0, $$pr486 = 0, $$pre = 0, $$pre$phi629Z2D = 0, $$pre$phi631Z2D = 0, $$pre621 = 0, $$pre623 = 0, $$pre625 = 0, $$pre626 = 0, $$pre630 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge596 = 0, $brmerge599 = 0, $brmerge600 = 0, $brmerge604 = 0, $exitcond = 0, $exitcond616 = 0, $exitcond618 = 0, $or$cond$not = 0, $or$cond12 = 0, $or$cond15 = 0, $or$cond18 = 0, $or$cond21 = 0, $or$cond24$not = 0;
 var $or$cond27 = 0, $or$cond3 = 0, $or$cond33 = 0, $or$cond36 = 0, $or$cond39 = 0, $or$cond42 = 0, $or$cond45 = 0, $or$cond48 = 0, $or$cond598 = 0, $or$cond602 = 0, $or$cond7 = 0, $or$cond9 = 0, $spec$select = 0, $spec$select476 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $5 = sp;
 HEAP32[$5>>2] = 0;
 $6 = $3 & 1;
 $7 = $3 & 2;
 $8 = ((($0)) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 4;
 $11 = ($2|0)==(0|0);
 if ($11) {
  $$0456 = 0;
 } else {
  $12 = ((($0)) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $$0456 = $13;
 }
 $14 = $$0456 << 2;
 $15 = ((($0)) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 3;
 $18 = (($17) + 8)|0;
 $19 = Math_imul($14, $16)|0;
 $20 = (($18) + ($19))|0;
 $21 = $20 << 1;
 $22 = (($14) + 12)|0;
 $23 = (($22) + ($17))|0;
 $24 = (($23) + ($21))|0;
 $25 = (_malloc($24)|0);
 $26 = ($25|0)==(0|0);
 if ($26) {
  $$1 = 12;
 } else {
  (_memset(($25|0),0,($24|0))|0);
  $27 = (($25) + ($14)|0);
  $28 = $27;
  $29 = $28 & 3;
  $30 = ($29|0)==(0);
  $31 = (4 - ($29))|0;
  $spec$select = $30 ? 0 : $31;
  $32 = (($27) + ($spec$select)|0);
  $33 = (($32) + ($18)|0);
  $34 = $33;
  $35 = $34 & 3;
  $36 = ($35|0)==(0);
  $37 = (4 - ($35))|0;
  $38 = $36 ? 0 : $37;
  $39 = (($33) + ($38)|0);
  $40 = (($39) + ($18)|0);
  $41 = $40;
  $42 = $41 & 3;
  $43 = ($42|0)==(0);
  $44 = (4 - ($42))|0;
  $spec$select476 = $43 ? 0 : $44;
  $45 = (($40) + ($spec$select476)|0);
  $46 = (($45) + ($17)|0);
  $47 = $46;
  $48 = $47 & 3;
  $49 = HEAP32[$15>>2]|0;
  $50 = ($49|0)>(0);
  if ($50) {
   $51 = ($48|0)==(0);
   $52 = (4 - ($48))|0;
   $53 = $51 ? 0 : $52;
   $54 = (($46) + ($53)|0);
   $$0420592 = $54;$$0448591 = 0;
   while(1) {
    $55 = (((($39) + ($$0448591<<3)|0)) + 4|0);
    HEAP32[$55>>2] = $$0420592;
    $56 = (($$0420592) + ($14)|0);
    $57 = (((($32) + ($$0448591<<3)|0)) + 4|0);
    HEAP32[$57>>2] = $56;
    $58 = (($56) + ($14)|0);
    $59 = (($$0448591) + 1)|0;
    $60 = ($59|0)<($49|0);
    if ($60) {
     $$0420592 = $58;$$0448591 = $59;
    } else {
     break;
    }
   }
   if ($50) {
    $$1449587 = 0;
    while(1) {
     $61 = (($45) + ($$1449587<<3)|0);
     HEAP32[$61>>2] = -1;
     $62 = (($$1449587) + 1)|0;
     $63 = ($62|0)<($49|0);
     if ($63) {
      $$1449587 = $62;
     } else {
      break;
     }
    }
   }
  }
  $64 = (_mbtowc($5,$1,4)|0);
  $65 = ($64|0)<(1);
  if ($65) {
   $66 = ($64|0)<(0);
   if ($66) {
    $$0426 = 1;
   } else {
    $$0423 = 1;
    label = 12;
   }
  } else {
   $$0423 = $64;
   label = 12;
  }
  L17: do {
   if ((label|0) == 12) {
    $67 = (($1) + ($$0423)|0);
    $68 = ((($0)) + 8|0);
    $69 = ($$0456|0)==(0);
    $70 = ($6|0)==(0);
    $71 = ($10|0)!=(0);
    $72 = ($$0456|0)>(0);
    $73 = ((($0)) + 12|0);
    $74 = ($$0456|0)<(1);
    $75 = ((($0)) + 44|0);
    $76 = ((($0)) + 36|0);
    $77 = ((($0)) + 32|0);
    $$0415 = 0;$$0421 = $67;$$0422 = 0;$$0432 = 0;$$0437 = -1;$$0460 = $32;$$1424 = $$0423;$$1430 = $25;$$1471 = $32;$$1474 = $39;
    while(1) {
     $78 = ($$0437|0)<(0);
     if ($78) {
      $79 = HEAP32[$68>>2]|0;
      $80 = ((($79)) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($81|0)==(0|0);
      L23: do {
       if ($82) {
        $$1433$ph$lcssa = $$0432;$$1438$ph$lcssa = $$0437;$$1461$ph$lcssa = $$0460;
       } else {
        $83 = ($$0422|0)<(1);
        $84 = ($$0415|0)==(10);
        $or$cond3 = $71 & $84;
        $85 = ($$0415|0)==(95);
        $86 = ($$0422|0)!=(0);
        $87 = ($$0422|0)==(0);
        $or$cond$not = $83 & $70;
        $$0427$ph526 = $79;$$1433$ph524 = $$0432;$$1438$ph522 = $$0437;$$1461$ph520 = $$0460;$397 = $80;
        while(1) {
         $$0427502 = $$0427$ph526;$154 = $397;
         L27: while(1) {
          $88 = ((($$0427502)) + 12|0);
          $89 = HEAP32[$88>>2]|0;
          $90 = (($45) + ($89<<3)|0);
          $91 = HEAP32[$90>>2]|0;
          $92 = ($91|0)<($$0422|0);
          if (!($92)) {
           $$2462 = $$1461$ph520;$$3435 = $$1433$ph524;$$3440 = $$1438$ph522;
           break;
          }
          $93 = ((($$0427502)) + 20|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = ($94|0)==(0);
          if ($95) {
           label = 47;
           break;
          }
          $96 = $94 & 1;
          $97 = ($96|0)==(0);
          $brmerge = $97 | $or$cond$not;
          $brmerge596 = $brmerge | $or$cond3;
          L31: do {
           if ($brmerge596) {
            $98 = $94 & 2;
            $99 = ($98|0)==(0);
            if (!($99)) {
             $100 = HEAP32[$5>>2]|0;
             $101 = $100 | $7;
             $102 = ($101|0)==(0);
             $103 = ($100|0)==(10);
             $or$cond7 = $71 & $103;
             $or$cond598 = $102 | $or$cond7;
             if (!($or$cond598)) {
              break;
             }
            }
            $104 = $94 & 16;
            $105 = ($104|0)==(0);
            do {
             if (!($105)) {
              if ($85) {
               break L31;
              }
              $106 = (_iswalnum($$0415)|0);
              $107 = ($106|0)==(0);
              if (!($107)) {
               break L31;
              }
              $108 = HEAP32[$5>>2]|0;
              $109 = ($108|0)==(95);
              if ($109) {
               break;
              }
              $110 = (_iswalnum($108)|0);
              $111 = ($110|0)==(0);
              if ($111) {
               break L31;
              }
             }
            } while(0);
            $112 = HEAP32[$93>>2]|0;
            $113 = $112 & 32;
            $114 = ($113|0)==(0);
            if ($114) {
             $123 = $112;
            } else {
             if ($85) {
              $$old = HEAP32[$5>>2]|0;
              $$old8 = ($$old|0)==(95);
              if ($$old8) {
               break;
              } else {
               $119 = $$old;
              }
             } else {
              $115 = (_iswalnum($$0415)|0);
              $116 = ($115|0)==(0);
              $117 = HEAP32[$5>>2]|0;
              $118 = ($117|0)==(95);
              $or$cond9 = $116 | $118;
              if ($or$cond9) {
               break;
              } else {
               $119 = $117;
              }
             }
             $120 = (_iswalnum($119)|0);
             $121 = ($120|0)==(0);
             if (!($121)) {
              break;
             }
             $$pre = HEAP32[$93>>2]|0;
             $123 = $$pre;
            }
            $122 = $123 & 64;
            $124 = ($122|0)!=(0);
            $or$cond12 = $86 & $124;
            $125 = HEAP32[$5>>2]|0;
            $126 = ($125|0)!=(0);
            $or$cond15 = $126 & $or$cond12;
            do {
             if ($or$cond15) {
              if ($85) {
               $130 = $125;$134 = 1;
              } else {
               $127 = (_iswalnum($$0415)|0);
               $128 = ($127|0)!=(0);
               $$pr = HEAP32[$5>>2]|0;
               $130 = $$pr;$134 = $128;
              }
              $129 = ($130|0)==(95);
              if ($129) {
               if ($134) {
                break L31;
               } else {
                break;
               }
              } else {
               $131 = (_iswalnum($130)|0);
               $132 = ($131|0)!=(0);
               $133 = $134 ^ $132;
               if ($133) {
                break;
               } else {
                break L31;
               }
              }
             }
            } while(0);
            $135 = HEAP32[$93>>2]|0;
            $136 = $135 & 128;
            $137 = ($136|0)==(0);
            if ($137) {
             label = 47;
             break L27;
            }
            $138 = HEAP32[$5>>2]|0;
            $139 = ($138|0)==(0);
            $or$cond18 = $87 | $139;
            if ($or$cond18) {
             break;
            }
            if ($85) {
             $143 = $138;$147 = 1;
            } else {
             $140 = (_iswalnum($$0415)|0);
             $141 = ($140|0)!=(0);
             $$pr481 = HEAP32[$5>>2]|0;
             $143 = $$pr481;$147 = $141;
            }
            $142 = ($143|0)==(95);
            if ($142) {
             if ($147) {
              label = 47;
              break L27;
             } else {
              break;
             }
            } else {
             $144 = (_iswalnum($143)|0);
             $145 = ($144|0)!=(0);
             $146 = $147 ^ $145;
             if ($146) {
              break;
             } else {
              label = 47;
              break L27;
             }
            }
           }
          } while(0);
          $148 = ((($$0427502)) + 32|0);
          $149 = ((($$0427502)) + 40|0);
          $150 = HEAP32[$149>>2]|0;
          $151 = ($150|0)==(0|0);
          if ($151) {
           $$1433$ph$lcssa = $$1433$ph524;$$1438$ph$lcssa = $$1438$ph522;$$1461$ph$lcssa = $$1461$ph520;
           break L23;
          } else {
           $$0427502 = $148;$154 = $149;
          }
         }
         if ((label|0) == 47) {
          label = 0;
          $152 = ((($$0427502)) + 12|0);
          $153 = HEAP32[$154>>2]|0;
          HEAP32[$$1461$ph520>>2] = $153;
          if ($72) {
           $155 = ((($$1461$ph520)) + 4|0);
           $156 = HEAP32[$155>>2]|0;
           _memset(($156|0),-1,($14|0))|0;
          }
          $157 = ((($$0427502)) + 16|0);
          $158 = HEAP32[$157>>2]|0;
          $159 = ($158|0)==(0|0);
          if (!($159)) {
           $160 = HEAP32[$158>>2]|0;
           $161 = ($160|0)>(-1);
           if ($161) {
            $162 = ((($$1461$ph520)) + 4|0);
            $$0457514 = $158;$164 = $160;
            while(1) {
             $163 = ($164|0)<($$0456|0);
             if ($163) {
              $165 = HEAP32[$162>>2]|0;
              $166 = (($165) + ($164<<2)|0);
              HEAP32[$166>>2] = $$0422;
             }
             $167 = ((($$0457514)) + 4|0);
             $168 = HEAP32[$167>>2]|0;
             $169 = ($168|0)>(-1);
             if ($169) {
              $$0457514 = $167;$164 = $168;
             } else {
              break;
             }
            }
           }
          }
          $170 = HEAP32[$$1461$ph520>>2]|0;
          $171 = HEAP32[$73>>2]|0;
          $172 = ($170|0)!=($171|0);
          $brmerge604 = $172 | $74;
          if ($brmerge604) {
           $$1433$ph525$mux = $172 ? $$1433$ph524 : 1;
           $$1438$ph523$mux = $172 ? $$1438$ph522 : $$0422;
           $$pre630 = ((($$1461$ph520)) + 4|0);
           $$2434 = $$1433$ph525$mux;$$2439 = $$1438$ph523$mux;$$pre$phi631Z2D = $$pre630;
          } else {
           $173 = ((($$1461$ph520)) + 4|0);
           $174 = HEAP32[$173>>2]|0;
           $$3451517 = 0;
           while(1) {
            $175 = (($174) + ($$3451517<<2)|0);
            $176 = HEAP32[$175>>2]|0;
            $177 = (($2) + ($$3451517<<2)|0);
            HEAP32[$177>>2] = $176;
            $178 = (($$3451517) + 1)|0;
            $exitcond = ($178|0)==($$0456|0);
            if ($exitcond) {
             $$2434 = 1;$$2439 = $$0422;$$pre$phi631Z2D = $173;
             break;
            } else {
             $$3451517 = $178;
            }
           }
          }
          $179 = HEAP32[$152>>2]|0;
          $180 = (($45) + ($179<<3)|0);
          HEAP32[$180>>2] = $$0422;
          $181 = (((($45) + ($179<<3)|0)) + 4|0);
          HEAP32[$181>>2] = $$pre$phi631Z2D;
          $182 = ((($$1461$ph520)) + 8|0);
          $$2462 = $182;$$3435 = $$2434;$$3440 = $$2439;
         }
         $183 = ((($$0427502)) + 32|0);
         $184 = ((($$0427502)) + 40|0);
         $185 = HEAP32[$184>>2]|0;
         $186 = ($185|0)==(0|0);
         if ($186) {
          $$1433$ph$lcssa = $$3435;$$1438$ph$lcssa = $$3440;$$1461$ph$lcssa = $$2462;
          break;
         } else {
          $$0427$ph526 = $183;$$1433$ph524 = $$3435;$$1438$ph522 = $$3440;$$1461$ph520 = $$2462;$397 = $184;
         }
        }
       }
      } while(0);
      HEAP32[$$1461$ph$lcssa>>2] = 0;
      $$old46 = HEAP32[$5>>2]|0;
      $$old47 = ($$old46|0)==(0);
      if ($$old47) {
       $$10447 = $$1438$ph$lcssa;
       break;
      } else {
       $$4436 = $$1433$ph$lcssa;$$4441 = $$1438$ph$lcssa;$237 = $$old46;
      }
     } else {
      if ($69) {
       $$10447 = $$0437;
       break;
      }
      $187 = ($$0460|0)!=($$1471|0);
      $188 = HEAP32[$5>>2]|0;
      $189 = ($188|0)!=(0);
      $or$cond48 = $187 & $189;
      if ($or$cond48) {
       $$4436 = $$0432;$$4441 = $$0437;$237 = $188;
      } else {
       $$10447 = $$0437;
       break;
      }
     }
     $190 = (($$0422) + ($$1424))|0;
     $191 = (_mbtowc($5,$$0421,4)|0);
     $192 = ($191|0)<(1);
     if ($192) {
      $193 = ($191|0)<(0);
      if ($193) {
       $$0426 = 1;
       break L17;
      } else {
       $$2425 = 1;
      }
     } else {
      $$2425 = $191;
     }
     $194 = (($$0421) + ($$2425)|0);
     $195 = HEAP32[$75>>2]|0;
     $196 = ($195|0)!=(0);
     $197 = ($$4436|0)!=(0);
     $or$cond21 = $197 & $196;
     if ($or$cond21) {
      $198 = HEAP32[$$1471>>2]|0;
      $199 = ($198|0)==(0|0);
      if ($199) {
       $$3463$lcssa = $$1474;
      } else {
       $200 = HEAP32[$76>>2]|0;
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)>(-1);
       $$0468534 = $$1471;$$3463536 = $$1474;
       while(1) {
        $203 = ((($$0468534)) + 4|0);
        L102: do {
         if ($202) {
          $$4452530 = 0;$208 = $201;
          while(1) {
           $204 = $$4452530 | 1;
           $205 = (($200) + ($204<<2)|0);
           $206 = HEAP32[$205>>2]|0;
           $207 = ($208|0)<($$0456|0);
           if (!($207)) {
            $$4464 = $$3463536;
            break L102;
           }
           $209 = HEAP32[$203>>2]|0;
           $210 = (($209) + ($206<<2)|0);
           $211 = HEAP32[$210>>2]|0;
           $212 = (($2) + ($206<<2)|0);
           $213 = HEAP32[$212>>2]|0;
           $214 = ($211|0)==($213|0);
           if ($214) {
            $215 = (($209) + ($208<<2)|0);
            $216 = HEAP32[$215>>2]|0;
            $217 = (($2) + ($208<<2)|0);
            $218 = HEAP32[$217>>2]|0;
            $219 = ($216|0)<($218|0);
            if ($219) {
             $$4464 = $$3463536;
             break L102;
            }
           }
           $220 = (($$4452530) + 2)|0;
           $221 = (($200) + ($220<<2)|0);
           $222 = HEAP32[$221>>2]|0;
           $223 = ($222|0)>(-1);
           if ($223) {
            $$4452530 = $220;$208 = $222;
           } else {
            break;
           }
          }
          $224 = $209;
          $$pre$phi629Z2D = $203;$228 = $224;
          label = 77;
         } else {
          $$pre621 = HEAP32[$203>>2]|0;
          $$pre$phi629Z2D = $203;$228 = $$pre621;
          label = 77;
         }
        } while(0);
        if ((label|0) == 77) {
         label = 0;
         $225 = HEAP32[$$0468534>>2]|0;
         HEAP32[$$3463536>>2] = $225;
         $226 = ((($$3463536)) + 4|0);
         $227 = HEAP32[$226>>2]|0;
         HEAP32[$226>>2] = $228;
         HEAP32[$$pre$phi629Z2D>>2] = $227;
         $229 = ((($$3463536)) + 8|0);
         $$4464 = $229;
        }
        $230 = ((($$0468534)) + 8|0);
        $231 = HEAP32[$230>>2]|0;
        $232 = ($231|0)==(0|0);
        if ($232) {
         $$3463$lcssa = $$4464;
         break;
        } else {
         $$0468534 = $230;$$3463536 = $$4464;
        }
       }
      }
      HEAP32[$$3463$lcssa>>2] = 0;
      $$2472 = $$1471;$$2475 = $$1474;$$5 = 0;
     } else {
      $$2472 = $$1474;$$2475 = $$1471;$$5 = $$4436;
     }
     $233 = HEAP32[$$2475>>2]|0;
     $234 = ($233|0)==(0|0);
     if ($234) {
      $$2431$lcssa = $$1430;$$5442$lcssa = $$4441;$$5465$lcssa = $$2472;$$6$lcssa = $$5;
     } else {
      $235 = ($190|0)<(1);
      $236 = ($237|0)==(10);
      $or$cond27 = $71 & $236;
      $238 = ($237|0)==(95);
      $239 = ($190|0)!=(0);
      $240 = ($190|0)==(0);
      $or$cond24$not = $235 & $70;
      $$1469575 = $$2475;$$2431579 = $$1430;$$5442577 = $$4441;$$5465576 = $$2472;$$6578 = $$5;$242 = $233;
      while(1) {
       $241 = ((($242)) + 8|0);
       $243 = HEAP32[$241>>2]|0;
       $244 = ($243|0)==(0|0);
       if ($244) {
        $$3$lcssa = $$2431579;$$6443$lcssa = $$5442577;$$6466$lcssa = $$5465576;$$7$lcssa = $$6578;
       } else {
        $245 = ((($$1469575)) + 4|0);
        $$1428565 = $242;$$3562 = $$2431579;$$6443556 = $$5442577;$$6466555 = $$5465576;$$7559 = $$6578;$360 = $241;
        while(1) {
         $246 = HEAP32[$$1428565>>2]|0;
         $247 = ($246>>>0)>($237>>>0);
         L125: do {
          if ($247) {
           $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
          } else {
           $248 = ((($$1428565)) + 4|0);
           $249 = HEAP32[$248>>2]|0;
           $250 = ($249>>>0)<($237>>>0);
           if ($250) {
            $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
           } else {
            $251 = ((($$1428565)) + 20|0);
            $252 = HEAP32[$251>>2]|0;
            $253 = ($252|0)==(0);
            do {
             if (!($253)) {
              $254 = $252 & 1;
              $255 = ($254|0)==(0);
              $brmerge599 = $255 | $or$cond24$not;
              $brmerge600 = $brmerge599 | $or$cond27;
              if (!($brmerge600)) {
               $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
               break L125;
              }
              $256 = $252 & 2;
              $257 = ($256|0)==(0);
              if (!($257)) {
               $258 = HEAP32[$5>>2]|0;
               $259 = $258 | $7;
               $260 = ($259|0)==(0);
               $261 = ($258|0)==(10);
               $or$cond33 = $71 & $261;
               $or$cond602 = $260 | $or$cond33;
               if (!($or$cond602)) {
                $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                break L125;
               }
              }
              $262 = $252 & 16;
              $263 = ($262|0)==(0);
              do {
               if (!($263)) {
                if ($238) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                }
                $264 = (_iswalnum($237)|0);
                $265 = ($264|0)==(0);
                if (!($265)) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                }
                $266 = HEAP32[$5>>2]|0;
                $267 = ($266|0)==(95);
                if ($267) {
                 break;
                }
                $268 = (_iswalnum($266)|0);
                $269 = ($268|0)==(0);
                if ($269) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                }
               }
              } while(0);
              $270 = HEAP32[$251>>2]|0;
              $271 = $270 & 32;
              $272 = ($271|0)==(0);
              if ($272) {
               $281 = $270;
              } else {
               if ($238) {
                $$old34 = HEAP32[$5>>2]|0;
                $$old35 = ($$old34|0)==(95);
                if ($$old35) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                } else {
                 $277 = $$old34;
                }
               } else {
                $273 = (_iswalnum($237)|0);
                $274 = ($273|0)==(0);
                $275 = HEAP32[$5>>2]|0;
                $276 = ($275|0)==(95);
                $or$cond36 = $274 | $276;
                if ($or$cond36) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                } else {
                 $277 = $275;
                }
               }
               $278 = (_iswalnum($277)|0);
               $279 = ($278|0)==(0);
               if (!($279)) {
                $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                break L125;
               }
               $$pre623 = HEAP32[$251>>2]|0;
               $281 = $$pre623;
              }
              $280 = $281 & 64;
              $282 = ($280|0)!=(0);
              $or$cond39 = $239 & $282;
              $283 = HEAP32[$5>>2]|0;
              $284 = ($283|0)!=(0);
              $or$cond42 = $284 & $or$cond39;
              do {
               if ($or$cond42) {
                if ($238) {
                 $288 = $283;$292 = 1;
                } else {
                 $285 = (_iswalnum($237)|0);
                 $286 = ($285|0)!=(0);
                 $$pr484 = HEAP32[$5>>2]|0;
                 $288 = $$pr484;$292 = $286;
                }
                $287 = ($288|0)==(95);
                if ($287) {
                 if ($292) {
                  $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                  break L125;
                 } else {
                  break;
                 }
                } else {
                 $289 = (_iswalnum($288)|0);
                 $290 = ($289|0)!=(0);
                 $291 = $292 ^ $290;
                 if ($291) {
                  break;
                 } else {
                  $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                  break L125;
                 }
                }
               }
              } while(0);
              $293 = HEAP32[$251>>2]|0;
              $294 = $293 & 128;
              $295 = ($294|0)==(0);
              do {
               if (!($295)) {
                $296 = HEAP32[$5>>2]|0;
                $297 = ($296|0)==(0);
                $or$cond45 = $240 | $297;
                if ($or$cond45) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                }
                if ($238) {
                 $301 = $296;$305 = 1;
                } else {
                 $298 = (_iswalnum($237)|0);
                 $299 = ($298|0)!=(0);
                 $$pr486 = HEAP32[$5>>2]|0;
                 $301 = $$pr486;$305 = $299;
                }
                $300 = ($301|0)==(95);
                if ($300) {
                 if ($305) {
                  break;
                 } else {
                  $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                  break L125;
                 }
                } else {
                 $302 = (_iswalnum($301)|0);
                 $303 = ($302|0)!=(0);
                 $304 = $305 ^ $303;
                 if ($304) {
                  $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                  break L125;
                 } else {
                  break;
                 }
                }
               }
              } while(0);
              $306 = HEAP32[$251>>2]|0;
              $307 = $306 & 4;
              $308 = ($307|0)==(0);
              do {
               if (!($308)) {
                $309 = HEAP32[$8>>2]|0;
                $310 = $309 & 2;
                $311 = ($310|0)==(0);
                if ($311) {
                 $312 = ((($$1428565)) + 24|0);
                 $313 = HEAP32[$312>>2]|0;
                 $314 = (_iswctype($237,$313)|0);
                 $315 = ($314|0)==(0);
                 if ($315) {
                  $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                  break L125;
                 }
                 $$pre625 = HEAP32[$251>>2]|0;
                 $$pre626 = $$pre625 & 4;
                 $316 = ($$pre626|0)==(0);
                 if ($316) {
                  break;
                 }
                }
                $317 = HEAP32[$8>>2]|0;
                $318 = $317 & 2;
                $319 = ($318|0)==(0);
                if ($319) {
                 break;
                }
                $320 = (_towlower($237)|0);
                $321 = ((($$1428565)) + 24|0);
                $322 = HEAP32[$321>>2]|0;
                $323 = (_iswctype($320,$322)|0);
                $324 = ($323|0)==(0);
                if (!($324)) {
                 break;
                }
                $325 = (_towupper($237)|0);
                $326 = HEAP32[$321>>2]|0;
                $327 = (_iswctype($325,$326)|0);
                $328 = ($327|0)==(0);
                if ($328) {
                 $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
                 break L125;
                }
               }
              } while(0);
              $329 = HEAP32[$251>>2]|0;
              $330 = $329 & 8;
              $331 = ($330|0)==(0);
              if ($331) {
               break;
              }
              $332 = ((($$1428565)) + 28|0);
              $333 = HEAP32[$332>>2]|0;
              $334 = HEAP32[$8>>2]|0;
              $335 = $334 & 2;
              $336 = (_tre_neg_char_classes_match($333,$237,$335)|0);
              $337 = ($336|0)==(0);
              if (!($337)) {
               $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
               break L125;
              }
             }
            } while(0);
            if ($72) {
             $338 = HEAP32[$245>>2]|0;
             $$5453542 = 0;
             while(1) {
              $339 = (($338) + ($$5453542<<2)|0);
              $340 = HEAP32[$339>>2]|0;
              $341 = (($$3562) + ($$5453542<<2)|0);
              HEAP32[$341>>2] = $340;
              $342 = (($$5453542) + 1)|0;
              $exitcond616 = ($342|0)==($$0456|0);
              if ($exitcond616) {
               break;
              } else {
               $$5453542 = $342;
              }
             }
            }
            $343 = ((($$1428565)) + 16|0);
            $344 = HEAP32[$343>>2]|0;
            $345 = ($344|0)==(0|0);
            do {
             if (!($345)) {
              $346 = HEAP32[$344>>2]|0;
              $347 = ($346|0)>(-1);
              if (!($347)) {
               break;
              }
              $$1458546 = $344;$349 = $346;
              while(1) {
               $348 = ($349|0)<($$0456|0);
               if ($348) {
                $350 = (($$3562) + ($349<<2)|0);
                HEAP32[$350>>2] = $190;
               }
               $351 = ((($$1458546)) + 4|0);
               $352 = HEAP32[$351>>2]|0;
               $353 = ($352|0)>(-1);
               if ($353) {
                $$1458546 = $351;$349 = $352;
               } else {
                break;
               }
              }
             }
            } while(0);
            $354 = ((($$1428565)) + 12|0);
            $355 = HEAP32[$354>>2]|0;
            $356 = (($45) + ($355<<3)|0);
            $357 = HEAP32[$356>>2]|0;
            $358 = ($357|0)<($190|0);
            if (!($358)) {
             $377 = HEAP32[$77>>2]|0;
             $378 = (((($45) + ($355<<3)|0)) + 4|0);
             $379 = HEAP32[$378>>2]|0;
             $380 = HEAP32[$379>>2]|0;
             $381 = (_tre_tag_order($$0456,$377,$$3562,$380)|0);
             $382 = ($381|0)==(0);
             if ($382) {
              $$10 = $$7559;$$4 = $$3562;$$7467 = $$6466555;$$9446 = $$6443556;
              break;
             }
             HEAP32[$379>>2] = $$3562;
             $383 = HEAP32[$360>>2]|0;
             $384 = HEAP32[$73>>2]|0;
             $385 = ($383|0)==($384|0);
             if (!($385)) {
              $$10 = $$7559;$$4 = $380;$$7467 = $$6466555;$$9446 = $$6443556;
              break;
             }
             if (!($72)) {
              $$10 = 1;$$4 = $380;$$7467 = $$6466555;$$9446 = $190;
              break;
             }
             $$7455549 = 0;
             while(1) {
              $386 = (($$3562) + ($$7455549<<2)|0);
              $387 = HEAP32[$386>>2]|0;
              $388 = (($2) + ($$7455549<<2)|0);
              HEAP32[$388>>2] = $387;
              $389 = (($$7455549) + 1)|0;
              $exitcond618 = ($389|0)==($$0456|0);
              if ($exitcond618) {
               $$10 = 1;$$4 = $380;$$7467 = $$6466555;$$9446 = $190;
               break L125;
              } else {
               $$7455549 = $389;
              }
             }
            }
            $359 = HEAP32[$360>>2]|0;
            HEAP32[$$6466555>>2] = $359;
            $361 = ((($$6466555)) + 4|0);
            $362 = HEAP32[$361>>2]|0;
            HEAP32[$361>>2] = $$3562;
            HEAP32[$356>>2] = $190;
            $363 = (((($45) + ($355<<3)|0)) + 4|0);
            HEAP32[$363>>2] = $361;
            $364 = $359;
            $365 = HEAP32[$73>>2]|0;
            $366 = ($365|0)==($364|0);
            do {
             if ($366) {
              $367 = ($$6443556|0)==(-1);
              if ($367) {
               if (!($72)) {
                $$7444 = $190;$$8 = 1;
                break;
               }
              } else {
               if (!($72)) {
                $$7444 = $$6443556;$$8 = $$7559;
                break;
               }
               $368 = HEAP32[$$3562>>2]|0;
               $369 = HEAP32[$2>>2]|0;
               $370 = ($368|0)>($369|0);
               if ($370) {
                $$7444 = $$6443556;$$8 = $$7559;
                break;
               }
              }
              $$6454552 = 0;
              while(1) {
               $371 = (($$3562) + ($$6454552<<2)|0);
               $372 = HEAP32[$371>>2]|0;
               $373 = (($2) + ($$6454552<<2)|0);
               HEAP32[$373>>2] = $372;
               $374 = (($$6454552) + 1)|0;
               $375 = ($374|0)<($$0456|0);
               if ($375) {
                $$6454552 = $374;
               } else {
                $$7444 = $190;$$8 = 1;
                break;
               }
              }
             } else {
              $$7444 = $$6443556;$$8 = $$7559;
             }
            } while(0);
            $376 = ((($$6466555)) + 8|0);
            $$10 = $$8;$$4 = $362;$$7467 = $376;$$9446 = $$7444;
           }
          }
         } while(0);
         $390 = ((($$1428565)) + 32|0);
         $391 = ((($$1428565)) + 40|0);
         $392 = HEAP32[$391>>2]|0;
         $393 = ($392|0)==(0|0);
         if ($393) {
          $$3$lcssa = $$4;$$6443$lcssa = $$9446;$$6466$lcssa = $$7467;$$7$lcssa = $$10;
          break;
         } else {
          $$1428565 = $390;$$3562 = $$4;$$6443556 = $$9446;$$6466555 = $$7467;$$7559 = $$10;$360 = $391;
         }
        }
       }
       $394 = ((($$1469575)) + 8|0);
       $395 = HEAP32[$394>>2]|0;
       $396 = ($395|0)==(0|0);
       if ($396) {
        $$2431$lcssa = $$3$lcssa;$$5442$lcssa = $$6443$lcssa;$$5465$lcssa = $$6466$lcssa;$$6$lcssa = $$7$lcssa;
        break;
       } else {
        $$1469575 = $394;$$2431579 = $$3$lcssa;$$5442577 = $$6443$lcssa;$$5465576 = $$6466$lcssa;$$6578 = $$7$lcssa;$242 = $395;
       }
      }
     }
     HEAP32[$$5465$lcssa>>2] = 0;
     $$0415 = $237;$$0421 = $194;$$0422 = $190;$$0432 = $$6$lcssa;$$0437 = $$5442$lcssa;$$0460 = $$5465$lcssa;$$1424 = $$2425;$$1430 = $$2431$lcssa;$$1471 = $$2472;$$1474 = $$2475;
    }
    HEAP32[$4>>2] = $$10447;
    $$10447$lobit = $$10447 >>> 31;
    $$0426 = $$10447$lobit;
   }
  } while(0);
  _free($25);
  $$1 = $$0426;
 }
 STACKTOP = sp;return ($$1|0);
}
function _tre_fill_pmatch($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$07984 = 0, $$091 = 0, $$188 = 0, $$2 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $or$cond81 = 0, $or$cond8190 = 0, $or$cond82 = 0, $or$cond99 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = ($5|0)>(-1);
 $7 = $2 & 8;
 $8 = ($7|0)==(0);
 $or$cond = $8 & $6;
 if ($or$cond) {
  $9 = ((($3)) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($3)) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)!=(0);
  $14 = ($0|0)!=(0);
  $or$cond8190 = $14 & $13;
  if ($or$cond8190) {
   $15 = ((($3)) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   $$091 = 0;
   while(1) {
    $17 = (($10) + (($$091*12)|0)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==($16|0);
    if ($19) {
     $23 = $5;
    } else {
     $20 = (($4) + ($18<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $23 = $21;
    }
    $22 = (($1) + ($$091<<3)|0);
    HEAP32[$22>>2] = $23;
    $24 = (((($10) + (($$091*12)|0)|0)) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==($16|0);
    if ($26) {
     $30 = $5;
    } else {
     $27 = (($4) + ($25<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $30 = $28;
    }
    $29 = (((($1) + ($$091<<3)|0)) + 4|0);
    HEAP32[$29>>2] = $30;
    $31 = ($23|0)==(-1);
    $32 = ($30|0)==(-1);
    $or$cond99 = $31 | $32;
    if ($or$cond99) {
     HEAP32[$29>>2] = -1;
     HEAP32[$22>>2] = -1;
    }
    $33 = (($$091) + 1)|0;
    $34 = ($33>>>0)<($12>>>0);
    $35 = ($33>>>0)<($0>>>0);
    $or$cond81 = $35 & $34;
    if ($or$cond81) {
     $$091 = $33;
    } else {
     break;
    }
   }
   if ($or$cond8190) {
    $$188 = 0;
    while(1) {
     $36 = (((($1) + ($$188<<3)|0)) + 4|0);
     $37 = (((($10) + (($$188*12)|0)|0)) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if (!($39)) {
      $40 = HEAP32[$38>>2]|0;
      $41 = ($40|0)>(-1);
      if ($41) {
       $42 = (($1) + ($$188<<3)|0);
       $$pre = HEAP32[$42>>2]|0;
       $$07984 = 0;$44 = $40;$47 = $$pre;
       while(1) {
        $43 = (($1) + ($44<<3)|0);
        $45 = HEAP32[$43>>2]|0;
        $46 = ($47|0)<($45|0);
        if ($46) {
         label = 18;
        } else {
         $48 = HEAP32[$36>>2]|0;
         $49 = (((($1) + ($44<<3)|0)) + 4|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = ($48|0)>($50|0);
         if ($51) {
          label = 18;
         } else {
          $62 = $47;
         }
        }
        if ((label|0) == 18) {
         label = 0;
         HEAP32[$36>>2] = -1;
         HEAP32[$42>>2] = -1;
         $62 = -1;
        }
        $52 = (($$07984) + 1)|0;
        $53 = (($38) + ($52<<2)|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)>(-1);
        if ($55) {
         $$07984 = $52;$44 = $54;$47 = $62;
        } else {
         break;
        }
       }
      }
     }
     $56 = (($$188) + 1)|0;
     $57 = ($56>>>0)<($12>>>0);
     $58 = ($56>>>0)<($0>>>0);
     $or$cond82 = $57 & $58;
     if ($or$cond82) {
      $$188 = $56;
     } else {
      $$2 = $56;
      break;
     }
    }
   } else {
    $$2 = 0;
   }
  } else {
   $$2 = 0;
  }
 } else {
  $$2 = 0;
 }
 $59 = ($$2>>>0)<($0>>>0);
 if ($59) {
  $scevgep = (($1) + ($$2<<3)|0);
  $60 = (($0) - ($$2))|0;
  $61 = $60 << 3;
  _memset(($scevgep|0),-1,($61|0))|0;
 }
 return;
}
function _tre_neg_char_classes_match($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$01011 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = ($2|0)==(0);
   $$01011 = $0;$6 = $3;
   while(1) {
    if ($5) {
     $7 = (_iswctype($1,$6)|0);
     $8 = ($7|0)==(0);
     if (!($8)) {
      $$0 = 1;
      break L1;
     }
    } else {
     $9 = (_towupper($1)|0);
     $10 = HEAP32[$$01011>>2]|0;
     $11 = (_iswctype($9,$10)|0);
     $12 = ($11|0)==(0);
     if (!($12)) {
      $$0 = 1;
      break L1;
     }
     $13 = (_towlower($1)|0);
     $14 = HEAP32[$$01011>>2]|0;
     $15 = (_iswctype($13,$14)|0);
     $16 = ($15|0)==(0);
     if (!($16)) {
      $$0 = 1;
      break L1;
     }
    }
    $17 = ((($$01011)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0);
    if ($19) {
     $$0 = 0;
     break;
    } else {
     $$01011 = $17;$6 = $18;
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _tre_tag_order($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$018 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($0|0)>(0);
 L1: do {
  if ($4) {
   $$019 = 0;
   while(1) {
    $5 = (($1) + ($$019<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(0);
    $8 = (($2) + ($$019<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($3) + ($$019<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    if ($7) {
     $12 = ($9|0)<($11|0);
     if ($12) {
      $$018 = 1;
      break L1;
     }
     $13 = ($9|0)>($11|0);
     if ($13) {
      $$018 = 0;
      break L1;
     }
    } else {
     $14 = ($9|0)>($11|0);
     if ($14) {
      $$018 = 1;
      break L1;
     }
     $15 = ($9|0)<($11|0);
     if ($15) {
      $$018 = 0;
      break L1;
     }
    }
    $16 = (($$019) + 1)|0;
    $17 = ($16|0)<($0|0);
    if ($17) {
     $$019 = $16;
    } else {
     $$018 = 0;
     break;
    }
   }
  } else {
   $$018 = 0;
  }
 } while(0);
 return ($$018|0);
}
function _strtok_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
  } else {
   $$015 = $4;
   label = 3;
  }
 } else {
  $$015 = $0;
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $6 = (_strspn($$015,$1)|0);
   $7 = (($$015) + ($6)|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    HEAP32[$2>>2] = 0;
    $$0 = 0;
    break;
   }
   $10 = (_strcspn($7,$1)|0);
   $11 = (($7) + ($10)|0);
   HEAP32[$2>>2] = $11;
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    HEAP32[$2>>2] = 0;
    $$0 = $7;
    break;
   } else {
    $14 = ((($11)) + 1|0);
    HEAP32[$2>>2] = $14;
    HEAP8[$11>>0] = 0;
    $$0 = $7;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _bzero($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_memset(($0|0),0,($1|0))|0);
 return;
}
function _wcsdup($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_wcslen($0)|0);
 $2 = (($1) + 1)|0;
 $3 = $2 << 2;
 $4 = (_malloc($3)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
 } else {
  $6 = (_wmemcpy($4,$0,$2)|0);
  $$0 = $4;
 }
 return ($$0|0);
}
function _strcasestr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$078 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($1)|0);
 $3 = HEAP8[$0>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $$078 = $0;
   while(1) {
    $5 = (_strncasecmp($$078,$1,$2)|0);
    $6 = ($5|0)==(0);
    if ($6) {
     $$0 = $$078;
     break L1;
    }
    $7 = ((($$078)) + 1|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $$0 = 0;
     break;
    } else {
     $$078 = $7;
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _wcsncat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$01013 = 0, $$01112 = 0, $$014 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcslen($0)|0);
 $4 = (($0) + ($3<<2)|0);
 $5 = ($2|0)==(0);
 L1: do {
  if ($5) {
   $$0$lcssa = $4;
  } else {
   $$01013 = $2;$$01112 = $1;$$014 = $4;
   while(1) {
    $6 = HEAP32[$$01112>>2]|0;
    $7 = ($6|0)==(0);
    if ($7) {
     $$0$lcssa = $$014;
     break L1;
    }
    $8 = (($$01013) + -1)|0;
    $9 = ((($$01112)) + 4|0);
    $10 = ((($$014)) + 4|0);
    HEAP32[$$014>>2] = $6;
    $11 = ($8|0)==(0);
    if ($11) {
     $$0$lcssa = $10;
     break;
    } else {
     $$01013 = $8;$$01112 = $9;$$014 = $10;
    }
   }
  }
 } while(0);
 HEAP32[$$0$lcssa>>2] = 0;
 return ($0|0);
}
function _wcspbrk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcscspn($0,$1)|0);
 $3 = (($0) + ($2<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 $6 = $5 ? 0 : $3;
 return ($6|0);
}
function _wcscspn($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$015$lcssa = 0, $$01516 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (_wcslen($0)|0);
   $$0 = $4;
  } else {
   $5 = ((($1)) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0);
   if ($7) {
    $8 = (_wcschr($0,$2)|0);
    $9 = ($8|0)==(0|0);
    if ($9) {
     $14 = (_wcslen($0)|0);
     $$0 = $14;
     break;
    } else {
     $10 = $8;
     $11 = $0;
     $12 = (($10) - ($11))|0;
     $13 = $12 >> 2;
     $$0 = $13;
     break;
    }
   }
   $15 = HEAP32[$0>>2]|0;
   $16 = ($15|0)==(0);
   L10: do {
    if ($16) {
     $$015$lcssa = $0;
    } else {
     $$01516 = $0;$17 = $15;
     while(1) {
      $18 = (_wcschr($1,$17)|0);
      $19 = ($18|0)==(0|0);
      if (!($19)) {
       $$015$lcssa = $$01516;
       break L10;
      }
      $20 = ((($$01516)) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(0);
      if ($22) {
       $$015$lcssa = $20;
       break;
      } else {
       $$01516 = $20;$17 = $21;
      }
     }
    }
   } while(0);
   $23 = $$015$lcssa;
   $24 = $0;
   $25 = (($23) - ($24))|0;
   $26 = $25 >> 2;
   $$0 = $26;
  }
 } while(0);
 return ($$0|0);
}
function _wcsncasecmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$016$lcssa = 0, $$01621 = 0, $$01720 = 0, $$018 = 0, $$022 = 0, $$022$in = 0, $$pre$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if ($3) {
  $$018 = 0;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)==(0);
  L3: do {
   if ($5) {
    $$016$lcssa = $1;$19 = 0;
   } else {
    $$01621 = $1;$$01720 = $0;$$022$in = $2;$10 = $4;
    while(1) {
     $$022 = (($$022$in) + -1)|0;
     $6 = HEAP32[$$01621>>2]|0;
     $7 = ($6|0)!=(0);
     $8 = ($$022|0)!=(0);
     $or$cond = $8 & $7;
     if (!($or$cond)) {
      $$016$lcssa = $$01621;$19 = $10;
      break L3;
     }
     $9 = ($10|0)==($6|0);
     if (!($9)) {
      $11 = (_towlower($10)|0);
      $12 = HEAP32[$$01621>>2]|0;
      $13 = (_towlower($12)|0);
      $14 = ($11|0)==($13|0);
      if (!($14)) {
       break;
      }
     }
     $15 = ((($$01720)) + 4|0);
     $16 = ((($$01621)) + 4|0);
     $17 = HEAP32[$15>>2]|0;
     $18 = ($17|0)==(0);
     if ($18) {
      $$016$lcssa = $16;$19 = 0;
      break L3;
     } else {
      $$01621 = $16;$$01720 = $15;$$022$in = $$022;$10 = $17;
     }
    }
    $$pre$pre = HEAP32[$$01720>>2]|0;
    $$016$lcssa = $$01621;$19 = $$pre$pre;
   }
  } while(0);
  $20 = (_towlower($19)|0);
  $21 = HEAP32[$$016$lcssa>>2]|0;
  $22 = (_towlower($21)|0);
  $23 = (($20) - ($22))|0;
  $$018 = $23;
 }
 return ($$018|0);
}
function _memccpy($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$lcssa = 0, $$051 = 0, $$052$lcssa = 0, $$05270 = 0, $$053$lcssa = 0, $$05383 = 0, $$054$lcssa = 0, $$05482 = 0, $$058$lcssa = 0, $$05881 = 0, $$071 = 0, $$1 = 0, $$155 = 0, $$159$lcssa = 0, $$15969 = 0, $$25663 = 0, $$260 = 0, $$264 = 0, $$3 = 0, $$357 = 0;
 var $$36162 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond80 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $2 & 255;
 $5 = $1;
 $6 = $0;
 $7 = $5 ^ $6;
 $8 = $7 & 3;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $10 = $5 & 3;
   $11 = ($10|0)!=(0);
   $12 = ($3|0)!=(0);
   $or$cond80 = $12 & $11;
   if ($or$cond80) {
    $13 = $2&255;
    $$05383 = $1;$$05482 = $0;$$05881 = $3;
    while(1) {
     $14 = HEAP8[$$05383>>0]|0;
     HEAP8[$$05482>>0] = $14;
     $15 = ($14<<24>>24)==($13<<24>>24);
     if ($15) {
      $$3 = $$05383;$$357 = $$05482;
      break L1;
     }
     $16 = (($$05881) + -1)|0;
     $17 = ((($$05383)) + 1|0);
     $18 = ((($$05482)) + 1|0);
     $19 = $17;
     $20 = $19 & 3;
     $21 = ($20|0)!=(0);
     $22 = ($16|0)!=(0);
     $or$cond = $22 & $21;
     if ($or$cond) {
      $$05383 = $17;$$05482 = $18;$$05881 = $16;
     } else {
      $$053$lcssa = $17;$$054$lcssa = $18;$$058$lcssa = $16;$$lcssa = $21;
      break;
     }
    }
   } else {
    $$053$lcssa = $1;$$054$lcssa = $0;$$058$lcssa = $3;$$lcssa = $11;
   }
   if ($$lcssa) {
    $$3 = $$053$lcssa;$$357 = $$054$lcssa;
   } else {
    $23 = Math_imul($4, 16843009)|0;
    $24 = ($$058$lcssa>>>0)>(3);
    L10: do {
     if ($24) {
      $$05270 = $$054$lcssa;$$071 = $$053$lcssa;$$15969 = $$058$lcssa;
      while(1) {
       $25 = HEAP32[$$071>>2]|0;
       $26 = $25 ^ $23;
       $27 = (($26) + -16843009)|0;
       $28 = $26 & -2139062144;
       $29 = $28 ^ -2139062144;
       $30 = $29 & $27;
       $31 = ($30|0)==(0);
       if (!($31)) {
        $$0$lcssa = $$071;$$052$lcssa = $$05270;$$159$lcssa = $$15969;
        break L10;
       }
       HEAP32[$$05270>>2] = $25;
       $32 = (($$15969) + -4)|0;
       $33 = ((($$071)) + 4|0);
       $34 = ((($$05270)) + 4|0);
       $35 = ($32>>>0)>(3);
       if ($35) {
        $$05270 = $34;$$071 = $33;$$15969 = $32;
       } else {
        $$0$lcssa = $33;$$052$lcssa = $34;$$159$lcssa = $32;
        break;
       }
      }
     } else {
      $$0$lcssa = $$053$lcssa;$$052$lcssa = $$054$lcssa;$$159$lcssa = $$058$lcssa;
     }
    } while(0);
    $$1 = $$0$lcssa;$$155 = $$052$lcssa;$$260 = $$159$lcssa;
    label = 12;
   }
  } else {
   $$1 = $1;$$155 = $0;$$260 = $3;
   label = 12;
  }
 } while(0);
 L16: do {
  if ((label|0) == 12) {
   $36 = ($$260|0)==(0);
   if ($36) {
    $$3 = $$1;$$357 = $$155;
   } else {
    $37 = $2&255;
    $$25663 = $$155;$$264 = $$1;$$36162 = $$260;
    while(1) {
     $38 = HEAP8[$$264>>0]|0;
     HEAP8[$$25663>>0] = $38;
     $39 = ($38<<24>>24)==($37<<24>>24);
     if ($39) {
      $$3 = $$264;$$357 = $$25663;
      break L16;
     }
     $40 = (($$36162) + -1)|0;
     $41 = ((($$264)) + 1|0);
     $42 = ((($$25663)) + 1|0);
     $43 = ($40|0)==(0);
     if ($43) {
      $$3 = $41;$$357 = $42;
      break;
     } else {
      $$25663 = $42;$$264 = $41;$$36162 = $40;
     }
    }
   }
  }
 } while(0);
 $44 = HEAP8[$$3>>0]|0;
 $45 = $2&255;
 $46 = ($44<<24>>24)==($45<<24>>24);
 $47 = ((($$357)) + 1|0);
 $$051 = $46 ? $47 : 0;
 return ($$051|0);
}
function _wcscasecmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcsncasecmp($0,$1,-1)|0);
 return ($2|0);
}
function _index($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strchr($0,$1)|0);
 return ($2|0);
}
function _wcsnlen($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wmemchr($0,0,$1)|0);
 $3 = ($2|0)==(0|0);
 $4 = $2;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $$0 = $3 ? $1 : $7;
 return ($$0|0);
}
function _strncat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$01013 = 0, $$01112 = 0, $$014 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strlen($0)|0);
 $4 = (($0) + ($3)|0);
 $5 = ($2|0)==(0);
 L1: do {
  if ($5) {
   $$0$lcssa = $4;
  } else {
   $$01013 = $2;$$01112 = $1;$$014 = $4;
   while(1) {
    $6 = HEAP8[$$01112>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     $$0$lcssa = $$014;
     break L1;
    }
    $8 = (($$01013) + -1)|0;
    $9 = ((($$01112)) + 1|0);
    $10 = ((($$014)) + 1|0);
    HEAP8[$$014>>0] = $6;
    $11 = ($8|0)==(0);
    if ($11) {
     $$0$lcssa = $10;
     break;
    } else {
     $$01013 = $8;$$01112 = $9;$$014 = $10;
    }
   }
  }
 } while(0);
 HEAP8[$$0$lcssa>>0] = 0;
 return ($0|0);
}
function _wcswcs($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcsstr($0,$1)|0);
 return ($2|0);
}
function _wcsstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = $0;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $$0 = 0;
  } else {
   $6 = (_wcschr($0,$2)|0);
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0 = 0;
   } else {
    $8 = ((($1)) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     $$0 = $6;
    } else {
     $11 = ((($6)) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0);
     if ($13) {
      $$0 = 0;
     } else {
      $14 = (_twoway_wcsstr($6,$1)|0);
      $$0 = $14;
     }
    }
   }
  }
 }
 return ($$0|0);
}
function _twoway_wcsstr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0145 = 0, $$0145$be = 0, $$0147 = 0, $$0148 = 0, $$0148$be = 0, $$0149 = 0, $$0154$lcssa214 = 0, $$0154196 = 0, $$0158195 = 0, $$0164194 = 0, $$0168$lcssa213 = 0, $$0168193 = 0, $$0172$lcssa211212 = 0, $$0172202 = 0, $$1155 = 0, $$1159 = 0, $$1165 = 0, $$1169 = 0, $$2156$$0154 = 0, $$2156$lcssa = 0;
 var $$2156187 = 0, $$2160186 = 0, $$2166185 = 0, $$2170$$0168 = 0, $$2170$$0168$ = 0, $$2170$lcssa = 0, $$2170184 = 0, $$3 = 0, $$3152 = 0, $$3157 = 0, $$3161 = 0, $$3167 = 0, $$3171 = 0, $$4162178 = 0, $$5 = 0, $$5163179 = 0, $$pn = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$0154$lcssa214 = 1;$$0168$lcssa213 = -1;$$0172$lcssa211212 = 0;$$2156$lcssa = 1;$$2170$lcssa = -1;
   label = 25;
  } else {
   $$0172202 = 0;
   while(1) {
    $4 = (($0) + ($$0172202<<2)|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==(0);
    if ($6) {
     $$3 = 0;
     break L1;
    }
    $7 = (($$0172202) + 1)|0;
    $8 = (($1) + ($7<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     break;
    } else {
     $$0172202 = $7;
    }
   }
   $11 = ($7>>>0)>(1);
   if ($11) {
    $$0154196 = 1;$$0158195 = 1;$$0164194 = 0;$$0168193 = -1;$16 = 1;
    while(1) {
     $12 = (($$0158195) + ($$0168193))|0;
     $13 = (($1) + ($12<<2)|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($1) + ($16<<2)|0);
     $17 = HEAP32[$15>>2]|0;
     $18 = ($14|0)==($17|0);
     do {
      if ($18) {
       $19 = ($$0158195|0)==($$0154196|0);
       if ($19) {
        $20 = (($$0154196) + ($$0164194))|0;
        $$1155 = $$0154196;$$1159 = 1;$$1165 = $20;$$1169 = $$0168193;
        break;
       } else {
        $21 = (($$0158195) + 1)|0;
        $$1155 = $$0154196;$$1159 = $21;$$1165 = $$0164194;$$1169 = $$0168193;
        break;
       }
      } else {
       $22 = ($14|0)>($17|0);
       if ($22) {
        $23 = (($16) - ($$0168193))|0;
        $$1155 = $23;$$1159 = 1;$$1165 = $16;$$1169 = $$0168193;
        break;
       } else {
        $24 = (($$0164194) + 1)|0;
        $$1155 = 1;$$1159 = 1;$$1165 = $24;$$1169 = $$0164194;
        break;
       }
      }
     } while(0);
     $25 = (($$1159) + ($$1165))|0;
     $26 = ($25>>>0)<($7>>>0);
     if ($26) {
      $$0154196 = $$1155;$$0158195 = $$1159;$$0164194 = $$1165;$$0168193 = $$1169;$16 = $25;
     } else {
      break;
     }
    }
    if ($11) {
     $$2156187 = 1;$$2160186 = 1;$$2166185 = 0;$$2170184 = -1;$31 = 1;
     while(1) {
      $27 = (($$2160186) + ($$2170184))|0;
      $28 = (($1) + ($27<<2)|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($1) + ($31<<2)|0);
      $32 = HEAP32[$30>>2]|0;
      $33 = ($29|0)==($32|0);
      do {
       if ($33) {
        $34 = ($$2160186|0)==($$2156187|0);
        if ($34) {
         $35 = (($$2156187) + ($$2166185))|0;
         $$3157 = $$2156187;$$3161 = 1;$$3167 = $35;$$3171 = $$2170184;
         break;
        } else {
         $36 = (($$2160186) + 1)|0;
         $$3157 = $$2156187;$$3161 = $36;$$3167 = $$2166185;$$3171 = $$2170184;
         break;
        }
       } else {
        $37 = ($29|0)<($32|0);
        if ($37) {
         $38 = (($31) - ($$2170184))|0;
         $$3157 = $38;$$3161 = 1;$$3167 = $31;$$3171 = $$2170184;
         break;
        } else {
         $39 = (($$2166185) + 1)|0;
         $$3157 = 1;$$3161 = 1;$$3167 = $39;$$3171 = $$2166185;
         break;
        }
       }
      } while(0);
      $40 = (($$3161) + ($$3167))|0;
      $41 = ($40>>>0)<($7>>>0);
      if ($41) {
       $$2156187 = $$3157;$$2160186 = $$3161;$$2166185 = $$3167;$$2170184 = $$3171;$31 = $40;
      } else {
       $$0154$lcssa214 = $$1155;$$0168$lcssa213 = $$1169;$$0172$lcssa211212 = $7;$$2156$lcssa = $$3157;$$2170$lcssa = $$3171;
       label = 25;
       break;
      }
     }
    } else {
     $$0154$lcssa214 = $$1155;$$0168$lcssa213 = $$1169;$$0172$lcssa211212 = $7;$$2156$lcssa = 1;$$2170$lcssa = -1;
     label = 25;
    }
   } else {
    $$0154$lcssa214 = 1;$$0168$lcssa213 = -1;$$0172$lcssa211212 = $7;$$2156$lcssa = 1;$$2170$lcssa = -1;
    label = 25;
   }
  }
 } while(0);
 L34: do {
  if ((label|0) == 25) {
   $42 = (($$2170$lcssa) + 1)|0;
   $43 = (($$0168$lcssa213) + 1)|0;
   $44 = ($42>>>0)>($43>>>0);
   $$2156$$0154 = $44 ? $$2156$lcssa : $$0154$lcssa214;
   $$2170$$0168 = $44 ? $$2170$lcssa : $$0168$lcssa213;
   $45 = (($1) + ($$2156$$0154<<2)|0);
   $46 = (($$2170$$0168) + 1)|0;
   $47 = (_wmemcmp($1,$45,$46)|0);
   $48 = ($47|0)==(0);
   if ($48) {
    $53 = (($$0172$lcssa211212) - ($$2156$$0154))|0;
    $$0147 = $53;$$5 = $$2156$$0154;
   } else {
    $49 = (($$0172$lcssa211212) - ($$2170$$0168))|0;
    $50 = (($49) + -1)|0;
    $51 = ($$2170$$0168>>>0)>($50>>>0);
    $$2170$$0168$ = $51 ? $$2170$$0168 : $50;
    $52 = (($$2170$$0168$) + 1)|0;
    $$0147 = 0;$$5 = $52;
   }
   $54 = $$0172$lcssa211212 | 63;
   $$0145 = $0;$$0148 = 0;$$0149 = $0;
   while(1) {
    $55 = $$0149;
    $56 = $$0145;
    $57 = (($55) - ($56))|0;
    $58 = $57 >> 2;
    $59 = ($58>>>0)<($$0172$lcssa211212>>>0);
    do {
     if ($59) {
      $60 = (_wmemchr($$0149,0,$54)|0);
      $61 = ($60|0)==(0|0);
      if ($61) {
       $66 = (($$0149) + ($54<<2)|0);
       $$3152 = $66;
       break;
      } else {
       $62 = $60;
       $63 = (($62) - ($56))|0;
       $64 = $63 >> 2;
       $65 = ($64>>>0)<($$0172$lcssa211212>>>0);
       if ($65) {
        $$3 = 0;
        break L34;
       } else {
        $$3152 = $60;
        break;
       }
      }
     } else {
      $$3152 = $$0149;
     }
    } while(0);
    $67 = ($46>>>0)>($$0148>>>0);
    $68 = $67 ? $46 : $$0148;
    $69 = (($1) + ($68<<2)|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0);
    L48: do {
     if ($71) {
      label = 39;
     } else {
      $$4162178 = $68;$75 = $70;
      while(1) {
       $72 = (($$0145) + ($$4162178<<2)|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($75|0)==($73|0);
       if (!($74)) {
        break;
       }
       $76 = (($$4162178) + 1)|0;
       $77 = (($1) + ($76<<2)|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==(0);
       if ($79) {
        label = 39;
        break L48;
       } else {
        $$4162178 = $76;$75 = $78;
       }
      }
      $80 = (($$4162178) - ($$2170$$0168))|0;
      $$0148$be = 0;$$pn = $80;
     }
    } while(0);
    L54: do {
     if ((label|0) == 39) {
      label = 0;
      if (!($67)) {
       $$3 = $$0145;
       break L34;
      }
      $$5163179 = $46;
      while(1) {
       $82 = (($$5163179) + -1)|0;
       $83 = (($1) + ($82<<2)|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($$0145) + ($82<<2)|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = ($84|0)==($86|0);
       if (!($87)) {
        $$0148$be = $$0147;$$pn = $$5;
        break L54;
       }
       $81 = ($82>>>0)>($$0148>>>0);
       if ($81) {
        $$5163179 = $82;
       } else {
        $$3 = $$0145;
        break L34;
       }
      }
     }
    } while(0);
    $$0145$be = (($$0145) + ($$pn<<2)|0);
    $$0145 = $$0145$be;$$0148 = $$0148$be;$$0149 = $$3152;
   }
  }
 } while(0);
 return ($$3|0);
}
function _wmemcmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$014 = 0, $$0813 = 0, $$0912 = 0, $10 = 0, $11 = 0, $12 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $12 = 0;
  } else {
   $$014 = $2;$$0813 = $1;$$0912 = $0;
   while(1) {
    $4 = HEAP32[$$0912>>2]|0;
    $5 = HEAP32[$$0813>>2]|0;
    $6 = ($4|0)==($5|0);
    if (!($6)) {
     break;
    }
    $7 = (($$014) + -1)|0;
    $8 = ((($$0912)) + 4|0);
    $9 = ((($$0813)) + 4|0);
    $10 = ($7|0)==(0);
    if ($10) {
     $12 = 0;
     break L1;
    } else {
     $$014 = $7;$$0813 = $9;$$0912 = $8;
    }
   }
   $11 = (($4) - ($5))|0;
   $12 = $11;
  }
 } while(0);
 return ($12|0);
}
function ___strcasecmp_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strcasecmp($0,$1)|0);
 return ($3|0);
}
function ___strncasecmp_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strncasecmp($0,$1,$2)|0);
 return ($4|0);
}
function _wcscat($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcslen($0)|0);
 $3 = (($0) + ($2<<2)|0);
 (_wcscpy($3,$1)|0);
 return ($0|0);
}
function _wcscpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$056 = 0, $$07 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$056 = $1;$$07 = $0;
  while(1) {
   $4 = ((($$07)) + 4|0);
   $5 = ((($$056)) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $6;
   $7 = ($6|0)==(0);
   if ($7) {
    break;
   } else {
    $$056 = $5;$$07 = $4;
   }
  }
 }
 return ($0|0);
}
function _wcscasecmp_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcscasecmp($0,$1)|0);
 return ($3|0);
}
function _bcopy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_memmove(($1|0),($0|0),($2|0))|0);
 return;
}
function _strpbrk($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strcspn($0,$1)|0);
 $3 = (($0) + ($2)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = $5 ? 0 : $3;
 return ($6|0);
}
function _wcstok($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$015 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
  } else {
   $$015 = $4;
   label = 3;
  }
 } else {
  $$015 = $0;
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $6 = (_wcsspn($$015,$1)|0);
   $7 = (($$015) + ($6<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    HEAP32[$2>>2] = 0;
    $$0 = 0;
    break;
   }
   $10 = (_wcscspn($7,$1)|0);
   $11 = (($7) + ($10<<2)|0);
   HEAP32[$2>>2] = $11;
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    HEAP32[$2>>2] = 0;
    $$0 = $7;
    break;
   } else {
    $14 = ((($11)) + 4|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$11>>2] = 0;
    $$0 = $7;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _memmem($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = $0;
  } else {
   $5 = ($1>>>0)<($3>>>0);
   if ($5) {
    $$0 = 0;
   } else {
    $6 = HEAP8[$2>>0]|0;
    $7 = $6&255;
    $8 = (_memchr($0,$7,$1)|0);
    $9 = ($8|0)==(0|0);
    $10 = ($3|0)==(1);
    $or$cond = $10 | $9;
    if ($or$cond) {
     $$0 = $8;
    } else {
     $11 = $8;
     $12 = $0;
     $13 = (($12) - ($11))|0;
     $14 = (($13) + ($1))|0;
     $15 = ($14>>>0)<($3>>>0);
     if ($15) {
      $$0 = 0;
     } else {
      switch ($3|0) {
      case 2:  {
       $16 = (_twobyte_memmem($8,$14,$2)|0);
       $$0 = $16;
       break L1;
       break;
      }
      case 3:  {
       $17 = (_threebyte_memmem($8,$14,$2)|0);
       $$0 = $17;
       break L1;
       break;
      }
      case 4:  {
       $18 = (_fourbyte_memmem($8,$14,$2)|0);
       $$0 = $18;
       break L1;
       break;
      }
      default: {
       $19 = (($8) + ($14)|0);
       $20 = (_twoway_memmem($8,$19,$2,$3)|0);
       $$0 = $20;
       break L1;
      }
      }
     }
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function _twobyte_memmem($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$in22 = 0, $$016 = 0, $$01721 = 0, $$018 = 0, $$01820 = 0, $$01823 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 8;
 $6 = ((($2)) + 1|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $5 | $8;
 $10 = ((($0)) + 1|0);
 $$01820 = (($1) + -1)|0;
 $11 = ($$01820|0)==(0);
 L1: do {
  if ($11) {
   $$016 = 0;
  } else {
   $12 = HEAP8[$0>>0]|0;
   $13 = $12&255;
   $14 = $13 << 8;
   $15 = HEAP8[$10>>0]|0;
   $16 = $15&255;
   $17 = $14 | $16;
   $$0$in22 = $17;$$01721 = $10;$$01823 = $$01820;
   while(1) {
    $18 = $$0$in22 & 65535;
    $19 = ($18|0)==($9|0);
    if ($19) {
     break;
    }
    $21 = $18 << 8;
    $22 = ((($$01721)) + 1|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = $21 | $24;
    $$018 = (($$01823) + -1)|0;
    $26 = ($$018|0)==(0);
    if ($26) {
     $$016 = 0;
     break L1;
    } else {
     $$0$in22 = $25;$$01721 = $22;$$01823 = $$018;
    }
   }
   $20 = ((($$01721)) + -1|0);
   $$016 = $20;
  }
 } while(0);
 return ($$016|0);
}
function _threebyte_memmem($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$018 = 0, $$01923 = 0, $$02022 = 0, $$024 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = ((($2)) + 1|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = ((($2)) + 2|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = ((($0)) + 2|0);
 $17 = (($1) + -2)|0;
 $18 = ($17|0)==(0);
 L1: do {
  if ($18) {
   $$018 = 0;
  } else {
   $19 = ((($0)) + 1|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = $21 << 16;
   $23 = HEAP8[$0>>0]|0;
   $24 = $23&255;
   $25 = $24 << 24;
   $26 = $22 | $25;
   $27 = HEAP8[$16>>0]|0;
   $28 = $27&255;
   $29 = $28 << 8;
   $30 = $26 | $29;
   $$01923 = $16;$$02022 = $17;$$024 = $30;
   while(1) {
    $31 = ($$024|0)==($15|0);
    if ($31) {
     break;
    }
    $33 = (($$02022) + -1)|0;
    $34 = ((($$01923)) + 1|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = $$024 | $36;
    $38 = $37 << 8;
    $39 = ($33|0)==(0);
    if ($39) {
     $$018 = 0;
     break L1;
    } else {
     $$01923 = $34;$$02022 = $33;$$024 = $38;
    }
   }
   $32 = ((($$01923)) + -2|0);
   $$018 = $32;
  }
 } while(0);
 return ($$018|0);
}
function _fourbyte_memmem($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$020 = 0, $$02125 = 0, $$02224 = 0, $$026 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = ((($2)) + 1|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = ((($2)) + 2|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = ((($2)) + 3|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ((($0)) + 3|0);
 $21 = (($1) + -3)|0;
 $22 = ($21|0)==(0);
 L1: do {
  if ($22) {
   $$020 = 0;
  } else {
   $23 = ((($0)) + 1|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = $25 << 16;
   $27 = HEAP8[$0>>0]|0;
   $28 = $27&255;
   $29 = $28 << 24;
   $30 = $26 | $29;
   $31 = ((($0)) + 2|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = $33 << 8;
   $35 = $30 | $34;
   $36 = HEAP8[$20>>0]|0;
   $37 = $36&255;
   $38 = $35 | $37;
   $$02125 = $20;$$02224 = $21;$$026 = $38;
   while(1) {
    $39 = ($$026|0)==($19|0);
    if ($39) {
     break;
    }
    $41 = (($$02224) + -1)|0;
    $42 = $$026 << 8;
    $43 = ((($$02125)) + 1|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = $42 | $45;
    $47 = ($41|0)==(0);
    if ($47) {
     $$020 = 0;
     break L1;
    } else {
     $$02125 = $43;$$02224 = $41;$$026 = $46;
    }
   }
   $40 = ((($$02125)) + -3|0);
   $$020 = $40;
  }
 } while(0);
 return ($$020|0);
}
function _twoway_memmem($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$0146$be = 0, $$0146176 = 0, $$0147 = 0, $$0149$lcssa202 = 0, $$0149188 = 0, $$0150187 = 0, $$0156186 = 0, $$0160$lcssa201 = 0, $$0160185 = 0, $$0164194 = 0, $$0165175 = 0, $$1 = 0, $$1151 = 0, $$1157 = 0, $$1161 = 0, $$2$$0149 = 0, $$2$lcssa = 0, $$2152180 = 0, $$2158179 = 0;
 var $$2162$$0160 = 0, $$2162$$0160$ = 0, $$2162$lcssa = 0, $$2162178 = 0, $$2181 = 0, $$3 = 0, $$3153 = 0, $$3159 = 0, $$3163 = 0, $$4154 = 0, $$4154$sink = 0, $$5 = 0, $$5155171 = 0, $$6172 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $or$cond = 0, $or$cond166 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1056|0);
 $4 = sp + 1024|0;
 $5 = sp;
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 $6 = ($3|0)==(0);
 if ($6) {
  $$0149$lcssa202 = 1;$$0160$lcssa201 = -1;$$2$lcssa = 1;$$2162$lcssa = -1;
 } else {
  $$0164194 = 0;
  while(1) {
   $7 = (($2) + ($$0164194)|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = $8&255;
   $10 = $9 & 31;
   $11 = 1 << $10;
   $12 = $9 >>> 5;
   $13 = (($4) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $11 | $14;
   HEAP32[$13>>2] = $15;
   $16 = (($$0164194) + 1)|0;
   $17 = (($5) + ($9<<2)|0);
   HEAP32[$17>>2] = $16;
   $exitcond = ($16|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $$0164194 = $16;
   }
  }
  $18 = ($3>>>0)>(1);
  if ($18) {
   $$0149188 = 1;$$0150187 = 1;$$0156186 = 0;$$0160185 = -1;$23 = 1;
   while(1) {
    $19 = (($$0150187) + ($$0160185))|0;
    $20 = (($2) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = (($2) + ($23)|0);
    $24 = HEAP8[$22>>0]|0;
    $25 = ($21<<24>>24)==($24<<24>>24);
    do {
     if ($25) {
      $26 = ($$0150187|0)==($$0149188|0);
      if ($26) {
       $27 = (($$0149188) + ($$0156186))|0;
       $$1 = $$0149188;$$1151 = 1;$$1157 = $27;$$1161 = $$0160185;
       break;
      } else {
       $28 = (($$0150187) + 1)|0;
       $$1 = $$0149188;$$1151 = $28;$$1157 = $$0156186;$$1161 = $$0160185;
       break;
      }
     } else {
      $29 = ($21&255)>($24&255);
      if ($29) {
       $30 = (($23) - ($$0160185))|0;
       $$1 = $30;$$1151 = 1;$$1157 = $23;$$1161 = $$0160185;
       break;
      } else {
       $31 = (($$0156186) + 1)|0;
       $$1 = 1;$$1151 = 1;$$1157 = $31;$$1161 = $$0156186;
       break;
      }
     }
    } while(0);
    $32 = (($$1151) + ($$1157))|0;
    $33 = ($32>>>0)<($3>>>0);
    if ($33) {
     $$0149188 = $$1;$$0150187 = $$1151;$$0156186 = $$1157;$$0160185 = $$1161;$23 = $32;
    } else {
     break;
    }
   }
   if ($18) {
    $$2152180 = 1;$$2158179 = 0;$$2162178 = -1;$$2181 = 1;$38 = 1;
    while(1) {
     $34 = (($$2152180) + ($$2162178))|0;
     $35 = (($2) + ($34)|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = (($2) + ($38)|0);
     $39 = HEAP8[$37>>0]|0;
     $40 = ($36<<24>>24)==($39<<24>>24);
     do {
      if ($40) {
       $41 = ($$2152180|0)==($$2181|0);
       if ($41) {
        $42 = (($$2181) + ($$2158179))|0;
        $$3 = $$2181;$$3153 = 1;$$3159 = $42;$$3163 = $$2162178;
        break;
       } else {
        $43 = (($$2152180) + 1)|0;
        $$3 = $$2181;$$3153 = $43;$$3159 = $$2158179;$$3163 = $$2162178;
        break;
       }
      } else {
       $44 = ($36&255)<($39&255);
       if ($44) {
        $45 = (($38) - ($$2162178))|0;
        $$3 = $45;$$3153 = 1;$$3159 = $38;$$3163 = $$2162178;
        break;
       } else {
        $46 = (($$2158179) + 1)|0;
        $$3 = 1;$$3153 = 1;$$3159 = $46;$$3163 = $$2158179;
        break;
       }
      }
     } while(0);
     $47 = (($$3153) + ($$3159))|0;
     $48 = ($47>>>0)<($3>>>0);
     if ($48) {
      $$2152180 = $$3153;$$2158179 = $$3159;$$2162178 = $$3163;$$2181 = $$3;$38 = $47;
     } else {
      $$0149$lcssa202 = $$1;$$0160$lcssa201 = $$1161;$$2$lcssa = $$3;$$2162$lcssa = $$3163;
      break;
     }
    }
   } else {
    $$0149$lcssa202 = $$1;$$0160$lcssa201 = $$1161;$$2$lcssa = 1;$$2162$lcssa = -1;
   }
  } else {
   $$0149$lcssa202 = 1;$$0160$lcssa201 = -1;$$2$lcssa = 1;$$2162$lcssa = -1;
  }
 }
 $49 = (($$2162$lcssa) + 1)|0;
 $50 = (($$0160$lcssa201) + 1)|0;
 $51 = ($49>>>0)>($50>>>0);
 $$2$$0149 = $51 ? $$2$lcssa : $$0149$lcssa202;
 $$2162$$0160 = $51 ? $$2162$lcssa : $$0160$lcssa201;
 $52 = (($2) + ($$2$$0149)|0);
 $53 = (($$2162$$0160) + 1)|0;
 $54 = (_memcmp($2,$52,$53)|0);
 $55 = ($54|0)==(0);
 if ($55) {
  $60 = (($3) - ($$2$$0149))|0;
  $$0 = $60;$$5 = $$2$$0149;
 } else {
  $56 = (($3) - ($$2162$$0160))|0;
  $57 = (($56) + -1)|0;
  $58 = ($$2162$$0160>>>0)>($57>>>0);
  $$2162$$0160$ = $58 ? $$2162$$0160 : $57;
  $59 = (($$2162$$0160$) + 1)|0;
  $$0 = 0;$$5 = $59;
 }
 $61 = $1;
 $62 = $0;
 $63 = (($61) - ($62))|0;
 $64 = ($63>>>0)<($3>>>0);
 L38: do {
  if ($64) {
   $$0147 = 0;
  } else {
   $65 = (($3) + -1)|0;
   $66 = ($$0|0)!=(0);
   $67 = (($3) - ($$5))|0;
   $$0146176 = 0;$$0165175 = $0;
   while(1) {
    $68 = (($$0165175) + ($65)|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = $69&255;
    $71 = $70 >>> 5;
    $72 = (($4) + ($71<<2)|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = $70 & 31;
    $75 = 1 << $74;
    $76 = $75 & $73;
    $77 = ($76|0)==(0);
    L42: do {
     if ($77) {
      $$0146$be = 0;$$4154$sink = $3;
     } else {
      $78 = (($5) + ($70<<2)|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = (($3) - ($79))|0;
      $81 = ($80|0)==(0);
      if (!($81)) {
       $82 = ($$0146176|0)!=(0);
       $or$cond = $66 & $82;
       $83 = ($80>>>0)<($$5>>>0);
       $or$cond166 = $or$cond & $83;
       $$4154 = $or$cond166 ? $67 : $80;
       $$0146$be = 0;$$4154$sink = $$4154;
       break;
      }
      $88 = ($53>>>0)>($$0146176>>>0);
      $89 = $88 ? $53 : $$0146176;
      $90 = ($89>>>0)<($3>>>0);
      L47: do {
       if ($90) {
        $$5155171 = $89;
        while(1) {
         $91 = (($2) + ($$5155171)|0);
         $92 = HEAP8[$91>>0]|0;
         $93 = (($$0165175) + ($$5155171)|0);
         $94 = HEAP8[$93>>0]|0;
         $95 = ($92<<24>>24)==($94<<24>>24);
         if (!($95)) {
          break;
         }
         $96 = (($$5155171) + 1)|0;
         $97 = ($96>>>0)<($3>>>0);
         if ($97) {
          $$5155171 = $96;
         } else {
          break L47;
         }
        }
        $98 = (($$5155171) - ($$2162$$0160))|0;
        $$0146$be = 0;$$4154$sink = $98;
        break L42;
       }
      } while(0);
      if (!($88)) {
       $$0147 = $$0165175;
       break L38;
      }
      $$6172 = $53;
      while(1) {
       $100 = (($$6172) + -1)|0;
       $101 = (($2) + ($100)|0);
       $102 = HEAP8[$101>>0]|0;
       $103 = (($$0165175) + ($100)|0);
       $104 = HEAP8[$103>>0]|0;
       $105 = ($102<<24>>24)==($104<<24>>24);
       if (!($105)) {
        $$0146$be = $$0;$$4154$sink = $$5;
        break L42;
       }
       $99 = ($100>>>0)>($$0146176>>>0);
       if ($99) {
        $$6172 = $100;
       } else {
        $$0147 = $$0165175;
        break L38;
       }
      }
     }
    } while(0);
    $84 = (($$0165175) + ($$4154$sink)|0);
    $85 = $84;
    $86 = (($61) - ($85))|0;
    $87 = ($86>>>0)<($3>>>0);
    if ($87) {
     $$0147 = 0;
     break;
    } else {
     $$0146176 = $$0146$be;$$0165175 = $84;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0147|0);
}
function _strndup($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strnlen($0,$1)|0);
 $3 = (($2) + 1)|0;
 $4 = (_malloc($3)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
 } else {
  (_memcpy(($4|0),($0|0),($2|0))|0);
  $6 = (($4) + ($2)|0);
  HEAP8[$6>>0] = 0;
  $$0 = $4;
 }
 return ($$0|0);
}
function _strtok($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$010 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0|0);
 if ($2) {
  $3 = HEAP32[(gb + (172072) | 0)>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 0;
  } else {
   $$010 = $3;
   label = 3;
  }
 } else {
  $$010 = $0;
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $5 = (_strspn($$010,$1)|0);
   $6 = (($$010) + ($5)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    HEAP32[(gb + (172072) | 0)>>2] = 0;
    $$0 = 0;
    break;
   }
   $9 = (_strcspn($6,$1)|0);
   $10 = (($6) + ($9)|0);
   HEAP32[(gb + (172072) | 0)>>2] = $10;
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    HEAP32[(gb + (172072) | 0)>>2] = 0;
    $$0 = $6;
    break;
   } else {
    $13 = ((($10)) + 1|0);
    HEAP32[(gb + (172072) | 0)>>2] = $13;
    HEAP8[$10>>0] = 0;
    $$0 = $6;
    break;
   }
  }
 } while(0);
 return ($$0|0);
}
function _swab($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01215 = 0, $$01314 = 0, $$016 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)>(1);
 if ($3) {
  $$01215 = $0;$$01314 = $2;$$016 = $1;
  while(1) {
   $4 = ((($$01215)) + 1|0);
   $5 = HEAP8[$4>>0]|0;
   HEAP8[$$016>>0] = $5;
   $6 = HEAP8[$$01215>>0]|0;
   $7 = ((($$016)) + 1|0);
   HEAP8[$7>>0] = $6;
   $8 = ((($$016)) + 2|0);
   $9 = ((($$01215)) + 2|0);
   $10 = (($$01314) + -2)|0;
   $11 = ($$01314|0)>(3);
   if ($11) {
    $$01215 = $9;$$01314 = $10;$$016 = $8;
   } else {
    break;
   }
  }
 }
 return;
}
function _wcpncpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_wcsncpy($0,$1,$2)|0);
 $4 = (_wcsnlen($1,$2)|0);
 $5 = (($0) + ($4<<2)|0);
 return ($5|0);
}
function _wcsncpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$01011 = 0, $$013 = 0, $$09$lcssa = 0, $$0912 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$0$lcssa = $0;$$09$lcssa = 0;
  } else {
   $$01011 = $1;$$013 = $0;$$0912 = $2;
   while(1) {
    $4 = HEAP32[$$01011>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     $$0$lcssa = $$013;$$09$lcssa = $$0912;
     break L1;
    }
    $6 = (($$0912) + -1)|0;
    $7 = ((($$01011)) + 4|0);
    $8 = ((($$013)) + 4|0);
    HEAP32[$$013>>2] = $4;
    $9 = ($6|0)==(0);
    if ($9) {
     $$0$lcssa = $8;$$09$lcssa = 0;
     break;
    } else {
     $$01011 = $7;$$013 = $8;$$0912 = $6;
    }
   }
  }
 } while(0);
 (_wmemset($$0$lcssa,0,$$09$lcssa)|0);
 return ($0|0);
}
function _wmemset($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$056 = 0, $$07 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$056 = $2;$$07 = $0;
  while(1) {
   $4 = (($$056) + -1)|0;
   $5 = ((($$07)) + 4|0);
   HEAP32[$$07>>2] = $1;
   $6 = ($4|0)==(0);
   if ($6) {
    break;
   } else {
    $$056 = $4;$$07 = $5;
   }
  }
 }
 return ($0|0);
}
function _bcmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_memcmp($0,$1,$2)|0);
 return ($3|0);
}
function _wcpcpy($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcscpy($0,$1)|0);
 $3 = (_wcslen($1)|0);
 $4 = (($0) + ($3<<2)|0);
 return ($4|0);
}
function _rindex($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strrchr($0,$1)|0);
 return ($2|0);
}
function _strrchr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_strlen($0)|0);
 $3 = (($2) + 1)|0;
 $4 = (___memrchr($0,$1,$3)|0);
 return ($4|0);
}
function ___memrchr($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$in = 0, $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$0 = 0;
  } else {
   $4 = $1&255;
   $$in = $2;
   while(1) {
    $6 = (($$in) + -1)|0;
    $7 = (($0) + ($6)|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==($4<<24>>24);
    if ($9) {
     break;
    }
    $5 = ($6|0)==(0);
    if ($5) {
     $$0 = 0;
     break L1;
    } else {
     $$in = $6;
    }
   }
   $10 = (($0) + ($6)|0);
   $$0 = $10;
  }
 } while(0);
 return ($$0|0);
}
function _wcsncmp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01218 = 0, $$01317 = 0, $$019 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $14 = 0;
  } else {
   $$01218 = $1;$$01317 = $0;$$019 = $2;
   while(1) {
    $4 = HEAP32[$$01317>>2]|0;
    $5 = HEAP32[$$01218>>2]|0;
    $6 = ($4|0)!=($5|0);
    $7 = ($4|0)==(0);
    $or$cond = $7 | $6;
    $8 = ($5|0)==(0);
    $or$cond14 = $8 | $or$cond;
    if ($or$cond14) {
     break;
    }
    $9 = (($$019) + -1)|0;
    $10 = ((($$01317)) + 4|0);
    $11 = ((($$01218)) + 4|0);
    $12 = ($9|0)==(0);
    if ($12) {
     $14 = 0;
     break L1;
    } else {
     $$01218 = $11;$$01317 = $10;$$019 = $9;
    }
   }
   $13 = (($4) - ($5))|0;
   $14 = $13;
  }
 } while(0);
 return ($14|0);
}
function _strsep($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$014 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$014 = 0;
 } else {
  $4 = (_strcspn($2,$1)|0);
  $5 = (($2) + ($4)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $$0 = 0;
  } else {
   $8 = ((($5)) + 1|0);
   HEAP8[$5>>0] = 0;
   $$0 = $8;
  }
  HEAP32[$0>>2] = $$0;
  $$014 = $2;
 }
 return ($$014|0);
}
function _strerror_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strerror($0)|0);
 $4 = (_strlen($3)|0);
 $5 = ($4>>>0)<($2>>>0);
 if ($5) {
  $9 = (($4) + 1)|0;
  (_memcpy(($1|0),($3|0),($9|0))|0);
  $$0 = 0;
 } else {
  $6 = ($2|0)==(0);
  $7 = (($2) + -1)|0;
  if ($6) {
   $$0 = 34;
  } else {
   $8 = (($1) + ($7)|0);
   (_memcpy(($1|0),($3|0),($7|0))|0);
   HEAP8[$8>>0] = 0;
   $$0 = 34;
  }
 }
 return ($$0|0);
}
function _wcsrchr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$010 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wcslen($0)|0);
 $3 = ($2|0)>(-1);
 L1: do {
  if ($3) {
   $4 = (($0) + ($2<<2)|0);
   $$010 = $4;
   while(1) {
    $5 = HEAP32[$$010>>2]|0;
    $6 = ($5|0)==($1|0);
    if ($6) {
     $9 = $$010;
     break L1;
    }
    $7 = ((($$010)) + -4|0);
    $8 = ($7>>>0)<($0>>>0);
    if ($8) {
     $9 = 0;
     break;
    } else {
     $$010 = $7;
    }
   }
  } else {
   $9 = 0;
  }
 } while(0);
 return ($9|0);
}
function _strsignal($0) {
 $0 = $0|0;
 var $$0$lcssa = 0, $$07 = 0, $$1 = 0, $$in = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($0) + -1)|0;
 $2 = ($1>>>0)>(63);
 $3 = ($0|0)==(0);
 $4 = $2 | $3;
 if ($4) {
  $$0$lcssa = (gb + (153712) | 0);
 } else {
  $$07 = (gb + (153712) | 0);$$in = $0;
  while(1) {
   $$1 = $$07;
   while(1) {
    $5 = HEAP8[$$1>>0]|0;
    $6 = ($5<<24>>24)==(0);
    $7 = ((($$1)) + 1|0);
    if ($6) {
     break;
    } else {
     $$1 = $7;
    }
   }
   $8 = (($$in) + -1)|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $$0$lcssa = $7;
    break;
   } else {
    $$07 = $7;$$in = $8;
   }
  }
 }
 $10 = (___lctrans_cur($$0$lcssa)|0);
 return ($10|0);
}
function _wcsncasecmp_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_wcsncasecmp($0,$1,$2)|0);
 return ($4|0);
}
function _strlcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0$lcssa = 0, $$042$lcssa = 0, $$04260 = 0, $$043$lcssa = 0, $$043$lcssa88 = 0, $$04373 = 0, $$044$lcssa = 0, $$044$lcssa87 = 0, $$04472 = 0, $$048$lcssa = 0, $$048$lcssa86 = 0, $$04871 = 0, $$061 = 0, $$1 = 0, $$145$lcssa = 0, $$14559 = 0, $$149 = 0, $$2$lcssa = 0, $$246 = 0, $$250$lcssa = 0;
 var $$25052 = 0, $$254 = 0, $$34753 = 0, $$351 = 0, $$lcssa = 0, $$pre = 0, $$pre$phi85Z2D = 0, $$pre$phiZ2D = 0, $$pre84 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond70 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($2) + -1)|0;
 $4 = ($2|0)==(0);
 if ($4) {
  $$pre = $0;
  $$351 = $1;$$pre$phi85Z2D = $$pre;$$pre$phiZ2D = $$pre;
 } else {
  $5 = $1;
  $6 = $0;
  $7 = $5 ^ $6;
  $8 = $7 & 3;
  $9 = ($8|0)==(0);
  do {
   if ($9) {
    $10 = $5 & 3;
    $11 = ($10|0)!=(0);
    $12 = ($3|0)!=(0);
    $or$cond70 = $12 & $11;
    L6: do {
     if ($or$cond70) {
      $$04373 = $0;$$04472 = $3;$$04871 = $1;
      while(1) {
       $13 = HEAP8[$$04871>>0]|0;
       HEAP8[$$04373>>0] = $13;
       $14 = ($13<<24>>24)==(0);
       if ($14) {
        $$043$lcssa88 = $$04373;$$044$lcssa87 = $$04472;$$048$lcssa86 = $$04871;
        break L6;
       }
       $15 = (($$04472) + -1)|0;
       $16 = ((($$04871)) + 1|0);
       $17 = ((($$04373)) + 1|0);
       $18 = $16;
       $19 = $18 & 3;
       $20 = ($19|0)!=(0);
       $21 = ($15|0)!=(0);
       $or$cond = $21 & $20;
       if ($or$cond) {
        $$04373 = $17;$$04472 = $15;$$04871 = $16;
       } else {
        $$043$lcssa = $17;$$044$lcssa = $15;$$048$lcssa = $16;$$lcssa = $21;
        label = 8;
        break;
       }
      }
     } else {
      $$043$lcssa = $0;$$044$lcssa = $3;$$048$lcssa = $1;$$lcssa = $12;
      label = 8;
     }
    } while(0);
    if ((label|0) == 8) {
     if ($$lcssa) {
      $$043$lcssa88 = $$043$lcssa;$$044$lcssa87 = $$044$lcssa;$$048$lcssa86 = $$048$lcssa;
     } else {
      $$2$lcssa = $$043$lcssa;$$250$lcssa = $$048$lcssa;
      break;
     }
    }
    $22 = HEAP8[$$048$lcssa86>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     $$1 = $$043$lcssa88;$$149 = $$048$lcssa86;$$246 = $$044$lcssa87;
     label = 15;
    } else {
     $24 = ($$044$lcssa87>>>0)>(3);
     L15: do {
      if ($24) {
       $$04260 = $$043$lcssa88;$$061 = $$048$lcssa86;$$14559 = $$044$lcssa87;
       while(1) {
        $25 = HEAP32[$$061>>2]|0;
        $26 = (($25) + -16843009)|0;
        $27 = $25 & -2139062144;
        $28 = $27 ^ -2139062144;
        $29 = $28 & $26;
        $30 = ($29|0)==(0);
        if (!($30)) {
         $$0$lcssa = $$061;$$042$lcssa = $$04260;$$145$lcssa = $$14559;
         break L15;
        }
        HEAP32[$$04260>>2] = $25;
        $31 = (($$14559) + -4)|0;
        $32 = ((($$061)) + 4|0);
        $33 = ((($$04260)) + 4|0);
        $34 = ($31>>>0)>(3);
        if ($34) {
         $$04260 = $33;$$061 = $32;$$14559 = $31;
        } else {
         $$0$lcssa = $32;$$042$lcssa = $33;$$145$lcssa = $31;
         break;
        }
       }
      } else {
       $$0$lcssa = $$048$lcssa86;$$042$lcssa = $$043$lcssa88;$$145$lcssa = $$044$lcssa87;
      }
     } while(0);
     $$1 = $$042$lcssa;$$149 = $$0$lcssa;$$246 = $$145$lcssa;
     label = 15;
    }
   } else {
    $$1 = $0;$$149 = $1;$$246 = $3;
    label = 15;
   }
  } while(0);
  L21: do {
   if ((label|0) == 15) {
    $35 = ($$246|0)==(0);
    if ($35) {
     $$2$lcssa = $$1;$$250$lcssa = $$149;
    } else {
     $$25052 = $$149;$$254 = $$1;$$34753 = $$246;
     while(1) {
      $36 = HEAP8[$$25052>>0]|0;
      HEAP8[$$254>>0] = $36;
      $37 = ($36<<24>>24)==(0);
      if ($37) {
       $$2$lcssa = $$254;$$250$lcssa = $$25052;
       break L21;
      }
      $38 = (($$34753) + -1)|0;
      $39 = ((($$25052)) + 1|0);
      $40 = ((($$254)) + 1|0);
      $41 = ($38|0)==(0);
      if ($41) {
       $$2$lcssa = $40;$$250$lcssa = $39;
       break;
      } else {
       $$25052 = $39;$$254 = $40;$$34753 = $38;
      }
     }
    }
   }
  } while(0);
  HEAP8[$$2$lcssa>>0] = 0;
  $$pre84 = $$2$lcssa;
  $$351 = $$250$lcssa;$$pre$phi85Z2D = $$pre84;$$pre$phiZ2D = $6;
 }
 $42 = (($$pre$phi85Z2D) - ($$pre$phiZ2D))|0;
 $43 = (_strlen($$351)|0);
 $44 = (($42) + ($43))|0;
 return ($44|0);
}
function _mempcpy($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_memcpy(($0|0),($1|0),($2|0))|0);
 $4 = (($3) + ($2)|0);
 return ($4|0);
}
function _strlcat($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$pn = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_strnlen($0,$2)|0);
 $4 = ($3|0)==($2|0);
 if ($4) {
  $5 = (_strlen($1)|0);
  $$pn = $5;
 } else {
  $6 = (($0) + ($3)|0);
  $7 = (($2) - ($3))|0;
  $8 = (_strlcpy($6,$1,$7)|0);
  $$pn = $8;
 }
 $$0 = (($$pn) + ($3))|0;
 return ($$0|0);
}
function _wmemmove($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$01416 = 0, $$018 = 0, $$117 = 0, $$in = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $3 = $0;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($2>>>0);
 if ($7) {
  $$in = $2;
  while(1) {
   $8 = (($$in) + -1)|0;
   $9 = (($1) + ($8<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($0) + ($8<<2)|0);
   HEAP32[$11>>2] = $10;
   $12 = ($8|0)==(0);
   if ($12) {
    break;
   } else {
    $$in = $8;
   }
  }
 } else {
  $13 = ($2|0)==(0);
  if (!($13)) {
   $$01416 = $1;$$018 = $0;$$117 = $2;
   while(1) {
    $14 = (($$117) + -1)|0;
    $15 = ((($$01416)) + 4|0);
    $16 = HEAP32[$$01416>>2]|0;
    $17 = ((($$018)) + 4|0);
    HEAP32[$$018>>2] = $16;
    $18 = ($14|0)==(0);
    if ($18) {
     break;
    } else {
     $$01416 = $15;$$018 = $17;$$117 = $14;
    }
   }
  }
 }
 return ($0|0);
}
function _fegetenv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _fesetenv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _fegetexceptflag($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_fetestexcept($1)|0);
 $3 = $2&65535;
 HEAP16[$0>>1] = $3;
 return 0;
}
function _fesetexceptflag($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _feupdateenv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _feholdexcept($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function ___flt_rounds() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_fegetround()|0);
 $1 = $0 >>> 10;
 $2 = $0 << 22;
 $3 = $1 | $2;
 switch ($3|0) {
 case 3:  {
  $$0 = 0;
  break;
 }
 case 0:  {
  $$0 = 1;
  break;
 }
 case 2:  {
  $$0 = 2;
  break;
 }
 case 1:  {
  $$0 = 3;
  break;
 }
 default: {
  $$0 = -1;
 }
 }
 return ($$0|0);
}
function _getresgid($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $1;
 $5 = $2;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $6 = (___syscall211(211,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _setmntent($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_fopen($0,$1)|0);
 return ($2|0);
}
function _endmntent($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  (_fclose($0)|0);
 }
 return 1;
}
function _getmntent_r($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer1 = sp + 40|0;
 $vararg_buffer = sp + 32|0;
 $4 = sp;
 $5 = ((($1)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($1)) + 20|0);
 HEAP32[$6>>2] = 0;
 (_fgets($2,$3,$0)|0);
 $7 = (_feof($0)|0);
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   $9 = ((($4)) + 4|0);
   $10 = ((($4)) + 8|0);
   $11 = ((($4)) + 12|0);
   $12 = ((($4)) + 16|0);
   $13 = ((($4)) + 20|0);
   $14 = ((($4)) + 24|0);
   $15 = ((($4)) + 28|0);
   while(1) {
    $16 = (_ferror($0)|0);
    $17 = ($16|0)==(0);
    if (!($17)) {
     $$0 = 0;
     break L1;
    }
    $18 = (_strchr($2,10)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     label = 5;
     break;
    }
    HEAP32[$vararg_buffer1>>2] = $4;
    $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
    HEAP32[$vararg_ptr3>>2] = $9;
    $vararg_ptr4 = ((($vararg_buffer1)) + 8|0);
    HEAP32[$vararg_ptr4>>2] = $10;
    $vararg_ptr5 = ((($vararg_buffer1)) + 12|0);
    HEAP32[$vararg_ptr5>>2] = $11;
    $vararg_ptr6 = ((($vararg_buffer1)) + 16|0);
    HEAP32[$vararg_ptr6>>2] = $12;
    $vararg_ptr7 = ((($vararg_buffer1)) + 20|0);
    HEAP32[$vararg_ptr7>>2] = $13;
    $vararg_ptr8 = ((($vararg_buffer1)) + 24|0);
    HEAP32[$vararg_ptr8>>2] = $14;
    $vararg_ptr9 = ((($vararg_buffer1)) + 28|0);
    HEAP32[$vararg_ptr9>>2] = $15;
    $vararg_ptr10 = ((($vararg_buffer1)) + 32|0);
    HEAP32[$vararg_ptr10>>2] = $5;
    $vararg_ptr11 = ((($vararg_buffer1)) + 36|0);
    HEAP32[$vararg_ptr11>>2] = $6;
    $21 = (_sscanf($2,(gb + (167468) | 0),$vararg_buffer1)|0);
    $22 = ($21|0)<(2);
    if (!($22)) {
     $23 = HEAP32[$4>>2]|0;
     $24 = (($2) + ($23)|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = ($25<<24>>24)==(35);
     if (!($26)) {
      label = 9;
      break;
     }
    }
    (_fgets($2,$3,$0)|0);
    $27 = (_feof($0)|0);
    $28 = ($27|0)==(0);
    if (!($28)) {
     $$0 = 0;
     break L1;
    }
   }
   if ((label|0) == 5) {
    (_fscanf($0,(gb + (167456) | 0),$vararg_buffer)|0);
    $20 = (___errno_location()|0);
    HEAP32[$20>>2] = 34;
    $$0 = 0;
    break;
   }
   else if ((label|0) == 9) {
    $29 = (($2) + ($23)|0);
    $30 = HEAP32[$9>>2]|0;
    $31 = (($2) + ($30)|0);
    HEAP8[$31>>0] = 0;
    $32 = HEAP32[$11>>2]|0;
    $33 = (($2) + ($32)|0);
    HEAP8[$33>>0] = 0;
    $34 = HEAP32[$13>>2]|0;
    $35 = (($2) + ($34)|0);
    HEAP8[$35>>0] = 0;
    $36 = HEAP32[$15>>2]|0;
    $37 = (($2) + ($36)|0);
    HEAP8[$37>>0] = 0;
    HEAP32[$1>>2] = $29;
    $38 = HEAP32[$10>>2]|0;
    $39 = (($2) + ($38)|0);
    $40 = ((($1)) + 4|0);
    HEAP32[$40>>2] = $39;
    $41 = HEAP32[$12>>2]|0;
    $42 = (($2) + ($41)|0);
    $43 = ((($1)) + 8|0);
    HEAP32[$43>>2] = $42;
    $44 = HEAP32[$14>>2]|0;
    $45 = (($2) + ($44)|0);
    $46 = ((($1)) + 12|0);
    HEAP32[$46>>2] = $45;
    $$0 = $1;
    break;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _getmntent($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (_getmntent_r($0,(gb + (172076) | 0),(gb + (170304) | 0),256)|0);
 return ($1|0);
}
function _addmntent($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$lobit = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0;
 var $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $2 = (_fseek($0,0,2)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = HEAP32[$1>>2]|0;
  $5 = ((($1)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($1)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($1)) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($1)) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($1)) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$vararg_buffer>>2] = $4;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $6;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $8;
  $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
  HEAP32[$vararg_ptr3>>2] = $10;
  $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
  HEAP32[$vararg_ptr4>>2] = $12;
  $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
  HEAP32[$vararg_ptr5>>2] = $14;
  $15 = (_fprintf($0,(gb + (167507) | 0),$vararg_buffer)|0);
  $$lobit = $15 >>> 31;
  $$0 = $$lobit;
 } else {
  $$0 = 1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _hasmntopt($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($0)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_strstr($3,$1)|0);
 return ($4|0);
}
function ___getopt_msg($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = HEAP32[(gb + (161300) | 0)>>2]|0;
 $5 = (___lctrans_cur($1)|0);
 _flockfile($4);
 $6 = (_fputs($0,$4)|0);
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = (_strlen($5)|0);
  $9 = (_fwrite($5,$8,1,$4)|0);
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = (_fwrite($2,1,$3,$4)|0);
   $12 = ($11|0)==($3|0);
   if ($12) {
    (_putc(10,$4)|0);
   }
  }
 }
 _funlockfile($4);
 return;
}
function _getopt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $$049 = 0, $$050 = 0, $$051 = 0, $$1 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$pre56 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[(gb + (161696) | 0)>>2]|0;
 $6 = ($5|0)==(0);
 $7 = HEAP32[(gb + (171180) | 0)>>2]|0;
 $8 = ($7|0)!=(0);
 $or$cond = $6 | $8;
 if ($or$cond) {
  HEAP32[(gb + (171180) | 0)>>2] = 0;
  HEAP32[(gb + (171184) | 0)>>2] = 0;
  HEAP32[(gb + (161696) | 0)>>2] = 1;
  $10 = 1;
 } else {
  $10 = $5;
 }
 $9 = ($10|0)<($0|0);
 L4: do {
  if ($9) {
   $11 = (($1) + ($10<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   $14 = $12;
   if ($13) {
    $$0 = -1;
   } else {
    $15 = HEAP8[$12>>0]|0;
    $16 = ($15<<24>>24)==(45);
    if (!($16)) {
     $17 = HEAP8[$2>>0]|0;
     $18 = ($17<<24>>24)==(45);
     if (!($18)) {
      $$0 = -1;
      break;
     }
     $19 = (($10) + 1)|0;
     HEAP32[(gb + (161696) | 0)>>2] = $19;
     HEAP32[(gb + (171188) | 0)>>2] = $14;
     $$0 = 1;
     break;
    }
    $20 = ((($12)) + 1|0);
    $21 = HEAP8[$20>>0]|0;
    switch ($21<<24>>24) {
    case 0:  {
     $$0 = -1;
     break L4;
     break;
    }
    case 45:  {
     $22 = ((($12)) + 2|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $25 = (($10) + 1)|0;
      HEAP32[(gb + (161696) | 0)>>2] = $25;
      $$0 = -1;
      break L4;
     }
     break;
    }
    default: {
    }
    }
    $26 = HEAP32[(gb + (171184) | 0)>>2]|0;
    $27 = ($26|0)==(0);
    if ($27) {
     HEAP32[(gb + (171184) | 0)>>2] = 1;
     $$pre$phiZ2D = $20;
    } else {
     $$pre56 = (($12) + ($26)|0);
     $$pre$phiZ2D = $$pre56;
    }
    $28 = (_mbtowc($3,$$pre$phiZ2D,4)|0);
    $29 = ($28|0)<(0);
    if ($29) {
     HEAP32[$3>>2] = 65533;
     $$050 = 1;$35 = 65533;
    } else {
     $$pre = HEAP32[$3>>2]|0;
     $$050 = $28;$35 = $$pre;
    }
    $30 = HEAP32[(gb + (161696) | 0)>>2]|0;
    $31 = (($1) + ($30<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[(gb + (171184) | 0)>>2]|0;
    $34 = (($32) + ($33)|0);
    HEAP32[(gb + (171192) | 0)>>2] = $35;
    $36 = (($33) + ($$050))|0;
    HEAP32[(gb + (171184) | 0)>>2] = $36;
    $37 = (($32) + ($36)|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $40 = (($30) + 1)|0;
     HEAP32[(gb + (161696) | 0)>>2] = $40;
     HEAP32[(gb + (171184) | 0)>>2] = 0;
    }
    $41 = HEAP8[$2>>0]|0;
    switch ($41<<24>>24) {
    case 43: case 45:  {
     $42 = ((($2)) + 1|0);
     $$049 = $42;
     break;
    }
    default: {
     $$049 = $2;
    }
    }
    HEAP32[$4>>2] = 0;
    $$051 = 0;
    while(1) {
     $43 = (($$049) + ($$051)|0);
     $44 = (_mbtowc($4,$43,4)|0);
     $45 = ($44|0)>(1);
     $$ = $45 ? $44 : 1;
     $$1 = (($$) + ($$051))|0;
     $46 = ($44|0)==(0);
     $$pre52 = HEAP32[$4>>2]|0;
     $$pre53 = HEAP32[$3>>2]|0;
     $47 = ($$pre52|0)==($$pre53|0);
     if ($46) {
      label = 24;
      break;
     }
     if ($47) {
      $77 = $$pre52;
      break;
     } else {
      $$051 = $$1;
     }
    }
    if ((label|0) == 24) {
     if ($47) {
      $77 = $$pre53;
     } else {
      $48 = HEAP8[$$049>>0]|0;
      $49 = ($48<<24>>24)!=(58);
      $50 = HEAP32[(gb + (161700) | 0)>>2]|0;
      $51 = ($50|0)!=(0);
      $or$cond3 = $49 & $51;
      if (!($or$cond3)) {
       $$0 = 63;
       break;
      }
      $52 = HEAP32[$1>>2]|0;
      ___getopt_msg($52,(gb + (167782) | 0),$34,$$050);
      $$0 = 63;
      break;
     }
    }
    $53 = (($$049) + ($$1)|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = ($54<<24>>24)==(58);
    if ($55) {
     $56 = (($$1) + 1)|0;
     $57 = (($$049) + ($56)|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = ($58<<24>>24)==(58);
     do {
      if ($59) {
       HEAP32[(gb + (171188) | 0)>>2] = 0;
       $$pre54 = HEAP8[$57>>0]|0;
       $68 = ($$pre54<<24>>24)!=(58);
       $69 = HEAP32[(gb + (171184) | 0)>>2]|0;
       $70 = ($69|0)!=(0);
       $or$cond5 = $68 | $70;
       if ($or$cond5) {
        $76 = $69;
       } else {
        $$0 = $77;
        break L4;
       }
      } else {
       $60 = HEAP32[(gb + (161696) | 0)>>2]|0;
       $61 = ($60|0)<($0|0);
       if ($61) {
        $62 = HEAP32[(gb + (171184) | 0)>>2]|0;
        $76 = $62;
        break;
       }
       $63 = HEAP8[$$049>>0]|0;
       $64 = ($63<<24>>24)==(58);
       if ($64) {
        $$0 = 58;
        break L4;
       }
       $65 = HEAP32[(gb + (161700) | 0)>>2]|0;
       $66 = ($65|0)==(0);
       if ($66) {
        $$0 = 63;
        break L4;
       }
       $67 = HEAP32[$1>>2]|0;
       ___getopt_msg($67,(gb + (167750) | 0),$34,$$050);
       $$0 = 63;
       break L4;
      }
     } while(0);
     $71 = HEAP32[(gb + (161696) | 0)>>2]|0;
     $72 = (($71) + 1)|0;
     HEAP32[(gb + (161696) | 0)>>2] = $72;
     $73 = (($1) + ($71<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($74) + ($76)|0);
     HEAP32[(gb + (171188) | 0)>>2] = $75;
     HEAP32[(gb + (171184) | 0)>>2] = 0;
     $$0 = $77;
    } else {
     $$0 = $77;
    }
   }
  } else {
   $$0 = -1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _getpriority($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $2 = (___syscall96(96,($vararg_buffer|0))|0);
 $3 = (___syscall_ret($2)|0);
 $4 = ($3|0)<(0);
 $5 = (20 - ($3))|0;
 $$0 = $4 ? $3 : $5;
 STACKTOP = sp;return ($$0|0);
}
function _login_tty($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 (_setsid()|0);
 HEAP32[$vararg_buffer>>2] = 0;
 $1 = (_ioctl($0,21518,$vararg_buffer)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  (_dup2($0,0)|0);
  (_dup2($0,1)|0);
  (_dup2($0,2)|0);
  $3 = ($0|0)>(2);
  if ($3) {
   (_close($0)|0);
   $$0 = 0;
  } else {
   $$0 = 0;
  }
 } else {
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _a64l($0) {
 $0 = $0|0;
 var $$01521 = 0, $$016$lcssa = 0, $$01620 = 0, $$01719 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$01521 = $0;$$01620 = 0;$$01719 = 0;
 while(1) {
  $1 = HEAP8[$$01521>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $$016$lcssa = $$01620;
   break;
  }
  $3 = $1 << 24 >> 24;
  $4 = (_strchr((gb + (152352) | 0),$3)|0);
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$016$lcssa = $$01620;
   break;
  }
  $6 = $4;
  $7 = (($6) - ((gb + (152352) | 0)))|0;
  $8 = $7 << $$01719;
  $9 = $8 | $$01620;
  $10 = (($$01719) + 6)|0;
  $11 = ((($$01521)) + 1|0);
  $12 = ($10>>>0)<(36);
  if ($12) {
   $$01521 = $11;$$01620 = $9;$$01719 = $10;
  } else {
   $$016$lcssa = $9;
   break;
  }
 }
 return ($$016$lcssa|0);
}
function _l64a($0) {
 $0 = $0|0;
 var $$011 = 0, $$09$lcssa = 0, $$0910 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$09$lcssa = (gb + (172132) | 0);
 } else {
  $$011 = $0;$$0910 = (gb + (172132) | 0);
  while(1) {
   $2 = $$011 & 63;
   $3 = ((gb + (152352) | 0) + ($2)|0);
   $4 = HEAP8[$3>>0]|0;
   HEAP8[$$0910>>0] = $4;
   $5 = ((($$0910)) + 1|0);
   $6 = $$011 >>> 6;
   $7 = ($6|0)==(0);
   if ($7) {
    $$09$lcssa = $5;
    break;
   } else {
    $$011 = $6;$$0910 = $5;
   }
  }
 }
 HEAP8[$$09$lcssa>>0] = 0;
 return ((gb + (172132) | 0)|0);
}
function _ptsname($0) {
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (___ptsname_r($0,(gb + (170560) | 0),22)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = (gb + (170560) | 0);
 } else {
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = $1;
  $$0 = 0;
 }
 return ($$0|0);
}
function ___ptsname_r($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $3 = sp + 20|0;
 $4 = ($1|0)==(0|0);
 $spec$select = $4 ? 0 : $2;
 $5 = $3;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = -2147199952;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $6 = (___syscall54(54,($vararg_buffer|0))|0);
 $7 = ($6|0)==(0);
 if ($7) {
  $9 = HEAP32[$3>>2]|0;
  HEAP32[$vararg_buffer3>>2] = $9;
  $10 = (_snprintf($1,$spec$select,(gb + (167526) | 0),$vararg_buffer3)|0);
  $11 = ($10>>>0)<($spec$select>>>0);
  $$ = $11 ? 0 : 34;
  $$0 = $$;
 } else {
  $8 = (0 - ($6))|0;
  $$0 = $8;
 }
 STACKTOP = sp;return ($$0|0);
}
function _lockf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $3 = sp + 24|0;
 HEAP16[$3>>1] = 1;
 $4 = ((($3)) + 2|0);
 HEAP16[$4>>1] = 1;
 $5 = ((($3)) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($3)) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = ((($3)) + 12|0);
 HEAP32[$7>>2] = 0;
 switch ($1|0) {
 case 3:  {
  HEAP16[$3>>1] = 0;
  HEAP32[$vararg_buffer>>2] = $3;
  $8 = (_fcntl($0,12,$vararg_buffer)|0);
  $9 = ($8|0)<(0);
  if ($9) {
   $$0 = -1;
  } else {
   $10 = HEAP16[$3>>1]|0;
   $11 = ($10<<16>>16)==(2);
   if ($11) {
    $$0 = 0;
   } else {
    $12 = HEAP32[$7>>2]|0;
    $13 = (_getpid()|0);
    $14 = ($12|0)==($13|0);
    if ($14) {
     $$0 = 0;
    } else {
     $15 = (___errno_location()|0);
     HEAP32[$15>>2] = 13;
     $$0 = -1;
    }
   }
  }
  break;
 }
 case 0:  {
  HEAP16[$3>>1] = 2;
  label = 7;
  break;
 }
 case 2:  {
  label = 7;
  break;
 }
 case 1:  {
  HEAP32[$vararg_buffer4>>2] = $3;
  $17 = (_fcntl($0,14,$vararg_buffer4)|0);
  $$0 = $17;
  break;
 }
 default: {
  $18 = (___errno_location()|0);
  HEAP32[$18>>2] = 22;
  $$0 = -1;
 }
 }
 if ((label|0) == 7) {
  HEAP32[$vararg_buffer1>>2] = $3;
  $16 = (_fcntl($0,13,$vararg_buffer1)|0);
  $$0 = $16;
 }
 STACKTOP = sp;return ($$0|0);
}
function _getrusage($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $1;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $2;
 $3 = (___syscall77(77,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function ___emscripten_pthread_data_constructor() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[((((gb + (161704) | 0)) + 188|0))>>2] = ((((gb + (171204) | 0)) + 40|0));
 return;
}
function _nftw($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4112|0);
 $4 = sp + 4100|0;
 $5 = sp;
 $6 = ($2|0)<(1);
 do {
  if ($6) {
   $$0 = 0;
  } else {
   $7 = (_strlen($0)|0);
   $8 = ($7>>>0)>(4096);
   if ($8) {
    $9 = (___errno_location()|0);
    HEAP32[$9>>2] = 36;
    $$0 = -1;
    break;
   } else {
    $10 = (($7) + 1)|0;
    (_memcpy(($5|0),($0|0),($10|0))|0);
    (_pthread_setcancelstate(1,($4|0))|0);
    $11 = (_do_nftw($5,$1,$2,$3,0)|0);
    $12 = HEAP32[$4>>2]|0;
    (_pthread_setcancelstate(($12|0),(0|0))|0);
    $$0 = $11;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _do_nftw($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$08798 = 0, $$090 = 0, $$3 = 0, $$sink102 = 0, $$sink103 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond6 = 0, $spec$select = 0, $spec$select97 = 0, $switch$split2D = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $5 = sp + 28|0;
 $6 = sp + 8|0;
 $7 = sp;
 $8 = (_strlen($0)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  label = 3;
 } else {
  $10 = (($8) + -1)|0;
  $11 = (($0) + ($10)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(47);
  if ($13) {
   $87 = $10;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $87 = $8;
 }
 $14 = $3 & 1;
 $15 = ($14|0)==(0);
 if ($15) {
  $18 = (_stat($0,$5)|0);
  $19 = ($18|0)<(0);
  if ($19) {
   $20 = (___errno_location()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(2);
   if ($22) {
    $23 = (_lstat($0,$5)|0);
    $24 = ($23|0)==(0);
    if ($24) {
     $$090 = 7;
     label = 13;
    } else {
     label = 9;
    }
   } else {
    label = 9;
   }
  } else {
   label = 10;
  }
 } else {
  $16 = (_lstat($0,$5)|0);
  $17 = ($16|0)==(0);
  if ($17) {
   label = 10;
  } else {
   label = 9;
  }
 }
 L11: do {
  if ((label|0) == 9) {
   $25 = (___errno_location()|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(13);
   if ($27) {
    $$090 = 4;
    label = 13;
   } else {
    $$3 = -1;
   }
  }
  else if ((label|0) == 10) {
   $28 = ((($5)) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $29 & 61440;
   $trunc = $30&65535;
   $switch$split2D = ($trunc<<16>>16)<(16384);
   if ($switch$split2D) {
    switch ($trunc<<16>>16) {
    case -24576:  {
     break;
    }
    default: {
     $$090 = 1;
     label = 13;
     break L11;
    }
    }
    $36 = $14 << 1;
    $37 = $36 ^ 7;
    $$090 = $37;
    label = 13;
    break;
   } else {
    switch ($trunc<<16>>16) {
    case 16384:  {
     break;
    }
    default: {
     $$090 = 1;
     label = 13;
     break L11;
    }
    }
    $31 = (_access($0,4)|0);
    $32 = ($31|0)<(0);
    $33 = $3 >>> 1;
    $34 = $33 & 4;
    $35 = $34 | 2;
    $spec$select = $32 ? 3 : $35;
    $$090 = $spec$select;
    label = 13;
    break;
   }
  }
 } while(0);
 L19: do {
  if ((label|0) == 13) {
   $38 = $3 & 2;
   $39 = ($38|0)!=(0);
   $40 = ($4|0)!=(0|0);
   $or$cond = $39 & $40;
   $41 = HEAP32[$5>>2]|0;
   if ($or$cond) {
    $42 = ((($4)) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)==($43|0);
    if (!($44)) {
     $$3 = 0;
     break;
    }
   }
   HEAP32[$6>>2] = $4;
   $45 = ((($6)) + 4|0);
   HEAP32[$45>>2] = $41;
   $46 = ((($5)) + 72|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ((($6)) + 8|0);
   HEAP32[$48>>2] = $47;
   if ($40) {
    $49 = ((($4)) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 1)|0;
    $52 = ((($4)) + 16|0);
    $53 = HEAP32[$52>>2]|0;
    $$sink103 = $51;$62 = $53;
   } else {
    $54 = (_strrchr($0,47)|0);
    $55 = ($54|0)==(0|0);
    $56 = $54;
    $57 = $0;
    $58 = (($56) - ($57))|0;
    $spec$select97 = $55 ? 0 : $58;
    $$sink103 = 0;$62 = $spec$select97;
   }
   $$sink102 = (($8) + 1)|0;
   $59 = ((($6)) + 12|0);
   HEAP32[$59>>2] = $$sink103;
   $60 = ((($6)) + 16|0);
   HEAP32[$60>>2] = $$sink102;
   $61 = ((($7)) + 4|0);
   HEAP32[$61>>2] = $$sink103;
   HEAP32[$7>>2] = $62;
   $63 = $3 & 8;
   $64 = ($63|0)!=(0);
   if (!($64)) {
    $65 = (mftCall_iiiii($1|0,($0|0),($5|0),($$090|0),($7|0))|0);
    $66 = ($65|0)==(0);
    if (!($66)) {
     $$3 = $65;
     break;
    }
   }
   $67 = ($4|0)==(0|0);
   if (!($67)) {
    $68 = HEAP32[$5>>2]|0;
    $69 = HEAP32[$46>>2]|0;
    $$08798 = $4;
    while(1) {
     $70 = ((($$08798)) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==($68|0);
     if ($72) {
      $73 = ((($$08798)) + 8|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==($69|0);
      if ($75) {
       $$3 = 0;
       break L19;
      }
     }
     $76 = HEAP32[$$08798>>2]|0;
     $77 = ($76|0)==(0|0);
     if ($77) {
      break;
     } else {
      $$08798 = $76;
     }
    }
   }
   $78 = $$090 | 4;
   $79 = ($78|0)==(6);
   $80 = ($2|0)!=(0);
   $or$cond6 = $80 & $79;
   do {
    if ($or$cond6) {
     $81 = (_opendir($0)|0);
     $82 = ($81|0)==(0|0);
     if ($82) {
      $106 = (___errno_location()|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ($107|0)==(13);
      if ($108) {
       break;
      } else {
       $$3 = -1;
       break L19;
      }
     }
     $83 = (_readdir($81)|0);
     $84 = ($83|0)==(0|0);
     L44: do {
      if (!($84)) {
       $85 = (4096 - ($8))|0;
       $86 = (($0) + ($87)|0);
       $88 = ((($86)) + 1|0);
       $89 = (($2) + -1)|0;
       $91 = $83;
       while(1) {
        $90 = ((($91)) + 11|0);
        $92 = HEAP8[$90>>0]|0;
        $93 = ($92<<24>>24)==(46);
        L48: do {
         if ($93) {
          $94 = ((($91)) + 12|0);
          $95 = HEAP8[$94>>0]|0;
          switch ($95<<24>>24) {
          case 0:  {
           break L48;
           break;
          }
          case 46:  {
           break;
          }
          default: {
           label = 33;
           break L48;
          }
          }
          $96 = ((($91)) + 13|0);
          $97 = HEAP8[$96>>0]|0;
          $98 = ($97<<24>>24)==(0);
          if (!($98)) {
           label = 33;
          }
         } else {
          label = 33;
         }
        } while(0);
        if ((label|0) == 33) {
         label = 0;
         $101 = (_strlen($90)|0);
         $102 = ($101>>>0)<($85>>>0);
         if (!($102)) {
          label = 34;
          break;
         }
         HEAP8[$86>>0] = 47;
         (_strcpy($88,$90)|0);
         $104 = (_do_nftw($0,$1,$89,$3,$6)|0);
         $105 = ($104|0)==(0);
         if (!($105)) {
          label = 36;
          break;
         }
        }
        $99 = (_readdir($81)|0);
        $100 = ($99|0)==(0|0);
        if ($100) {
         break L44;
        } else {
         $91 = $99;
        }
       }
       if ((label|0) == 34) {
        $103 = (___errno_location()|0);
        HEAP32[$103>>2] = 36;
        (_closedir($81)|0);
        $$3 = -1;
        break L19;
       }
       else if ((label|0) == 36) {
        (_closedir($81)|0);
        $$3 = $104;
        break L19;
       }
      }
     } while(0);
     (_closedir($81)|0);
    }
   } while(0);
   $109 = (($0) + ($8)|0);
   HEAP8[$109>>0] = 0;
   if ($64) {
    $110 = (mftCall_iiiii($1|0,($0|0),($5|0),($$090|0),($7|0))|0);
    $111 = ($110|0)==(0);
    if (!($111)) {
     $$3 = $110;
     break;
    }
   }
   $$3 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$3|0);
}
function _setpriority($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $2;
 $3 = (___syscall97(97,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _gethostid() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _forkpty($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0 = 0, $$09 = 0, $$110 = 0, $$111 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(304|0);
 $4 = sp + 288|0;
 $5 = sp + 284|0;
 $6 = sp + 280|0;
 $7 = sp + 272|0;
 $8 = sp + 264|0;
 $9 = sp + 136|0;
 $10 = sp + 8|0;
 $11 = sp;
 HEAP32[$6>>2] = 0;
 $12 = (_openpty($4,$5,$1,$2,$3)|0);
 $13 = ($12|0)<(0);
 do {
  if ($13) {
   $$09 = -1;
  } else {
   (_sigfillset(($9|0))|0);
   (_pthread_sigmask(0,($9|0),($10|0))|0);
   (_pthread_setcancelstate(1,($8|0))|0);
   $14 = (_pipe2($7,524288)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $18 = (_fork()|0);
    $19 = ($18|0)==(0);
    if ($19) {
     $20 = HEAP32[$4>>2]|0;
     (_close($20)|0);
     $21 = HEAP32[$7>>2]|0;
     (_close($21)|0);
     $22 = HEAP32[$5>>2]|0;
     $23 = (_login_tty($22)|0);
     $24 = ($23|0)==(0);
     $25 = ((($7)) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     if ($24) {
      (_close($26)|0);
      $28 = HEAP32[$8>>2]|0;
      (_pthread_setcancelstate(($28|0),(0|0))|0);
      (_pthread_sigmask(2,($10|0),(0|0))|0);
      $$09 = 0;
      break;
     } else {
      $27 = (___errno_location()|0);
      (_write($26,$27,4)|0);
      __exit(127);
      // unreachable;
     }
    }
    $29 = HEAP32[$5>>2]|0;
    (_close($29)|0);
    $30 = ((($7)) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    (_close($31)|0);
    $32 = HEAP32[$7>>2]|0;
    $33 = (_read($32,$6,4)|0);
    $34 = ($33|0)>(0);
    if ($34) {
     (_waitpid(($18|0),($11|0),0)|0);
     $35 = HEAP32[$6>>2]|0;
     $36 = (___errno_location()|0);
     HEAP32[$36>>2] = $35;
     $$0 = -1;
    } else {
     $$0 = $18;
    }
    $37 = HEAP32[$7>>2]|0;
    (_close($37)|0);
    $38 = ($$0|0)>(0);
    $39 = HEAP32[$4>>2]|0;
    if ($38) {
     HEAP32[$0>>2] = $39;
     $$110 = $$0;
    } else {
     $$111 = $$0;$40 = $39;
     label = 12;
    }
   } else {
    $16 = HEAP32[$5>>2]|0;
    (_close($16)|0);
    $17 = HEAP32[$4>>2]|0;
    $$111 = -1;$40 = $17;
    label = 12;
   }
   if ((label|0) == 12) {
    (_close($40)|0);
    $$110 = $$111;
   }
   $41 = HEAP32[$8>>2]|0;
   (_pthread_setcancelstate(($41|0),(0|0))|0);
   (_pthread_sigmask(2,($10|0),(0|0))|0);
   $$09 = $$110;
  }
 } while(0);
 STACKTOP = sp;return ($$09|0);
}
function _openpty($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $spec$select = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer11 = sp + 64|0;
 $vararg_buffer9 = sp + 56|0;
 $vararg_buffer6 = sp + 48|0;
 $vararg_buffer3 = sp + 40|0;
 $vararg_buffer1 = sp + 32|0;
 $vararg_buffer = sp + 24|0;
 $5 = sp + 72|0;
 $6 = sp + 68|0;
 $7 = sp;
 HEAP32[$5>>2] = 0;
 $8 = (_open((gb + (167695) | 0),258,$vararg_buffer)|0);
 $9 = ($8|0)<(0);
 do {
  if ($9) {
   $$0 = -1;
  } else {
   (_pthread_setcancelstate(1,($6|0))|0);
   HEAP32[$vararg_buffer1>>2] = $5;
   $10 = (_ioctl($8,1074025521,$vararg_buffer1)|0);
   $11 = ($10|0)==(0);
   if ($11) {
    HEAP32[$vararg_buffer3>>2] = $5;
    $12 = (_ioctl($8,-2147199952,$vararg_buffer3)|0);
    $13 = ($12|0)==(0);
    if ($13) {
     $14 = ($2|0)==(0|0);
     $spec$select = $14 ? $7 : $2;
     $15 = HEAP32[$5>>2]|0;
     HEAP32[$vararg_buffer6>>2] = $15;
     (_snprintf($spec$select,20,(gb + (167526) | 0),$vararg_buffer6)|0);
     $16 = (_open($spec$select,258,$vararg_buffer9)|0);
     $17 = ($16|0)<(0);
     if (!($17)) {
      $18 = ($3|0)==(0|0);
      if (!($18)) {
       (_tcsetattr($16,0,$3)|0);
      }
      $19 = ($4|0)==(0|0);
      if (!($19)) {
       HEAP32[$vararg_buffer11>>2] = $4;
       (_ioctl($16,21524,$vararg_buffer11)|0);
      }
      HEAP32[$0>>2] = $8;
      HEAP32[$1>>2] = $16;
      $20 = HEAP32[$6>>2]|0;
      (_pthread_setcancelstate(($20|0),(0|0))|0);
      $$0 = 0;
      break;
     }
    }
   }
   (_close($8)|0);
   $21 = HEAP32[$6>>2]|0;
   (_pthread_setcancelstate(($21|0),(0|0))|0);
   $$0 = -1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _fmtmsg($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$078 = 0, $$07994 = 0, $$08493 = 0, $$095 = 0, $$182 = 0, $$283 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $cond = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond9 = 0, $spec$select = 0;
 var $spec$select87 = 0, $spec$select88 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr17 = 0, $vararg_ptr18 = 0, $vararg_ptr19 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $vararg_buffer10 = sp + 40|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $6 = sp + 72|0;
 $7 = (_getenv(((gb + (167538) | 0)|0))|0);
 (_pthread_setcancelstate(1,($6|0))|0);
 switch ($2|0) {
 case 1:  {
  $$078 = (gb + (167571) | 0);
  break;
 }
 case 2:  {
  $$078 = (gb + (167546) | 0);
  break;
 }
 case 3:  {
  $$078 = (gb + (167554) | 0);
  break;
 }
 case 4:  {
  $$078 = (gb + (167564) | 0);
  break;
 }
 default: {
  $$078 = 0;
 }
 }
 $8 = $0 & 512;
 $9 = ($8|0)==(0);
 if ($9) {
  $$182 = 0;
 } else {
  $10 = (_open((gb + (167677) | 0),1,$vararg_buffer)|0);
  $11 = ($10|0)<(0);
  if ($11) {
   $$182 = 4;
  } else {
   $12 = ($1|0)!=(0|0);
   $13 = $12 ? $1 : (gb + (172139) | 0);
   $14 = $12 ? (gb + (167578) | 0) : (gb + (172139) | 0);
   $15 = ($2|0)==(0);
   $16 = $15 ? (gb + (172139) | 0) : $$078;
   $17 = ($3|0)==(0|0);
   $18 = $17 ? (gb + (172139) | 0) : $3;
   $19 = ($4|0)!=(0|0);
   $20 = $19 ? (gb + (167581) | 0) : (gb + (172139) | 0);
   $21 = $19 ? $4 : (gb + (172139) | 0);
   $22 = $19 ? (gb + (167591) | 0) : (gb + (172139) | 0);
   $23 = ($5|0)==(0|0);
   $24 = $23 ? (gb + (172139) | 0) : $5;
   HEAP32[$vararg_buffer1>>2] = $13;
   $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr3>>2] = $14;
   $vararg_ptr4 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr4>>2] = $16;
   $vararg_ptr5 = ((($vararg_buffer1)) + 12|0);
   HEAP32[$vararg_ptr5>>2] = $18;
   $vararg_ptr6 = ((($vararg_buffer1)) + 16|0);
   HEAP32[$vararg_ptr6>>2] = $20;
   $vararg_ptr7 = ((($vararg_buffer1)) + 20|0);
   HEAP32[$vararg_ptr7>>2] = $21;
   $vararg_ptr8 = ((($vararg_buffer1)) + 24|0);
   HEAP32[$vararg_ptr8>>2] = $22;
   $vararg_ptr9 = ((($vararg_buffer1)) + 28|0);
   HEAP32[$vararg_ptr9>>2] = $24;
   $25 = (_dprintf($10,(gb + (167593) | 0),$vararg_buffer1)|0);
   $26 = ($25|0)<(1);
   $spec$select = $26 ? 4 : 0;
   (_close($10)|0);
   $$182 = $spec$select;
  }
 }
 $27 = $0 & 256;
 $28 = ($27|0)==(0);
 if ($28) {
  $$283 = $$182;
 } else {
  $29 = ($7|0)==(0|0);
  L13: do {
   if ($29) {
    label = 18;
   } else {
    $$07994 = 0;$$095 = $7;
    while(1) {
     $30 = HEAP8[$$095>>0]|0;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      break;
     }
     $$08493 = 0;
     while(1) {
      $32 = ((gb + (154384) | 0) + ($$08493<<2)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (__strcolcmp($33,$$095)|0);
      $35 = ($34|0)==(0);
      if ($35) {
       break;
      }
      $36 = (($$08493) + 1)|0;
      $cond = ($36|0)==(5);
      if ($cond) {
       $44 = 255;
       break L13;
      } else {
       $$08493 = $36;
      }
     }
     $37 = 1 << $$08493;
     $38 = $37 | $$07994;
     $39 = (_strchr($$095,58)|0);
     $40 = ($39|0)==(0|0);
     $41 = ((($39)) + 1|0);
     if ($40) {
      $44 = $38;
      break L13;
     } else {
      $$07994 = $38;$$095 = $41;
     }
    }
    $42 = ($$07994|0)==(0);
    if ($42) {
     label = 18;
    } else {
     $44 = $$07994;
    }
   }
  } while(0);
  if ((label|0) == 18) {
   $44 = 255;
  }
  $43 = $44 & 1;
  $45 = ($43|0)!=(0);
  $46 = ($1|0)!=(0|0);
  $or$cond = $46 & $45;
  $47 = $or$cond ? $1 : (gb + (172139) | 0);
  $48 = $or$cond ? (gb + (167578) | 0) : (gb + (172139) | 0);
  $49 = $44 & 2;
  $50 = ($49|0)!=(0);
  $51 = ($2|0)!=(0);
  $or$cond3 = $51 & $50;
  $52 = $or$cond3 ? $$078 : (gb + (172139) | 0);
  $53 = $44 & 4;
  $54 = ($53|0)!=(0);
  $55 = ($3|0)!=(0|0);
  $or$cond5 = $55 & $54;
  $56 = $or$cond5 ? $3 : (gb + (172139) | 0);
  $57 = $44 & 8;
  $58 = ($57|0)!=(0);
  $59 = ($4|0)!=(0|0);
  $60 = $59 & $58;
  $61 = $60 ? (gb + (167581) | 0) : (gb + (172139) | 0);
  $62 = $60 ? $4 : (gb + (172139) | 0);
  $63 = $60 ? (gb + (167591) | 0) : (gb + (172139) | 0);
  $64 = $44 & 16;
  $65 = ($64|0)!=(0);
  $66 = ($5|0)!=(0|0);
  $or$cond9 = $66 & $65;
  $67 = $or$cond9 ? $5 : (gb + (172139) | 0);
  HEAP32[$vararg_buffer10>>2] = $47;
  $vararg_ptr13 = ((($vararg_buffer10)) + 4|0);
  HEAP32[$vararg_ptr13>>2] = $48;
  $vararg_ptr14 = ((($vararg_buffer10)) + 8|0);
  HEAP32[$vararg_ptr14>>2] = $52;
  $vararg_ptr15 = ((($vararg_buffer10)) + 12|0);
  HEAP32[$vararg_ptr15>>2] = $56;
  $vararg_ptr16 = ((($vararg_buffer10)) + 16|0);
  HEAP32[$vararg_ptr16>>2] = $61;
  $vararg_ptr17 = ((($vararg_buffer10)) + 20|0);
  HEAP32[$vararg_ptr17>>2] = $62;
  $vararg_ptr18 = ((($vararg_buffer10)) + 24|0);
  HEAP32[$vararg_ptr18>>2] = $63;
  $vararg_ptr19 = ((($vararg_buffer10)) + 28|0);
  HEAP32[$vararg_ptr19>>2] = $67;
  $68 = (_dprintf(2,(gb + (167593) | 0),$vararg_buffer10)|0);
  $69 = ($68|0)<(1);
  $70 = $69&1;
  $spec$select88 = $$182 | $70;
  $$283 = $spec$select88;
 }
 $71 = $$283 & 5;
 $72 = ($71|0)==(5);
 $spec$select87 = $72 ? -1 : $$283;
 $73 = HEAP32[$6>>2]|0;
 (_pthread_setcancelstate(($73|0),(0|0))|0);
 STACKTOP = sp;return ($spec$select87|0);
}
function __strcolcmp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$017 = 0, $$019 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP8[$0>>0]|0;
 $3 = ($2<<24>>24)==(0);
 $4 = HEAP8[$1>>0]|0;
 L1: do {
  if ($3) {
   $$lcssa = $4;
   label = 5;
  } else {
   $$019 = 0;$12 = $4;$14 = $2;
   while(1) {
    $11 = ($12<<24>>24)!=(0);
    $13 = ($12<<24>>24)==($14<<24>>24);
    $or$cond = $11 & $13;
    $6 = (($$019) + 1)|0;
    if (!($or$cond)) {
     $$017 = 1;
     break L1;
    }
    $5 = (($0) + ($6)|0);
    $7 = HEAP8[$5>>0]|0;
    $8 = ($7<<24>>24)==(0);
    $9 = (($1) + ($6)|0);
    $10 = HEAP8[$9>>0]|0;
    if ($8) {
     $$lcssa = $10;
     label = 5;
     break;
    } else {
     $$019 = $6;$12 = $10;$14 = $7;
    }
   }
  }
 } while(0);
 L6: do {
  if ((label|0) == 5) {
   switch ($$lcssa<<24>>24) {
   case 58: case 0:  {
    break;
   }
   default: {
    $$017 = 1;
    break L6;
   }
   }
   $$017 = 0;
  }
 } while(0);
 return ($$017|0);
}
function _ffsl($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (_a_ctz_l_647($0)|0);
  $3 = (($2) + 1)|0;
  $4 = $3;
 }
 return ($4|0);
}
function _a_ctz_l_647($0) {
 $0 = $0|0;
 var $$068 = 0, $$07 = 0, $$09 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$07 = 32;
 } else {
  $2 = $0 & 1;
  $3 = ($2|0)==(0);
  if ($3) {
   $$068 = $0;$$09 = 0;
   while(1) {
    $4 = (($$09) + 1)|0;
    $5 = $$068 >>> 1;
    $6 = $$068 & 2;
    $7 = ($6|0)==(0);
    if ($7) {
     $$068 = $5;$$09 = $4;
    } else {
     $$07 = $4;
     break;
    }
   }
  } else {
   $$07 = 0;
  }
 }
 return ($$07|0);
}
function _setlogmask($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ___lock(((gb + (172100) | 0)|0));
 $1 = HEAP32[(gb + (166332) | 0)>>2]|0;
 $2 = ($0|0)==(0);
 if (!($2)) {
  HEAP32[(gb + (166332) | 0)>>2] = $0;
 }
 ___unlock(((gb + (172100) | 0)|0));
 return ($1|0);
}
function _closelog() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $0 = sp;
 (_pthread_setcancelstate(1,($0|0))|0);
 ___lock(((gb + (172100) | 0)|0));
 $1 = HEAP32[(gb + (166336) | 0)>>2]|0;
 (_close($1)|0);
 HEAP32[(gb + (166336) | 0)>>2] = -1;
 ___unlock(((gb + (172100) | 0)|0));
 $2 = HEAP32[$0>>2]|0;
 (_pthread_setcancelstate(($2|0),(0|0))|0);
 STACKTOP = sp;return;
}
function _openlog($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 (_pthread_setcancelstate(1,($3|0))|0);
 ___lock(((gb + (172100) | 0)|0));
 $4 = ($0|0)==(0|0);
 if ($4) {
  HEAP8[(gb + (170592) | 0)>>0] = 0;
 } else {
  $5 = (_strnlen($0,31)|0);
  (_memcpy(((gb + (170592) | 0)|0),($0|0),($5|0))|0);
  $6 = ((gb + (170592) | 0) + ($5)|0);
  HEAP8[$6>>0] = 0;
 }
 HEAP32[(gb + (172108) | 0)>>2] = $1;
 HEAP32[(gb + (166340) | 0)>>2] = $2;
 $7 = $1 & 8;
 $8 = ($7|0)!=(0);
 $9 = HEAP32[(gb + (166336) | 0)>>2]|0;
 $10 = ($9|0)<(0);
 $or$cond = $8 & $10;
 if ($or$cond) {
  ___openlog();
 }
 ___unlock(((gb + (172100) | 0)|0));
 $11 = HEAP32[$3>>2]|0;
 (_pthread_setcancelstate(($11|0),(0|0))|0);
 STACKTOP = sp;return;
}
function ___openlog() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_socket(1,524290,0)|0);
 HEAP32[(gb + (166336) | 0)>>2] = $0;
 $1 = ($0|0)>(-1);
 if ($1) {
  (_connect($0,(gb + (166370) | 0),12)|0);
 }
 return;
}
function ___vsyslog($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = HEAP32[(gb + (166332) | 0)>>2]|0;
 $5 = $0 & 7;
 $6 = 1 << $5;
 $7 = $4 & $6;
 $8 = ($7|0)==(0);
 $9 = ($0>>>0)>(1023);
 $or$cond = $9 | $8;
 if (!($or$cond)) {
  (_pthread_setcancelstate(1,($3|0))|0);
  ___lock(((gb + (172100) | 0)|0));
  __vsyslog($0,$1,$2);
  ___unlock(((gb + (172100) | 0)|0));
  $10 = HEAP32[$3>>2]|0;
  (_pthread_setcancelstate(($10|0),(0|0))|0);
 }
 STACKTOP = sp;return;
}
function __vsyslog($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$0 = 0, $$033 = 0, $$1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer13 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1152|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(1152|0);
 $vararg_buffer13 = sp + 1088|0;
 $vararg_buffer9 = sp + 1080|0;
 $vararg_buffer7 = sp + 1072|0;
 $vararg_buffer = sp + 1040|0;
 $3 = sp + 1024|0;
 $4 = sp + 1144|0;
 $5 = sp + 1100|0;
 $6 = sp;
 $7 = sp + 1096|0;
 $8 = (___errno_location()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[(gb + (166336) | 0)>>2]|0;
 $11 = ($10|0)<(0);
 if ($11) {
  ___openlog();
 }
 $12 = $0 & 1016;
 $13 = ($12|0)==(0);
 $14 = HEAP32[(gb + (166340) | 0)>>2]|0;
 $15 = $13 ? $14 : 0;
 $$0 = $15 | $0;
 $16 = (_time((0|0))|0);
 HEAP32[$4>>2] = $16;
 (_gmtime_r(($4|0),($5|0))|0);
 (_strftime(($3|0),16,((gb + (167642) | 0)|0),($5|0))|0);
 $17 = HEAP32[(gb + (172108) | 0)>>2]|0;
 $18 = $17 & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $22 = 0;
 } else {
  $20 = (_getpid()|0);
  $22 = $20;
 }
 $21 = ($22|0)==(0);
 $23 = $21&1;
 $24 = ((gb + (167651) | 0) + ($23)|0);
 $25 = ((gb + (167653) | 0) + ($23)|0);
 HEAP32[$vararg_buffer>>2] = $$0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $3;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $7;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = (gb + (170592) | 0);
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $24;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $22;
 $vararg_ptr6 = ((($vararg_buffer)) + 24|0);
 HEAP32[$vararg_ptr6>>2] = $25;
 $26 = (_snprintf($6,1024,(gb + (167655) | 0),$vararg_buffer)|0);
 $27 = (___errno_location()|0);
 HEAP32[$27>>2] = $9;
 $28 = (($6) + ($26)|0);
 $29 = (1024 - ($26))|0;
 $30 = (_vsnprintf($28,$29,$1,$2)|0);
 $31 = ($30|0)>(-1);
 if ($31) {
  $32 = ($30>>>0)<($29>>>0);
  $33 = (($30) + ($26))|0;
  $$033 = $32 ? $33 : 1023;
  $34 = (($$033) + -1)|0;
  $35 = (($6) + ($34)|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = ($36<<24>>24)==(10);
  if ($37) {
   $$1 = $$033;
  } else {
   $38 = (($6) + ($$033)|0);
   $39 = (($$033) + 1)|0;
   HEAP8[$38>>0] = 10;
   $$1 = $39;
  }
  $40 = HEAP32[(gb + (166336) | 0)>>2]|0;
  $41 = (_send($40,$6,$$1,0)|0);
  $42 = ($41|0)<(0);
  do {
   if ($42) {
    $43 = (___errno_location()|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (_is_lost_conn($44)|0);
    $46 = ($45|0)==(0);
    if (!($46)) {
     $47 = HEAP32[(gb + (166336) | 0)>>2]|0;
     $48 = (_connect($47,(gb + (166370) | 0),12)|0);
     $49 = ($48|0)<(0);
     if (!($49)) {
      $50 = HEAP32[(gb + (166336) | 0)>>2]|0;
      $51 = (_send($50,$6,$$1,0)|0);
      $52 = ($51|0)<(0);
      if (!($52)) {
       break;
      }
     }
    }
    $53 = HEAP32[(gb + (172108) | 0)>>2]|0;
    $54 = $53 & 2;
    $55 = ($54|0)==(0);
    if (!($55)) {
     $56 = (_open((gb + (167677) | 0),524545,$vararg_buffer7)|0);
     $57 = ($56|0)>(-1);
     if ($57) {
      $58 = HEAP32[$7>>2]|0;
      $59 = (($$1) - ($58))|0;
      $60 = (($6) + ($58)|0);
      HEAP32[$vararg_buffer9>>2] = $59;
      $vararg_ptr12 = ((($vararg_buffer9)) + 4|0);
      HEAP32[$vararg_ptr12>>2] = $60;
      (_dprintf($56,(gb + (167690) | 0),$vararg_buffer9)|0);
      (_close($56)|0);
     }
    }
   }
  } while(0);
  $61 = HEAP32[(gb + (172108) | 0)>>2]|0;
  $62 = $61 & 32;
  $63 = ($62|0)==(0);
  if (!($63)) {
   $64 = HEAP32[$7>>2]|0;
   $65 = (($$1) - ($64))|0;
   $66 = (($6) + ($64)|0);
   HEAP32[$vararg_buffer13>>2] = $65;
   $vararg_ptr16 = ((($vararg_buffer13)) + 4|0);
   HEAP32[$vararg_ptr16>>2] = $66;
   (_dprintf(2,(gb + (167690) | 0),$vararg_buffer13)|0);
  }
 }
 STACKTOP = sp;return;
}
function _is_lost_conn($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($0|0) {
 case 104: case 107: case 111:  {
  $2 = 1;
  break;
 }
 default: {
  $1 = ($0|0)==(32);
  $phitmp = $1&1;
  $2 = $phitmp;
 }
 }
 return ($2|0);
}
function _syslog($0,$1,$varargs) {
 $0 = $0|0;
 $1 = $1|0;
 $varargs = $varargs|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $varargs;
 ___vsyslog($0,$1,$2);
 STACKTOP = sp;return;
}
function _setdomainname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $2 = $0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $3 = (___syscall121(121,($vararg_buffer|0))|0);
 $4 = (___syscall_ret($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _getauxval($0) {
 $0 = $0|0;
 var $$06 = 0, $$08 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(23);
 L1: do {
  if ($1) {
   $2 = HEAP32[((((gb + (171204) | 0)) + 8|0))>>2]|0;
   $$06 = $2;
  } else {
   $3 = HEAP32[((((gb + (171204) | 0)) + 16|0))>>2]|0;
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   L4: do {
    if (!($5)) {
     $$08 = $3;$7 = $4;
     while(1) {
      $6 = ($7|0)==($0|0);
      if ($6) {
       break;
      }
      $10 = ((($$08)) + 8|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)==(0);
      if ($12) {
       break L4;
      } else {
       $$08 = $10;$7 = $11;
      }
     }
     $8 = ((($$08)) + 4|0);
     $9 = HEAP32[$8>>2]|0;
     $$06 = $9;
     break L1;
    }
   } while(0);
   $13 = (___errno_location()|0);
   HEAP32[$13>>2] = 2;
   $$06 = 0;
  }
 } while(0);
 return ($$06|0);
}
function _ffsll($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0);
 $3 = ($1|0)==(0);
 $4 = $2 & $3;
 if ($4) {
  $7 = 0;
 } else {
  $5 = (_a_ctz_64($0,$1)|0);
  $6 = (($5) + 1)|0;
  $7 = $6;
 }
 return ($7|0);
}
function _a_ctz_64($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($0|0)==(0);
 if ($2) {
  $3 = (_a_ctz_l_659($1)|0);
  $4 = (($3) + 32)|0;
  $$0 = $4;
 } else {
  $5 = (_a_ctz_l_659($0)|0);
  $$0 = $5;
 }
 return ($$0|0);
}
function _a_ctz_l_659($0) {
 $0 = $0|0;
 var $$068 = 0, $$07 = 0, $$09 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$07 = 32;
 } else {
  $2 = $0 & 1;
  $3 = ($2|0)==(0);
  if ($3) {
   $$068 = $0;$$09 = 0;
   while(1) {
    $4 = (($$09) + 1)|0;
    $5 = $$068 >>> 1;
    $6 = $$068 & 2;
    $7 = ($6|0)==(0);
    if ($7) {
     $$068 = $5;$$09 = $4;
    } else {
     $$07 = $4;
     break;
    }
   }
  } else {
   $$07 = 0;
  }
 }
 return ($$07|0);
}
function _getrlimit($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = sp + 24|0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = 0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 0;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $3;
 $4 = (___syscall340(340,($vararg_buffer|0))|0);
 $5 = (___syscall_ret($4)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = $1;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = ($9|0)==(-1);
  $14 = ($12|0)==(-1);
  $15 = $13 & $14;
  if ($15) {
   $16 = $1;
   $17 = $16;
   HEAP32[$17>>2] = -1;
   $18 = (($16) + 4)|0;
   $19 = $18;
   HEAP32[$19>>2] = -1;
  }
  $20 = ((($1)) + 8|0);
  $21 = $20;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 4)|0;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = ($23|0)==(-1);
  $28 = ($26|0)==(-1);
  $29 = $27 & $28;
  if ($29) {
   $30 = $20;
   $31 = $30;
   HEAP32[$31>>2] = -1;
   $32 = (($30) + 4)|0;
   $33 = $32;
   HEAP32[$33>>2] = -1;
   $$0 = 0;
  } else {
   $$0 = 0;
  }
 } else {
  $34 = (___errno_location()|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(38);
  if ($36) {
   $37 = $2;
   HEAP32[$vararg_buffer4>>2] = $0;
   $vararg_ptr7 = ((($vararg_buffer4)) + 4|0);
   HEAP32[$vararg_ptr7>>2] = $37;
   $38 = (___syscall191(191,($vararg_buffer4|0))|0);
   $39 = (___syscall_ret($38)|0);
   $40 = ($39|0)<(0);
   if ($40) {
    $$0 = -1;
   } else {
    $41 = HEAP32[$2>>2]|0;
    $42 = ($41|0)==(-1);
    $43 = $42 ? -1 : $41;
    $44 = $42 ? -1 : 0;
    $45 = $1;
    $46 = $45;
    HEAP32[$46>>2] = $43;
    $47 = (($45) + 4)|0;
    $48 = $47;
    HEAP32[$48>>2] = $44;
    $49 = ((($2)) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(-1);
    $52 = $51 ? -1 : $50;
    $53 = $51 ? -1 : 0;
    $54 = ((($1)) + 8|0);
    $55 = $54;
    $56 = $55;
    HEAP32[$56>>2] = $52;
    $57 = (($55) + 4)|0;
    $58 = $57;
    HEAP32[$58>>2] = $53;
    if ($42) {
     $59 = $1;
     $60 = $59;
     HEAP32[$60>>2] = -1;
     $61 = (($59) + 4)|0;
     $62 = $61;
     HEAP32[$62>>2] = -1;
    }
    if ($51) {
     $63 = $54;
     $64 = $63;
     HEAP32[$64>>2] = -1;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = -1;
     $$0 = 0;
    } else {
     $$0 = 0;
    }
   }
  } else {
   $$0 = $5;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _basename($0) {
 $0 = $0|0;
 var $$0 = 0, $$017 = 0, $$021 = 0, $$022 = 0, $$1$lcssa = 0, $$118 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$017 = (gb + (167711) | 0);
 } else {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   $$017 = (gb + (167711) | 0);
  } else {
   $4 = (_strlen($0)|0);
   $$021 = (($4) + -1)|0;
   $5 = ($$021|0)==(0);
   L4: do {
    if ($5) {
     $$1$lcssa = 0;
    } else {
     $$022 = $$021;
     while(1) {
      $6 = (($0) + ($$022)|0);
      $7 = HEAP8[$6>>0]|0;
      $8 = ($7<<24>>24)==(47);
      if (!($8)) {
       break;
      }
      HEAP8[$6>>0] = 0;
      $$0 = (($$022) + -1)|0;
      $9 = ($$0|0)==(0);
      if ($9) {
       $$1$lcssa = 0;
       break L4;
      } else {
       $$022 = $$0;
      }
     }
     $$118 = $$022;
     while(1) {
      $11 = (($$118) + -1)|0;
      $12 = (($0) + ($11)|0);
      $13 = HEAP8[$12>>0]|0;
      $14 = ($13<<24>>24)==(47);
      if ($14) {
       $$1$lcssa = $$118;
       break L4;
      }
      $10 = ($11|0)==(0);
      if ($10) {
       $$1$lcssa = 0;
       break;
      } else {
       $$118 = $11;
      }
     }
    }
   } while(0);
   $15 = (($0) + ($$1$lcssa)|0);
   $$017 = $15;
  }
 }
 return ($$017|0);
}
function _posix_openpt($0) {
 $0 = $0|0;
 var $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = (_open((gb + (167695) | 0),$0,$vararg_buffer)|0);
 STACKTOP = sp;return ($1|0);
}
function _grantpt($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _unlockpt($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 HEAP32[$1>>2] = 0;
 HEAP32[$vararg_buffer>>2] = $1;
 $2 = (_ioctl($0,1074025521,$vararg_buffer)|0);
 STACKTOP = sp;return ($2|0);
}
function ___setrlimit($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer = sp;
 $2 = sp + 24|0;
 $3 = $1;
 HEAP32[$vararg_buffer>>2] = 0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $3;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = 0;
 $4 = (___syscall340(340,($vararg_buffer|0))|0);
 $5 = ($4|0)==(-38);
 if ($5) {
  $6 = $1;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11>>>0)<(0);
  $13 = ($8>>>0)<(4294967295);
  $14 = ($11|0)==(0);
  $15 = $14 & $13;
  $16 = $12 | $15;
  $17 = $16 ? $8 : -1;
  $16 ? $11 : 0;
  HEAP32[$2>>2] = $17;
  $18 = ((($1)) + 8|0);
  $19 = $18;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($19) + 4)|0;
  $23 = $22;
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24>>>0)<(0);
  $26 = ($21>>>0)<(4294967295);
  $27 = ($24|0)==(0);
  $28 = $27 & $26;
  $29 = $25 | $28;
  $30 = $29 ? $21 : -1;
  $29 ? $24 : 0;
  $31 = ((($2)) + 4|0);
  HEAP32[$31>>2] = $30;
  $32 = $2;
  HEAP32[$vararg_buffer4>>2] = $0;
  $vararg_ptr7 = ((($vararg_buffer4)) + 4|0);
  HEAP32[$vararg_ptr7>>2] = $32;
  $33 = (___syscall75(75,($vararg_buffer4|0))|0);
  $$0 = $33;
 } else {
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function _setrlimit($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 HEAP32[$2>>2] = $1;
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = $0;
 $4 = ((($2)) + 8|0);
 HEAP32[$4>>2] = -1;
 ___synccall((fb + (38) | 0),$2);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 0;
 } else {
  $7 = ($5|0)>(0);
  if ($7) {
   $8 = (___errno_location()|0);
   HEAP32[$8>>2] = $5;
   $$0 = -1;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _do_setrlimit($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  $4 = ((($0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$0>>2]|0;
  $7 = (___setrlimit($5,$6)|0);
  $8 = (0 - ($7))|0;
  HEAP32[$1>>2] = $8;
 }
 return;
}
function _getsubopt($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$03134 = 0, $$2 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = 0;
 $4 = (_strchr($3,44)|0);
 HEAP32[$0>>2] = $4;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $7 = (_strlen($3)|0);
  $8 = (($3) + ($7)|0);
  HEAP32[$0>>2] = $8;
 } else {
  $6 = ((($4)) + 1|0);
  HEAP32[$0>>2] = $6;
  HEAP8[$4>>0] = 0;
 }
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0|0);
 L5: do {
  if ($10) {
   $$2 = -1;
  } else {
   $$03134 = 0;$11 = $9;
   L7: while(1) {
    $12 = (_strlen($11)|0);
    $13 = (_strncmp($11,$3,$12)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     $15 = (($3) + ($12)|0);
     $16 = HEAP8[$15>>0]|0;
     switch ($16<<24>>24) {
     case 0:  {
      $$2 = $$03134;
      break L5;
      break;
     }
     case 61:  {
      break L7;
      break;
     }
     default: {
     }
     }
    }
    $19 = (($$03134) + 1)|0;
    $20 = (($1) + ($19<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$2 = -1;
     break L5;
    } else {
     $$03134 = $19;$11 = $21;
    }
   }
   $17 = (($3) + ($12)|0);
   $18 = ((($17)) + 1|0);
   HEAP32[$2>>2] = $18;
   $$2 = $$03134;
  }
 } while(0);
 return ($$2|0);
}
function _dirname($0) {
 $0 = $0|0;
 var $$0 = 0, $$019 = 0, $$031 = 0, $$032 = 0, $$126 = 0, $$126$ph = 0, $$225 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0|0);
 L1: do {
  if ($1) {
   $$019 = (gb + (167711) | 0);
  } else {
   $2 = HEAP8[$0>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    $$019 = (gb + (167711) | 0);
   } else {
    $4 = (_strlen($0)|0);
    $$031 = (($4) + -1)|0;
    $5 = (($0) + ($$031)|0);
    $6 = HEAP8[$5>>0]|0;
    $7 = ($6<<24>>24)==(47);
    if ($7) {
     $$032 = $$031;
     while(1) {
      $11 = ($$032|0)==(0);
      if ($11) {
       $$019 = (gb + (167705) | 0);
       break L1;
      }
      $$0 = (($$032) + -1)|0;
      $8 = (($0) + ($$0)|0);
      $9 = HEAP8[$8>>0]|0;
      $10 = ($9<<24>>24)==(47);
      if ($10) {
       $$032 = $$0;
      } else {
       $$126$ph = $$0;
       break;
      }
     }
    } else {
     $$126$ph = $$031;
    }
    $$126 = $$126$ph;
    while(1) {
     $12 = ($$126|0)==(0);
     if ($12) {
      $$019 = (gb + (167711) | 0);
      break L1;
     }
     $13 = (($$126) + -1)|0;
     $14 = (($0) + ($13)|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)==(47);
     if ($16) {
      break;
     } else {
      $$126 = $13;
     }
    }
    $$225 = $13;
    while(1) {
     $17 = ($$225|0)==(0);
     if ($17) {
      $$019 = (gb + (167705) | 0);
      break L1;
     }
     $18 = (($$225) + -1)|0;
     $19 = (($0) + ($18)|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($20<<24>>24)==(47);
     if ($21) {
      $$225 = $18;
     } else {
      break;
     }
    }
    $22 = (($0) + ($$225)|0);
    HEAP8[$22>>0] = 0;
    $$019 = $0;
   }
  }
 } while(0);
 return ($$019|0);
}
function _realpath($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer5 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(4304|0);
 $vararg_buffer5 = sp + 4144|0;
 $vararg_buffer2 = sp + 4136|0;
 $vararg_buffer = sp + 4128|0;
 $2 = sp + 4224|0;
 $3 = sp + 4148|0;
 $4 = sp + 4096|0;
 $5 = sp;
 $6 = ($0|0)==(0|0);
 do {
  if ($6) {
   $7 = (___errno_location()|0);
   HEAP32[$7>>2] = 22;
   $$0 = 0;
  } else {
   $8 = $0;
   HEAP32[$vararg_buffer>>2] = $8;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 2656256;
   $9 = (___syscall5(5,($vararg_buffer|0))|0);
   $10 = (___syscall_ret($9)|0);
   $11 = ($10|0)<(0);
   if ($11) {
    $$0 = 0;
   } else {
    ___procfdname($4,$10);
    $12 = (_readlink($4,$5,4095)|0);
    $13 = ($12|0)<(0);
    if (!($13)) {
     $14 = (($5) + ($12)|0);
     HEAP8[$14>>0] = 0;
     (_fstat($10,$2)|0);
     $15 = (_stat($5,$3)|0);
     $16 = ($15|0)<(0);
     if (!($16)) {
      $17 = HEAP32[$2>>2]|0;
      $18 = HEAP32[$3>>2]|0;
      $19 = ($17|0)==($18|0);
      if ($19) {
       $20 = ((($2)) + 72|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ((($3)) + 72|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($21|0)==($23|0);
       if ($24) {
        HEAP32[$vararg_buffer2>>2] = $10;
        (___syscall6(6,($vararg_buffer2|0))|0);
        $27 = ($1|0)==(0|0);
        if ($27) {
         $29 = (mftCall_ii((fb + (9) | 0)|0,($5|0))|0);
         $$0 = $29;
         break;
        } else {
         $28 = (_strcpy($1,$5)|0);
         $$0 = $1;
         break;
        }
       }
      }
      $25 = ($15|0)==(0);
      if ($25) {
       $26 = (___errno_location()|0);
       HEAP32[$26>>2] = 40;
      }
     }
    }
    HEAP32[$vararg_buffer5>>2] = $10;
    (___syscall6(6,($vararg_buffer5|0))|0);
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _getresuid($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $vararg_buffer = sp;
 $3 = $0;
 $4 = $1;
 $5 = $2;
 HEAP32[$vararg_buffer>>2] = $3;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $4;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $5;
 $6 = (___syscall209(209,($vararg_buffer|0))|0);
 $7 = (___syscall_ret($6)|0);
 STACKTOP = sp;return ($7|0);
}
function _get_current_dir_name() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(160|0);
 $0 = sp + 76|0;
 $1 = sp;
 $2 = (_getenv(((gb + (167707) | 0)|0))|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 8;
 } else {
  $4 = HEAP8[$2>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   label = 8;
  } else {
   $6 = (_stat($2,$0)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    $8 = (_stat((gb + (167711) | 0),$1)|0);
    $9 = ($8|0)==(0);
    if ($9) {
     $10 = HEAP32[$0>>2]|0;
     $11 = HEAP32[$1>>2]|0;
     $12 = ($10|0)==($11|0);
     if ($12) {
      $13 = ((($0)) + 72|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ((($1)) + 72|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($14|0)==($16|0);
      if ($17) {
       $18 = (mftCall_ii((fb + (9) | 0)|0,($2|0))|0);
       $$0 = $18;
      } else {
       label = 8;
      }
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  }
 }
 if ((label|0) == 8) {
  $19 = (_getcwd(0,0)|0);
  $$0 = $19;
 }
 STACKTOP = sp;return ($$0|0);
}
function _issetugid() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((((gb + (171204) | 0)) + 8|0))>>2]|0;
 return ($0|0);
}
function _getdomainname($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(400|0);
 $2 = sp;
 (_uname($2)|0);
 $3 = ($1|0)==(0);
 if ($3) {
  label = 3;
 } else {
  $4 = ((($2)) + 325|0);
  $5 = (_strlen($4)|0);
  $6 = ($5>>>0)<($1>>>0);
  if ($6) {
   (_strcpy($0,$4)|0);
   $$0 = 0;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $7 = (___errno_location()|0);
  HEAP32[$7>>2] = 22;
  $$0 = -1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _ffs($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (_a_ctz_l_671($0)|0);
  $3 = (($2) + 1)|0;
  $4 = $3;
 }
 return ($4|0);
}
function _a_ctz_l_671($0) {
 $0 = $0|0;
 var $$068 = 0, $$07 = 0, $$09 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0|0)==(0);
 if ($1) {
  $$07 = 32;
 } else {
  $2 = $0 & 1;
  $3 = ($2|0)==(0);
  if ($3) {
   $$068 = $0;$$09 = 0;
   while(1) {
    $4 = (($$09) + 1)|0;
    $5 = $$068 >>> 1;
    $6 = $$068 & 2;
    $7 = ($6|0)==(0);
    if ($7) {
     $$068 = $5;$$09 = $4;
    } else {
     $$07 = $4;
     break;
    }
   }
  } else {
   $$07 = 0;
  }
 }
 return ($$07|0);
}
function _getopt_long($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (___getopt_long($0,$1,$2,$3,$4,0)|0);
 return ($5|0);
}
function ___getopt_long($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$0454960 = 0, $$1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre56 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond59 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = HEAP32[(gb + (161696) | 0)>>2]|0;
 $7 = ($6|0)==(0);
 $8 = HEAP32[(gb + (171180) | 0)>>2]|0;
 $9 = ($8|0)!=(0);
 $or$cond = $7 | $9;
 if ($or$cond) {
  HEAP32[(gb + (171180) | 0)>>2] = 0;
  HEAP32[(gb + (171184) | 0)>>2] = 0;
  HEAP32[(gb + (161696) | 0)>>2] = 1;
  $11 = 1;
 } else {
  $11 = $6;
 }
 $10 = ($11|0)<($0|0);
 L4: do {
  if ($10) {
   $12 = (($1) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$1 = -1;
   } else {
    $15 = HEAP8[$2>>0]|0;
    switch ($15<<24>>24) {
    case 45: case 43:  {
     $25 = (___getopt_long_core($0,$1,$2,$3,$4,$5)|0);
     $$1 = $25;
     break L4;
     break;
    }
    default: {
    }
    }
    $$0454960 = $11;$17 = $13;
    while(1) {
     $16 = HEAP8[$17>>0]|0;
     $18 = ($16<<24>>24)==(45);
     if ($18) {
      $19 = ((($17)) + 1|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = ($20<<24>>24)==(0);
      if (!($21)) {
       break;
      }
     }
     $22 = (($$0454960) + 1)|0;
     $23 = ($22|0)<($0|0);
     if (!($23)) {
      $$1 = -1;
      break L4;
     }
     $$phi$trans$insert = (($1) + ($22<<2)|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $24 = ($$pre|0)==(0|0);
     if ($24) {
      $$1 = -1;
      break L4;
     } else {
      $$0454960 = $22;$17 = $$pre;
     }
    }
    HEAP32[(gb + (161696) | 0)>>2] = $$0454960;
    $26 = (___getopt_long_core($0,$1,$2,$3,$4,$5)|0);
    $27 = ($$0454960|0)>($11|0);
    if ($27) {
     $28 = HEAP32[(gb + (161696) | 0)>>2]|0;
     $29 = (($28) - ($$0454960))|0;
     $30 = ($29|0)>(0);
     if ($30) {
      $31 = (($28) + -1)|0;
      _permute($1,$11,$31);
      $exitcond59 = ($29|0)==(1);
      if (!($exitcond59)) {
       $34 = 1;
       while(1) {
        $$pre56 = HEAP32[(gb + (161696) | 0)>>2]|0;
        $32 = (($$pre56) + -1)|0;
        _permute($1,$11,$32);
        $33 = (($34) + 1)|0;
        $exitcond = ($33|0)==($29|0);
        if ($exitcond) {
         break;
        } else {
         $34 = $33;
        }
       }
      }
     }
     $35 = (($29) + ($11))|0;
     HEAP32[(gb + (161696) | 0)>>2] = $35;
     $$1 = $26;
    } else {
     $$1 = $26;
    }
   }
  } else {
   $$1 = -1;
  }
 } while(0);
 return ($$1|0);
}
function ___getopt_long_core($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$083105 = 0, $$086111 = 0, $$089110 = 0, $$092108 = 0, $$18798 = 0, $$19097 = 0, $$194 = 0, $$2$lcssa = 0, $$2104 = 0, $$288 = 0, $$291 = 0, $$291127 = 0, $$lcssa = 0, $$not = 0, $$not102 = 0, $$phi$trans$insert = 0, $$pr = 0, $$pr$lcssa = 0, $$pr101 = 0, $$pre = 0;
 var $$pre124 = 0, $$pre125 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $9 = 0, $narrow = 0, $or$cond = 0, $or$cond100 = 0, $or$cond100103 = 0, $or$cond3 = 0, $phitmp = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[(gb + (171188) | 0)>>2] = 0;
 $6 = ($3|0)==(0|0);
 L1: do {
  if ($6) {
   label = 35;
  } else {
   $7 = HEAP32[(gb + (161696) | 0)>>2]|0;
   $8 = (($1) + ($7<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(45);
   if ($11) {
    $12 = ($5|0)==(0);
    $$phi$trans$insert = ((($9)) + 1|0);
    $$pre = HEAP8[$$phi$trans$insert>>0]|0;
    if ($12) {
     $phitmp = ($$pre<<24>>24)==(45);
     if (!($phitmp)) {
      label = 35;
      break;
     }
     $14 = ((($9)) + 2|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      label = 35;
      break;
     } else {
      $28 = 45;
     }
    } else {
     $13 = ($$pre<<24>>24)==(0);
     if ($13) {
      label = 35;
      break;
     } else {
      $28 = $$pre;
     }
    }
    $17 = HEAP8[$2>>0]|0;
    $18 = ($17<<24>>24)==(43);
    $19 = ($17<<24>>24)==(45);
    $narrow = $18 | $19;
    $20 = $narrow&1;
    $21 = (($2) + ($20)|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)==(58);
    $24 = HEAP32[$3>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$291127 = 0;
    } else {
     $26 = ((($9)) + 1|0);
     $27 = ($28<<24>>24)==(45);
     $29 = ((($9)) + 2|0);
     $spec$select = $27 ? $29 : $26;
     $$pr101 = HEAP8[$spec$select>>0]|0;
     $$086111 = 0;$$089110 = 0;$$092108 = 0;$31 = $24;
     L11: while(1) {
      $30 = HEAP8[$31>>0]|0;
      $32 = ($30<<24>>24)==(0);
      $$not102 = $32 ^ 1;
      $33 = ($30<<24>>24)==($$pr101<<24>>24);
      $or$cond100103 = $33 & $$not102;
      if ($or$cond100103) {
       $$083105 = $31;$$2104 = $spec$select;
       while(1) {
        $34 = ((($$083105)) + 1|0);
        $35 = ((($$2104)) + 1|0);
        $36 = HEAP8[$34>>0]|0;
        $37 = ($36<<24>>24)==(0);
        $$pr = HEAP8[$35>>0]|0;
        $$not = $37 ^ 1;
        $38 = ($36<<24>>24)==($$pr<<24>>24);
        $or$cond100 = $38 & $$not;
        if ($or$cond100) {
         $$083105 = $34;$$2104 = $35;
        } else {
         $$2$lcssa = $35;$$lcssa = $37;$$pr$lcssa = $$pr;
         break;
        }
       }
      } else {
       $$2$lcssa = $spec$select;$$lcssa = $32;$$pr$lcssa = $$pr101;
      }
      switch ($$pr$lcssa<<24>>24) {
      case 61: case 0:  {
       $39 = (($$089110) + 1)|0;
       if ($$lcssa) {
        $$288 = $$092108;$$291 = 1;
        break L11;
       } else {
        $$18798 = $$092108;$$19097 = $39;
       }
       break;
      }
      default: {
       $$18798 = $$086111;$$19097 = $$089110;
      }
      }
      $40 = (($$092108) + 1)|0;
      $41 = (($3) + ($40<<4)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       $$288 = $$18798;$$291 = $$19097;
       break;
      } else {
       $$086111 = $$18798;$$089110 = $$19097;$$092108 = $40;$31 = $42;
      }
     }
     $44 = ($$291|0)==(1);
     if ($44) {
      $45 = (($7) + 1)|0;
      HEAP32[(gb + (161696) | 0)>>2] = $45;
      $46 = (($3) + ($$288<<4)|0);
      $47 = (((($3) + ($$288<<4)|0)) + 12|0);
      $48 = HEAP32[$47>>2]|0;
      HEAP32[(gb + (171192) | 0)>>2] = $48;
      $49 = HEAP8[$$2$lcssa>>0]|0;
      $50 = ($49<<24>>24)==(61);
      $51 = (((($3) + ($$288<<4)|0)) + 4|0);
      $52 = HEAP32[$51>>2]|0;
      do {
       if ($50) {
        $53 = ($52|0)==(0);
        if (!($53)) {
         $60 = ((($$2$lcssa)) + 1|0);
         HEAP32[(gb + (171188) | 0)>>2] = $60;
         break;
        }
        $54 = $23 ^ 1;
        $55 = HEAP32[(gb + (161700) | 0)>>2]|0;
        $56 = ($55|0)!=(0);
        $or$cond = $56 & $54;
        if (!($or$cond)) {
         $$194 = 63;
         break L1;
        }
        $57 = HEAP32[$1>>2]|0;
        $58 = HEAP32[$46>>2]|0;
        $59 = (_strlen($58)|0);
        ___getopt_msg($57,(gb + (167713) | 0),$58,$59);
        $$194 = 63;
        break L1;
       } else {
        $61 = ($52|0)==(1);
        if ($61) {
         $62 = (($1) + ($45<<2)|0);
         $63 = HEAP32[$62>>2]|0;
         HEAP32[(gb + (171188) | 0)>>2] = $63;
         $64 = ($63|0)==(0|0);
         if (!($64)) {
          $70 = (($7) + 2)|0;
          HEAP32[(gb + (161696) | 0)>>2] = $70;
          break;
         }
         if ($23) {
          $$194 = 58;
          break L1;
         }
         $65 = HEAP32[(gb + (161700) | 0)>>2]|0;
         $66 = ($65|0)==(0);
         if ($66) {
          $$194 = 63;
          break L1;
         }
         $67 = HEAP32[$1>>2]|0;
         $68 = HEAP32[$46>>2]|0;
         $69 = (_strlen($68)|0);
         ___getopt_msg($67,(gb + (167750) | 0),$68,$69);
         $$194 = 63;
         break L1;
        }
       }
      } while(0);
      $71 = ($4|0)==(0|0);
      if ($71) {
       $75 = $48;
      } else {
       HEAP32[$4>>2] = $$288;
       $$pre125 = HEAP32[$47>>2]|0;
       $75 = $$pre125;
      }
      $72 = (((($3) + ($$288<<4)|0)) + 8|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ($73|0)==(0|0);
      if ($74) {
       $$194 = $75;
       break;
      }
      HEAP32[$73>>2] = $75;
      $$194 = 0;
      break;
     } else {
      $$291127 = $$291;
     }
    }
    $76 = ($28<<24>>24)==(45);
    if ($76) {
     $77 = $23 ^ 1;
     $78 = HEAP32[(gb + (161700) | 0)>>2]|0;
     $79 = ($78|0)!=(0);
     $or$cond3 = $79 & $77;
     $80 = ((($9)) + 2|0);
     if ($or$cond3) {
      $81 = ($$291127|0)==(0);
      $82 = $81 ? (gb + (167782) | 0) : (gb + (167806) | 0);
      $83 = HEAP32[$1>>2]|0;
      $84 = (_strlen($80)|0);
      ___getopt_msg($83,$82,$80,$84);
      $$pre124 = HEAP32[(gb + (161696) | 0)>>2]|0;
      $86 = $$pre124;
     } else {
      $86 = $7;
     }
     $85 = (($86) + 1)|0;
     HEAP32[(gb + (161696) | 0)>>2] = $85;
     $$194 = 63;
    } else {
     label = 35;
    }
   } else {
    label = 35;
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $87 = (_getopt($0,$1,$2)|0);
  $$194 = $87;
 }
 return ($$194|0);
}
function _permute($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$018 = 0, $10 = 0, $11 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($0) + ($2<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)>($1|0);
 if ($5) {
  $$018 = $2;
  while(1) {
   $6 = (($$018) + -1)|0;
   $7 = (($0) + ($6<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($0) + ($$018<<2)|0);
   HEAP32[$9>>2] = $8;
   $10 = ($6|0)>($1|0);
   if ($10) {
    $$018 = $6;
   } else {
    break;
   }
  }
 }
 $11 = (($0) + ($1<<2)|0);
 HEAP32[$11>>2] = $4;
 return;
}
function _getopt_long_only($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (___getopt_long($0,$1,$2,$3,$4,1)|0);
 return ($5|0);
}
function _strlwr($0) {
 $0 = $0|0;
 var $$07 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$07 = $0;$4 = $1;
  while(1) {
   $3 = $4 << 24 >> 24;
   $5 = (_tolower($3)|0);
   $6 = $5&255;
   HEAP8[$$07>>0] = $6;
   $7 = ((($$07)) + 1|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    break;
   } else {
    $$07 = $7;$4 = $8;
   }
  }
 }
 return ($0|0);
}
function _aligned_alloc($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = (_posix_memalign($2,$0,$1)|0);
 $4 = ($3|0)==(0);
 $5 = HEAP32[$2>>2]|0;
 $6 = $4 ? $5 : 0;
 STACKTOP = sp;return ($6|0);
}
function _strtoull_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtoull($0,$1,$2)|0);
 $5 = (getTempRet0() | 0);
 setTempRet0(($5) | 0);
 return ($4|0);
}
function _strtoll_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtoll($0,$1,$2)|0);
 $5 = (getTempRet0() | 0);
 setTempRet0(($5) | 0);
 return ($4|0);
}
function _strtoul_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtoul($0,$1,$2)|0);
 return ($4|0);
}
function _strtol_l($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (_strtol($0,$1,$2)|0);
 return ($4|0);
}
function _strupr($0) {
 $0 = $0|0;
 var $$07 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$07 = $0;$4 = $1;
  while(1) {
   $3 = $4 << 24 >> 24;
   $5 = (_toupper($3)|0);
   $6 = $5&255;
   HEAP8[$$07>>0] = $6;
   $7 = ((($$07)) + 1|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    break;
   } else {
    $$07 = $7;$4 = $8;
   }
  }
 }
 return ($0|0);
}
function _pselect($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $vararg_buffer = sp + 8|0;
 $6 = sp + 32|0;
 $7 = sp;
 $8 = $5;
 HEAP32[$6>>2] = $8;
 $9 = ((($6)) + 4|0);
 HEAP32[$9>>2] = 8;
 $10 = ($4|0)!=(0|0);
 if ($10) {
  $11 = $4;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = $7;
  $18 = $17;
  HEAP32[$18>>2] = $13;
  $19 = (($17) + 4)|0;
  $20 = $19;
  HEAP32[$20>>2] = $16;
 }
 $21 = $1;
 $22 = $2;
 $23 = $3;
 $24 = $7;
 $25 = $10 ? $24 : 0;
 $26 = $6;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $21;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $22;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $23;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $25;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $26;
 $27 = (___syscall308(308,($vararg_buffer|0))|0);
 $28 = (___syscall_ret($27)|0);
 STACKTOP = sp;return ($28|0);
}
function _select($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $10 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $vararg_buffer = sp;
 $5 = $1;
 $6 = $2;
 $7 = $3;
 $8 = $4;
 HEAP32[$vararg_buffer>>2] = $0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $6;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $7;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $8;
 $9 = (___syscall142(142,($vararg_buffer|0))|0);
 $10 = (___syscall_ret($9)|0);
 STACKTOP = sp;return ($10|0);
}
function _catanhl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _catanh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _catanh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = - $5;
 $7 = +HEAPF64[$1>>3];
 $8 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $6;
 HEAPF64[$8>>3] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _catan($2,$$byval_copy);
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = - $9;
 $13 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$13>>3] = $12;
 STACKTOP = sp;return;
}
function _catan($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0.0, $$sink40 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($1)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 $5 = $2 == 0.0;
 $6 = $4 > 1.0;
 $or$cond = $5 & $6;
 if ($or$cond) {
  $$sink = 1.0E+308;$$sink40 = 1.0E+308;
 } else {
  $7 = $2 * $2;
  $8 = 1.0 - $7;
  $9 = $4 * $4;
  $10 = $8 - $9;
  $11 = $10 == 0.0;
  if ($11) {
   $$sink = 1.0E+308;$$sink40 = 1.0E+308;
  } else {
   $12 = $2 * 2.0;
   $13 = (+Math_atan2((+$12),(+$10)));
   $14 = $4 + -1.0;
   $15 = $14 * $14;
   $16 = $7 + $15;
   $17 = $16 == 0.0;
   if ($17) {
    $$sink = 1.0E+308;$$sink40 = 1.0E+308;
   } else {
    $18 = $13 * 0.5;
    $19 = (+__redupi($18));
    $20 = $4 + 1.0;
    $21 = $20 * $20;
    $22 = $7 + $21;
    $23 = $22 / $16;
    $24 = (+Math_log((+$23)));
    $25 = $24 * 0.25;
    $26 = $25 * 0.0;
    $27 = $19 + $26;
    $28 = $25 + 0.0;
    $$sink = $28;$$sink40 = $27;
   }
  }
 }
 $29 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sink40;
 HEAPF64[$29>>3] = $$sink;
 return;
}
function __redupi($0) {
 $0 = +$0;
 var $$0 = 0.0, $$0$v = 0.0, $1 = 0.0, $10 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 / 3.1415926535897931;
 $2 = !($1 >= 0.0);
 $$0$v = $2 ? -0.5 : 0.5;
 $$0 = $1 + $$0$v;
 $3 = (~~(($$0)));
 $4 = (+($3|0));
 $5 = $4 * 3.1415926516056061;
 $6 = $0 - $5;
 $7 = $4 * 1.9841871479187034E-9;
 $8 = $6 - $7;
 $9 = $4 * 1.1442377452219664E-17;
 $10 = $8 - $9;
 return (+$10);
}
function _cimagf($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = +HEAPF32[$1>>2];
 return (+$2);
}
function _creall($0) {
 $0 = $0|0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = +HEAPF64[$0>>3];
 return (+$1);
}
function _clogf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($2)) + 4|0);
 HEAP32[$2>>2] = $4;
 HEAP32[$7>>2] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 $8 = (+_cabsf($$byval_copy));
 $9 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $4;
 HEAP32[$9>>2] = $6;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;
 $10 = (+_cargf($$byval_copy1));
 $11 = (+Math_log((+$8)));
 $12 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $11;
 HEAPF32[$12>>2] = $10;
 STACKTOP = sp;return;
}
function _cabsf($0) {
 $0 = $0|0;
 var $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = +HEAPF32[$0>>2];
 $2 = ((($0)) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (+_hypotf($1,$3));
 return (+$4);
}
function _cargf($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 4|0);
 $2 = +HEAPF32[$1>>2];
 $3 = +HEAPF32[$0>>2];
 $4 = (+Math_atan2((+$2),(+$3)));
 return (+$4);
}
function _csin($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = - $5;
 $7 = +HEAPF64[$1>>3];
 $8 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $6;
 HEAPF64[$8>>3] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _csinh($2,$$byval_copy);
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = - $9;
 $13 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$13>>3] = $12;
 STACKTOP = sp;return;
}
function _csinh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$sink = 0.0, $$sink133 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0.0, $61 = 0.0;
 var $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 HEAPF64[tempDoublePtr>>3] = $4;$7 = HEAP32[tempDoublePtr>>2]|0;
 $8 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $6;$9 = HEAP32[tempDoublePtr>>2]|0;
 $10 = HEAP32[tempDoublePtr+4>>2]|0;
 $11 = $8 & 2147483647;
 $12 = $10 & 2147483647;
 $13 = ($11>>>0)<(2146435072);
 $14 = ($12>>>0)<(2146435072);
 $or$cond = $13 & $14;
 do {
  if ($or$cond) {
   $15 = $12 | $9;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (+_sinh($4));
    $$sink = $6;$$sink133 = $17;
    break;
   }
   $18 = ($11>>>0)<(1077280768);
   if ($18) {
    $19 = (+_sinh($4));
    $20 = (+Math_cos((+$6)));
    $21 = $19 * $20;
    $22 = (+_cosh($4));
    $23 = (+Math_sin((+$6)));
    $24 = $22 * $23;
    $$sink = $24;$$sink133 = $21;
    break;
   }
   $25 = ($11>>>0)<(1082535490);
   if ($25) {
    $26 = (+Math_abs((+$4)));
    $27 = (+Math_exp((+$26)));
    $28 = $27 * 0.5;
    $29 = (+_copysign($28,$4));
    $30 = (+Math_cos((+$6)));
    $31 = $29 * $30;
    $32 = (+Math_sin((+$6)));
    $33 = $28 * $32;
    $$sink = $33;$$sink133 = $31;
    break;
   }
   $34 = ($11>>>0)<(1083620266);
   if ($34) {
    $35 = (+Math_abs((+$4)));
    $36 = ((($3)) + 8|0);
    HEAPF64[$3>>3] = $35;
    HEAPF64[$36>>3] = $6;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
    ___ldexp_cexp($2,$$byval_copy,-1);
    $37 = +HEAPF64[$2>>3];
    $38 = ((($2)) + 8|0);
    $39 = +HEAPF64[$38>>3];
    HEAPF64[$1>>3] = $37;
    HEAPF64[$5>>3] = $39;
    $40 = (+_copysign(1.0,$4));
    $41 = $37 * $40;
    $$sink = $39;$$sink133 = $41;
    break;
   } else {
    $42 = $4 * 8.9884656743115795E+307;
    $43 = (+Math_cos((+$6)));
    $44 = $42 * $43;
    $45 = $42 * $42;
    $46 = (+Math_sin((+$6)));
    $47 = $45 * $46;
    $$sink = $47;$$sink133 = $44;
    break;
   }
  } else {
   $48 = $11 | $7;
   $49 = ($48|0)==(0);
   $50 = ($12>>>0)>(2146435071);
   $or$cond3 = $49 & $50;
   if ($or$cond3) {
    $51 = $6 - $6;
    $52 = $4 * $51;
    $53 = (+_copysign(0.0,$52));
    $$sink = $51;$$sink133 = $53;
    break;
   }
   $54 = $12 | $9;
   $55 = ($54|0)==(0);
   $56 = ($11>>>0)>(2146435071);
   $or$cond5 = $56 & $55;
   if ($or$cond5) {
    $57 = $8 & 1048575;
    $58 = $57 | $7;
    $59 = ($58|0)==(0);
    if ($59) {
     $$sink = $6;$$sink133 = $4;
     break;
    }
    $60 = (+_copysign(0.0,$6));
    $$sink = $60;$$sink133 = $4;
    break;
   }
   $or$cond7 = $13 & $50;
   if ($or$cond7) {
    $61 = $6 - $6;
    $62 = $4 * $61;
    $$sink = $62;$$sink133 = $61;
    break;
   }
   if ($56) {
    $63 = $8 & 1048575;
    $64 = $63 | $7;
    $65 = ($64|0)==(0);
    if ($65) {
     if ($50) {
      $66 = $4 * $4;
      $67 = $6 - $6;
      $68 = $4 * $67;
      $$sink = $68;$$sink133 = $66;
      break;
     } else {
      $69 = (+Math_cos((+$6)));
      $70 = $4 * $69;
      $71 = (+Math_sin((+$6)));
      $72 = $71 * inf;
      $$sink = $72;$$sink133 = $70;
      break;
     }
    }
   }
   $73 = $4 * $4;
   $74 = $6 - $6;
   $75 = $73 * $74;
   $76 = $4 + $4;
   $77 = $76 * $74;
   $$sink = $77;$$sink133 = $75;
  }
 } while(0);
 $78 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sink133;
 HEAPF64[$78>>3] = $$sink;
 STACKTOP = sp;return;
}
function ___ldexp_cexp($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $3 = 0, $4 = 0.0, $5 = 0;
 var $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = (+___frexp_exp($4,$3));
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + ($2))|0;
 $10 = (($9|0) / 2)&-1;
 $11 = $10 << 20;
 $12 = (($11) + 1072693248)|0;
 HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $12;$13 = +HEAPF64[tempDoublePtr>>3];
 $14 = (($9) - ($10))|0;
 $15 = $14 << 20;
 $16 = (($15) + 1072693248)|0;
 HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
 $18 = (+Math_cos((+$6)));
 $19 = $7 * $18;
 $20 = $19 * $13;
 $21 = $20 * $17;
 $22 = (+Math_sin((+$6)));
 $23 = $7 * $22;
 $24 = $23 * $13;
 $25 = $24 * $17;
 $26 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $21;
 HEAPF64[$26>>3] = $25;
 STACKTOP = sp;return;
}
function ___frexp_exp($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 + -1246.9717778273416;
 $3 = (+Math_exp((+$2)));
 HEAPF64[tempDoublePtr>>3] = $3;$4 = HEAP32[tempDoublePtr>>2]|0;
 $5 = HEAP32[tempDoublePtr+4>>2]|0;
 $6 = (_bitshift64Lshr(($4|0),($5|0),52)|0);
 $7 = (getTempRet0() | 0);
 $8 = (($6) + -247)|0;
 HEAP32[$1>>2] = $8;
 $9 = $5 & 1048575;
 $10 = $9 | 2145386496;
 HEAP32[tempDoublePtr>>2] = $4;HEAP32[tempDoublePtr+4>>2] = $10;$11 = +HEAPF64[tempDoublePtr>>3];
 return (+$11);
}
function _cpowf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0;
 var $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp + 40|0;
 $3 = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 8|0;
 $7 = sp;
 $8 = +HEAPF32[$2>>2];
 $9 = ((($2)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = HEAP32[$1>>2]|0;
 $12 = ((($1)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($4)) + 4|0);
 HEAP32[$4>>2] = $11;
 HEAP32[$14>>2] = $13;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 _clogf($3,$$byval_copy);
 $15 = +HEAPF32[$3>>2];
 $16 = ((($3)) + 4|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $8 * $15;
 $19 = $10 * $17;
 $20 = $8 * $17;
 $21 = $10 * $15;
 $22 = $18 - $19;
 $23 = $21 + $20;
 $24 = ($22 != $22) | (0.0 != 0.0);
 $25 = ($23 != $23) | (0.0 != 0.0);
 $or$cond = $24 & $25;
 if ($or$cond) {
  ___mulsc3($5,$8,$10,$15,$17);
  $26 = +HEAPF32[$5>>2];
  $27 = ((($5)) + 4|0);
  $28 = +HEAPF32[$27>>2];
  $30 = $26;$31 = $28;
 } else {
  $30 = $22;$31 = $23;
 }
 $29 = ((($7)) + 4|0);
 HEAPF32[$7>>2] = $30;
 HEAPF32[$29>>2] = $31;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$7+4>>2]|0;
 _cexpf($6,$$byval_copy1);
 $32 = HEAP32[$6>>2]|0;
 $33 = ((($6)) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $32;
 HEAP32[$35>>2] = $34;
 STACKTOP = sp;return;
}
function _cexpf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = +HEAPF32[$1>>2];
 $5 = ((($1)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
 $8 = $7 & 2147483647;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $10 = (+Math_exp((+$4)));
   $11 = ((($0)) + 4|0);
   HEAPF32[$0>>2] = $10;
   HEAPF32[$11>>2] = $6;
  } else {
   $12 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
   $13 = $12 & 2147483647;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = (+Math_cos((+$6)));
    $16 = (+Math_sin((+$6)));
    $17 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $15;
    HEAPF32[$17>>2] = $16;
    break;
   }
   $18 = ($8>>>0)>(2139095039);
   if (!($18)) {
    $$off = (($12) + -1118925336)|0;
    $26 = ($$off>>>0)<(9342557);
    if ($26) {
     $27 = ((($3)) + 4|0);
     HEAPF32[$3>>2] = $4;
     HEAPF32[$27>>2] = $6;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
     ___ldexp_cexpf($2,$$byval_copy,0);
     $28 = HEAP32[$2>>2]|0;
     $29 = ((($2)) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ((($0)) + 4|0);
     HEAP32[$0>>2] = $28;
     HEAP32[$31>>2] = $30;
     break;
    } else {
     $32 = (+Math_exp((+$4)));
     $33 = (+Math_cos((+$6)));
     $34 = $32 * $33;
     $35 = (+Math_sin((+$6)));
     $36 = $32 * $35;
     $37 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $34;
     HEAPF32[$37>>2] = $36;
     break;
    }
   }
   $19 = ($13|0)==(2139095040);
   if (!($19)) {
    $20 = $6 - $6;
    $21 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $20;
    HEAPF32[$21>>2] = $20;
    break;
   }
   $22 = ($12|0)<(0);
   if ($22) {
    $23 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = 0.0;
    HEAPF32[$23>>2] = 0.0;
    break;
   } else {
    $24 = $6 - $6;
    $25 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $4;
    HEAPF32[$25>>2] = $24;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function ___ldexp_cexpf($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $3 = 0, $4 = 0.0, $5 = 0;
 var $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $3 = sp;
 $4 = +HEAPF32[$1>>2];
 $5 = ((($1)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (+___frexp_expf($4,$3));
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + ($2))|0;
 $10 = (($9|0) / 2)&-1;
 $11 = $10 << 23;
 $12 = (($11) + 1065353216)|0;
 $13 = (HEAP32[tempDoublePtr>>2]=$12,+HEAPF32[tempDoublePtr>>2]);
 $14 = (($9) - ($10))|0;
 $15 = $14 << 23;
 $16 = (($15) + 1065353216)|0;
 $17 = (HEAP32[tempDoublePtr>>2]=$16,+HEAPF32[tempDoublePtr>>2]);
 $18 = (+Math_cos((+$6)));
 $19 = $7 * $18;
 $20 = $19 * $13;
 $21 = $20 * $17;
 $22 = (+Math_sin((+$6)));
 $23 = $7 * $22;
 $24 = $23 * $13;
 $25 = $24 * $17;
 $26 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $21;
 HEAPF32[$26>>2] = $25;
 STACKTOP = sp;return;
}
function ___frexp_expf($0,$1) {
 $0 = +$0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $0 + -162.88958740234375;
 $3 = (+Math_exp((+$2)));
 $4 = (HEAPF32[tempDoublePtr>>2]=$3,HEAP32[tempDoublePtr>>2]|0);
 $5 = $4 >>> 23;
 $6 = (($5) + -19)|0;
 HEAP32[$1>>2] = $6;
 $7 = $4 & 8388607;
 $8 = $7 | 2130706432;
 $9 = (HEAP32[tempDoublePtr>>2]=$8,+HEAPF32[tempDoublePtr>>2]);
 return (+$9);
}
function _cacoshl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _cacosh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _cacosh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _cacos($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = - $10;
 $12 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$12>>3] = $8;
 STACKTOP = sp;return;
}
function _cacos($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _casin($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = 1.5707963267948966 - $8;
 $12 = - $10;
 $13 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$13>>3] = $12;
 STACKTOP = sp;return;
}
function _casin($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(96|0);
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp + 64|0;
 $2 = sp + 48|0;
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = +HEAPF64[$1>>3];
 $7 = ((($1)) + 8|0);
 $8 = +HEAPF64[$7>>3];
 $9 = $6 - $8;
 $10 = $6 + $8;
 $11 = $9 * $10;
 $12 = 1.0 - $11;
 $13 = $6 * -2.0;
 $14 = $13 * $8;
 $15 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $12;
 HEAPF64[$15>>3] = $14;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _csqrt($2,$$byval_copy);
 $16 = +HEAPF64[$2>>3];
 $17 = ((($2)) + 8|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $16 - $8;
 $20 = $6 + $18;
 $21 = ((($5)) + 8|0);
 HEAPF64[$5>>3] = $19;
 HEAPF64[$21>>3] = $20;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$5>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$5+12>>2]|0;
 _clog($4,$$byval_copy1);
 $22 = +HEAPF64[$4>>3];
 $23 = ((($4)) + 8|0);
 $24 = +HEAPF64[$23>>3];
 $25 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $22;
 HEAPF64[$25>>3] = $24;
 STACKTOP = sp;return;
}
function _csqrt($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0.0, $$061 = 0.0, $$062 = 0, $$sroa$056$0 = 0.0, $$sroa$056$1$sink = 0.0, $$sroa$7$0 = 0.0, $$sroa$7$1$sink = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0;
 var $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(16|0);
 $2 = sp;
 $3 = +HEAPF64[$1>>3];
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $3 == 0.0;
 $7 = $5 == 0.0;
 $8 = $6 & $7;
 do {
  if ($8) {
   $$sroa$056$1$sink = 0.0;$$sroa$7$1$sink = $5;
  } else {
   $9 = (___DOUBLE_BITS_710($5)|0);
   $10 = (getTempRet0() | 0);
   $11 = $10 & 2147483647;
   $12 = ($9|0)==(0);
   $13 = ($11|0)==(2146435072);
   $14 = $12 & $13;
   if ($14) {
    $$sroa$056$1$sink = inf;$$sroa$7$1$sink = $5;
   } else {
    $15 = (___DOUBLE_BITS_710($3)|0);
    $16 = (getTempRet0() | 0);
    $17 = $16 & 2147483647;
    $18 = ($17>>>0)>(2146435072);
    $19 = ($15>>>0)>(0);
    $20 = ($17|0)==(2146435072);
    $21 = $20 & $19;
    $22 = $18 | $21;
    if ($22) {
     $23 = $5 - $5;
     $24 = $23 / $23;
     $$sroa$056$1$sink = $3;$$sroa$7$1$sink = $24;
     break;
    }
    $25 = ($15|0)==(0);
    $26 = ($17|0)==(2146435072);
    $27 = $25 & $26;
    if ($27) {
     $28 = ($16|0)<(0);
     $29 = $5 - $5;
     if ($28) {
      $30 = (+Math_abs((+$29)));
      $31 = (+_copysign($3,$5));
      $$sroa$056$1$sink = $30;$$sroa$7$1$sink = $31;
      break;
     } else {
      $32 = (+_copysign($29,$5));
      $$sroa$056$1$sink = $3;$$sroa$7$1$sink = $32;
      break;
     }
    }
    $33 = (+Math_abs((+$3)));
    $34 = !($33 >= 7.4462887744497663E+307);
    if ($34) {
     $35 = (+Math_abs((+$5)));
     $36 = !($35 >= 7.4462887744497663E+307);
     if ($36) {
      $$0 = $3;$$061 = $5;$$062 = 0;
     } else {
      label = 11;
     }
    } else {
     label = 11;
    }
    if ((label|0) == 11) {
     $37 = $3 * 0.25;
     $38 = $5 * 0.25;
     $$0 = $37;$$061 = $38;$$062 = 1;
    }
    $39 = !($$0 >= 0.0);
    $40 = (+_hypot($$0,$$061));
    if ($39) {
     $46 = $40 - $$0;
     $47 = $46 * 0.5;
     $48 = (+Math_sqrt((+$47)));
     $49 = (+Math_abs((+$$061)));
     $50 = $48 * 2.0;
     $51 = $49 / $50;
     $52 = (+_copysign($48,$$061));
     $$sroa$056$0 = $51;$$sroa$7$0 = $52;
    } else {
     $41 = $$0 + $40;
     $42 = $41 * 0.5;
     $43 = (+Math_sqrt((+$42)));
     $44 = $43 * 2.0;
     $45 = $$061 / $44;
     $$sroa$056$0 = $43;$$sroa$7$0 = $45;
    }
    $53 = ($$062|0)==(0);
    if ($53) {
     $$sroa$056$1$sink = $$sroa$056$0;$$sroa$7$1$sink = $$sroa$7$0;
    } else {
     $54 = $$sroa$056$0 * 2.0;
     $55 = $$sroa$7$0 * 0.0;
     $56 = $$sroa$056$0 * 0.0;
     $57 = $$sroa$7$0 * 2.0;
     $58 = $54 - $55;
     $59 = $56 + $57;
     $60 = ($58 != $58) | (0.0 != 0.0);
     $61 = ($59 != $59) | (0.0 != 0.0);
     $or$cond = $60 & $61;
     if ($or$cond) {
      ___muldc3($2,$$sroa$056$0,$$sroa$7$0,2.0,0.0);
      $62 = +HEAPF64[$2>>3];
      $63 = ((($2)) + 8|0);
      $64 = +HEAPF64[$63>>3];
      $$sroa$056$1$sink = $62;$$sroa$7$1$sink = $64;
     } else {
      $$sroa$056$1$sink = $58;$$sroa$7$1$sink = $59;
     }
    }
   }
  }
 } while(0);
 $65 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sroa$056$1$sink;
 HEAPF64[$65>>3] = $$sroa$7$1$sink;
 STACKTOP = sp;return;
}
function _clog($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(64|0);
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($2)) + 8|0);
 HEAPF64[$2>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$2>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
 $8 = (+_cabs($$byval_copy));
 $9 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$9>>3] = $6;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$3+12>>2]|0;
 $10 = (+_carg($$byval_copy1));
 $11 = (+Math_log((+$8)));
 $12 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$12>>3] = $10;
 STACKTOP = sp;return;
}
function _cabs($0) {
 $0 = $0|0;
 var $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = +HEAPF64[$0>>3];
 $2 = ((($0)) + 8|0);
 $3 = +HEAPF64[$2>>3];
 $4 = (+_hypot($1,$3));
 return (+$4);
}
function _carg($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = +HEAPF64[$1>>3];
 $3 = +HEAPF64[$0>>3];
 $4 = (+Math_atan2((+$2),(+$3)));
 return (+$4);
}
function ___DOUBLE_BITS_710($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _cpow($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0;
 var $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(112|0);
 $$byval_copy1 = sp + 96|0;
 $$byval_copy = sp + 80|0;
 $3 = sp + 64|0;
 $4 = sp + 48|0;
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $7 = sp;
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = +HEAPF64[$1>>3];
 $12 = ((($1)) + 8|0);
 $13 = +HEAPF64[$12>>3];
 $14 = ((($4)) + 8|0);
 HEAPF64[$4>>3] = $11;
 HEAPF64[$14>>3] = $13;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$4+12>>2]|0;
 _clog($3,$$byval_copy);
 $15 = +HEAPF64[$3>>3];
 $16 = ((($3)) + 8|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $8 * $15;
 $19 = $10 * $17;
 $20 = $8 * $17;
 $21 = $10 * $15;
 $22 = $18 - $19;
 $23 = $21 + $20;
 $24 = ($22 != $22) | (0.0 != 0.0);
 $25 = ($23 != $23) | (0.0 != 0.0);
 $or$cond = $24 & $25;
 if ($or$cond) {
  ___muldc3($5,$8,$10,$15,$17);
  $26 = +HEAPF64[$5>>3];
  $27 = ((($5)) + 8|0);
  $28 = +HEAPF64[$27>>3];
  $30 = $26;$31 = $28;
 } else {
  $30 = $22;$31 = $23;
 }
 $29 = ((($7)) + 8|0);
 HEAPF64[$7>>3] = $30;
 HEAPF64[$29>>3] = $31;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$7>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$7+12>>2]|0;
 _cexp($6,$$byval_copy1);
 $32 = +HEAPF64[$6>>3];
 $33 = ((($6)) + 8|0);
 $34 = +HEAPF64[$33>>3];
 $35 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $32;
 HEAPF64[$35>>3] = $34;
 STACKTOP = sp;return;
}
function _cexp($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$off = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0, $5 = 0, $6 = 0.0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 HEAPF64[tempDoublePtr>>3] = $6;$7 = HEAP32[tempDoublePtr>>2]|0;
 $8 = HEAP32[tempDoublePtr+4>>2]|0;
 $9 = $8 & 2147483647;
 $10 = $9 | $7;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = (+Math_exp((+$4)));
   $13 = ((($0)) + 8|0);
   HEAPF64[$0>>3] = $12;
   HEAPF64[$13>>3] = $6;
  } else {
   HEAPF64[tempDoublePtr>>3] = $4;$14 = HEAP32[tempDoublePtr>>2]|0;
   $15 = HEAP32[tempDoublePtr+4>>2]|0;
   $16 = $15 & 2147483647;
   $17 = $16 | $14;
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = (+Math_cos((+$6)));
    $20 = (+Math_sin((+$6)));
    $21 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $19;
    HEAPF64[$21>>3] = $20;
    break;
   }
   $22 = ($9>>>0)>(2146435071);
   if (!($22)) {
    $$off = (($15) + -1082535490)|0;
    $30 = ($$off>>>0)<(1084067);
    if ($30) {
     $31 = ((($3)) + 8|0);
     HEAPF64[$3>>3] = $4;
     HEAPF64[$31>>3] = $6;
     ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
     ___ldexp_cexp($2,$$byval_copy,0);
     $32 = +HEAPF64[$2>>3];
     $33 = ((($2)) + 8|0);
     $34 = +HEAPF64[$33>>3];
     $35 = ((($0)) + 8|0);
     HEAPF64[$0>>3] = $32;
     HEAPF64[$35>>3] = $34;
     break;
    } else {
     $36 = (+Math_exp((+$4)));
     $37 = (+Math_cos((+$6)));
     $38 = $36 * $37;
     $39 = (+Math_sin((+$6)));
     $40 = $36 * $39;
     $41 = ((($0)) + 8|0);
     HEAPF64[$0>>3] = $38;
     HEAPF64[$41>>3] = $40;
     break;
    }
   }
   $23 = ($14|0)==(0);
   $24 = ($16|0)==(2146435072);
   $or$cond = $23 & $24;
   if (!($or$cond)) {
    $25 = $6 - $6;
    $26 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $25;
    HEAPF64[$26>>3] = $25;
    break;
   }
   $27 = ($15|0)<(0);
   if ($27) {
    ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    break;
   } else {
    $28 = $6 - $6;
    $29 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $4;
    HEAPF64[$29>>3] = $28;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _csinhf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$cast = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0;
 var $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0;
 var $81 = 0.0, $82 = 0, $9 = 0, $or$cond = 0, $or$cond122 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = +HEAPF32[$1>>2];
 $5 = ((($1)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
 $8 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
 $9 = $7 & 2147483647;
 $10 = $8 & 2147483647;
 $11 = ($9>>>0)<(2139095040);
 $12 = ($10>>>0)<(2139095040);
 $or$cond = $11 & $12;
 do {
  if ($or$cond) {
   $13 = ($10|0)==(0);
   if ($13) {
    $14 = (+_sinhf($4));
    $15 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $14;
    HEAPF32[$15>>2] = $6;
    break;
   }
   $16 = ($9>>>0)<(1091567616);
   if ($16) {
    $17 = (+_sinhf($4));
    $18 = (+Math_cos((+$6)));
    $19 = $17 * $18;
    $20 = (+_coshf($4));
    $21 = (+Math_sin((+$6)));
    $22 = $20 * $21;
    $23 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $19;
    HEAPF32[$23>>2] = $22;
    break;
   }
   $24 = ($9>>>0)<(1118925336);
   if ($24) {
    $25 = (+Math_abs((+$4)));
    $26 = (+Math_exp((+$25)));
    $27 = $26 * 0.5;
    $28 = (+_copysignf($27,$4));
    $29 = (+Math_cos((+$6)));
    $30 = $28 * $29;
    $31 = (+Math_sin((+$6)));
    $32 = $27 * $31;
    $33 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $30;
    HEAPF32[$33>>2] = $32;
    break;
   }
   $34 = ($9>>>0)<(1128313319);
   if ($34) {
    $35 = (+Math_abs((+$4)));
    $36 = ((($3)) + 4|0);
    HEAPF32[$3>>2] = $35;
    HEAPF32[$36>>2] = $6;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
    ___ldexp_cexpf($2,$$byval_copy,-1);
    $37 = HEAP32[$2>>2]|0;
    $38 = ((($2)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$1>>2] = $37;
    HEAP32[$5>>2] = $39;
    $$cast = (HEAP32[tempDoublePtr>>2]=$37,+HEAPF32[tempDoublePtr>>2]);
    $40 = (+_copysignf(1.0,$4));
    $41 = $40 * $$cast;
    $42 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $41;
    HEAP32[$42>>2] = $39;
    break;
   } else {
    $43 = $4 * 1.7014118346046923E+38;
    $44 = (+Math_cos((+$6)));
    $45 = $43 * $44;
    $46 = $43 * $43;
    $47 = (+Math_sin((+$6)));
    $48 = $46 * $47;
    $49 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $45;
    HEAPF32[$49>>2] = $48;
    break;
   }
  } else {
   $50 = ($9|0)==(0);
   $51 = ($10>>>0)>(2139095039);
   $or$cond3 = $50 & $51;
   if ($or$cond3) {
    $52 = $6 - $6;
    $53 = $4 * $52;
    $54 = (+_copysignf(0.0,$53));
    $55 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $54;
    HEAPF32[$55>>2] = $52;
    break;
   }
   $56 = ($10|0)==(0);
   $57 = ($9>>>0)>(2139095039);
   $or$cond5 = $57 & $56;
   if ($or$cond5) {
    $58 = $7 & 8388607;
    $59 = ($58|0)==(0);
    if ($59) {
     $60 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $4;
     HEAPF32[$60>>2] = $6;
     break;
    } else {
     $61 = (+_copysignf(0.0,$6));
     $62 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $4;
     HEAPF32[$62>>2] = $61;
     break;
    }
   }
   $or$cond7 = $11 & $51;
   if ($or$cond7) {
    $63 = $6 - $6;
    $64 = $4 * $63;
    $65 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $63;
    HEAPF32[$65>>2] = $64;
    break;
   }
   $66 = $7 & 8388607;
   $67 = ($66|0)==(0);
   $or$cond122 = $57 & $67;
   if (!($or$cond122)) {
    $77 = $4 * $4;
    $78 = $6 - $6;
    $79 = $77 * $78;
    $80 = $4 + $4;
    $81 = $80 * $78;
    $82 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $79;
    HEAPF32[$82>>2] = $81;
    break;
   }
   if ($51) {
    $68 = $4 * $4;
    $69 = $6 - $6;
    $70 = $4 * $69;
    $71 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $68;
    HEAPF32[$71>>2] = $70;
    break;
   } else {
    $72 = (+Math_cos((+$6)));
    $73 = $4 * $72;
    $74 = (+Math_sin((+$6)));
    $75 = $74 * inf;
    $76 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $73;
    HEAPF32[$76>>2] = $75;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _cpowl($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(80|0);
 $$byval_copy1 = sp + 64|0;
 $$byval_copy = sp + 48|0;
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = +HEAPF64[$1>>3];
 $7 = ((($1)) + 8|0);
 $8 = +HEAPF64[$7>>3];
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($4)) + 8|0);
 HEAPF64[$4>>3] = $6;
 HEAPF64[$12>>3] = $8;
 $13 = ((($5)) + 8|0);
 HEAPF64[$5>>3] = $9;
 HEAPF64[$13>>3] = $11;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$4>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$4+12>>2]|0;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$5>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$5+12>>2]|0;
 _cpow($3,$$byval_copy,$$byval_copy1);
 $14 = +HEAPF64[$3>>3];
 $15 = ((($3)) + 8|0);
 $16 = +HEAPF64[$15>>3];
 $17 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $14;
 HEAPF64[$17>>3] = $16;
 STACKTOP = sp;return;
}
function _creal($0) {
 $0 = $0|0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = +HEAPF64[$0>>3];
 return (+$1);
}
function _csqrtl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _csqrt($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _ccos($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = - $5;
 $7 = +HEAPF64[$1>>3];
 $8 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $6;
 HEAPF64[$8>>3] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ccosh($2,$$byval_copy);
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $9;
 HEAPF64[$12>>3] = $11;
 STACKTOP = sp;return;
}
function _ccosh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$sink = 0.0, $$sink141 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0;
 var $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 HEAPF64[tempDoublePtr>>3] = $4;$7 = HEAP32[tempDoublePtr>>2]|0;
 $8 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $6;$9 = HEAP32[tempDoublePtr>>2]|0;
 $10 = HEAP32[tempDoublePtr+4>>2]|0;
 $11 = $8 & 2147483647;
 $12 = $10 & 2147483647;
 $13 = ($11>>>0)<(2146435072);
 $14 = ($12>>>0)<(2146435072);
 $or$cond = $13 & $14;
 do {
  if ($or$cond) {
   $15 = $12 | $9;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (+_cosh($4));
    $18 = $4 * $6;
    $$sink = $18;$$sink141 = $17;
    break;
   }
   $19 = ($11>>>0)<(1077280768);
   if ($19) {
    $20 = (+_cosh($4));
    $21 = (+Math_cos((+$6)));
    $22 = $20 * $21;
    $23 = (+_sinh($4));
    $24 = (+Math_sin((+$6)));
    $25 = $23 * $24;
    $$sink = $25;$$sink141 = $22;
    break;
   }
   $26 = ($11>>>0)<(1082535490);
   if ($26) {
    $27 = (+Math_abs((+$4)));
    $28 = (+Math_exp((+$27)));
    $29 = $28 * 0.5;
    $30 = (+Math_cos((+$6)));
    $31 = $29 * $30;
    $32 = (+_copysign($29,$4));
    $33 = (+Math_sin((+$6)));
    $34 = $32 * $33;
    $$sink = $34;$$sink141 = $31;
    break;
   }
   $35 = ($11>>>0)<(1083620266);
   if ($35) {
    $36 = (+Math_abs((+$4)));
    $37 = ((($3)) + 8|0);
    HEAPF64[$3>>3] = $36;
    HEAPF64[$37>>3] = $6;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
    ___ldexp_cexp($2,$$byval_copy,-1);
    $38 = +HEAPF64[$2>>3];
    $39 = ((($2)) + 8|0);
    $40 = +HEAPF64[$39>>3];
    HEAPF64[$1>>3] = $38;
    HEAPF64[$5>>3] = $40;
    $41 = (+_copysign(1.0,$4));
    $42 = $40 * $41;
    $$sink = $42;$$sink141 = $38;
    break;
   } else {
    $43 = $4 * 8.9884656743115795E+307;
    $44 = $43 * $43;
    $45 = (+Math_cos((+$6)));
    $46 = $44 * $45;
    $47 = (+Math_sin((+$6)));
    $48 = $43 * $47;
    $$sink = $48;$$sink141 = $46;
    break;
   }
  } else {
   $49 = $11 | $7;
   $50 = ($49|0)==(0);
   $51 = ($12>>>0)>(2146435071);
   $or$cond3 = $50 & $51;
   if ($or$cond3) {
    $52 = $6 - $6;
    $53 = $4 * $52;
    $54 = (+_copysign(0.0,$53));
    $$sink = $54;$$sink141 = $52;
    break;
   }
   $55 = $12 | $9;
   $56 = ($55|0)==(0);
   $57 = ($11>>>0)>(2146435071);
   $or$cond5 = $57 & $56;
   if ($or$cond5) {
    $58 = $8 & 1048575;
    $59 = $58 | $7;
    $60 = ($59|0)==(0);
    $61 = $4 * $4;
    if ($60) {
     $62 = (+_copysign(0.0,$4));
     $63 = $6 * $62;
     $$sink = $63;$$sink141 = $61;
     break;
    } else {
     $64 = $4 + $4;
     $65 = $64 * $6;
     $66 = (+_copysign(0.0,$65));
     $$sink = $66;$$sink141 = $61;
     break;
    }
   }
   $or$cond7 = $13 & $51;
   if ($or$cond7) {
    $67 = $6 - $6;
    $68 = $4 * $67;
    $$sink = $68;$$sink141 = $67;
    break;
   }
   if ($57) {
    $69 = $8 & 1048575;
    $70 = $69 | $7;
    $71 = ($70|0)==(0);
    if ($71) {
     $72 = $4 * $4;
     if ($51) {
      $73 = $6 - $6;
      $74 = $4 * $73;
      $$sink = $74;$$sink141 = $72;
      break;
     } else {
      $75 = (+Math_cos((+$6)));
      $76 = $72 * $75;
      $77 = (+Math_sin((+$6)));
      $78 = $4 * $77;
      $$sink = $78;$$sink141 = $76;
      break;
     }
    }
   }
   $79 = $4 * $4;
   $80 = $6 - $6;
   $81 = $79 * $80;
   $82 = $4 + $4;
   $83 = $82 * $80;
   $$sink = $83;$$sink141 = $81;
  }
 } while(0);
 $84 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sink141;
 HEAPF64[$84>>3] = $$sink;
 STACKTOP = sp;return;
}
function _conj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($1)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 $5 = - $4;
 $6 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $2;
 HEAPF64[$6>>3] = $5;
 return;
}
function _cargl($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $2 = +HEAPF64[$0>>3];
 $3 = ((($0)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 $5 = ((($1)) + 8|0);
 HEAPF64[$1>>3] = $2;
 HEAPF64[$5>>3] = $4;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
 $6 = (+_carg($$byval_copy));
 STACKTOP = sp;return (+$6);
}
function _cproj($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0.0, $$sink3 = 0.0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = (___DOUBLE_BITS_682($2)|0);
 $4 = (getTempRet0() | 0);
 $5 = $4 & 2147483647;
 $6 = ($3|0)==(0);
 $7 = ($5|0)==(2146435072);
 $8 = $6 & $7;
 if ($8) {
  label = 3;
 } else {
  $9 = ((($1)) + 8|0);
  $10 = +HEAPF64[$9>>3];
  $11 = (___DOUBLE_BITS_682($10)|0);
  $12 = (getTempRet0() | 0);
  $13 = $12 & 2147483647;
  $14 = ($11|0)==(0);
  $15 = ($13|0)==(2146435072);
  $16 = $14 & $15;
  if ($16) {
   label = 3;
  } else {
   $$sink = $10;$$sink3 = $2;
  }
 }
 if ((label|0) == 3) {
  $17 = (+_copysign(0.0,$2));
  $$sink = $17;$$sink3 = inf;
 }
 $18 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sink3;
 HEAPF64[$18>>3] = $$sink;
 return;
}
function ___DOUBLE_BITS_682($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _cacosf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $4;
 HEAP32[$7>>2] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _casinf($2,$$byval_copy);
 $8 = +HEAPF32[$2>>2];
 $9 = ((($2)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = 1.5707963705062866 - $8;
 $12 = - $10;
 $13 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $11;
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function _casinf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy1 = sp + 40|0;
 $$byval_copy = sp + 32|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = +HEAPF32[$1>>2];
 $7 = ((($1)) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 - $8;
 $10 = $6 + $8;
 $11 = $9 * $10;
 $12 = 1.0 - $11;
 $13 = $6;
 $14 = $13 * -2.0;
 $15 = $8;
 $16 = $14 * $15;
 $17 = $16;
 $18 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $12;
 HEAPF32[$18>>2] = $17;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _csqrtf($2,$$byval_copy);
 $19 = +HEAPF32[$2>>2];
 $20 = ((($2)) + 4|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $19 - $8;
 $23 = $6 + $21;
 $24 = ((($5)) + 4|0);
 HEAPF32[$5>>2] = $22;
 HEAPF32[$24>>2] = $23;
 ;HEAP32[$$byval_copy1>>2]=HEAP32[$5>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$5+4>>2]|0;
 _clogf($4,$$byval_copy1);
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($4)) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $25;
 HEAP32[$28>>2] = $27;
 STACKTOP = sp;return;
}
function _csqrtf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0.0, $$sink51 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = ((($1)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $2 == 0.0;
 $6 = $4 == 0.0;
 $7 = $5 & $6;
 do {
  if ($7) {
   $$sink = $4;$$sink51 = 0.0;
  } else {
   $8 = (___FLOAT_BITS_685($4)|0);
   $9 = $8 & 2147483647;
   $10 = ($9|0)==(2139095040);
   if ($10) {
    $$sink = $4;$$sink51 = inf;
   } else {
    $11 = (___FLOAT_BITS_685($2)|0);
    $12 = $11 & 2147483647;
    $13 = ($12>>>0)>(2139095040);
    if ($13) {
     $14 = $4 - $4;
     $15 = $14 / $14;
     $$sink = $15;$$sink51 = $2;
     break;
    }
    $16 = ($12|0)==(2139095040);
    if ($16) {
     $17 = ($11|0)<(0);
     $18 = $4 - $4;
     if ($17) {
      $19 = (+Math_abs((+$18)));
      $20 = (+_copysignf($2,$4));
      $$sink = $20;$$sink51 = $19;
      break;
     } else {
      $21 = (+_copysignf($18,$4));
      $$sink = $21;$$sink51 = $2;
      break;
     }
    } else {
     $22 = !($2 >= 0.0);
     if ($22) {
      $33 = - $2;
      $34 = $33;
      $35 = $2;
      $36 = $4;
      $37 = (+_hypot($35,$36));
      $38 = $37 + $34;
      $39 = $38 * 0.5;
      $40 = (+Math_sqrt((+$39)));
      $41 = (+Math_abs((+$4)));
      $42 = $41;
      $43 = $40 * 2.0;
      $44 = $42 / $43;
      $45 = $44;
      $46 = $40;
      $47 = (+_copysignf($46,$4));
      $$sink = $47;$$sink51 = $45;
      break;
     } else {
      $23 = $2;
      $24 = $4;
      $25 = (+_hypot($23,$24));
      $26 = $25 + $23;
      $27 = $26 * 0.5;
      $28 = (+Math_sqrt((+$27)));
      $29 = $28;
      $30 = $28 * 2.0;
      $31 = $24 / $30;
      $32 = $31;
      $$sink = $32;$$sink51 = $29;
      break;
     }
    }
   }
  }
 } while(0);
 $48 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $$sink51;
 HEAPF32[$48>>2] = $$sink;
 return;
}
function ___FLOAT_BITS_685($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _ccoshf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0;
 var $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0.0;
 var $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0;
 var $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0;
 var $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0, $9 = 0, $or$cond = 0, $or$cond130 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = +HEAPF32[$1>>2];
 $5 = ((($1)) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
 $8 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
 $9 = $7 & 2147483647;
 $10 = $8 & 2147483647;
 $11 = ($9>>>0)<(2139095040);
 $12 = ($10>>>0)<(2139095040);
 $or$cond = $11 & $12;
 do {
  if ($or$cond) {
   $13 = ($10|0)==(0);
   if ($13) {
    $14 = (+_coshf($4));
    $15 = $4 * $6;
    $16 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $14;
    HEAPF32[$16>>2] = $15;
    break;
   }
   $17 = ($9>>>0)<(1091567616);
   if ($17) {
    $18 = (+_coshf($4));
    $19 = (+Math_cos((+$6)));
    $20 = $18 * $19;
    $21 = (+_sinhf($4));
    $22 = (+Math_sin((+$6)));
    $23 = $21 * $22;
    $24 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $20;
    HEAPF32[$24>>2] = $23;
    break;
   }
   $25 = ($9>>>0)<(1118925336);
   if ($25) {
    $26 = (+Math_abs((+$4)));
    $27 = (+Math_exp((+$26)));
    $28 = $27 * 0.5;
    $29 = (+Math_cos((+$6)));
    $30 = $28 * $29;
    $31 = (+_copysignf($28,$4));
    $32 = (+Math_sin((+$6)));
    $33 = $31 * $32;
    $34 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $30;
    HEAPF32[$34>>2] = $33;
    break;
   }
   $35 = ($9>>>0)<(1128313319);
   if ($35) {
    $36 = (+Math_abs((+$4)));
    $37 = ((($3)) + 4|0);
    HEAPF32[$3>>2] = $36;
    HEAPF32[$37>>2] = $6;
    ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
    ___ldexp_cexpf($2,$$byval_copy,-1);
    $38 = HEAP32[$2>>2]|0;
    $39 = ((($2)) + 4|0);
    $40 = +HEAPF32[$39>>2];
    HEAP32[$1>>2] = $38;
    HEAPF32[$5>>2] = $40;
    $41 = (+_copysignf(1.0,$4));
    $42 = $40 * $41;
    $43 = ((($0)) + 4|0);
    HEAP32[$0>>2] = $38;
    HEAPF32[$43>>2] = $42;
    break;
   } else {
    $44 = $4 * 1.7014118346046923E+38;
    $45 = $44 * $44;
    $46 = (+Math_cos((+$6)));
    $47 = $45 * $46;
    $48 = (+Math_sin((+$6)));
    $49 = $44 * $48;
    $50 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $47;
    HEAPF32[$50>>2] = $49;
    break;
   }
  } else {
   $51 = ($9|0)==(0);
   $52 = ($10>>>0)>(2139095039);
   $or$cond3 = $51 & $52;
   if ($or$cond3) {
    $53 = $6 - $6;
    $54 = $4 * $53;
    $55 = (+_copysignf(0.0,$54));
    $56 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $53;
    HEAPF32[$56>>2] = $55;
    break;
   }
   $57 = ($10|0)==(0);
   $58 = ($9>>>0)>(2139095039);
   $or$cond5 = $58 & $57;
   if ($or$cond5) {
    $59 = $7 & 8388607;
    $60 = ($59|0)==(0);
    $61 = $4 * $4;
    if ($60) {
     $62 = (+_copysignf(0.0,$4));
     $63 = $6 * $62;
     $64 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $61;
     HEAPF32[$64>>2] = $63;
     break;
    } else {
     $65 = $4 + $4;
     $66 = $65 * $6;
     $67 = (+_copysignf(0.0,$66));
     $68 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $61;
     HEAPF32[$68>>2] = $67;
     break;
    }
   }
   $or$cond7 = $11 & $52;
   if ($or$cond7) {
    $69 = $6 - $6;
    $70 = $4 * $69;
    $71 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $69;
    HEAPF32[$71>>2] = $70;
    break;
   }
   $72 = $7 & 8388607;
   $73 = ($72|0)==(0);
   $or$cond130 = $58 & $73;
   $74 = $4 * $4;
   if (!($or$cond130)) {
    $83 = $6 - $6;
    $84 = $74 * $83;
    $85 = $4 + $4;
    $86 = $85 * $83;
    $87 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $84;
    HEAPF32[$87>>2] = $86;
    break;
   }
   if ($52) {
    $75 = $6 - $6;
    $76 = $4 * $75;
    $77 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $74;
    HEAPF32[$77>>2] = $76;
    break;
   } else {
    $78 = (+Math_cos((+$6)));
    $79 = $74 * $78;
    $80 = (+Math_sin((+$6)));
    $81 = $4 * $80;
    $82 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $79;
    HEAPF32[$82>>2] = $81;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function _catanf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$sink = 0.0, $$sink40 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = ((($1)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $2 == 0.0;
 $6 = $4 > 1.0;
 $or$cond = $5 & $6;
 if ($or$cond) {
  $$sink = 9.9999996802856924E+37;$$sink40 = 9.9999996802856924E+37;
 } else {
  $7 = $2 * $2;
  $8 = 1.0 - $7;
  $9 = $4 * $4;
  $10 = $8 - $9;
  $11 = $10 == 0.0;
  if ($11) {
   $$sink = 9.9999996802856924E+37;$$sink40 = 9.9999996802856924E+37;
  } else {
   $12 = $2 * 2.0;
   $13 = (+Math_atan2((+$12),(+$10)));
   $14 = $4 + -1.0;
   $15 = $14 * $14;
   $16 = $7 + $15;
   $17 = $16 == 0.0;
   if ($17) {
    $$sink = 9.9999996802856924E+37;$$sink40 = 9.9999996802856924E+37;
   } else {
    $18 = $13 * 0.5;
    $19 = (+__redupif($18));
    $20 = $4 + 1.0;
    $21 = $20 * $20;
    $22 = $7 + $21;
    $23 = $22 / $16;
    $24 = (+Math_log((+$23)));
    $25 = $24 * 0.25;
    $26 = $25 * 0.0;
    $27 = $19 + $26;
    $28 = $25 + 0.0;
    $$sink = $28;$$sink40 = $27;
   }
  }
 }
 $29 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $$sink40;
 HEAPF32[$29>>2] = $$sink;
 return;
}
function __redupif($0) {
 $0 = +$0;
 var $$0 = 0.0, $$0$v = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 / 3.1415927410125732;
 $2 = !($1 >= 0.0);
 $$0$v = $2 ? -0.5 : 0.5;
 $$0 = $1 + $$0$v;
 $3 = (~~(($$0)));
 $4 = (+($3|0));
 $5 = $0;
 $6 = $4;
 $7 = $6 * 3.140625;
 $8 = $5 - $7;
 $9 = $6 * 9.6750259399414063E-4;
 $10 = $8 - $9;
 $11 = $6 * 1.5099579909783765E-7;
 $12 = $10 - $11;
 $13 = $12;
 return (+$13);
}
function _catanhf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($1)) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = - $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $6;
 HEAP32[$8>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _catanf($2,$$byval_copy);
 $9 = +HEAPF32[$2>>2];
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = - $9;
 $13 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $11;
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function _ccosl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ccos($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _casinl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _casin($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _ccosf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($1)) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = - $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $6;
 HEAP32[$8>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _ccoshf($2,$$byval_copy);
 $9 = HEAP32[$2>>2]|0;
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $9;
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function _cexpl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _cexp($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _csinf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($1)) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = - $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $6;
 HEAP32[$8>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _csinhf($2,$$byval_copy);
 $9 = +HEAPF32[$2>>2];
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = - $9;
 $13 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $11;
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function _ctanf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($1)) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = - $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $6;
 HEAP32[$8>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _ctanhf($2,$$byval_copy);
 $9 = +HEAPF32[$2>>2];
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = - $9;
 $13 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $11;
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function _ctanhf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0;
 var $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0;
 var $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = ((($1)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (HEAPF32[tempDoublePtr>>2]=$2,HEAP32[tempDoublePtr>>2]|0);
 $6 = $5 & 2147483647;
 $7 = ($6>>>0)>(2139095039);
 do {
  if ($7) {
   $8 = $5 & 8388607;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $4 == 0.0;
    $11 = $2 * $4;
    $12 = $10 ? $4 : $11;
    $13 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $2;
    HEAPF32[$13>>2] = $12;
    break;
   }
   $14 = (($5) + -1073741824)|0;
   $15 = (___FLOAT_BITS_713($4)|0);
   $16 = $15 & 2147483647;
   $17 = ($16|0)==(2139095040);
   if ($17) {
    $21 = $4;
   } else {
    $18 = (+Math_sin((+$4)));
    $19 = (+Math_cos((+$4)));
    $20 = $18 * $19;
    $21 = $20;
   }
   $22 = (+_copysignf(0.0,$21));
   $23 = ((($0)) + 4|0);
   HEAP32[$0>>2] = $14;
   HEAPF32[$23>>2] = $22;
  } else {
   $24 = (___FLOAT_BITS_713($4)|0);
   $25 = $24 & 2139095040;
   $26 = ($25|0)==(2139095040);
   if ($26) {
    $27 = ($6|0)==(0);
    $28 = $4 - $4;
    $29 = $27 ? $2 : $28;
    $30 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $29;
    HEAPF32[$30>>2] = $28;
    break;
   }
   $31 = ($6>>>0)>(1093664767);
   if ($31) {
    $32 = (+Math_abs((+$2)));
    $33 = - $32;
    $34 = (+Math_exp((+$33)));
    $35 = (+_copysignf(1.0,$2));
    $36 = (+Math_sin((+$4)));
    $37 = $36 * 4.0;
    $38 = (+Math_cos((+$4)));
    $39 = $37 * $38;
    $40 = $34 * $39;
    $41 = $34 * $40;
    $42 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $35;
    HEAPF32[$42>>2] = $41;
    break;
   } else {
    $43 = (+Math_tan((+$4)));
    $44 = $43 * $43;
    $45 = $44 + 1.0;
    $46 = (+_sinhf($2));
    $47 = $46 * $46;
    $48 = $47 + 1.0;
    $49 = (+Math_sqrt((+$48)));
    $50 = $46 * $45;
    $51 = $46 * $50;
    $52 = $51 + 1.0;
    $53 = $45 * $49;
    $54 = $46 * $53;
    $55 = $54 / $52;
    $56 = $43 / $52;
    $57 = ((($0)) + 4|0);
    HEAPF32[$0>>2] = $55;
    HEAPF32[$57>>2] = $56;
    break;
   }
  }
 } while(0);
 return;
}
function ___FLOAT_BITS_713($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _cacoshf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($1)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($3)) + 4|0);
 HEAP32[$3>>2] = $4;
 HEAP32[$7>>2] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _cacosf($2,$$byval_copy);
 $8 = HEAP32[$2>>2]|0;
 $9 = ((($2)) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = - $10;
 $12 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return;
}
function _cprojf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF32[$1>>2];
 $3 = (___FLOAT_BITS_698($2)|0);
 $4 = $3 & 2147483647;
 $5 = ($4|0)==(2139095040);
 if ($5) {
  label = 3;
 } else {
  $6 = ((($1)) + 4|0);
  $7 = +HEAPF32[$6>>2];
  $8 = (___FLOAT_BITS_698($7)|0);
  $9 = $8 & 2147483647;
  $10 = ($9|0)==(2139095040);
  if ($10) {
   label = 3;
  } else {
   $13 = ((($0)) + 4|0);
   HEAPF32[$0>>2] = $2;
   HEAPF32[$13>>2] = $7;
  }
 }
 if ((label|0) == 3) {
  $11 = (+_copysignf(0.0,$2));
  $12 = ((($0)) + 4|0);
  HEAPF32[$0>>2] = inf;
  HEAPF32[$12>>2] = $11;
 }
 return;
}
function ___FLOAT_BITS_698($0) {
 $0 = +$0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 return ($1|0);
}
function _ccoshl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ccosh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _conjl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($1)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 $5 = - $4;
 $6 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $2;
 HEAPF64[$6>>3] = $5;
 return;
}
function _cabsl($0) {
 $0 = $0|0;
 var $$byval_copy = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $2 = +HEAPF64[$0>>3];
 $3 = ((($0)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 $5 = ((($1)) + 8|0);
 HEAPF64[$1>>3] = $2;
 HEAPF64[$5>>3] = $4;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$1>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
 $6 = (+_cabs($$byval_copy));
 STACKTOP = sp;return (+$6);
}
function _ctanhl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ctanh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _ctanh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0;
 var $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0;
 var $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = +HEAPF64[$1>>3];
 $3 = ((($1)) + 8|0);
 $4 = +HEAPF64[$3>>3];
 HEAPF64[tempDoublePtr>>3] = $2;$5 = HEAP32[tempDoublePtr>>2]|0;
 $6 = HEAP32[tempDoublePtr+4>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)>(2146435071);
 do {
  if ($8) {
   $9 = $6 & 1048575;
   $10 = $9 | $5;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = $4 == 0.0;
    $13 = $2 * $4;
    $14 = $12 ? $4 : $13;
    $15 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $2;
    HEAPF64[$15>>3] = $14;
    break;
   }
   $16 = (($6) + -1073741824)|0;
   $17 = (___DOUBLE_BITS_707($4)|0);
   $18 = (getTempRet0() | 0);
   $19 = $18 & 2147483647;
   $20 = ($17|0)==(0);
   $21 = ($19|0)==(2146435072);
   $22 = $20 & $21;
   if ($22) {
    $26 = $4;
   } else {
    $23 = (+Math_sin((+$4)));
    $24 = (+Math_cos((+$4)));
    $25 = $23 * $24;
    $26 = $25;
   }
   $27 = (+_copysign(0.0,$26));
   $28 = ((($0)) + 8|0);
   $29 = $0;
   $30 = $29;
   HEAP32[$30>>2] = $5;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $16;
   HEAPF64[$28>>3] = $27;
  } else {
   (___DOUBLE_BITS_707($4)|0);
   $33 = (getTempRet0() | 0);
   $34 = $33 & 2146435072;
   $35 = (0)==(0);
   $36 = ($34|0)==(2146435072);
   $37 = $35 & $36;
   if ($37) {
    $38 = $2 != 0.0;
    $39 = $4 - $4;
    $40 = $38 ? $39 : $2;
    $41 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $40;
    HEAPF64[$41>>3] = $39;
    break;
   }
   $42 = ($7>>>0)>(1077280767);
   if ($42) {
    $43 = (+Math_abs((+$2)));
    $44 = - $43;
    $45 = (+Math_exp((+$44)));
    $46 = (+_copysign(1.0,$2));
    $47 = (+Math_sin((+$4)));
    $48 = $47 * 4.0;
    $49 = (+Math_cos((+$4)));
    $50 = $48 * $49;
    $51 = $45 * $50;
    $52 = $45 * $51;
    $53 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $46;
    HEAPF64[$53>>3] = $52;
    break;
   } else {
    $54 = (+Math_tan((+$4)));
    $55 = $54 * $54;
    $56 = $55 + 1.0;
    $57 = (+_sinh($2));
    $58 = $57 * $57;
    $59 = $58 + 1.0;
    $60 = (+Math_sqrt((+$59)));
    $61 = $57 * $56;
    $62 = $57 * $61;
    $63 = $62 + 1.0;
    $64 = $56 * $60;
    $65 = $57 * $64;
    $66 = $65 / $63;
    $67 = $54 / $63;
    $68 = ((($0)) + 8|0);
    HEAPF64[$0>>3] = $66;
    HEAPF64[$68>>3] = $67;
    break;
   }
  }
 } while(0);
 return;
}
function ___DOUBLE_BITS_707($0) {
 $0 = +$0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 setTempRet0(($2) | 0);
 return ($1|0);
}
function _casinhf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(32|0);
 $$byval_copy = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = ((($1)) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = - $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($3)) + 4|0);
 HEAPF32[$3>>2] = $6;
 HEAP32[$8>>2] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 _casinf($2,$$byval_copy);
 $9 = +HEAPF32[$2>>2];
 $10 = ((($2)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = - $9;
 $13 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $11;
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function _crealf($0) {
 $0 = $0|0;
 var $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = +HEAPF32[$0>>2];
 return (+$1);
}
function _casinhl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _casinh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _casinh($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = - $5;
 $7 = +HEAPF64[$1>>3];
 $8 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $6;
 HEAPF64[$8>>3] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _casin($2,$$byval_copy);
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = - $9;
 $13 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$13>>3] = $12;
 STACKTOP = sp;return;
}
function _ctan($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = ((($1)) + 8|0);
 $5 = +HEAPF64[$4>>3];
 $6 = - $5;
 $7 = +HEAPF64[$1>>3];
 $8 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $6;
 HEAPF64[$8>>3] = $7;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ctanh($2,$$byval_copy);
 $9 = +HEAPF64[$2>>3];
 $10 = ((($2)) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = - $9;
 $13 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $11;
 HEAPF64[$13>>3] = $12;
 STACKTOP = sp;return;
}
function _cprojl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _cproj($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _catanl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _catan($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _csinl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _csin($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _clogl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _clog($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _cimagl($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = +HEAPF64[$1>>3];
 return (+$2);
}
function _csinhl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _csinh($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _conjf($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($1)) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = - $4;
 $6 = ((($0)) + 4|0);
 HEAP32[$0>>2] = $2;
 HEAPF32[$6>>2] = $5;
 return;
}
function _cacosl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _cacos($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _ctanl($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abortStackOverflow(48|0);
 $$byval_copy = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = +HEAPF64[$1>>3];
 $5 = ((($1)) + 8|0);
 $6 = +HEAPF64[$5>>3];
 $7 = ((($3)) + 8|0);
 HEAPF64[$3>>3] = $4;
 HEAPF64[$7>>3] = $6;
 ;HEAP32[$$byval_copy>>2]=HEAP32[$3>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 _ctan($2,$$byval_copy);
 $8 = +HEAPF64[$2>>3];
 $9 = ((($2)) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $8;
 HEAPF64[$11>>3] = $10;
 STACKTOP = sp;return;
}
function _cimag($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ((($0)) + 8|0);
 $2 = +HEAPF64[$1>>3];
 return (+$2);
}
function ___libc_get_version() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (167830) | 0)|0);
}
function ___iswupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswupper($0)|0);
 return ($2|0);
}
function ___ctype_toupper_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (166344) | 0)|0);
}
function ___tolower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_tolower($0)|0);
 return ($2|0);
}
function ___iscntrl_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iscntrl($0)|0);
 return ($2|0);
}
function ___iswspace_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswspace($0)|0);
 return ($2|0);
}
function ___isgraph_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isgraph($0)|0);
 return ($2|0);
}
function ___isupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isupper($0)|0);
 return ($2|0);
}
function _wcswidth($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $$01216 = 0, $$01415 = 0, $$in = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $11 = 0;
  } else {
   $$01216 = 0;$$01415 = $0;$$in = $1;
   while(1) {
    $3 = (($$in) + -1)|0;
    $4 = HEAP32[$$01415>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     $11 = $$01216;
     break L1;
    }
    $6 = (_wcwidth($4)|0);
    $7 = ($6|0)>(-1);
    if (!($7)) {
     $11 = $6;
     break L1;
    }
    $8 = (($6) + ($$01216))|0;
    $9 = ((($$01415)) + 4|0);
    $10 = ($3|0)==(0);
    if ($10) {
     $11 = $8;
     break;
    } else {
     $$01216 = $8;$$01415 = $9;$$in = $3;
    }
   }
  }
 } while(0);
 return ($11|0);
}
function _wcwidth($0) {
 $0 = $0|0;
 var $$ = 0, $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$or$cond15 = 0, $spec$select = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(255);
 do {
  if ($1) {
   $2 = (($0) + 1)|0;
   $3 = $2 & 127;
   $4 = ($3>>>0)>(32);
   $5 = ($0|0)!=(0);
   $6 = $5 << 31 >> 31;
   $7 = $4 ? 1 : $6;
   $$0 = $7;
  } else {
   $8 = $0 & -65538;
   $9 = ($8>>>0)<(65534);
   if ($9) {
    $10 = $0 >> 8;
    $11 = ((gb + (155952) | 0) + ($10)|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12&255;
    $14 = $13 << 5;
    $15 = $0 >>> 3;
    $16 = $15 & 31;
    $17 = $14 | $16;
    $18 = ((gb + (155952) | 0) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19&255;
    $21 = $0 & 7;
    $22 = 1 << $21;
    $23 = $22 & $20;
    $24 = ($23|0)==(0);
    if (!($24)) {
     $$0 = 0;
     break;
    }
    $25 = ((gb + (157872) | 0) + ($10)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = $27 << 5;
    $29 = $28 | $16;
    $30 = ((gb + (157872) | 0) + ($29)|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31&255;
    $33 = $22 & $32;
    $34 = ($33|0)==(0);
    $$ = $34 ? 1 : 2;
    $$0 = $$;
    break;
   }
   $35 = $0 & 65534;
   $36 = ($35|0)==(65534);
   if ($36) {
    $$0 = -1;
   } else {
    $37 = $0 & -131072;
    $38 = ($37|0)==(131072);
    if ($38) {
     $$0 = 2;
    } else {
     $39 = (($0) + -917536)|0;
     $40 = ($39>>>0)>(94);
     $41 = ($0|0)>(917998);
     $not$or$cond15 = $41 & $40;
     $spec$select = $not$or$cond15&1;
     return ($spec$select|0);
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function ___isprint_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isprint($0)|0);
 return ($2|0);
}
function ___isdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isdigit($0)|0);
 return ($2|0);
}
function ___ctype_tolower_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (166348) | 0)|0);
}
function ___iswctype_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_iswctype($0,$1)|0);
 return ($3|0);
}
function ___wctype_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wctype($0)|0);
 return ($2|0);
}
function ___iswcntrl_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswcntrl($0)|0);
 return ($2|0);
}
function _toascii($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $0 & 127;
 return ($1|0);
}
function ___ctype_b_loc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 return ((gb + (166352) | 0)|0);
}
function _isascii($0) {
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($0>>>0)<(128);
 $2 = $1&1;
 return ($2|0);
}
function ___isxdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isxdigit($0)|0);
 return ($2|0);
}
function ___toupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_toupper($0)|0);
 return ($2|0);
}
function ___iswalnum_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswalnum($0)|0);
 return ($2|0);
}
function ___iswxdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswxdigit($0)|0);
 return ($2|0);
}
function ___isblank_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isblank($0)|0);
 return ($2|0);
}
function ___iswblank_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswblank($0)|0);
 return ($2|0);
}
function ___ispunct_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_ispunct($0)|0);
 return ($2|0);
}
function ___iswprint_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswprint($0)|0);
 return ($2|0);
}
function ___islower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_islower($0)|0);
 return ($2|0);
}
function ___isalpha_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isalpha($0)|0);
 return ($2|0);
}
function ___isalnum_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isalnum($0)|0);
 return ($2|0);
}
function ___iswpunct_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswpunct($0)|0);
 return ($2|0);
}
function ___isspace_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_isspace($0)|0);
 return ($2|0);
}
function ___wctrans_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_wctrans($0)|0);
 return ($2|0);
}
function ___towctrans_l($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (_towctrans($0,$1)|0);
 return ($3|0);
}
function ___towupper_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_towupper($0)|0);
 return ($2|0);
}
function ___towlower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_towlower($0)|0);
 return ($2|0);
}
function ___iswdigit_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswdigit($0)|0);
 return ($2|0);
}
function ___iswalpha_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswalpha($0)|0);
 return ($2|0);
}
function ___iswlower_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswlower($0)|0);
 return ($2|0);
}
function ___iswgraph_l($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_iswgraph($0)|0);
 return ($2|0);
}
function ___ctype_get_mb_cur_max() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___pthread_self_828()|0);
 $1 = ((($0)) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = $4 ? 1 : 4;
 return ($5|0);
}
function ___pthread_self_828() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 return ($0|0);
}
function ___divdc3($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0 = 0, $$072 = 0.0, $$073 = 0.0, $$sroa$0$0 = 0.0, $$sroa$8$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $8 = 0.0, $9 = 0.0, $or$cond$not = 0, $or$cond74 = 0, $or$cond75 = 0, $or$cond77 = 0, $or$cond77$not = 0;
 var $or$cond79 = 0, $or$cond81 = 0, $or$cond82 = 0, $or$cond84 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (+Math_abs((+$3)));
 $6 = (+Math_abs((+$4)));
 $7 = (+_llvm_maxnum_f64((+$5),(+$6)));
 $8 = (+_logb($7));
 $9 = (+Math_abs((+$8)));
 $10 = ($9 != $9) | (inf != inf) |($9 == inf);
 $11 = (~~(($8)));
 $12 = (0 - ($11))|0;
 if ($10) {
  $$0 = 0;$$072 = $4;$$073 = $3;
 } else {
  $13 = (+_scalbn($3,$12));
  $14 = (+_scalbn($4,$12));
  $$0 = $12;$$072 = $14;$$073 = $13;
 }
 $15 = $$073 * $$073;
 $16 = $$072 * $$072;
 $17 = $15 + $16;
 $18 = $$073 * $1;
 $19 = $$072 * $2;
 $20 = $18 + $19;
 $21 = $20 / $17;
 $22 = (+_scalbn($21,$$0));
 $23 = $$073 * $2;
 $24 = $$072 * $1;
 $25 = $23 - $24;
 $26 = $25 / $17;
 $27 = (+_scalbn($26,$$0));
 $28 = ($22 != $22) | (0.0 != 0.0);
 $29 = ($27 != $27) | (0.0 != 0.0);
 $or$cond74 = $28 & $29;
 if (!($or$cond74)) {
  $$sroa$0$0 = $22;$$sroa$8$0 = $27;
  $74 = ((($0)) + 8|0);
  HEAPF64[$0>>3] = $$sroa$0$0;
  HEAPF64[$74>>3] = $$sroa$8$0;
  return;
 }
 $30 = $17 == 0.0;
 if ($30) {
  $31 = ($1 != $1) | (0.0 != 0.0);
  $32 = ($2 != $2) | (0.0 != 0.0);
  $or$cond75 = $31 & $32;
  if (!($or$cond75)) {
   $33 = (+_llvm_copysign_f64(inf,(+$$073)));
   $34 = $33 * $1;
   $35 = $33 * $2;
   $$sroa$0$0 = $34;$$sroa$8$0 = $35;
   $74 = ((($0)) + 8|0);
   HEAPF64[$0>>3] = $$sroa$0$0;
   HEAPF64[$74>>3] = $$sroa$8$0;
   return;
  }
 }
 $36 = (+Math_abs((+$1)));
 $37 = $36 == inf;
 $38 = (+Math_abs((+$2)));
 $39 = $38 == inf;
 $or$cond77 = $37 | $39;
 $or$cond77$not = $or$cond77 ^ 1;
 $40 = (+Math_abs((+$$073)));
 $41 = ($40 != $40) | (inf != inf) |($40 == inf);
 $or$cond79 = $41 | $or$cond77$not;
 $42 = (+Math_abs((+$$072)));
 $43 = ($42 != $42) | (inf != inf) |($42 == inf);
 $or$cond81 = $or$cond79 | $43;
 if (!($or$cond81)) {
  $44 = $37 ? 1.0 : 0.0;
  $45 = (+_llvm_copysign_f64((+$44),(+$1)));
  $46 = $39 ? 1.0 : 0.0;
  $47 = (+_llvm_copysign_f64((+$46),(+$2)));
  $48 = $45 * $$073;
  $49 = $47 * $$072;
  $50 = $48 + $49;
  $51 = $50 * inf;
  $52 = $47 * $$073;
  $53 = $45 * $$072;
  $54 = $52 - $53;
  $55 = $54 * inf;
  $$sroa$0$0 = $51;$$sroa$8$0 = $55;
  $74 = ((($0)) + 8|0);
  HEAPF64[$0>>3] = $$sroa$0$0;
  HEAPF64[$74>>3] = $$sroa$8$0;
  return;
 }
 $56 = $9 != inf;
 $57 = !($8 > 0.0);
 $or$cond$not = $57 | $56;
 $58 = ($36 != $36) | (inf != inf) |($36 == inf);
 $or$cond82 = $58 | $or$cond$not;
 $59 = ($38 != $38) | (inf != inf) |($38 == inf);
 $or$cond84 = $59 | $or$cond82;
 if ($or$cond84) {
  $$sroa$0$0 = $22;$$sroa$8$0 = $27;
  $74 = ((($0)) + 8|0);
  HEAPF64[$0>>3] = $$sroa$0$0;
  HEAPF64[$74>>3] = $$sroa$8$0;
  return;
 }
 $60 = $40 == inf;
 $61 = $60 ? 1.0 : 0.0;
 $62 = (+_llvm_copysign_f64((+$61),(+$$073)));
 $63 = $42 == inf;
 $64 = $63 ? 1.0 : 0.0;
 $65 = (+_llvm_copysign_f64((+$64),(+$$072)));
 $66 = $62 * $1;
 $67 = $65 * $2;
 $68 = $66 + $67;
 $69 = $68 * 0.0;
 $70 = $62 * $2;
 $71 = $65 * $1;
 $72 = $70 - $71;
 $73 = $72 * 0.0;
 $$sroa$0$0 = $69;$$sroa$8$0 = $73;
 $74 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sroa$0$0;
 HEAPF64[$74>>3] = $$sroa$8$0;
 return;
}
function ___divsc3($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0 = 0, $$072 = 0.0, $$073 = 0.0, $$sroa$0$0 = 0.0, $$sroa$8$0 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0;
 var $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $8 = 0.0, $9 = 0.0, $or$cond$not = 0, $or$cond74 = 0, $or$cond75 = 0, $or$cond77 = 0, $or$cond77$not = 0;
 var $or$cond79 = 0, $or$cond81 = 0, $or$cond82 = 0, $or$cond84 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (+Math_abs((+$3)));
 $6 = (+Math_abs((+$4)));
 $7 = (+_llvm_maxnum_f32((+$5),(+$6)));
 $8 = (+_logbf($7));
 $9 = (+Math_abs((+$8)));
 $10 = ($9 != $9) | (inf != inf) |($9 == inf);
 $11 = (~~(($8)));
 $12 = (0 - ($11))|0;
 if ($10) {
  $$0 = 0;$$072 = $4;$$073 = $3;
 } else {
  $13 = (+_scalbnf($3,$12));
  $14 = (+_scalbnf($4,$12));
  $$0 = $12;$$072 = $14;$$073 = $13;
 }
 $15 = $$073 * $$073;
 $16 = $$072 * $$072;
 $17 = $15 + $16;
 $18 = $$073 * $1;
 $19 = $$072 * $2;
 $20 = $18 + $19;
 $21 = $20 / $17;
 $22 = (+_scalbnf($21,$$0));
 $23 = $$073 * $2;
 $24 = $$072 * $1;
 $25 = $23 - $24;
 $26 = $25 / $17;
 $27 = (+_scalbnf($26,$$0));
 $28 = ($22 != $22) | (0.0 != 0.0);
 $29 = ($27 != $27) | (0.0 != 0.0);
 $or$cond74 = $28 & $29;
 if (!($or$cond74)) {
  $$sroa$0$0 = $22;$$sroa$8$0 = $27;
  $74 = ((($0)) + 4|0);
  HEAPF32[$0>>2] = $$sroa$0$0;
  HEAPF32[$74>>2] = $$sroa$8$0;
  return;
 }
 $30 = $17 == 0.0;
 if ($30) {
  $31 = ($1 != $1) | (0.0 != 0.0);
  $32 = ($2 != $2) | (0.0 != 0.0);
  $or$cond75 = $31 & $32;
  if (!($or$cond75)) {
   $33 = (+_llvm_copysign_f32(inf,(+$$073)));
   $34 = $33 * $1;
   $35 = $33 * $2;
   $$sroa$0$0 = $34;$$sroa$8$0 = $35;
   $74 = ((($0)) + 4|0);
   HEAPF32[$0>>2] = $$sroa$0$0;
   HEAPF32[$74>>2] = $$sroa$8$0;
   return;
  }
 }
 $36 = (+Math_abs((+$1)));
 $37 = $36 == inf;
 $38 = (+Math_abs((+$2)));
 $39 = $38 == inf;
 $or$cond77 = $37 | $39;
 $or$cond77$not = $or$cond77 ^ 1;
 $40 = (+Math_abs((+$$073)));
 $41 = ($40 != $40) | (inf != inf) |($40 == inf);
 $or$cond79 = $41 | $or$cond77$not;
 $42 = (+Math_abs((+$$072)));
 $43 = ($42 != $42) | (inf != inf) |($42 == inf);
 $or$cond81 = $or$cond79 | $43;
 if (!($or$cond81)) {
  $44 = (+($37&1));
  $45 = (+_llvm_copysign_f32((+$44),(+$1)));
  $46 = (+($39&1));
  $47 = (+_llvm_copysign_f32((+$46),(+$2)));
  $48 = $45 * $$073;
  $49 = $47 * $$072;
  $50 = $48 + $49;
  $51 = $50 * inf;
  $52 = $47 * $$073;
  $53 = $45 * $$072;
  $54 = $52 - $53;
  $55 = $54 * inf;
  $$sroa$0$0 = $51;$$sroa$8$0 = $55;
  $74 = ((($0)) + 4|0);
  HEAPF32[$0>>2] = $$sroa$0$0;
  HEAPF32[$74>>2] = $$sroa$8$0;
  return;
 }
 $56 = $9 != inf;
 $57 = !($8 > 0.0);
 $or$cond$not = $57 | $56;
 $58 = ($36 != $36) | (inf != inf) |($36 == inf);
 $or$cond82 = $58 | $or$cond$not;
 $59 = ($38 != $38) | (inf != inf) |($38 == inf);
 $or$cond84 = $59 | $or$cond82;
 if ($or$cond84) {
  $$sroa$0$0 = $22;$$sroa$8$0 = $27;
  $74 = ((($0)) + 4|0);
  HEAPF32[$0>>2] = $$sroa$0$0;
  HEAPF32[$74>>2] = $$sroa$8$0;
  return;
 }
 $60 = $40 == inf;
 $61 = (+($60&1));
 $62 = (+_llvm_copysign_f32((+$61),(+$$073)));
 $63 = $42 == inf;
 $64 = (+($63&1));
 $65 = (+_llvm_copysign_f32((+$64),(+$$072)));
 $66 = $62 * $1;
 $67 = $65 * $2;
 $68 = $66 + $67;
 $69 = $68 * 0.0;
 $70 = $62 * $2;
 $71 = $65 * $1;
 $72 = $70 - $71;
 $73 = $72 * 0.0;
 $$sroa$0$0 = $69;$$sroa$8$0 = $73;
 $74 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $$sroa$0$0;
 HEAPF32[$74>>2] = $$sroa$8$0;
 return;
}
function ___muldc3($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0 = 0, $$066 = 0.0, $$069 = 0.0, $$074 = 0.0, $$079 = 0.0, $$167 = 0.0, $$170 = 0.0, $$175 = 0.0, $$180 = 0.0, $$3 = 0.0, $$372 = 0.0, $$377 = 0.0, $$382 = 0.0, $$4$ph = 0.0, $$473$ph = 0.0, $$478$ph = 0.0, $$483$ph = 0.0, $$sroa$0$1 = 0.0, $$sroa$6$1 = 0.0, $10 = 0.0;
 var $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $30 = 0.0;
 var $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0.0;
 var $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, $or$cond85 = 0, $or$cond87 = 0;
 var $or$cond89 = 0, $or$cond91 = 0, $or$cond93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $1 * $3;
 $6 = $2 * $4;
 $7 = $1 * $4;
 $8 = $2 * $3;
 $9 = $5 - $6;
 $10 = $8 + $7;
 $11 = ($9 != $9) | (0.0 != 0.0);
 $12 = ($10 != $10) | (0.0 != 0.0);
 $or$cond = $11 & $12;
 if (!($or$cond)) {
  $$sroa$0$1 = $9;$$sroa$6$1 = $10;
  $62 = ((($0)) + 8|0);
  HEAPF64[$0>>3] = $$sroa$0$1;
  HEAPF64[$62>>3] = $$sroa$6$1;
  return;
 }
 $13 = (+Math_abs((+$1)));
 $14 = $13 == inf;
 $15 = (+Math_abs((+$2)));
 $16 = $15 == inf;
 $or$cond85 = $14 | $16;
 if ($or$cond85) {
  $17 = (+($14&1));
  $18 = (+_llvm_copysign_f64((+$17),(+$1)));
  $19 = (+($16&1));
  $20 = (+_llvm_copysign_f64((+$19),(+$2)));
  $21 = ($3 != $3) | (0.0 != 0.0);
  $22 = (+_llvm_copysign_f64(0.0,(+$3)));
  $$074 = $21 ? $22 : $3;
  $23 = ($4 != $4) | (0.0 != 0.0);
  $24 = (+_llvm_copysign_f64(0.0,(+$4)));
  $$079 = $23 ? $24 : $4;
  $$0 = 1;$$066 = $18;$$069 = $20;$$175 = $$074;$$180 = $$079;
 } else {
  $$0 = 0;$$066 = $1;$$069 = $2;$$175 = $3;$$180 = $4;
 }
 $25 = (+Math_abs((+$$175)));
 $26 = $25 == inf;
 $27 = (+Math_abs((+$$180)));
 $28 = $27 == inf;
 $or$cond87 = $28 | $26;
 do {
  if ($or$cond87) {
   $29 = (+($26&1));
   $30 = (+_llvm_copysign_f64((+$29),(+$$175)));
   $31 = (+($28&1));
   $32 = (+_llvm_copysign_f64((+$31),(+$$180)));
   $33 = ($$066 != $$066) | (0.0 != 0.0);
   $34 = (+_llvm_copysign_f64(0.0,(+$$066)));
   $$167 = $33 ? $34 : $$066;
   $35 = ($$069 != $$069) | (0.0 != 0.0);
   $36 = (+_llvm_copysign_f64(0.0,(+$$069)));
   $$170 = $35 ? $36 : $$069;
   $$4$ph = $$167;$$473$ph = $$170;$$478$ph = $30;$$483$ph = $32;
  } else {
   $37 = ($$0|0)==(0);
   if ($37) {
    $38 = (+Math_abs((+$5)));
    $39 = $38 == inf;
    $40 = (+Math_abs((+$6)));
    $41 = $40 == inf;
    $or$cond89 = $39 | $41;
    $42 = (+Math_abs((+$7)));
    $43 = $42 == inf;
    $or$cond91 = $43 | $or$cond89;
    $44 = (+Math_abs((+$8)));
    $45 = $44 == inf;
    $or$cond93 = $45 | $or$cond91;
    if ($or$cond93) {
     $46 = ($$066 != $$066) | (0.0 != 0.0);
     $47 = (+_llvm_copysign_f64(0.0,(+$$066)));
     $$3 = $46 ? $47 : $$066;
     $48 = ($$069 != $$069) | (0.0 != 0.0);
     $49 = (+_llvm_copysign_f64(0.0,(+$$069)));
     $$372 = $48 ? $49 : $$069;
     $50 = ($$175 != $$175) | (0.0 != 0.0);
     $51 = (+_llvm_copysign_f64(0.0,(+$$175)));
     $$377 = $50 ? $51 : $$175;
     $52 = ($$180 != $$180) | (0.0 != 0.0);
     $53 = (+_llvm_copysign_f64(0.0,(+$$180)));
     $$382 = $52 ? $53 : $$180;
     $$4$ph = $$3;$$473$ph = $$372;$$478$ph = $$377;$$483$ph = $$382;
     break;
    } else {
     $$sroa$0$1 = $9;$$sroa$6$1 = $10;
     $62 = ((($0)) + 8|0);
     HEAPF64[$0>>3] = $$sroa$0$1;
     HEAPF64[$62>>3] = $$sroa$6$1;
     return;
    }
   } else {
    $$4$ph = $$066;$$473$ph = $$069;$$478$ph = $$175;$$483$ph = $$180;
   }
  }
 } while(0);
 $54 = $$478$ph * $$4$ph;
 $55 = $$483$ph * $$473$ph;
 $56 = $54 - $55;
 $57 = $56 * inf;
 $58 = $$483$ph * $$4$ph;
 $59 = $$478$ph * $$473$ph;
 $60 = $59 + $58;
 $61 = $60 * inf;
 $$sroa$0$1 = $57;$$sroa$6$1 = $61;
 $62 = ((($0)) + 8|0);
 HEAPF64[$0>>3] = $$sroa$0$1;
 HEAPF64[$62>>3] = $$sroa$6$1;
 return;
}
function ___mulsc3($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = +$1;
 $2 = +$2;
 $3 = +$3;
 $4 = +$4;
 var $$0 = 0, $$066 = 0.0, $$069 = 0.0, $$074 = 0.0, $$079 = 0.0, $$167 = 0.0, $$170 = 0.0, $$175 = 0.0, $$180 = 0.0, $$3 = 0.0, $$372 = 0.0, $$377 = 0.0, $$382 = 0.0, $$4$ph = 0.0, $$473$ph = 0.0, $$478$ph = 0.0, $$483$ph = 0.0, $$sroa$0$1 = 0.0, $$sroa$6$1 = 0.0, $10 = 0.0;
 var $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $30 = 0.0;
 var $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0.0;
 var $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0, $or$cond85 = 0, $or$cond87 = 0;
 var $or$cond89 = 0, $or$cond91 = 0, $or$cond93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = $1 * $3;
 $6 = $2 * $4;
 $7 = $1 * $4;
 $8 = $2 * $3;
 $9 = $5 - $6;
 $10 = $8 + $7;
 $11 = ($9 != $9) | (0.0 != 0.0);
 $12 = ($10 != $10) | (0.0 != 0.0);
 $or$cond = $11 & $12;
 if (!($or$cond)) {
  $$sroa$0$1 = $9;$$sroa$6$1 = $10;
  $62 = ((($0)) + 4|0);
  HEAPF32[$0>>2] = $$sroa$0$1;
  HEAPF32[$62>>2] = $$sroa$6$1;
  return;
 }
 $13 = (+Math_abs((+$1)));
 $14 = $13 == inf;
 $15 = (+Math_abs((+$2)));
 $16 = $15 == inf;
 $or$cond85 = $14 | $16;
 if ($or$cond85) {
  $17 = (+($14&1));
  $18 = (+_llvm_copysign_f32((+$17),(+$1)));
  $19 = (+($16&1));
  $20 = (+_llvm_copysign_f32((+$19),(+$2)));
  $21 = ($3 != $3) | (0.0 != 0.0);
  $22 = (+_llvm_copysign_f32(0.0,(+$3)));
  $$074 = $21 ? $22 : $3;
  $23 = ($4 != $4) | (0.0 != 0.0);
  $24 = (+_llvm_copysign_f32(0.0,(+$4)));
  $$079 = $23 ? $24 : $4;
  $$0 = 1;$$066 = $18;$$069 = $20;$$175 = $$074;$$180 = $$079;
 } else {
  $$0 = 0;$$066 = $1;$$069 = $2;$$175 = $3;$$180 = $4;
 }
 $25 = (+Math_abs((+$$175)));
 $26 = $25 == inf;
 $27 = (+Math_abs((+$$180)));
 $28 = $27 == inf;
 $or$cond87 = $28 | $26;
 do {
  if ($or$cond87) {
   $29 = (+($26&1));
   $30 = (+_llvm_copysign_f32((+$29),(+$$175)));
   $31 = (+($28&1));
   $32 = (+_llvm_copysign_f32((+$31),(+$$180)));
   $33 = ($$066 != $$066) | (0.0 != 0.0);
   $34 = (+_llvm_copysign_f32(0.0,(+$$066)));
   $$167 = $33 ? $34 : $$066;
   $35 = ($$069 != $$069) | (0.0 != 0.0);
   $36 = (+_llvm_copysign_f32(0.0,(+$$069)));
   $$170 = $35 ? $36 : $$069;
   $$4$ph = $$167;$$473$ph = $$170;$$478$ph = $30;$$483$ph = $32;
  } else {
   $37 = ($$0|0)==(0);
   if ($37) {
    $38 = (+Math_abs((+$5)));
    $39 = $38 == inf;
    $40 = (+Math_abs((+$6)));
    $41 = $40 == inf;
    $or$cond89 = $39 | $41;
    $42 = (+Math_abs((+$7)));
    $43 = $42 == inf;
    $or$cond91 = $43 | $or$cond89;
    $44 = (+Math_abs((+$8)));
    $45 = $44 == inf;
    $or$cond93 = $45 | $or$cond91;
    if ($or$cond93) {
     $46 = ($$066 != $$066) | (0.0 != 0.0);
     $47 = (+_llvm_copysign_f32(0.0,(+$$066)));
     $$3 = $46 ? $47 : $$066;
     $48 = ($$069 != $$069) | (0.0 != 0.0);
     $49 = (+_llvm_copysign_f32(0.0,(+$$069)));
     $$372 = $48 ? $49 : $$069;
     $50 = ($$175 != $$175) | (0.0 != 0.0);
     $51 = (+_llvm_copysign_f32(0.0,(+$$175)));
     $$377 = $50 ? $51 : $$175;
     $52 = ($$180 != $$180) | (0.0 != 0.0);
     $53 = (+_llvm_copysign_f32(0.0,(+$$180)));
     $$382 = $52 ? $53 : $$180;
     $$4$ph = $$3;$$473$ph = $$372;$$478$ph = $$377;$$483$ph = $$382;
     break;
    } else {
     $$sroa$0$1 = $9;$$sroa$6$1 = $10;
     $62 = ((($0)) + 4|0);
     HEAPF32[$0>>2] = $$sroa$0$1;
     HEAPF32[$62>>2] = $$sroa$6$1;
     return;
    }
   } else {
    $$4$ph = $$066;$$473$ph = $$069;$$478$ph = $$175;$$483$ph = $$180;
   }
  }
 } while(0);
 $54 = $$478$ph * $$4$ph;
 $55 = $$483$ph * $$473$ph;
 $56 = $54 - $55;
 $57 = $56 * inf;
 $58 = $$483$ph * $$4$ph;
 $59 = $$478$ph * $$473$ph;
 $60 = $59 + $58;
 $61 = $60 * inf;
 $$sroa$0$1 = $57;$$sroa$6$1 = $61;
 $62 = ((($0)) + 4|0);
 HEAPF32[$0>>2] = $$sroa$0$1;
 HEAPF32[$62>>2] = $$sroa$6$1;
 return;
}
function runPostSets() {
 var temp = 0;

 HEAP32[(gb + (161232) | 0) >> 2] = (HEAP32[(gb + (161232) | 0) >> 2] | 0) + (gb + (0) | 0);

 HEAP32[(gb + (161260) | 0) >> 2] = (HEAP32[(gb + (161260) | 0) >> 2] | 0) + (gb + (161232) | 0);

 HEAP32[(gb + (161300) | 0) >> 2] = (HEAP32[(gb + (161300) | 0) >> 2] | 0) + (gb + (161304) | 0);

 HEAP32[(gb + (161316) | 0) >> 2] = (fb + (1) | 0);

 HEAP32[(gb + (161340) | 0) >> 2] = (fb + (2) | 0);

 HEAP32[(gb + (161344) | 0) >> 2] = (fb + (3) | 0);

 HEAP32[(gb + (161348) | 0) >> 2] = (HEAP32[(gb + (161348) | 0) >> 2] | 0) + (gb + (172118) | 0);

 HEAP32[(gb + (161428) | 0) >> 2] = (HEAP32[(gb + (161428) | 0) >> 2] | 0) + (gb + (161304) | 0);

 HEAP32[(gb + (161432) | 0) >> 2] = (HEAP32[(gb + (161432) | 0) >> 2] | 0) + (gb + (161436) | 0);

 HEAP32[(gb + (161448) | 0) >> 2] = (fb + (1) | 0);

 HEAP32[(gb + (161468) | 0) >> 2] = (fb + (4) | 0);

 HEAP32[(gb + (161476) | 0) >> 2] = (fb + (3) | 0);

 HEAP32[(gb + (161480) | 0) >> 2] = (HEAP32[(gb + (161480) | 0) >> 2] | 0) + (gb + (167840) | 0);

 HEAP32[(gb + (161560) | 0) >> 2] = (HEAP32[(gb + (161560) | 0) >> 2] | 0) + (gb + (161436) | 0);

 HEAP32[(gb + (161564) | 0) >> 2] = (HEAP32[(gb + (161564) | 0) >> 2] | 0) + (gb + (161568) | 0);

 HEAP32[(gb + (161580) | 0) >> 2] = (fb + (1) | 0);

 HEAP32[(gb + (161604) | 0) >> 2] = (fb + (5) | 0);

 HEAP32[(gb + (161608) | 0) >> 2] = (fb + (3) | 0);

 HEAP32[(gb + (161612) | 0) >> 2] = (HEAP32[(gb + (161612) | 0) >> 2] | 0) + (gb + (168880) | 0);

 HEAP32[(gb + (161692) | 0) >> 2] = (HEAP32[(gb + (161692) | 0) >> 2] | 0) + (gb + (161568) | 0);

 HEAP32[(gb + (161892) | 0) >> 2] = (HEAP32[(gb + (161892) | 0) >> 2] | 0) + (gb + (171204) | 0);

 HEAP32[(gb + (161952) | 0) >> 2] = (HEAP32[(gb + (161952) | 0) >> 2] | 0) + (gb + (10016) | 0);

 HEAP32[(gb + (161996) | 0) >> 2] = (fb + (6) | 0);

 HEAP32[(gb + (162084) | 0) >> 2] = (HEAP32[(gb + (162084) | 0) >> 2] | 0) + (gb + (167711) | 0);

 HEAP32[(gb + (162088) | 0) >> 2] = (HEAP32[(gb + (162088) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162092) | 0) >> 2] = (HEAP32[(gb + (162092) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162096) | 0) >> 2] = (HEAP32[(gb + (162096) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162100) | 0) >> 2] = (HEAP32[(gb + (162100) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162104) | 0) >> 2] = (HEAP32[(gb + (162104) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162108) | 0) >> 2] = (HEAP32[(gb + (162108) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162112) | 0) >> 2] = (HEAP32[(gb + (162112) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162116) | 0) >> 2] = (HEAP32[(gb + (162116) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (162120) | 0) >> 2] = (HEAP32[(gb + (162120) | 0) >> 2] | 0) + (gb + (172139) | 0);

 HEAP32[(gb + (153604) | 0) >> 2] = (HEAP32[(gb + (153604) | 0) >> 2] | 0) + (gb + (167367) | 0);

 HEAP32[(gb + (153612) | 0) >> 2] = (HEAP32[(gb + (153612) | 0) >> 2] | 0) + (gb + (167369) | 0);

 HEAP32[(gb + (153620) | 0) >> 2] = (HEAP32[(gb + (153620) | 0) >> 2] | 0) + (gb + (167371) | 0);

 HEAP32[(gb + (153628) | 0) >> 2] = (HEAP32[(gb + (153628) | 0) >> 2] | 0) + (gb + (167373) | 0);

 HEAP32[(gb + (153636) | 0) >> 2] = (HEAP32[(gb + (153636) | 0) >> 2] | 0) + (gb + (167375) | 0);

 HEAP32[(gb + (153644) | 0) >> 2] = (HEAP32[(gb + (153644) | 0) >> 2] | 0) + (gb + (167377) | 0);

 HEAP32[(gb + (153652) | 0) >> 2] = (HEAP32[(gb + (153652) | 0) >> 2] | 0) + (gb + (167379) | 0);

 HEAP32[(gb + (153660) | 0) >> 2] = (HEAP32[(gb + (153660) | 0) >> 2] | 0) + (gb + (167392) | 0);

 HEAP32[(gb + (153668) | 0) >> 2] = (HEAP32[(gb + (153668) | 0) >> 2] | 0) + (gb + (167406) | 0);

 HEAP32[(gb + (153676) | 0) >> 2] = (HEAP32[(gb + (153676) | 0) >> 2] | 0) + (gb + (167418) | 0);

 HEAP32[(gb + (153684) | 0) >> 2] = (HEAP32[(gb + (153684) | 0) >> 2] | 0) + (gb + (167431) | 0);

 HEAP32[(gb + (153692) | 0) >> 2] = (HEAP32[(gb + (153692) | 0) >> 2] | 0) + (gb + (167443) | 0);

 HEAP32[(gb + (154384) | 0) >> 2] = (HEAP32[(gb + (154384) | 0) >> 2] | 0) + (gb + (167611) | 0);

 HEAP32[(gb + (154388) | 0) >> 2] = (HEAP32[(gb + (154388) | 0) >> 2] | 0) + (gb + (167617) | 0);

 HEAP32[(gb + (154392) | 0) >> 2] = (HEAP32[(gb + (154392) | 0) >> 2] | 0) + (gb + (167626) | 0);

 HEAP32[(gb + (154396) | 0) >> 2] = (HEAP32[(gb + (154396) | 0) >> 2] | 0) + (gb + (167631) | 0);

 HEAP32[(gb + (154400) | 0) >> 2] = (HEAP32[(gb + (154400) | 0) >> 2] | 0) + (gb + (167638) | 0);

 HEAP32[(gb + (166344) | 0) >> 2] = (HEAP32[(gb + (166344) | 0) >> 2] | 0) + (gb + (154416) | 0);

 HEAP32[(gb + (166348) | 0) >> 2] = (HEAP32[(gb + (166348) | 0) >> 2] | 0) + (gb + (158928) | 0);

 HEAP32[(gb + (166352) | 0) >> 2] = (HEAP32[(gb + (166352) | 0) >> 2] | 0) + (gb + (160464) | 0);
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((setTempRet0((h) | 0),l|0)|0);
}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((setTempRet0((h) | 0),l|0)|0);
}
function _llvm_cttz_i32(x) { // Note: Currently doesn't take isZeroUndef()
    x = x | 0;
    return (x ? (31 - (Math_clz32((x ^ (x - 1))) | 0) | 0) : 32) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    $rem = $rem | 0;
    var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
    $n_sroa_0_0_extract_trunc = $a$0;
    $n_sroa_1_4_extract_shift$0 = $a$1;
    $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
    $d_sroa_0_0_extract_trunc = $b$0;
    $d_sroa_1_4_extract_shift$0 = $b$1;
    $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
    if (($n_sroa_1_4_extract_trunc | 0) == 0) {
      $4 = ($rem | 0) != 0;
      if (($d_sroa_1_4_extract_trunc | 0) == 0) {
        if ($4) {
          HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
      } else {
        if (!$4) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
      }
    }
    $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
    do {
      if (($d_sroa_0_0_extract_trunc | 0) == 0) {
        if ($17) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
            HEAP32[$rem + 4 >> 2] = 0;
          }
          $_0$1 = 0;
          $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        if (($n_sroa_0_0_extract_trunc | 0) == 0) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = 0;
            HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
          }
          $_0$1 = 0;
          $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
        if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
          if (($rem | 0) != 0) {
            HEAP32[$rem >> 2] = 0 | $a$0 & -1;
            HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
          }
          $_0$1 = 0;
          $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        $49 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
        $51 = $49 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($51 >>> 0 <= 30) {
          $57 = $51 + 1 | 0;
          $58 = 31 - $51 | 0;
          $sr_1_ph = $57;
          $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
      } else {
        if (!$17) {
          $117 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
          $119 = $117 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
          if ($119 >>> 0 <= 31) {
            $125 = $119 + 1 | 0;
            $126 = 31 - $119 | 0;
            $130 = $119 - 31 >> 31;
            $sr_1_ph = $125;
            $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
            $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
            $q_sroa_0_1_ph = 0;
            $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
            break;
          }
          if (($rem | 0) == 0) {
            $_0$1 = 0;
            $_0$0 = 0;
            return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
          }
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
          $_0$1 = 0;
          $_0$0 = 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
        $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
        if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
          $86 = (Math_clz32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
          $88 = $86 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
          $89 = 64 - $88 | 0;
          $91 = 32 - $88 | 0;
          $92 = $91 >> 31;
          $95 = $88 - 32 | 0;
          $105 = $95 >> 31;
          $sr_1_ph = $88;
          $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
          $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
          $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
          $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
          break;
        }
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
          HEAP32[$rem + 4 >> 2] = 0;
        }
        if (($d_sroa_0_0_extract_trunc | 0) == 1) {
          $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
          $_0$0 = 0 | $a$0 & -1;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        } else {
          $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
          $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
          $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
          return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
        }
      }
    } while (0);
    if (($sr_1_ph | 0) == 0) {
      $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
      $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
      $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
      $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
      $carry_0_lcssa$1 = 0;
      $carry_0_lcssa$0 = 0;
    } else {
      $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
      $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
      $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0 | 0, $d_sroa_0_0_insert_insert99$1 | 0, -1, -1) | 0;
      $137$1 = (getTempRet0() | 0);
      $q_sroa_1_1198 = $q_sroa_1_1_ph;
      $q_sroa_0_1199 = $q_sroa_0_1_ph;
      $r_sroa_1_1200 = $r_sroa_1_1_ph;
      $r_sroa_0_1201 = $r_sroa_0_1_ph;
      $sr_1202 = $sr_1_ph;
      $carry_0203 = 0;
      while (1) {
        $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
        $149 = $carry_0203 | $q_sroa_0_1199 << 1;
        $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
        $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
        _i64Subtract($137$0 | 0, $137$1 | 0, $r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0) | 0;
        $150$1 = (getTempRet0() | 0);
        $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
        $152 = $151$0 & 1;
        $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0, $151$0 & $d_sroa_0_0_insert_insert99$0 | 0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1 | 0) | 0;
        $r_sroa_0_0_extract_trunc = $154$0;
        $r_sroa_1_4_extract_trunc = (getTempRet0() | 0);
        $155 = $sr_1202 - 1 | 0;
        if (($155 | 0) == 0) {
          break;
        } else {
          $q_sroa_1_1198 = $147;
          $q_sroa_0_1199 = $149;
          $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
          $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
          $sr_1202 = $155;
          $carry_0203 = $152;
        }
      }
      $q_sroa_1_1_lcssa = $147;
      $q_sroa_0_1_lcssa = $149;
      $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
      $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
      $carry_0_lcssa$1 = 0;
      $carry_0_lcssa$0 = $152;
    }
    $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
    $q_sroa_0_0_insert_ext75$1 = 0;
    $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
    if (($rem | 0) != 0) {
      HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
      HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
    }
    $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
    $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
    return (setTempRet0(($_0$1) | 0), $_0$0) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
    $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
    $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
    $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
    $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
    $4$0 = _i64Subtract($1$0 ^ $a$0 | 0, $1$1 ^ $a$1 | 0, $1$0 | 0, $1$1 | 0) | 0;
    $4$1 = (getTempRet0() | 0);
    $6$0 = _i64Subtract($2$0 ^ $b$0 | 0, $2$1 ^ $b$1 | 0, $2$0 | 0, $2$1 | 0) | 0;
    $7$0 = $2$0 ^ $1$0;
    $7$1 = $2$1 ^ $1$1;
    $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, (getTempRet0() | 0), 0) | 0;
    $10$0 = _i64Subtract($8$0 ^ $7$0 | 0, (getTempRet0() | 0) ^ $7$1 | 0, $7$0 | 0, $7$1 | 0) | 0;
    return $10$0 | 0;
}
function ___muldsi3($a, $b) {
    $a = $a | 0;
    $b = $b | 0;
    var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
    $1 = $a & 65535;
    $2 = $b & 65535;
    $3 = Math_imul($2, $1) | 0;
    $6 = $a >>> 16;
    $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
    $11 = $b >>> 16;
    $12 = Math_imul($11, $1) | 0;
    return (setTempRet0(((($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0) | 0), 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
    $x_sroa_0_0_extract_trunc = $a$0;
    $y_sroa_0_0_extract_trunc = $b$0;
    $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
    $1$1 = (getTempRet0() | 0);
    $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
    return (setTempRet0((((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0) | 0), 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $1$0 = 0;
    $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
    return $1$0 | 0;
}
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      setTempRet0((high >> bits) | 0);
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    setTempRet0(((high|0) < 0 ? -1 : 0) | 0);
    return (high >> (bits - 32))|0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      setTempRet0((high >>> bits) | 0);
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    setTempRet0((0) | 0);
    return (high >>> (bits - 32))|0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      setTempRet0(((high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits))) | 0);
      return low << bits;
    }
    setTempRet0((low << (bits - 32)) | 0);
    return 0;
}
function _llvm_bswap_i16(x) {
    x = x|0;
    return (((x&0xff)<<8) | ((x>>8)&0xff))|0;
}
function _llvm_bswap_i32(x) {
    x = x|0;
    return (((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24))|0;
}
function _llvm_maxnum_f32(x, y) {
    x = +x;
    y = +y;
    if (x != x) return +y;
    if (y != y) return +x;
    return +Math_max(+x, +y);
}
function _llvm_maxnum_f64(x, y) {
    x = +x;
    y = +y;
    if (x != x) return +y;
    if (y != y) return +x;
    return +Math_max(+x, +y);
}
function _memcpy(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    var aligned_dest_end = 0;
    var block_aligned_dest_end = 0;
    var dest_end = 0;
    // Test against a benchmarked cutoff limit for when HEAPU8.set() becomes faster to use.
    if ((num|0) >=
      8192
    ) {
      return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    }

    ret = dest|0;
    dest_end = (dest + num)|0;
    if ((dest&3) == (src&3)) {
      // The initial unaligned < 4-byte front.
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      aligned_dest_end = (dest_end & -4)|0;
      block_aligned_dest_end = (aligned_dest_end - 64)|0;
      while ((dest|0) <= (block_aligned_dest_end|0) ) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        HEAP32[(((dest)+(4))>>2)]=((HEAP32[(((src)+(4))>>2)])|0);
        HEAP32[(((dest)+(8))>>2)]=((HEAP32[(((src)+(8))>>2)])|0);
        HEAP32[(((dest)+(12))>>2)]=((HEAP32[(((src)+(12))>>2)])|0);
        HEAP32[(((dest)+(16))>>2)]=((HEAP32[(((src)+(16))>>2)])|0);
        HEAP32[(((dest)+(20))>>2)]=((HEAP32[(((src)+(20))>>2)])|0);
        HEAP32[(((dest)+(24))>>2)]=((HEAP32[(((src)+(24))>>2)])|0);
        HEAP32[(((dest)+(28))>>2)]=((HEAP32[(((src)+(28))>>2)])|0);
        HEAP32[(((dest)+(32))>>2)]=((HEAP32[(((src)+(32))>>2)])|0);
        HEAP32[(((dest)+(36))>>2)]=((HEAP32[(((src)+(36))>>2)])|0);
        HEAP32[(((dest)+(40))>>2)]=((HEAP32[(((src)+(40))>>2)])|0);
        HEAP32[(((dest)+(44))>>2)]=((HEAP32[(((src)+(44))>>2)])|0);
        HEAP32[(((dest)+(48))>>2)]=((HEAP32[(((src)+(48))>>2)])|0);
        HEAP32[(((dest)+(52))>>2)]=((HEAP32[(((src)+(52))>>2)])|0);
        HEAP32[(((dest)+(56))>>2)]=((HEAP32[(((src)+(56))>>2)])|0);
        HEAP32[(((dest)+(60))>>2)]=((HEAP32[(((src)+(60))>>2)])|0);
        dest = (dest+64)|0;
        src = (src+64)|0;
      }
      while ((dest|0) < (aligned_dest_end|0) ) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
      }
    } else {
      // In the unaligned copy case, unroll a bit as well.
      aligned_dest_end = (dest_end - 4)|0;
      while ((dest|0) < (aligned_dest_end|0) ) {
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        HEAP8[(((dest)+(1))>>0)]=((HEAP8[(((src)+(1))>>0)])|0);
        HEAP8[(((dest)+(2))>>0)]=((HEAP8[(((src)+(2))>>0)])|0);
        HEAP8[(((dest)+(3))>>0)]=((HEAP8[(((src)+(3))>>0)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
      }
    }
    // The remaining unaligned < 4 byte tail.
    while ((dest|0) < (dest_end|0)) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
    }
    return ret|0;
}
function _memmove(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if (((src|0) < (dest|0)) & ((dest|0) < ((src + num)|0))) {
      // Unlikely case: Copy backwards in a safe manner
      ret = dest;
      src = (src + num)|0;
      dest = (dest + num)|0;
      while ((num|0) > 0) {
        dest = (dest - 1)|0;
        src = (src - 1)|0;
        num = (num - 1)|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      }
      dest = ret;
    } else {
      _memcpy(dest, src, num) | 0;
    }
    return dest | 0;
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var end = 0, aligned_end = 0, block_aligned_end = 0, value4 = 0;
    end = (ptr + num)|0;

    value = value & 0xff;
    if ((num|0) >= 67 /* 64 bytes for an unrolled loop + 3 bytes for unaligned head*/) {
      while ((ptr&3) != 0) {
        HEAP8[((ptr)>>0)]=value;
        ptr = (ptr+1)|0;
      }

      aligned_end = (end & -4)|0;
      block_aligned_end = (aligned_end - 64)|0;
      value4 = value | (value << 8) | (value << 16) | (value << 24);

      while((ptr|0) <= (block_aligned_end|0)) {
        HEAP32[((ptr)>>2)]=value4;
        HEAP32[(((ptr)+(4))>>2)]=value4;
        HEAP32[(((ptr)+(8))>>2)]=value4;
        HEAP32[(((ptr)+(12))>>2)]=value4;
        HEAP32[(((ptr)+(16))>>2)]=value4;
        HEAP32[(((ptr)+(20))>>2)]=value4;
        HEAP32[(((ptr)+(24))>>2)]=value4;
        HEAP32[(((ptr)+(28))>>2)]=value4;
        HEAP32[(((ptr)+(32))>>2)]=value4;
        HEAP32[(((ptr)+(36))>>2)]=value4;
        HEAP32[(((ptr)+(40))>>2)]=value4;
        HEAP32[(((ptr)+(44))>>2)]=value4;
        HEAP32[(((ptr)+(48))>>2)]=value4;
        HEAP32[(((ptr)+(52))>>2)]=value4;
        HEAP32[(((ptr)+(56))>>2)]=value4;
        HEAP32[(((ptr)+(60))>>2)]=value4;
        ptr = (ptr + 64)|0;
      }

      while ((ptr|0) < (aligned_end|0) ) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    // The remaining bytes.
    while ((ptr|0) < (end|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (end-num)|0;
}
function _round(d) {
    d = +d;
    return d >= +0 ? +Math_floor(d + +0.5) : +Math_ceil(d - +0.5);
}
function _rintf(f) {
    f = +f;
    return (f - +Math_floor(f) != .5) ? +_round(f) : +_round(f / +2) * +2;
}
function _roundf(d) {
    d = +d;
    return d >= +0 ? +Math_floor(d + +0.5) : +Math_ceil(d - +0.5);
}
function _sbrk(increment) {
    increment = increment|0;
    var oldDynamicTop = 0;
    var oldDynamicTopOnChange = 0;
    var newDynamicTop = 0;
    var totalMemory = 0;
    oldDynamicTop = HEAP32[DYNAMICTOP_PTR>>2]|0;
    newDynamicTop = oldDynamicTop + increment | 0;

    if (((increment|0) > 0 & (newDynamicTop|0) < (oldDynamicTop|0)) // Detect and fail if we would wrap around signed 32-bit int.
      | (newDynamicTop|0) < 0) { // Also underflow, sbrk() should be able to be used to subtract.
      abortOnCannotGrowMemory()|0;
      ___setErrNo(12);
      return -1;
    }

    HEAP32[DYNAMICTOP_PTR>>2] = newDynamicTop;
    totalMemory = getTotalMemory()|0;
    if ((newDynamicTop|0) > (totalMemory|0)) {
      if ((enlargeMemory()|0) == 0) {
        HEAP32[DYNAMICTOP_PTR>>2] = oldDynamicTop;
        ___setErrNo(12);
        return -1;
      }
    }
    return oldDynamicTop|0;
}
function _brk(newDynamicTop) {
    newDynamicTop = newDynamicTop|0;
    var oldDynamicTop = 0;
    var totalMemory = 0;
    if ((newDynamicTop|0) < 0) {
      abortOnCannotGrowMemory()|0;
      ___setErrNo(12);
      return -1;
    }

    oldDynamicTop = HEAP32[DYNAMICTOP_PTR>>2]|0;
    HEAP32[DYNAMICTOP_PTR>>2] = newDynamicTop;
    totalMemory = getTotalMemory()|0;
    if ((newDynamicTop|0) > (totalMemory|0)) {
      if ((enlargeMemory()|0) == 0) {
        ___setErrNo(12);
        HEAP32[DYNAMICTOP_PTR>>2] = oldDynamicTop;
        return -1;
      }
    }
    return 0;
}
function _llvm_ctlz_i8(x, isZeroUndef) {
    x = x | 0;
    isZeroUndef = isZeroUndef | 0;
    return (Math_clz32(x & 0xff) | 0) - 24 | 0;
}
function _llvm_ctlz_i16(x, isZeroUndef) {
    x = x | 0;
    isZeroUndef = isZeroUndef | 0;
    return (Math_clz32(x & 0xffff) | 0) - 16 | 0
}
function _llvm_ctlz_i64(l, h, isZeroUndef) {
    l = l | 0;
    h = h | 0;
    isZeroUndef = isZeroUndef | 0;
    var ret = 0;
    ret = Math_clz32(h) | 0;
    if ((ret | 0) == 32) ret = ret + (Math_clz32(l) | 0) | 0;
    setTempRet0((0) | 0);
    return ret | 0;
}
function _llvm_ctpop_i32(x) {
    // http://graphics.stanford.edu/~seander/bithacks.html#CountBitsSetParallel
    // http://bits.stephan-brumme.com/countBits.html
    x = x | 0;
    x = x - ((x >>> 1) & 0x55555555) | 0;
    x = (x & 0x33333333) + ((x >>> 2) & 0x33333333) | 0;
    return (Math_imul((x + (x >>> 4) & 252645135 /* 0xF0F0F0F, but hits uglify parse bug? */), 0x1010101) >>> 24) | 0;
}
function _llvm_ctpop_i64(l, h) {
    l = l | 0;
    h = h | 0;
    return (_llvm_ctpop_i32(l) | 0) + (_llvm_ctpop_i32(h) | 0) | 0;
}
function _llvm_bitreverse_i32(x) {
    x = x|0;
    x = ((x & 0xaaaaaaaa) >>> 1) | ((x & 0x55555555) << 1);
    x = ((x & 0xcccccccc) >>> 2) | ((x & 0x33333333) << 2);
    x = ((x & 0xf0f0f0f0) >>> 4) | ((x & 0x0f0f0f0f) << 4);
    x = ((x & 0xff00ff00) >>> 8) | ((x & 0x00ff00ff) << 8);
    return (x >>> 16) | (x << 16);
}
function _llvm_round_f64(d) {
    d = +d;
    return d >= +0 ? +Math_floor(d + +0.5) : +Math_ceil(d - +0.5);
}
function _llvm_round_f32(f) {
    f = +f;
    return f >= +0 ? +Math_floor(f + +0.5) : +Math_ceil(f - +0.5); // TODO: use fround?
}
function _llvm_rint_f32(f) {
    f = +f;
    return (f - +Math_floor(f) != .5) ? +_roundf(f) : +_roundf(f / +2) * +2;
}
function _llvm_rint_f64(f) {
    f = +f;
    return (f - +Math_floor(f) != .5) ? +_round(f) : +_round(f / +2) * +2;
}
function _llvm_nearbyint_f32(f) {
    f = +f;
    return (f - +Math_floor(f) != .5) ? +_roundf(f) : +_roundf(f / +2) * +2;
}
function _llvm_nearbyint_f64(f) {
    f = +f;
    return (f - +Math_floor(f) != .5) ? +_round(f) : +_round(f / +2) * +2;
}
function _llvm_minnum_f32(x, y) {
    x = +x;
    y = +y;
    if (x != x) return +y;
    if (y != y) return +x;
    return +Math_min(+x, +y);
}
function _llvm_minnum_f64(x, y) {
    x = +x;
    y = +y;
    if (x != x) return +y;
    if (y != y) return +x;
    return +Math_min(+x, +y);
}
function _saveSetjmp(env, label, table, size) {
    // Not particularly fast: slow table lookup of setjmpId to label. But setjmp
    // prevents relooping anyhow, so slowness is to be expected. And typical case
    // is 1 setjmp per invocation, or less.
    env = env|0;
    label = label|0;
    table = table|0;
    size = size|0;
    var i = 0;
    setjmpId = (setjmpId+1)|0;
    HEAP32[((env)>>2)]=setjmpId;
    while ((i|0) < (size|0)) {
      if (((HEAP32[(((table)+((i<<3)))>>2)])|0) == 0) {
        HEAP32[(((table)+((i<<3)))>>2)]=setjmpId;
        HEAP32[(((table)+((i<<3)+4))>>2)]=label;
        // prepare next slot
        HEAP32[(((table)+((i<<3)+8))>>2)]=0;
        setTempRet0((size) | 0);
        return table | 0;
      }
      i = i+1|0;
    }
    // grow the table
    size = (size*2)|0;
    table = _realloc(table|0, 8*(size+1|0)|0) | 0;
    table = _saveSetjmp(env|0, label|0, table|0, size|0) | 0;
    setTempRet0((size) | 0);
    return table | 0;
}
function _testSetjmp(id, table, size) {
    id = id|0;
    table = table|0;
    size = size|0;
    var i = 0, curr = 0;
    while ((i|0) < (size|0)) {
      curr = ((HEAP32[(((table)+((i<<3)))>>2)])|0);
      if ((curr|0) == 0) break;
      if ((curr|0) == (id|0)) {
        return ((HEAP32[(((table)+((i<<3)+4))>>2)])|0);
      }
      i = i+1|0;
    }
    return 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
    __stackBase__ = STACKTOP;
    STACKTOP = STACKTOP + 16 | 0;
    $rem = __stackBase__ | 0;
    $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
    $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
    $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
    $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
    $4$0 = _i64Subtract($1$0 ^ $a$0 | 0, $1$1 ^ $a$1 | 0, $1$0 | 0, $1$1 | 0) | 0;
    $4$1 = (getTempRet0() | 0);
    $6$0 = _i64Subtract($2$0 ^ $b$0 | 0, $2$1 ^ $b$1 | 0, $2$0 | 0, $2$1 | 0) | 0;
    ___udivmoddi4($4$0, $4$1, $6$0, (getTempRet0() | 0), $rem) | 0;
    $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0 | 0, HEAP32[$rem + 4 >> 2] ^ $1$1 | 0, $1$0 | 0, $1$1 | 0) | 0;
    $10$1 = (getTempRet0() | 0);
    STACKTOP = __stackBase__;
    return (setTempRet0(($10$1) | 0), $10$0) | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
    $a$0 = $a$0 | 0;
    $a$1 = $a$1 | 0;
    $b$0 = $b$0 | 0;
    $b$1 = $b$1 | 0;
    var $rem = 0, __stackBase__ = 0;
    __stackBase__ = STACKTOP;
    STACKTOP = STACKTOP + 16 | 0;
    $rem = __stackBase__ | 0;
    ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
    STACKTOP = __stackBase__;
    return (setTempRet0((HEAP32[$rem + 4 >> 2] | 0) | 0), HEAP32[$rem >> 2] | 0) | 0;
}
function _pthread_mutex_lock(x) {
    x = x | 0;
    return 0;
}
function _pthread_mutex_unlock(x) {
    x = x | 0;
    return 0;
}
function _pthread_mutex_trylock(x) {
    x = x | 0;
    return 0;
}
function _pthread_cond_broadcast(x) {
    x = x | 0;
    return 0;
}
function mftCall_ii(ptr,p0) {
 ptr = ptr | 0;p0 = p0|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 31 | 0))) { return FUNCTION_TABLE_ii[(ptr-fb)&31](p0|0)|0;  }return ftCall_ii(ptr|0,p0|0)|0;
}
function mftCall_iii(ptr,p0,p1) {
 ptr = ptr | 0;p0 = p0|0;p1 = p1|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 63 | 0))) { return FUNCTION_TABLE_iii[(ptr-fb)&63](p0|0,p1|0)|0;  }return ftCall_iii(ptr|0,p0|0,p1|0)|0;
}
function mftCall_iiii(ptr,p0,p1,p2) {
 ptr = ptr | 0;p0 = p0|0;p1 = p1|0;p2 = p2|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 63 | 0))) { return FUNCTION_TABLE_iiii[(ptr-fb)&63](p0|0,p1|0,p2|0)|0;  }return ftCall_iiii(ptr|0,p0|0,p1|0,p2|0)|0;
}
function mftCall_iiiii(ptr,p0,p1,p2,p3) {
 ptr = ptr | 0;p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 0 | 0))) { return FUNCTION_TABLE_iiiii[(ptr-fb)&0](p0|0,p1|0,p2|0,p3|0)|0;  }return ftCall_iiiii(ptr|0,p0|0,p1|0,p2|0,p3|0)|0;
}
function mftCall_iiiiii(ptr,p0,p1,p2,p3,p4) {
 ptr = ptr | 0;p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 31 | 0))) { return FUNCTION_TABLE_iiiiii[(ptr-fb)&31](p0|0,p1|0,p2|0,p3|0,p4|0)|0;  }return ftCall_iiiiii(ptr|0,p0|0,p1|0,p2|0,p3|0,p4|0)|0;
}
function mftCall_v(ptr) {
 ptr = ptr | 0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 63 | 0))) {  FUNCTION_TABLE_v[(ptr-fb)&63](); return; } ftCall_v(ptr|0);
}
function mftCall_vi(ptr,p0) {
 ptr = ptr | 0;p0 = p0|0; if (((ptr|0) >= (fb|0)) & ((ptr|0) < (fb + 63 | 0))) {  FUNCTION_TABLE_vi[(ptr-fb)&63](p0|0); return; } ftCall_vi(ptr|0,p0|0);
}

  
//ii = ftCall_ii;


//iii = ftCall_iii;


//iiii = ftCall_iiii;


//iiiii = ftCall_iiiii;


//iiiiii = ftCall_iiiiii;


//v = ftCall_v;


//vi = ftCall_vi;

function b0(p0) {
 p0 = p0|0; nullFunc_ii(0);return 0;
}
function b1(p0,p1) {
 p0 = p0|0;p1 = p1|0; nullFunc_iii(1);return 0;
}
function b2(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_iiii(2);return 0;
}
function b3(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_iiiii(3);return 0;
}
function b4(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; nullFunc_iiiiii(4);return 0;
}
function b5() {
 ; nullFunc_v(5);
}
function b6(p0) {
 p0 = p0|0; nullFunc_vi(6);
}

// EMSCRIPTEN_END_FUNCS
var FUNCTION_TABLE_ii = [b0,___stdio_close,b0,b0,b0,b0,b0,_dummy,b0,___strdup,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,_wms_close,b0,b0,b0,_mclose,b0
,b0,b0,_ms_close];
var FUNCTION_TABLE_iii = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,_netlink_msg_to_ifaddr,_netlink_msg_to_nameindex,b1,_addrcmp,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,_ignore_err,_sort,_tre_compare_lit,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1];
var FUNCTION_TABLE_iiii = [b2,b2,___stdio_write,___stdio_seek,___stdio_read,___stdout_write,_sn_write,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,_do_read,_do_read_331,_sw_write,_wms_write,_wms_seek,b2,_mread,_mwrite,_mseek,b2,_wstring_read
,_ms_write,_ms_seek,b2,_wrap_write,b2,_do_read_418,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2];
var FUNCTION_TABLE_iiiii = [b3];
var FUNCTION_TABLE_iiiiii = [b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,___dn_expand,b4,_dns_parse_callback,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4];
var FUNCTION_TABLE_v = [b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,_dummy_284,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,___stdio_exit,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5];
var FUNCTION_TABLE_vi = [b6,b6,b6,b6,b6,b6,b6,b6,_do_setxid,b6,b6,_cleanup_241,_cleanup,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,_do_setrlimit,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6];

  return { ___divdi3: ___divdi3, ___dn_expand: ___dn_expand, ___errno_location: ___errno_location, ___lockfile: ___lockfile, ___muldi3: ___muldi3, ___stdio_close: ___stdio_close, ___stdio_exit: ___stdio_exit, ___stdio_read: ___stdio_read, ___stdio_seek: ___stdio_seek, ___stdio_write: ___stdio_write, ___stdout_write: ___stdout_write, ___strdup: ___strdup, ___udivdi3: ___udivdi3, ___unlockfile: ___unlockfile, _addrcmp: _addrcmp, _bitshift64Ashr: _bitshift64Ashr, _bitshift64Lshr: _bitshift64Lshr, _bitshift64Shl: _bitshift64Shl, _cleanup: _cleanup, _cleanup_241: _cleanup_241, _dns_parse_callback: _dns_parse_callback, _do_read: _do_read, _do_read_331: _do_read_331, _do_read_418: _do_read_418, _do_setrlimit: _do_setrlimit, _do_setxid: _do_setxid, _dummy: _dummy, _dummy_284: _dummy_284, _fflush: _fflush, _free: _free, _htons: _htons, _i64Add: _i64Add, _i64Subtract: _i64Subtract, _ignore_err: _ignore_err, _labs: _labs, _llvm_bswap_i16: _llvm_bswap_i16, _llvm_bswap_i32: _llvm_bswap_i32, _llvm_cttz_i32: _llvm_cttz_i32, _llvm_maxnum_f32: _llvm_maxnum_f32, _llvm_maxnum_f64: _llvm_maxnum_f64, _main: _main, _malloc: _malloc, _mclose: _mclose, _memcmp: _memcmp, _memcpy: _memcpy, _memmove: _memmove, _memset: _memset, _mread: _mread, _ms_close: _ms_close, _ms_seek: _ms_seek, _ms_write: _ms_write, _mseek: _mseek, _mwrite: _mwrite, _netlink_msg_to_ifaddr: _netlink_msg_to_ifaddr, _netlink_msg_to_nameindex: _netlink_msg_to_nameindex, _pause: _pause, _printf: _printf, _pthread_self: _pthread_self, _puts: _puts, _rand: _rand, _realloc: _realloc, _rintf: _rintf, _round: _round, _roundf: _roundf, _saveSetjmp: _saveSetjmp, _sbrk: _sbrk, _sleep: _sleep, _sn_write: _sn_write, _sort: _sort, _strlen: _strlen, _sw_write: _sw_write, _testSetjmp: _testSetjmp, _tre_compare_lit: _tre_compare_lit, _ualarm: _ualarm, _wms_close: _wms_close, _wms_seek: _wms_seek, _wms_write: _wms_write, _wrap_write: _wrap_write, _wstring_read: _wstring_read, establishStackSpace: establishStackSpace, runPostSets: runPostSets, setThrew: setThrew, stackAlloc: stackAlloc, stackRestore: stackRestore, stackSave: stackSave };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);

var real____divdi3 = asm["___divdi3"]; asm["___divdi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____divdi3.apply(null, arguments);
};

var real____errno_location = asm["___errno_location"]; asm["___errno_location"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____errno_location.apply(null, arguments);
};

var real____lockfile = asm["___lockfile"]; asm["___lockfile"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____lockfile.apply(null, arguments);
};

var real____muldi3 = asm["___muldi3"]; asm["___muldi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____muldi3.apply(null, arguments);
};

var real____udivdi3 = asm["___udivdi3"]; asm["___udivdi3"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____udivdi3.apply(null, arguments);
};

var real____unlockfile = asm["___unlockfile"]; asm["___unlockfile"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real____unlockfile.apply(null, arguments);
};

var real__bitshift64Ashr = asm["_bitshift64Ashr"]; asm["_bitshift64Ashr"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__bitshift64Ashr.apply(null, arguments);
};

var real__bitshift64Lshr = asm["_bitshift64Lshr"]; asm["_bitshift64Lshr"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__bitshift64Lshr.apply(null, arguments);
};

var real__bitshift64Shl = asm["_bitshift64Shl"]; asm["_bitshift64Shl"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__bitshift64Shl.apply(null, arguments);
};

var real__fflush = asm["_fflush"]; asm["_fflush"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__fflush.apply(null, arguments);
};

var real__free = asm["_free"]; asm["_free"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__free.apply(null, arguments);
};

var real__htons = asm["_htons"]; asm["_htons"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__htons.apply(null, arguments);
};

var real__i64Add = asm["_i64Add"]; asm["_i64Add"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__i64Add.apply(null, arguments);
};

var real__i64Subtract = asm["_i64Subtract"]; asm["_i64Subtract"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__i64Subtract.apply(null, arguments);
};

var real__labs = asm["_labs"]; asm["_labs"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__labs.apply(null, arguments);
};

var real__llvm_bswap_i16 = asm["_llvm_bswap_i16"]; asm["_llvm_bswap_i16"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_bswap_i16.apply(null, arguments);
};

var real__llvm_bswap_i32 = asm["_llvm_bswap_i32"]; asm["_llvm_bswap_i32"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_bswap_i32.apply(null, arguments);
};

var real__llvm_cttz_i32 = asm["_llvm_cttz_i32"]; asm["_llvm_cttz_i32"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_cttz_i32.apply(null, arguments);
};

var real__llvm_maxnum_f32 = asm["_llvm_maxnum_f32"]; asm["_llvm_maxnum_f32"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_maxnum_f32.apply(null, arguments);
};

var real__llvm_maxnum_f64 = asm["_llvm_maxnum_f64"]; asm["_llvm_maxnum_f64"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__llvm_maxnum_f64.apply(null, arguments);
};

var real__main = asm["_main"]; asm["_main"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__main.apply(null, arguments);
};

var real__malloc = asm["_malloc"]; asm["_malloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__malloc.apply(null, arguments);
};

var real__memcmp = asm["_memcmp"]; asm["_memcmp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__memcmp.apply(null, arguments);
};

var real__memmove = asm["_memmove"]; asm["_memmove"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__memmove.apply(null, arguments);
};

var real__pause = asm["_pause"]; asm["_pause"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pause.apply(null, arguments);
};

var real__printf = asm["_printf"]; asm["_printf"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__printf.apply(null, arguments);
};

var real__pthread_self = asm["_pthread_self"]; asm["_pthread_self"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__pthread_self.apply(null, arguments);
};

var real__puts = asm["_puts"]; asm["_puts"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__puts.apply(null, arguments);
};

var real__rand = asm["_rand"]; asm["_rand"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__rand.apply(null, arguments);
};

var real__realloc = asm["_realloc"]; asm["_realloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__realloc.apply(null, arguments);
};

var real__rintf = asm["_rintf"]; asm["_rintf"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__rintf.apply(null, arguments);
};

var real__round = asm["_round"]; asm["_round"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__round.apply(null, arguments);
};

var real__roundf = asm["_roundf"]; asm["_roundf"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__roundf.apply(null, arguments);
};

var real__saveSetjmp = asm["_saveSetjmp"]; asm["_saveSetjmp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__saveSetjmp.apply(null, arguments);
};

var real__sbrk = asm["_sbrk"]; asm["_sbrk"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__sbrk.apply(null, arguments);
};

var real__sleep = asm["_sleep"]; asm["_sleep"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__sleep.apply(null, arguments);
};

var real__strlen = asm["_strlen"]; asm["_strlen"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__strlen.apply(null, arguments);
};

var real__testSetjmp = asm["_testSetjmp"]; asm["_testSetjmp"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__testSetjmp.apply(null, arguments);
};

var real__ualarm = asm["_ualarm"]; asm["_ualarm"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real__ualarm.apply(null, arguments);
};

var real_establishStackSpace = asm["establishStackSpace"]; asm["establishStackSpace"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_establishStackSpace.apply(null, arguments);
};

var real_setThrew = asm["setThrew"]; asm["setThrew"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_setThrew.apply(null, arguments);
};

var real_stackAlloc = asm["stackAlloc"]; asm["stackAlloc"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackAlloc.apply(null, arguments);
};

var real_stackRestore = asm["stackRestore"]; asm["stackRestore"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackRestore.apply(null, arguments);
};

var real_stackSave = asm["stackSave"]; asm["stackSave"] = function() {
  assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
  assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
  return real_stackSave.apply(null, arguments);
};
var ___divdi3 = Module["___divdi3"] = asm["___divdi3"];
var ___errno_location = Module["___errno_location"] = asm["___errno_location"];
var ___lockfile = Module["___lockfile"] = asm["___lockfile"];
var ___muldi3 = Module["___muldi3"] = asm["___muldi3"];
var ___udivdi3 = Module["___udivdi3"] = asm["___udivdi3"];
var ___unlockfile = Module["___unlockfile"] = asm["___unlockfile"];
var _bitshift64Ashr = Module["_bitshift64Ashr"] = asm["_bitshift64Ashr"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var _fflush = Module["_fflush"] = asm["_fflush"];
var _free = Module["_free"] = asm["_free"];
var _htons = Module["_htons"] = asm["_htons"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _labs = Module["_labs"] = asm["_labs"];
var _llvm_bswap_i16 = Module["_llvm_bswap_i16"] = asm["_llvm_bswap_i16"];
var _llvm_bswap_i32 = Module["_llvm_bswap_i32"] = asm["_llvm_bswap_i32"];
var _llvm_cttz_i32 = Module["_llvm_cttz_i32"] = asm["_llvm_cttz_i32"];
var _llvm_maxnum_f32 = Module["_llvm_maxnum_f32"] = asm["_llvm_maxnum_f32"];
var _llvm_maxnum_f64 = Module["_llvm_maxnum_f64"] = asm["_llvm_maxnum_f64"];
var _main = Module["_main"] = asm["_main"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _memset = Module["_memset"] = asm["_memset"];
var _pause = Module["_pause"] = asm["_pause"];
var _printf = Module["_printf"] = asm["_printf"];
var _pthread_self = Module["_pthread_self"] = asm["_pthread_self"];
var _puts = Module["_puts"] = asm["_puts"];
var _rand = Module["_rand"] = asm["_rand"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _rintf = Module["_rintf"] = asm["_rintf"];
var _round = Module["_round"] = asm["_round"];
var _roundf = Module["_roundf"] = asm["_roundf"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _sbrk = Module["_sbrk"] = asm["_sbrk"];
var _sleep = Module["_sleep"] = asm["_sleep"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _ualarm = Module["_ualarm"] = asm["_ualarm"];
var establishStackSpace = Module["establishStackSpace"] = asm["establishStackSpace"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var setThrew = Module["setThrew"] = asm["setThrew"];
var stackAlloc = Module["stackAlloc"] = asm["stackAlloc"];
var stackRestore = Module["stackRestore"] = asm["stackRestore"];
var stackSave = Module["stackSave"] = asm["stackSave"];

function b0(p0) {
 p0 = p0|0; nullFunc_ii(0);return 0;
}
function b1(p0,p1) {
 p0 = p0|0;p1 = p1|0; nullFunc_iii(1);return 0;
}
function b2(p0,p1,p2) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_iiii(2);return 0;
}
function b3(p0,p1,p2,p3) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_iiiii(3);return 0;
}
function b4(p0,p1,p2,p3,p4) {
 p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; nullFunc_iiiiii(4);return 0;
}
function b5() {
 ; nullFunc_v(5);
}
function b6(p0) {
 p0 = p0|0; nullFunc_vi(6);
}

var FUNCTION_TABLE_ii = [b0,asm['___stdio_close'],b0,b0,b0,b0,b0,asm['_dummy'],b0,asm['___strdup'],b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,asm['_wms_close'],b0,b0,b0,asm['_mclose'],b0
,b0,b0,asm['_ms_close']];
var FUNCTION_TABLE_iii = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,asm['_netlink_msg_to_ifaddr'],asm['_netlink_msg_to_nameindex'],b1,asm['_addrcmp'],b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,asm['_ignore_err'],asm['_sort'],asm['_tre_compare_lit'],b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1];
var FUNCTION_TABLE_iiii = [b2,b2,asm['___stdio_write'],asm['___stdio_seek'],asm['___stdio_read'],asm['___stdout_write'],asm['_sn_write'],b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,asm['_do_read'],asm['_do_read_331'],asm['_sw_write'],asm['_wms_write'],asm['_wms_seek'],b2,asm['_mread'],asm['_mwrite'],asm['_mseek'],b2,asm['_wstring_read']
,asm['_ms_write'],asm['_ms_seek'],b2,asm['_wrap_write'],b2,asm['_do_read_418'],b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2];
var FUNCTION_TABLE_iiiii = [b3];
var FUNCTION_TABLE_iiiiii = [b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,asm['___dn_expand'],b4,asm['_dns_parse_callback'],b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4];
var FUNCTION_TABLE_v = [b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,asm['_dummy_284'],b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,asm['___stdio_exit'],b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5];
var FUNCTION_TABLE_vi = [b6,b6,b6,b6,b6,b6,b6,b6,asm['_do_setxid'],b6,b6,asm['_cleanup_241'],asm['_cleanup'],b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,asm['_do_setrlimit'],b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6];
Module["dynCall_ii"] = dynCall_ii
Module["dynCall_iii"] = dynCall_iii
Module["dynCall_iiii"] = dynCall_iiii
Module["dynCall_iiiii"] = dynCall_iiiii
Module["dynCall_iiiiii"] = dynCall_iiiiii
Module["dynCall_v"] = dynCall_v
Module["dynCall_vi"] = dynCall_vi
Module["FUNCTION_TABLE_ii"] = FUNCTION_TABLE_ii;
Module["FUNCTION_TABLE_iii"] = FUNCTION_TABLE_iii;
Module["FUNCTION_TABLE_iiii"] = FUNCTION_TABLE_iiii;
Module["FUNCTION_TABLE_iiiii"] = FUNCTION_TABLE_iiiii;
Module["FUNCTION_TABLE_iiiiii"] = FUNCTION_TABLE_iiiiii;
Module["FUNCTION_TABLE_v"] = FUNCTION_TABLE_v;
Module["FUNCTION_TABLE_vi"] = FUNCTION_TABLE_vi;

var NAMED_GLOBALS = { "__c_dot_utf8": 161232, "__c_dot_utf8_locale": 161260, "__c_locale": 171132, "__fsmu8": 160, "__hwcap": 171268, "__libc": 171204, "__optpos": 171184, "__optreset": 171180, "__progname": 171196, "__progname_full": 171200, "__seed48": 166356, "__signgam": 171128, "__stderr_used": 161428, "__stdin_used": 161560, "__stdout_used": 161692, "__sysinfo": 171272, "_ns_flagdata": 32, "h_errno": 171172, "in6addr_any": 171156, "in6addr_loopback": 161284, "optarg": 171188, "opterr": 161700, "optind": 161696, "optopt": 171192, "stderr": 161300, "stdin": 161432, "stdout": 161564 };
for (var named in NAMED_GLOBALS) {
  Module['_' + named] = gb + NAMED_GLOBALS[named];
}
Module['NAMED_GLOBALS'] = NAMED_GLOBALS;
Module['__IO_feof_unlocked'] = Module['_feof']
Module['__IO_ferror_unlocked'] = Module['_ferror']
Module['__IO_getc'] = Module['_getc']
Module['__IO_getc_unlocked'] = Module['_getc_unlocked']
Module['__IO_putc'] = Module['_putc']
Module['__IO_putc_unlocked'] = Module['_putc_unlocked']
Module['___aio_close'] = Module['_dummy']
Module['___freelocale'] = Module['_freelocale']
Module['___fxstat64'] = Module['___fxstat']
Module['___fxstatat64'] = Module['___fxstatat']
Module['___getdelim'] = Module['_getdelim']
Module['___isoc99_fscanf'] = Module['_fscanf']
Module['___isoc99_fwscanf'] = Module['_fwscanf']
Module['___isoc99_scanf'] = Module['_scanf']
Module['___isoc99_sscanf'] = Module['_sscanf']
Module['___isoc99_swscanf'] = Module['_swscanf']
Module['___isoc99_vfscanf'] = Module['_vfscanf']
Module['___isoc99_vfwscanf'] = Module['_vfwscanf']
Module['___isoc99_vscanf'] = Module['_vscanf']
Module['___isoc99_vsscanf'] = Module['_vsscanf']
Module['___isoc99_vswscanf'] = Module['_vswscanf']
Module['___isoc99_vwscanf'] = Module['_vwscanf']
Module['___isoc99_wscanf'] = Module['_wscanf']
Module['___lxstat64'] = Module['___lxstat']
Module['___posix_getopt'] = Module['_getopt']
Module['___stdio_exit_needed'] = Module['___stdio_exit']
Module['___strtoimax_internal'] = Module['_strtoimax']
Module['___strtol_internal'] = Module['_strtol']
Module['___strtoll_internal'] = Module['_strtoll']
Module['___strtoul_internal'] = Module['_strtoul']
Module['___strtoull_internal'] = Module['_strtoull']
Module['___strtoumax_internal'] = Module['_strtoumax']
Module['___vm_wait'] = Module['_dummy_284']
Module['___xpg_basename'] = Module['_basename']
Module['___xpg_strerror_r'] = Module['_strerror_r']
Module['___xstat64'] = Module['___xstat']
Module['_alphasort64'] = Module['_alphasort']
Module['_cfsetspeed'] = Module['_cfsetospeed']
Module['_clearerr_unlocked'] = Module['_clearerr']
Module['_creat64'] = Module['_creat']
Module['_crypt_r'] = Module['___crypt_r']
Module['_dn_comp'] = Module['___dn_comp']
Module['_dn_expand'] = Module['___dn_expand']
Module['_drem'] = Module['_remainder']
Module['_dremf'] = Module['_remainderf']
Module['_dup3'] = Module['___dup3']
Module['_duplocale'] = Module['___duplocale']
Module['_emscripten_builtin_free'] = Module['_free']
Module['_emscripten_builtin_malloc'] = Module['_malloc']
Module['_endnetent'] = Module['_endhostent']
Module['_fdopen'] = Module['___fdopen']
Module['_feof_unlocked'] = Module['_feof']
Module['_ferror_unlocked'] = Module['_ferror']
Module['_fflush_unlocked'] = Module['___fflush_unlocked']
Module['_fgetc_unlocked'] = Module['_getc_unlocked']
Module['_fgetpos64'] = Module['_fgetpos']
Module['_fgets_unlocked'] = Module['_fgets']
Module['_fgetwc_unlocked'] = Module['___fgetwc_unlocked']
Module['_fgetws_unlocked'] = Module['_fgetws']
Module['_fileno_unlocked'] = Module['_fileno']
Module['_fopen64'] = Module['_fopen']
Module['_fpurge'] = Module['___fpurge']
Module['_fputc_unlocked'] = Module['_putc_unlocked']
Module['_fputs_unlocked'] = Module['_fputs']
Module['_fputwc_unlocked'] = Module['___fputwc_unlocked']
Module['_fputws_unlocked'] = Module['_fputws']
Module['_fread_unlocked'] = Module['_fread']
Module['_freopen64'] = Module['_freopen']
Module['_fseeko'] = Module['___fseeko']
Module['_fseeko64'] = Module['___fseeko']
Module['_fsetpos64'] = Module['_fsetpos']
Module['_fstat64'] = Module['_fstat']
Module['_fstatat64'] = Module['_fstatat']
Module['_fstatfs'] = Module['___fstatfs']
Module['_fstatfs64'] = Module['___fstatfs']
Module['_fstatvfs64'] = Module['_fstatvfs']
Module['_ftello'] = Module['___ftello']
Module['_ftello64'] = Module['___ftello']
Module['_ftruncate64'] = Module['_ftruncate']
Module['_futimesat'] = Module['___futimesat']
Module['_fwrite_unlocked'] = Module['_fwrite']
Module['_getdents'] = Module['___getdents']
Module['_getdents64'] = Module['___getdents']
Module['_getnetent'] = Module['_gethostent']
Module['_getrlimit64'] = Module['_getrlimit']
Module['_getwc_unlocked'] = Module['___fgetwc_unlocked']
Module['_getwchar_unlocked'] = Module['_getwchar']
Module['_glob64'] = Module['_glob']
Module['_globfree64'] = Module['_globfree']
Module['_inet_aton'] = Module['___inet_aton']
Module['_lgamma_r'] = Module['___lgamma_r']
Module['_lgammaf_r'] = Module['___lgammaf_r']
Module['_lgammal_r'] = Module['___lgammal_r']
Module['_lockf64'] = Module['_lockf']
Module['_lseek64'] = Module['_lseek']
Module['_lstat64'] = Module['_lstat']
Module['_madvise'] = Module['___madvise']
Module['_memrchr'] = Module['___memrchr']
Module['_mkostemp64'] = Module['_mkostemp']
Module['_mkostemps'] = Module['___mkostemps']
Module['_mkostemps64'] = Module['___mkostemps']
Module['_mkstemp64'] = Module['_mkstemp']
Module['_mkstemps64'] = Module['_mkstemps']
Module['_mmap'] = Module['___mmap']
Module['_mmap64'] = Module['___mmap']
Module['_mprotect'] = Module['___mprotect']
Module['_mremap'] = Module['___mremap']
Module['_munmap'] = Module['___munmap']
Module['_newlocale'] = Module['___newlocale']
Module['_nftw64'] = Module['_nftw']
Module['_nl_langinfo'] = Module['___nl_langinfo']
Module['_nl_langinfo_l'] = Module['___nl_langinfo_l']
Module['_open64'] = Module['_open']
Module['_openat64'] = Module['_openat']
Module['_optreset'] = Module['___optreset']
Module['_posix_fadvise64'] = Module['_posix_fadvise']
Module['_posix_fallocate64'] = Module['_posix_fallocate']
Module['_pow10'] = Module['_exp10']
Module['_pow10f'] = Module['_exp10f']
Module['_pow10l'] = Module['_exp10l']
Module['_pread64'] = Module['_pread']
Module['_preadv64'] = Module['_preadv']
Module['_program_invocation_name'] = Module['___progname_full']
Module['_program_invocation_short_name'] = Module['___progname']
Module['_ptsname_r'] = Module['___ptsname_r']
Module['_putwc_unlocked'] = Module['___fputwc_unlocked']
Module['_putwchar_unlocked'] = Module['_putwchar']
Module['_pwrite64'] = Module['_pwrite']
Module['_pwritev64'] = Module['_pwritev']
Module['_readdir64'] = Module['_readdir']
Module['_readdir64_r'] = Module['_readdir_r']
Module['_res_mkquery'] = Module['___res_mkquery']
Module['_res_send'] = Module['___res_send']
Module['_scandir64'] = Module['_scandir']
Module['_setnetent'] = Module['_sethostent']
Module['_setrlimit64'] = Module['_setrlimit']
Module['_signgam'] = Module['___signgam']
Module['_stat64'] = Module['_stat']
Module['_statfs'] = Module['___statfs']
Module['_statfs64'] = Module['___statfs']
Module['_statvfs64'] = Module['_statvfs']
Module['_stpcpy'] = Module['___stpcpy']
Module['_stpncpy'] = Module['___stpncpy']
Module['_strchrnul'] = Module['___strchrnul']
Module['_strcoll_l'] = Module['___strcoll_l']
Module['_strdup'] = Module['___strdup']
Module['_strxfrm_l'] = Module['___strxfrm_l']
Module['_tmpfile64'] = Module['_tmpfile']
Module['_truncate64'] = Module['_truncate']
Module['_uselocale'] = Module['___uselocale']
Module['_versionsort64'] = Module['_versionsort']
Module['_vsyslog'] = Module['___vsyslog']
Module['_wcscoll_l'] = Module['___wcscoll_l']
Module['_wcsxfrm_l'] = Module['___wcsxfrm_l']
;



// === Auto-generated postamble setup entry stuff ===

Module['asm'] = asm;

if (!Module["intArrayFromString"]) Module["intArrayFromString"] = function() { abort("'intArrayFromString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["intArrayToString"]) Module["intArrayToString"] = function() { abort("'intArrayToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["ccall"]) Module["ccall"] = function() { abort("'ccall' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["cwrap"]) Module["cwrap"] = function() { abort("'cwrap' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["setValue"]) Module["setValue"] = function() { abort("'setValue' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["getValue"]) Module["getValue"] = function() { abort("'getValue' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
Module["allocate"] = allocate;
Module["getMemory"] = getMemory;
if (!Module["Pointer_stringify"]) Module["Pointer_stringify"] = function() { abort("'Pointer_stringify' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["AsciiToString"]) Module["AsciiToString"] = function() { abort("'AsciiToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stringToAscii"]) Module["stringToAscii"] = function() { abort("'stringToAscii' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["UTF8ArrayToString"]) Module["UTF8ArrayToString"] = function() { abort("'UTF8ArrayToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["UTF8ToString"]) Module["UTF8ToString"] = function() { abort("'UTF8ToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stringToUTF8Array"]) Module["stringToUTF8Array"] = function() { abort("'stringToUTF8Array' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stringToUTF8"]) Module["stringToUTF8"] = function() { abort("'stringToUTF8' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["lengthBytesUTF8"]) Module["lengthBytesUTF8"] = function() { abort("'lengthBytesUTF8' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["UTF16ToString"]) Module["UTF16ToString"] = function() { abort("'UTF16ToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stringToUTF16"]) Module["stringToUTF16"] = function() { abort("'stringToUTF16' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["lengthBytesUTF16"]) Module["lengthBytesUTF16"] = function() { abort("'lengthBytesUTF16' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["UTF32ToString"]) Module["UTF32ToString"] = function() { abort("'UTF32ToString' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stringToUTF32"]) Module["stringToUTF32"] = function() { abort("'stringToUTF32' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["lengthBytesUTF32"]) Module["lengthBytesUTF32"] = function() { abort("'lengthBytesUTF32' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["allocateUTF8"]) Module["allocateUTF8"] = function() { abort("'allocateUTF8' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stackTrace"]) Module["stackTrace"] = function() { abort("'stackTrace' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addOnPreRun"]) Module["addOnPreRun"] = function() { abort("'addOnPreRun' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addOnInit"]) Module["addOnInit"] = function() { abort("'addOnInit' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addOnPreMain"]) Module["addOnPreMain"] = function() { abort("'addOnPreMain' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addOnExit"]) Module["addOnExit"] = function() { abort("'addOnExit' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addOnPostRun"]) Module["addOnPostRun"] = function() { abort("'addOnPostRun' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["writeStringToMemory"]) Module["writeStringToMemory"] = function() { abort("'writeStringToMemory' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["writeArrayToMemory"]) Module["writeArrayToMemory"] = function() { abort("'writeArrayToMemory' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["writeAsciiToMemory"]) Module["writeAsciiToMemory"] = function() { abort("'writeAsciiToMemory' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addRunDependency"]) Module["addRunDependency"] = function() { abort("'addRunDependency' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["removeRunDependency"]) Module["removeRunDependency"] = function() { abort("'removeRunDependency' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["ENV"]) Module["ENV"] = function() { abort("'ENV' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["FS"]) Module["FS"] = function() { abort("'FS' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["FS_createFolder"]) Module["FS_createFolder"] = function() { abort("'FS_createFolder' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createPath"]) Module["FS_createPath"] = function() { abort("'FS_createPath' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createDataFile"]) Module["FS_createDataFile"] = function() { abort("'FS_createDataFile' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createPreloadedFile"]) Module["FS_createPreloadedFile"] = function() { abort("'FS_createPreloadedFile' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createLazyFile"]) Module["FS_createLazyFile"] = function() { abort("'FS_createLazyFile' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createLink"]) Module["FS_createLink"] = function() { abort("'FS_createLink' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_createDevice"]) Module["FS_createDevice"] = function() { abort("'FS_createDevice' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["FS_unlink"]) Module["FS_unlink"] = function() { abort("'FS_unlink' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ). Alternatively, forcing filesystem support (-s FORCE_FILESYSTEM=1) can export this for you") };
if (!Module["GL"]) Module["GL"] = function() { abort("'GL' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["staticAlloc"]) Module["staticAlloc"] = function() { abort("'staticAlloc' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["dynamicAlloc"]) Module["dynamicAlloc"] = function() { abort("'dynamicAlloc' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["warnOnce"]) Module["warnOnce"] = function() { abort("'warnOnce' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["loadDynamicLibrary"]) Module["loadDynamicLibrary"] = function() { abort("'loadDynamicLibrary' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["loadWebAssemblyModule"]) Module["loadWebAssemblyModule"] = function() { abort("'loadWebAssemblyModule' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["getLEB"]) Module["getLEB"] = function() { abort("'getLEB' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["getFunctionTables"]) Module["getFunctionTables"] = function() { abort("'getFunctionTables' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["alignFunctionTables"]) Module["alignFunctionTables"] = function() { abort("'alignFunctionTables' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["registerFunctions"]) Module["registerFunctions"] = function() { abort("'registerFunctions' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["addFunction"]) Module["addFunction"] = function() { abort("'addFunction' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["removeFunction"]) Module["removeFunction"] = function() { abort("'removeFunction' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["getFuncWrapper"]) Module["getFuncWrapper"] = function() { abort("'getFuncWrapper' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["prettyPrint"]) Module["prettyPrint"] = function() { abort("'prettyPrint' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["makeBigInt"]) Module["makeBigInt"] = function() { abort("'makeBigInt' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["dynCall"]) Module["dynCall"] = function() { abort("'dynCall' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["getCompilerSetting"]) Module["getCompilerSetting"] = function() { abort("'getCompilerSetting' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stackSave"]) Module["stackSave"] = function() { abort("'stackSave' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stackRestore"]) Module["stackRestore"] = function() { abort("'stackRestore' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["stackAlloc"]) Module["stackAlloc"] = function() { abort("'stackAlloc' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["establishStackSpace"]) Module["establishStackSpace"] = function() { abort("'establishStackSpace' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["print"]) Module["print"] = function() { abort("'print' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };
if (!Module["printErr"]) Module["printErr"] = function() { abort("'printErr' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") };if (!Module["ALLOC_NORMAL"]) Object.defineProperty(Module, "ALLOC_NORMAL", { get: function() { abort("'ALLOC_NORMAL' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") } });
if (!Module["ALLOC_STACK"]) Object.defineProperty(Module, "ALLOC_STACK", { get: function() { abort("'ALLOC_STACK' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") } });
if (!Module["ALLOC_STATIC"]) Object.defineProperty(Module, "ALLOC_STATIC", { get: function() { abort("'ALLOC_STATIC' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") } });
if (!Module["ALLOC_DYNAMIC"]) Object.defineProperty(Module, "ALLOC_DYNAMIC", { get: function() { abort("'ALLOC_DYNAMIC' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") } });
if (!Module["ALLOC_NONE"]) Object.defineProperty(Module, "ALLOC_NONE", { get: function() { abort("'ALLOC_NONE' was not exported. add it to EXTRA_EXPORTED_RUNTIME_METHODS (see the FAQ)") } });

if (memoryInitializer) {
  if (!isDataURI(memoryInitializer)) {
    memoryInitializer = locateFile(memoryInitializer);
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, GLOBAL_BASE);
  } else {
    addRunDependency('memory initializer');
    var applyMemoryInitializer = function(data) {
      if (data.byteLength) data = new Uint8Array(data);
      for (var i = 0; i < data.length; i++) {
        assert(HEAPU8[GLOBAL_BASE + i] === 0, "area for memory initializer should not have been touched before it's loaded");
      }
      HEAPU8.set(data, GLOBAL_BASE);
      // Delete the typed array that contains the large blob of the memory initializer request response so that
      // we won't keep unnecessary memory lying around. However, keep the XHR object itself alive so that e.g.
      // its .status field can still be accessed later.
      if (Module['memoryInitializerRequest']) delete Module['memoryInitializerRequest'].response;
      removeRunDependency('memory initializer');
    }
    function doBrowserLoad() {
      Module['readAsync'](memoryInitializer, applyMemoryInitializer, function() {
        throw 'could not load memory initializer ' + memoryInitializer;
      });
    }
    if (Module['memoryInitializerRequest']) {
      // a network request has already been created, just use that
      function useRequest() {
        var request = Module['memoryInitializerRequest'];
        var response = request.response;
        if (request.status !== 200 && request.status !== 0) {
            // If you see this warning, the issue may be that you are using locateFile and defining it in JS. That
            // means that the HTML file doesn't know about it, and when it tries to create the mem init request early, does it to the wrong place.
            // Look in your browser's devtools network console to see what's going on.
            console.warn('a problem seems to have happened with Module.memoryInitializerRequest, status: ' + request.status + ', retrying ' + memoryInitializer);
            doBrowserLoad();
            return;
        }
        applyMemoryInitializer(response);
      }
      if (Module['memoryInitializerRequest'].response) {
        setTimeout(useRequest, 0); // it's already here; but, apply it asynchronously
      } else {
        Module['memoryInitializerRequest'].addEventListener('load', useRequest); // wait for it
      }
    } else {
      // fetch it from the network ourselves
      doBrowserLoad();
    }
  }
}



/**
 * @constructor
 * @extends {Error}
 * @this {ExitStatus}
 */
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  var argv = stackAlloc((argc + 1) * 4);
  HEAP32[argv >> 2] = allocateUTF8OnStack(Module['thisProgram']);
  for (var i = 1; i < argc; i++) {
    HEAP32[(argv >> 2) + i] = allocateUTF8OnStack(args[i - 1]);
  }
  HEAP32[(argv >> 2) + argc] = 0;


  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
      exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      var toLog = e;
      if (e && typeof e === 'object' && e.stack) {
        toLog = [e, e.stack];
      }
      err('exception thrown: ' + toLog);
      Module['quit'](1, e);
    }
  } finally {
    calledMain = true;
  }
}




/** @type {function(Array=)} */
function run(args) {
  args = args || Module['arguments'];

  if (runDependencies > 0) {
    return;
  }

  writeStackCookie();

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return;

    ensureInitRuntime();

    preMain();

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
  checkStackCookie();
}
Module['run'] = run;

function checkUnflushedContent() {
  // Compiler settings do not allow exiting the runtime, so flushing
  // the streams is not possible. but in ASSERTIONS mode we check
  // if there was something to flush, and if so tell the user they
  // should request that the runtime be exitable.
  // Normally we would not even include flush() at all, but in ASSERTIONS
  // builds we do so just for this check, and here we see if there is any
  // content to flush, that is, we check if there would have been
  // something a non-ASSERTIONS build would have not seen.
  // How we flush the streams depends on whether we are in FILESYSTEM=0
  // mode (which has its own special function for this; otherwise, all
  // the code is inside libc)
  var print = out;
  var printErr = err;
  var has = false;
  out = err = function(x) {
    has = true;
  }
  try { // it doesn't matter if it fails
    var flush = Module['_fflush'];
    if (flush) flush(0);
    // also flush in the JS FS layer
    var hasFS = true;
    if (hasFS) {
      ['stdout', 'stderr'].forEach(function(name) {
        var info = FS.analyzePath('/dev/' + name);
        if (!info) return;
        var stream = info.object;
        var rdev = stream.rdev;
        var tty = TTY.ttys[rdev];
        if (tty && tty.output && tty.output.length) {
          has = true;
        }
      });
    }
  } catch(e) {}
  out = print;
  err = printErr;
  if (has) {
    warnOnce('stdio streams had content in them that was not flushed. you should set EXIT_RUNTIME to 1 (see the FAQ), or make sure to emit a newline when you printf etc.');
  }
}

function exit(status, implicit) {
  checkUnflushedContent();

  // if this is just main exit-ing implicitly, and the status is 0, then we
  // don't need to do anything here and can just leave. if the status is
  // non-zero, though, then we need to report it.
  // (we may have warned about this earlier, if a situation justifies doing so)
  if (implicit && Module['noExitRuntime'] && status === 0) {
    return;
  }

  if (Module['noExitRuntime']) {
    // if exit() was called, we may warn the user if the runtime isn't actually being shut down
    if (!implicit) {
      err('exit(' + status + ') called, but EXIT_RUNTIME is not set, so halting execution but not exiting the runtime or preventing further async execution (build with EXIT_RUNTIME=1, if you want a true shutdown)');
    }
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  Module['quit'](status, new ExitStatus(status));
}

var abortDecorators = [];

function abort(what) {
  if (Module['onAbort']) {
    Module['onAbort'](what);
  }

  if (what !== undefined) {
    out(what);
    err(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '';
  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = abort;

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

  Module["noExitRuntime"] = true;

run();





// {{MODULE_ADDITIONS}}



